/********************************************************************************
** Form generated from reading UI file 'managesubtitles_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGESUBTITLES_UI_H
#define UI_MANAGESUBTITLES_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ManageSubtitles_UI
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    KMessageWidget *messageWidget;
    QTabWidget *tabWidget;
    QWidget *tabFile;
    QGridLayout *gridLayout_2;
    QTreeWidget *fileList;
    QToolButton *buttonMenuFile;
    QPushButton *buttonNewFile;
    QSpacerItem *horizontalSpacerFile;
    QPushButton *buttonDeleteFile;
    QPushButton *buttonDuplicateFile;
    QWidget *tabLayer;
    QGridLayout *gridLayout_3;
    QListWidget *eventFileSideBar;
    QTreeWidget *eventList;
    QPushButton *buttonDuplicateLayer;
    QPushButton *buttonDeleteLayer;
    QPushButton *buttonNewLayer;
    QSpacerItem *horizontalSpacer;
    QWidget *tabStyle;
    QGridLayout *gridLayout_4;
    QListWidget *styleFileSideBar;
    QPushButton *buttonEditStyle;
    QTreeWidget *styleList;
    QPushButton *buttonNewStyle;
    QPushButton *buttonDuplicateStyle;
    QPushButton *buttonDeleteStyle;
    QSpacerItem *horizontalSpacerStyle;
    QWidget *tabInfo;
    QGridLayout *gridLayout_5;
    QTreeWidget *infoList;
    QListWidget *infoFileSideBar;

    void setupUi(QDialog *ManageSubtitles_UI)
    {
        if (ManageSubtitles_UI->objectName().isEmpty())
            ManageSubtitles_UI->setObjectName("ManageSubtitles_UI");
        ManageSubtitles_UI->resize(592, 559);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ManageSubtitles_UI->sizePolicy().hasHeightForWidth());
        ManageSubtitles_UI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ManageSubtitles_UI);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(ManageSubtitles_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Close);

        gridLayout->addWidget(buttonBox, 2, 0, 1, 3);

        messageWidget = new KMessageWidget(ManageSubtitles_UI);
        messageWidget->setObjectName("messageWidget");

        gridLayout->addWidget(messageWidget, 1, 0, 1, 3);

        tabWidget = new QTabWidget(ManageSubtitles_UI);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setTabPosition(QTabWidget::TabPosition::North);
        tabWidget->setTabShape(QTabWidget::TabShape::Rounded);
        tabFile = new QWidget();
        tabFile->setObjectName("tabFile");
        gridLayout_2 = new QGridLayout(tabFile);
        gridLayout_2->setObjectName("gridLayout_2");
        fileList = new QTreeWidget(tabFile);
        fileList->setObjectName("fileList");
        fileList->setColumnCount(2);
        fileList->header()->setVisible(true);

        gridLayout_2->addWidget(fileList, 0, 0, 1, 7);

        buttonMenuFile = new QToolButton(tabFile);
        buttonMenuFile->setObjectName("buttonMenuFile");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("application-menu")));
        buttonMenuFile->setIcon(icon);
        buttonMenuFile->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        buttonMenuFile->setAutoRaise(false);

        gridLayout_2->addWidget(buttonMenuFile, 3, 6, 1, 1);

        buttonNewFile = new QPushButton(tabFile);
        buttonNewFile->setObjectName("buttonNewFile");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(buttonNewFile->sizePolicy().hasHeightForWidth());
        buttonNewFile->setSizePolicy(sizePolicy1);
        QIcon icon1(QIcon::fromTheme(QIcon::ThemeIcon::DocumentNew));
        buttonNewFile->setIcon(icon1);

        gridLayout_2->addWidget(buttonNewFile, 3, 0, 1, 1);

        horizontalSpacerFile = new QSpacerItem(208, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacerFile, 3, 4, 1, 2);

        buttonDeleteFile = new QPushButton(tabFile);
        buttonDeleteFile->setObjectName("buttonDeleteFile");
        sizePolicy1.setHeightForWidth(buttonDeleteFile->sizePolicy().hasHeightForWidth());
        buttonDeleteFile->setSizePolicy(sizePolicy1);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        buttonDeleteFile->setIcon(icon2);

        gridLayout_2->addWidget(buttonDeleteFile, 3, 2, 1, 1);

        buttonDuplicateFile = new QPushButton(tabFile);
        buttonDuplicateFile->setObjectName("buttonDuplicateFile");
        sizePolicy1.setHeightForWidth(buttonDuplicateFile->sizePolicy().hasHeightForWidth());
        buttonDuplicateFile->setSizePolicy(sizePolicy1);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("edit-copy")));
        buttonDuplicateFile->setIcon(icon3);

        gridLayout_2->addWidget(buttonDuplicateFile, 3, 1, 1, 1);

        tabWidget->addTab(tabFile, QString());
        tabLayer = new QWidget();
        tabLayer->setObjectName("tabLayer");
        gridLayout_3 = new QGridLayout(tabLayer);
        gridLayout_3->setObjectName("gridLayout_3");
        eventFileSideBar = new QListWidget(tabLayer);
        eventFileSideBar->setObjectName("eventFileSideBar");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(eventFileSideBar->sizePolicy().hasHeightForWidth());
        eventFileSideBar->setSizePolicy(sizePolicy2);
        eventFileSideBar->setMaximumSize(QSize(100, 16777215));
        eventFileSideBar->setAcceptDrops(true);
        eventFileSideBar->setDragDropMode(QAbstractItemView::DragDropMode::DropOnly);
        eventFileSideBar->setDefaultDropAction(Qt::DropAction::IgnoreAction);

        gridLayout_3->addWidget(eventFileSideBar, 0, 6, 2, 1);

        eventList = new QTreeWidget(tabLayer);
        eventList->setObjectName("eventList");
        eventList->setDragEnabled(true);
        eventList->setDragDropMode(QAbstractItemView::DragDropMode::DragOnly);
        eventList->setColumnCount(4);
        eventList->header()->setVisible(true);

        gridLayout_3->addWidget(eventList, 0, 1, 2, 5);

        buttonDuplicateLayer = new QPushButton(tabLayer);
        buttonDuplicateLayer->setObjectName("buttonDuplicateLayer");
        sizePolicy1.setHeightForWidth(buttonDuplicateLayer->sizePolicy().hasHeightForWidth());
        buttonDuplicateLayer->setSizePolicy(sizePolicy1);
        buttonDuplicateLayer->setIcon(icon3);

        gridLayout_3->addWidget(buttonDuplicateLayer, 2, 2, 1, 1);

        buttonDeleteLayer = new QPushButton(tabLayer);
        buttonDeleteLayer->setObjectName("buttonDeleteLayer");
        sizePolicy1.setHeightForWidth(buttonDeleteLayer->sizePolicy().hasHeightForWidth());
        buttonDeleteLayer->setSizePolicy(sizePolicy1);
        buttonDeleteLayer->setIcon(icon2);

        gridLayout_3->addWidget(buttonDeleteLayer, 2, 3, 1, 1);

        buttonNewLayer = new QPushButton(tabLayer);
        buttonNewLayer->setObjectName("buttonNewLayer");
        sizePolicy1.setHeightForWidth(buttonNewLayer->sizePolicy().hasHeightForWidth());
        buttonNewLayer->setSizePolicy(sizePolicy1);
        QIcon icon4(QIcon::fromTheme(QIcon::ThemeIcon::ListAdd));
        buttonNewLayer->setIcon(icon4);

        gridLayout_3->addWidget(buttonNewLayer, 2, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer, 2, 4, 1, 3);

        tabWidget->addTab(tabLayer, QString());
        tabStyle = new QWidget();
        tabStyle->setObjectName("tabStyle");
        gridLayout_4 = new QGridLayout(tabStyle);
        gridLayout_4->setObjectName("gridLayout_4");
        styleFileSideBar = new QListWidget(tabStyle);
        styleFileSideBar->setObjectName("styleFileSideBar");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(styleFileSideBar->sizePolicy().hasHeightForWidth());
        styleFileSideBar->setSizePolicy(sizePolicy3);
        styleFileSideBar->setMaximumSize(QSize(100, 16777215));
        styleFileSideBar->setAcceptDrops(true);
        styleFileSideBar->setDragDropMode(QAbstractItemView::DragDropMode::DropOnly);
        styleFileSideBar->setDefaultDropAction(Qt::DropAction::IgnoreAction);

        gridLayout_4->addWidget(styleFileSideBar, 0, 8, 1, 1);

        buttonEditStyle = new QPushButton(tabStyle);
        buttonEditStyle->setObjectName("buttonEditStyle");
        sizePolicy1.setHeightForWidth(buttonEditStyle->sizePolicy().hasHeightForWidth());
        buttonEditStyle->setSizePolicy(sizePolicy1);
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        buttonEditStyle->setIcon(icon5);

        gridLayout_4->addWidget(buttonEditStyle, 2, 2, 1, 1);

        styleList = new QTreeWidget(tabStyle);
        styleList->setObjectName("styleList");
        styleList->setDragEnabled(true);
        styleList->setDragDropMode(QAbstractItemView::DragDropMode::DragOnly);
        styleList->setColumnCount(23);
        styleList->header()->setMinimumSectionSize(33);
        styleList->header()->setStretchLastSection(false);

        gridLayout_4->addWidget(styleList, 0, 0, 1, 8);

        buttonNewStyle = new QPushButton(tabStyle);
        buttonNewStyle->setObjectName("buttonNewStyle");
        sizePolicy1.setHeightForWidth(buttonNewStyle->sizePolicy().hasHeightForWidth());
        buttonNewStyle->setSizePolicy(sizePolicy1);
        buttonNewStyle->setIcon(icon4);

        gridLayout_4->addWidget(buttonNewStyle, 2, 0, 1, 1);

        buttonDuplicateStyle = new QPushButton(tabStyle);
        buttonDuplicateStyle->setObjectName("buttonDuplicateStyle");
        sizePolicy1.setHeightForWidth(buttonDuplicateStyle->sizePolicy().hasHeightForWidth());
        buttonDuplicateStyle->setSizePolicy(sizePolicy1);
        buttonDuplicateStyle->setIcon(icon3);

        gridLayout_4->addWidget(buttonDuplicateStyle, 2, 1, 1, 1);

        buttonDeleteStyle = new QPushButton(tabStyle);
        buttonDeleteStyle->setObjectName("buttonDeleteStyle");
        sizePolicy1.setHeightForWidth(buttonDeleteStyle->sizePolicy().hasHeightForWidth());
        buttonDeleteStyle->setSizePolicy(sizePolicy1);
        buttonDeleteStyle->setIcon(icon2);

        gridLayout_4->addWidget(buttonDeleteStyle, 2, 3, 1, 1);

        horizontalSpacerStyle = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_4->addItem(horizontalSpacerStyle, 2, 4, 1, 5);

        tabWidget->addTab(tabStyle, QString());
        tabInfo = new QWidget();
        tabInfo->setObjectName("tabInfo");
        gridLayout_5 = new QGridLayout(tabInfo);
        gridLayout_5->setObjectName("gridLayout_5");
        infoList = new QTreeWidget(tabInfo);
        infoList->setObjectName("infoList");
        infoList->setColumnCount(2);

        gridLayout_5->addWidget(infoList, 1, 1, 1, 1);

        infoFileSideBar = new QListWidget(tabInfo);
        infoFileSideBar->setObjectName("infoFileSideBar");
        sizePolicy3.setHeightForWidth(infoFileSideBar->sizePolicy().hasHeightForWidth());
        infoFileSideBar->setSizePolicy(sizePolicy3);
        infoFileSideBar->setMaximumSize(QSize(100, 16777215));

        gridLayout_5->addWidget(infoFileSideBar, 1, 2, 1, 1);

        tabWidget->addTab(tabInfo, QString());

        gridLayout->addWidget(tabWidget, 0, 0, 1, 3);


        retranslateUi(ManageSubtitles_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ManageSubtitles_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ManageSubtitles_UI, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ManageSubtitles_UI);
    } // setupUi

    void retranslateUi(QDialog *ManageSubtitles_UI)
    {
        ManageSubtitles_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = fileList->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Path", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Name", nullptr));
        buttonMenuFile->setText(tr2i18n("...", nullptr));
        buttonNewFile->setText(tr2i18n("New File", nullptr));
        buttonDeleteFile->setText(tr2i18n("Delete", nullptr));
        buttonDuplicateFile->setText(tr2i18n("Duplicate", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabFile), tr2i18n("Files", nullptr));
        QTreeWidgetItem *___qtreewidgetitem1 = eventList->headerItem();
        ___qtreewidgetitem1->setText(3, tr2i18n("Text", nullptr));
        ___qtreewidgetitem1->setText(2, tr2i18n("Style", nullptr));
        ___qtreewidgetitem1->setText(1, tr2i18n("End", nullptr));
        ___qtreewidgetitem1->setText(0, tr2i18n("Start", nullptr));
        buttonDuplicateLayer->setText(tr2i18n("Duplicate", nullptr));
        buttonDeleteLayer->setText(tr2i18n("Delete", nullptr));
        buttonNewLayer->setText(tr2i18n("New Layer", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabLayer), tr2i18n("Layers and Content", nullptr));
        buttonEditStyle->setText(tr2i18n("Edit", nullptr));
        QTreeWidgetItem *___qtreewidgetitem2 = styleList->headerItem();
        ___qtreewidgetitem2->setText(22, tr2i18n("Encoding", nullptr));
        ___qtreewidgetitem2->setText(21, tr2i18n("MarginV", nullptr));
        ___qtreewidgetitem2->setText(20, tr2i18n("MarginR", nullptr));
        ___qtreewidgetitem2->setText(19, tr2i18n("MarginL", nullptr));
        ___qtreewidgetitem2->setText(18, tr2i18n("BoardStyle", nullptr));
        ___qtreewidgetitem2->setText(17, tr2i18n("Angle", nullptr));
        ___qtreewidgetitem2->setText(16, tr2i18n("Spacing", nullptr));
        ___qtreewidgetitem2->setText(15, tr2i18n("ScaleY", nullptr));
        ___qtreewidgetitem2->setText(14, tr2i18n("ScaleX", nullptr));
        ___qtreewidgetitem2->setText(13, tr2i18n("Alignment", nullptr));
        ___qtreewidgetitem2->setText(12, tr2i18n("Shadow", nullptr));
        ___qtreewidgetitem2->setText(11, tr2i18n("Outline", nullptr));
        ___qtreewidgetitem2->setText(10, tr2i18n("BackColor", nullptr));
        ___qtreewidgetitem2->setText(9, tr2i18n("OutlineColor", nullptr));
        ___qtreewidgetitem2->setText(8, tr2i18n("SecondaryColor", nullptr));
        ___qtreewidgetitem2->setText(7, tr2i18n("PrimaryColor", nullptr));
        ___qtreewidgetitem2->setText(6, tr2i18n("StrikeOut", nullptr));
        ___qtreewidgetitem2->setText(5, tr2i18n("Underline", nullptr));
        ___qtreewidgetitem2->setText(4, tr2i18n("Italic", nullptr));
        ___qtreewidgetitem2->setText(3, tr2i18n("Bold", nullptr));
        ___qtreewidgetitem2->setText(2, tr2i18n("FontSize", nullptr));
        ___qtreewidgetitem2->setText(1, tr2i18n("FontName", nullptr));
        ___qtreewidgetitem2->setText(0, tr2i18n("Name", nullptr));
        buttonNewStyle->setText(tr2i18n("New Style", nullptr));
        buttonDuplicateStyle->setText(tr2i18n("Duplicate", nullptr));
        buttonDeleteStyle->setText(tr2i18n("Delete", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabStyle), tr2i18n("Styles", nullptr));
        QTreeWidgetItem *___qtreewidgetitem3 = infoList->headerItem();
        ___qtreewidgetitem3->setText(1, tr2i18n("Value", nullptr));
        ___qtreewidgetitem3->setText(0, tr2i18n("Key", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tabInfo), tr2i18n("Info", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManageSubtitles_UI: public Ui_ManageSubtitles_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGESUBTITLES_UI_H

