/****************************************************************************
** Meta object code from reading C++ file 'assetpanel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/assetpanel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'assetpanel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10AssetPanelE_t {};
} // unnamed namespace

template <> constexpr inline auto AssetPanel::qt_create_metaobjectdata<qt_meta_tag_ZN10AssetPanelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AssetPanel",
        "doSplitEffect",
        "",
        "doSplitBinEffect",
        "seekToPos",
        "reloadEffect",
        "path",
        "switchCurrentComposition",
        "tid",
        "compoId",
        "slotSaveStack",
        "slotSwitchCollapseAll",
        "clearAssetPanel",
        "itemId",
        "assetPanelWarning",
        "service",
        "message",
        "log",
        "deleteCurrentEffect",
        "collapseCurrentEffect",
        "slotCheckWheelEventFilter",
        "slotAddRemoveKeyframe",
        "slotNextKeyframe",
        "slotPreviousKeyframe",
        "updateAssetPosition",
        "QUuid",
        "uuid",
        "processSplitEffect",
        "enable",
        "showKeyframes",
        "enableStack",
        "scrollTo",
        "QRect",
        "rect",
        "checkDragScroll",
        "slotShowMaskPanel"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'doSplitEffect'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'doSplitBinEffect'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'reloadEffect'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'switchCurrentComposition'
        QtMocHelpers::SignalData<void(int, const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'slotSaveStack'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slotSwitchCollapseAll'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'clearAssetPanel'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'assetPanelWarning'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'assetPanelWarning'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 15 }, { QMetaType::QString, 16 },
        }}),
        // Slot 'deleteCurrentEffect'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'collapseCurrentEffect'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCheckWheelEventFilter'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddRemoveKeyframe'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNextKeyframe'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPreviousKeyframe'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateAssetPosition'
        QtMocHelpers::SlotData<void(int, const QUuid)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'processSplitEffect'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'showKeyframes'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'enableStack'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'scrollTo'
        QtMocHelpers::SlotData<void(QRect)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'checkDragScroll'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowMaskPanel'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AssetPanel, qt_meta_tag_ZN10AssetPanelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AssetPanel::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AssetPanelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AssetPanelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10AssetPanelE_t>.metaTypes,
    nullptr
} };

void AssetPanel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AssetPanel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doSplitEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->doSplitBinEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->reloadEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->switchCurrentComposition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->slotSaveStack(); break;
        case 6: _t->slotSwitchCollapseAll(); break;
        case 7: _t->clearAssetPanel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->assetPanelWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->assetPanelWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 10: _t->deleteCurrentEffect(); break;
        case 11: _t->collapseCurrentEffect(); break;
        case 12: _t->slotCheckWheelEventFilter(); break;
        case 13: _t->slotAddRemoveKeyframe(); break;
        case 14: _t->slotNextKeyframe(); break;
        case 15: _t->slotPreviousKeyframe(); break;
        case 16: _t->updateAssetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 17: _t->processSplitEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->showKeyframes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->enableStack((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->scrollTo((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 21: _t->checkDragScroll(); break;
        case 22: _t->slotShowMaskPanel(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)(bool )>(_a, &AssetPanel::doSplitEffect, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)(bool )>(_a, &AssetPanel::doSplitBinEffect, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)(int )>(_a, &AssetPanel::seekToPos, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)(const QString & )>(_a, &AssetPanel::reloadEffect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)(int , const QString & )>(_a, &AssetPanel::switchCurrentComposition, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)()>(_a, &AssetPanel::slotSaveStack, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetPanel::*)()>(_a, &AssetPanel::slotSwitchCollapseAll, 6))
            return;
    }
}

const QMetaObject *AssetPanel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AssetPanel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10AssetPanelE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int AssetPanel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void AssetPanel::doSplitEffect(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AssetPanel::doSplitBinEffect(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AssetPanel::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AssetPanel::reloadEffect(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AssetPanel::switchCurrentComposition(int _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void AssetPanel::slotSaveStack()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AssetPanel::slotSwitchCollapseAll()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
