/********************************************************************************
** Form generated from reading UI file 'maskmanage_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MASKMANAGE_UI_H
#define UI_MASKMANAGE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MaskManage_UI
{
public:
    QGridLayout *gridLayout_4;
    QStackedWidget *maskTools;
    QWidget *page;
    QGridLayout *gridLayout_2;
    QTreeWidget *maskTree;
    QPushButton *buttonApply;
    QPushButton *buttonEdit;
    QPushButton *buttonPreview;
    QGridLayout *gridLayout;
    QToolButton *buttonAdd;
    QToolButton *buttonDelete;
    QToolButton *buttonImport;
    QSpacerItem *horizontalSpacer;
    QWidget *page_2;
    QGridLayout *gridLayout_3;
    QLabel *label;
    QPushButton *buttonStop;
    QLabel *label_2;
    QSpinBox *borderWidth;
    QToolButton *resetMask;
    QLabel *label_3;
    KColorButton *borderColor;
    KColorButton *maskColor;
    QSpacerItem *verticalSpacer_2;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *buttonAbort;
    QProgressBar *samProgress;
    KMessageWidget *samStatus;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *MaskManage_UI)
    {
        if (MaskManage_UI->objectName().isEmpty())
            MaskManage_UI->setObjectName("MaskManage_UI");
        MaskManage_UI->resize(314, 266);
        gridLayout_4 = new QGridLayout(MaskManage_UI);
        gridLayout_4->setObjectName("gridLayout_4");
        maskTools = new QStackedWidget(MaskManage_UI);
        maskTools->setObjectName("maskTools");
        page = new QWidget();
        page->setObjectName("page");
        gridLayout_2 = new QGridLayout(page);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        maskTree = new QTreeWidget(page);
        maskTree->setObjectName("maskTree");

        gridLayout_2->addWidget(maskTree, 0, 0, 3, 1);

        buttonApply = new QPushButton(page);
        buttonApply->setObjectName("buttonApply");
        buttonApply->setEnabled(false);

        gridLayout_2->addWidget(buttonApply, 0, 1, 1, 1);

        buttonEdit = new QPushButton(page);
        buttonEdit->setObjectName("buttonEdit");
        buttonEdit->setEnabled(false);
        buttonEdit->setCheckable(true);

        gridLayout_2->addWidget(buttonEdit, 1, 1, 1, 1);

        buttonPreview = new QPushButton(page);
        buttonPreview->setObjectName("buttonPreview");
        buttonPreview->setEnabled(false);
        buttonPreview->setCheckable(true);

        gridLayout_2->addWidget(buttonPreview, 2, 1, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        buttonAdd = new QToolButton(page);
        buttonAdd->setObjectName("buttonAdd");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-add")));
        buttonAdd->setIcon(icon);

        gridLayout->addWidget(buttonAdd, 0, 0, 1, 1);

        buttonDelete = new QToolButton(page);
        buttonDelete->setObjectName("buttonDelete");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        buttonDelete->setIcon(icon1);

        gridLayout->addWidget(buttonDelete, 0, 1, 1, 1);

        buttonImport = new QToolButton(page);
        buttonImport->setObjectName("buttonImport");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("document-import")));
        buttonImport->setIcon(icon2);

        gridLayout->addWidget(buttonImport, 0, 2, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);


        gridLayout_2->addLayout(gridLayout, 3, 0, 1, 2);

        maskTools->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_3 = new QGridLayout(page_2);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        label = new QLabel(page_2);
        label->setObjectName("label");

        gridLayout_3->addWidget(label, 2, 0, 1, 1);

        buttonStop = new QPushButton(page_2);
        buttonStop->setObjectName("buttonStop");

        gridLayout_3->addWidget(buttonStop, 3, 0, 1, 3);

        label_2 = new QLabel(page_2);
        label_2->setObjectName("label_2");

        gridLayout_3->addWidget(label_2, 1, 0, 1, 1);

        borderWidth = new QSpinBox(page_2);
        borderWidth->setObjectName("borderWidth");

        gridLayout_3->addWidget(borderWidth, 2, 2, 1, 1);

        resetMask = new QToolButton(page_2);
        resetMask->setObjectName("resetMask");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("edit-reset")));
        resetMask->setIcon(icon3);

        gridLayout_3->addWidget(resetMask, 1, 2, 1, 1);

        label_3 = new QLabel(page_2);
        label_3->setObjectName("label_3");

        gridLayout_3->addWidget(label_3, 0, 0, 1, 3);

        borderColor = new KColorButton(page_2);
        borderColor->setObjectName("borderColor");
        borderColor->setAlphaChannelEnabled(true);

        gridLayout_3->addWidget(borderColor, 2, 1, 1, 1);

        maskColor = new KColorButton(page_2);
        maskColor->setObjectName("maskColor");
        maskColor->setAlphaChannelEnabled(true);

        gridLayout_3->addWidget(maskColor, 1, 1, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 4, 0, 1, 1);

        maskTools->addWidget(page_2);

        gridLayout_4->addWidget(maskTools, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        buttonAbort = new QToolButton(MaskManage_UI);
        buttonAbort->setObjectName("buttonAbort");
        QIcon icon4(QIcon::fromTheme(QIcon::ThemeIcon::ProcessStop));
        buttonAbort->setIcon(icon4);
        buttonAbort->setAutoRaise(true);

        horizontalLayout_2->addWidget(buttonAbort);

        samProgress = new QProgressBar(MaskManage_UI);
        samProgress->setObjectName("samProgress");
        samProgress->setValue(24);

        horizontalLayout_2->addWidget(samProgress);


        gridLayout_4->addLayout(horizontalLayout_2, 1, 0, 1, 1);

        samStatus = new KMessageWidget(MaskManage_UI);
        samStatus->setObjectName("samStatus");
        samStatus->setCloseButtonVisible(false);

        gridLayout_4->addWidget(samStatus, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_4->addItem(verticalSpacer, 3, 0, 1, 1);


        retranslateUi(MaskManage_UI);

        maskTools->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(MaskManage_UI);
    } // setupUi

    void retranslateUi(QWidget *MaskManage_UI)
    {
        MaskManage_UI->setWindowTitle(tr2i18n("Form", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = maskTree->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("Zone", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Mask", nullptr));
        buttonApply->setText(tr2i18n("Apply Mask", nullptr));
        buttonEdit->setText(tr2i18n("Edit Mask", nullptr));
        buttonPreview->setText(tr2i18n("Preview Mask", nullptr));
#if QT_CONFIG(tooltip)
        buttonAdd->setToolTip(tr2i18n("Create New Mask", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAdd->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonDelete->setToolTip(tr2i18n("Delete Mask", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonDelete->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonImport->setToolTip(tr2i18n("Import Mask in Project", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonImport->setText(tr2i18n("...", nullptr));
        label->setText(tr2i18n("Border", nullptr));
        buttonStop->setText(tr2i18n("Abort Mask", nullptr));
        label_2->setText(tr2i18n("Mask", nullptr));
        resetMask->setText(tr2i18n("...", nullptr));
        label_3->setText(tr2i18n("Creating Mask", nullptr));
        buttonAbort->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MaskManage_UI: public Ui_MaskManage_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MASKMANAGE_UI_H

