/****************************************************************************
** Meta object code from reading C++ file 'kdenlivesettingsdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/settings/kdenlivesettingsdialog.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdenlivesettingsdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22KdenliveSettingsDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto KdenliveSettingsDialog::qt_create_metaobjectdata<qt_meta_tag_ZN22KdenliveSettingsDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KdenliveSettingsDialog",
        "customChanged",
        "",
        "doResetConsumer",
        "fullReset",
        "updateCaptureFolder",
        "updateLibraryFolder",
        "restartKdenlive",
        "resetConfig",
        "checkTabPosition",
        "resetView",
        "updateSettings",
        "updateWidgets",
        "hasChanged",
        "accept",
        "slotCheckShuttle",
        "state",
        "slotUpdateShuttleDevice",
        "ix",
        "slotEditImageApplication",
        "slotEditAudioApplication",
        "slotEditVideoApplication",
        "slotEditGlaxnimateApplication",
        "slotReadAudioDevices",
        "slotUpdateGrabRegionStatus",
        "slotCheckAlsaDriver",
        "slotCheckAudioBackend",
        "slotAddTranscode",
        "slotDeleteTranscode",
        "slotUpdateTranscodingProfile",
        "slotEnableTranscodeUpdate",
        "slotSetTranscodeProfile",
        "slotShuttleModified",
        "slotDialogModified",
        "slotRevealCaptureFolder",
        "slotEnableLibraryFolder",
        "slotEnableVideoFolder",
        "slotReloadBlackMagic",
        "slotReloadShuttleDevices",
        "fillMonitorData",
        "configureExternalProxies",
        "openBrowserUrl",
        "url",
        "loadExternalProxyProfiles",
        "slotUpdateBreezeDrag",
        "dragOnTitleBar",
        "useRecordDefault"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'customChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doResetConsumer'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Signal 'updateCaptureFolder'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateLibraryFolder'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'restartKdenlive'
        QtMocHelpers::SignalData<void(bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 8 },
        }}),
        // Signal 'restartKdenlive'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'checkTabPosition'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'resetView'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateSettings'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'updateWidgets'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'hasChanged'
        QtMocHelpers::SlotData<bool()>(13, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'accept'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotCheckShuttle'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'slotCheckShuttle'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpdateShuttleDevice'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'slotUpdateShuttleDevice'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotEditImageApplication'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditAudioApplication'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditVideoApplication'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditGlaxnimateApplication'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReadAudioDevices'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateGrabRegionStatus'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckAlsaDriver'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckAudioBackend'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddTranscode'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteTranscode'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateTranscodingProfile'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableTranscodeUpdate'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetTranscodeProfile'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShuttleModified'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDialogModified'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRevealCaptureFolder'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'slotEnableLibraryFolder'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEnableVideoFolder'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Slot 'slotReloadBlackMagic'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReloadShuttleDevices'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'fillMonitorData'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureExternalProxies'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openBrowserUrl'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'loadExternalProxyProfiles'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateBreezeDrag'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'useRecordDefault'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KdenliveSettingsDialog, qt_meta_tag_ZN22KdenliveSettingsDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KdenliveSettingsDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KdenliveSettingsDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KdenliveSettingsDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22KdenliveSettingsDialogE_t>.metaTypes,
    nullptr
} };

void KdenliveSettingsDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KdenliveSettingsDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->customChanged(); break;
        case 1: _t->doResetConsumer((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->updateCaptureFolder(); break;
        case 3: _t->updateLibraryFolder(); break;
        case 4: _t->restartKdenlive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->restartKdenlive(); break;
        case 6: _t->checkTabPosition(); break;
        case 7: _t->resetView(); break;
        case 8: _t->updateSettings(); break;
        case 9: _t->updateWidgets(); break;
        case 10: { bool _r = _t->hasChanged();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->accept(); break;
        case 12: _t->slotCheckShuttle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->slotCheckShuttle(); break;
        case 14: _t->slotUpdateShuttleDevice((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->slotUpdateShuttleDevice(); break;
        case 16: _t->slotEditImageApplication(); break;
        case 17: _t->slotEditAudioApplication(); break;
        case 18: _t->slotEditVideoApplication(); break;
        case 19: _t->slotEditGlaxnimateApplication(); break;
        case 20: _t->slotReadAudioDevices(); break;
        case 21: _t->slotUpdateGrabRegionStatus(); break;
        case 22: _t->slotCheckAlsaDriver(); break;
        case 23: _t->slotCheckAudioBackend(); break;
        case 24: _t->slotAddTranscode(); break;
        case 25: _t->slotDeleteTranscode(); break;
        case 26: _t->slotUpdateTranscodingProfile(); break;
        case 27: _t->slotEnableTranscodeUpdate(); break;
        case 28: _t->slotSetTranscodeProfile(); break;
        case 29: _t->slotShuttleModified(); break;
        case 30: _t->slotDialogModified(); break;
        case 31: _t->slotRevealCaptureFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->slotEnableLibraryFolder(); break;
        case 33: _t->slotEnableVideoFolder((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->slotReloadBlackMagic(); break;
        case 35: _t->slotReloadShuttleDevices(); break;
        case 36: _t->fillMonitorData(); break;
        case 37: _t->configureExternalProxies(); break;
        case 38: _t->openBrowserUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 39: _t->loadExternalProxyProfiles(); break;
        case 40: _t->slotUpdateBreezeDrag((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->useRecordDefault(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)()>(_a, &KdenliveSettingsDialog::customChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)(bool )>(_a, &KdenliveSettingsDialog::doResetConsumer, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)()>(_a, &KdenliveSettingsDialog::updateCaptureFolder, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)()>(_a, &KdenliveSettingsDialog::updateLibraryFolder, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)(bool )>(_a, &KdenliveSettingsDialog::restartKdenlive, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)()>(_a, &KdenliveSettingsDialog::checkTabPosition, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettingsDialog::*)()>(_a, &KdenliveSettingsDialog::resetView, 7))
            return;
    }
}

const QMetaObject *KdenliveSettingsDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KdenliveSettingsDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22KdenliveSettingsDialogE_t>.strings))
        return static_cast<void*>(this);
    return KConfigDialog::qt_metacast(_clname);
}

int KdenliveSettingsDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 42)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 42;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 42)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 42;
    }
    return _id;
}

// SIGNAL 0
void KdenliveSettingsDialog::customChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KdenliveSettingsDialog::doResetConsumer(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KdenliveSettingsDialog::updateCaptureFolder()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KdenliveSettingsDialog::updateLibraryFolder()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KdenliveSettingsDialog::restartKdenlive(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 6
void KdenliveSettingsDialog::checkTabPosition()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KdenliveSettingsDialog::resetView()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
