/********************************************************************************
** Form generated from reading UI file 'templateclip_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEMPLATECLIP_UI_H
#define UI_TEMPLATECLIP_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QTextEdit>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_TemplateClip_UI
{
public:
    QGridLayout *gridLayout_2;
    QLabel *label;
    KUrlComboRequester *template_list;
    QGroupBox *text_box;
    QGridLayout *gridLayout;
    QLabel *preview;
    QTextEdit *description;
    KMessageWidget *errorMessage;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *TemplateClip_UI)
    {
        if (TemplateClip_UI->objectName().isEmpty())
            TemplateClip_UI->setObjectName("TemplateClip_UI");
        TemplateClip_UI->resize(576, 360);
        gridLayout_2 = new QGridLayout(TemplateClip_UI);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(TemplateClip_UI);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        template_list = new KUrlComboRequester(TemplateClip_UI);
        template_list->setObjectName("template_list");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(template_list->sizePolicy().hasHeightForWidth());
        template_list->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(template_list, 0, 1, 1, 2);

        text_box = new QGroupBox(TemplateClip_UI);
        text_box->setObjectName("text_box");
        gridLayout = new QGridLayout(text_box);
        gridLayout->setObjectName("gridLayout");
        preview = new QLabel(text_box);
        preview->setObjectName("preview");
        sizePolicy.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy);
        preview->setMinimumSize(QSize(300, 0));

        gridLayout->addWidget(preview, 0, 1, 1, 1);

        description = new QTextEdit(text_box);
        description->setObjectName("description");

        gridLayout->addWidget(description, 0, 0, 1, 1);

        errorMessage = new KMessageWidget(text_box);
        errorMessage->setObjectName("errorMessage");
        errorMessage->setWordWrap(true);
        errorMessage->setCloseButtonVisible(false);
        errorMessage->setMessageType(KMessageWidget::MessageType::Warning);

        gridLayout->addWidget(errorMessage, 1, 0, 1, 2);


        gridLayout_2->addWidget(text_box, 1, 0, 1, 3);

        buttonBox = new QDialogButtonBox(TemplateClip_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout_2->addWidget(buttonBox, 2, 2, 1, 1);


        retranslateUi(TemplateClip_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TemplateClip_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TemplateClip_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TemplateClip_UI);
    } // setupUi

    void retranslateUi(QDialog *TemplateClip_UI)
    {
        label->setText(tr2i18n("Template:", nullptr));
        text_box->setTitle(QString());
        preview->setText(QString());
        description->setPlaceholderText(tr2i18n("Enter the text that will replace the %s string from the template", nullptr));
        (void)TemplateClip_UI;
    } // retranslateUi

};

namespace Ui {
    class TemplateClip_UI: public Ui_TemplateClip_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEMPLATECLIP_UI_H

