/********************************************************************************
** Form generated from reading UI file 'newtimeline_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_NEWTIMELINE_UI_H
#define UI_NEWTIMELINE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_NewTimeline_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QLabel *label;
    QSpinBox *audio_tracks;
    QSpinBox *video_tracks;
    QLabel *label_audio_tracks;
    QLabel *label_video_tracks;
    QLineEdit *sequence_name;

    void setupUi(QDialog *NewTimeline_UI)
    {
        if (NewTimeline_UI->objectName().isEmpty())
            NewTimeline_UI->setObjectName("NewTimeline_UI");
        NewTimeline_UI->resize(186, 190);
        gridLayout = new QGridLayout(NewTimeline_UI);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 0, 1, 1);

        buttonBox = new QDialogButtonBox(NewTimeline_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 5, 0, 1, 2);

        label = new QLabel(NewTimeline_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 2);

        audio_tracks = new QSpinBox(NewTimeline_UI);
        audio_tracks->setObjectName("audio_tracks");

        gridLayout->addWidget(audio_tracks, 3, 1, 1, 1);

        video_tracks = new QSpinBox(NewTimeline_UI);
        video_tracks->setObjectName("video_tracks");

        gridLayout->addWidget(video_tracks, 2, 1, 1, 1);

        label_audio_tracks = new QLabel(NewTimeline_UI);
        label_audio_tracks->setObjectName("label_audio_tracks");

        gridLayout->addWidget(label_audio_tracks, 3, 0, 1, 1);

        label_video_tracks = new QLabel(NewTimeline_UI);
        label_video_tracks->setObjectName("label_video_tracks");

        gridLayout->addWidget(label_video_tracks, 2, 0, 1, 1);

        sequence_name = new QLineEdit(NewTimeline_UI);
        sequence_name->setObjectName("sequence_name");

        gridLayout->addWidget(sequence_name, 1, 0, 1, 2);

        QWidget::setTabOrder(sequence_name, video_tracks);
        QWidget::setTabOrder(video_tracks, audio_tracks);

        retranslateUi(NewTimeline_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, NewTimeline_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, NewTimeline_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(NewTimeline_UI);
    } // setupUi

    void retranslateUi(QDialog *NewTimeline_UI)
    {
        NewTimeline_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label->setText(tr2i18n("Sequence Name", nullptr));
        label_audio_tracks->setText(tr2i18n("Audio tracks:", nullptr));
        label_video_tracks->setText(tr2i18n("Video tracks:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class NewTimeline_UI: public Ui_NewTimeline_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // NEWTIMELINE_UI_H

