/********************************************************************************
** Form generated from reading UI file 'transcodeseekable_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TRANSCODESEEKABLE_UI_H
#define UI_TRANSCODESEEKABLE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TranscodeSeekable_UI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_2;
    QDialogButtonBox *buttonBox;
    QListWidget *listWidget;
    QComboBox *encodingprofiles;
    QLabel *label;
    KMessageWidget *messagewidget;
    QCheckBox *replace_original;

    void setupUi(QDialog *TranscodeSeekable_UI)
    {
        if (TranscodeSeekable_UI->objectName().isEmpty())
            TranscodeSeekable_UI->setObjectName("TranscodeSeekable_UI");
        TranscodeSeekable_UI->resize(460, 366);
        gridLayout = new QGridLayout(TranscodeSeekable_UI);
        gridLayout->setObjectName("gridLayout");
        label_2 = new QLabel(TranscodeSeekable_UI);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        buttonBox = new QDialogButtonBox(TranscodeSeekable_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 5, 0, 1, 2);

        listWidget = new QListWidget(TranscodeSeekable_UI);
        listWidget->setObjectName("listWidget");
        listWidget->setAlternatingRowColors(true);

        gridLayout->addWidget(listWidget, 1, 0, 1, 2);

        encodingprofiles = new QComboBox(TranscodeSeekable_UI);
        encodingprofiles->setObjectName("encodingprofiles");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(encodingprofiles->sizePolicy().hasHeightForWidth());
        encodingprofiles->setSizePolicy(sizePolicy);

        gridLayout->addWidget(encodingprofiles, 3, 1, 1, 1);

        label = new QLabel(TranscodeSeekable_UI);
        label->setObjectName("label");
        label->setAlignment(Qt::AlignJustify|Qt::AlignVCenter);
        label->setWordWrap(true);

        gridLayout->addWidget(label, 0, 0, 1, 2);

        messagewidget = new KMessageWidget(TranscodeSeekable_UI);
        messagewidget->setObjectName("messagewidget");
        messagewidget->setWordWrap(true);
        messagewidget->setCloseButtonVisible(false);

        gridLayout->addWidget(messagewidget, 2, 0, 1, 2);

        replace_original = new QCheckBox(TranscodeSeekable_UI);
        replace_original->setObjectName("replace_original");

        gridLayout->addWidget(replace_original, 4, 0, 1, 2);


        retranslateUi(TranscodeSeekable_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TranscodeSeekable_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TranscodeSeekable_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TranscodeSeekable_UI);
    } // setupUi

    void retranslateUi(QDialog *TranscodeSeekable_UI)
    {
        TranscodeSeekable_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_2->setText(tr2i18n("Convert to", nullptr));
        label->setText(tr2i18n("The following clips are not usable for editing. This will transcode them in an edit friendly format and replace the original ones in your project.", nullptr));
        replace_original->setText(tr2i18n("Replace clip by transcoded version in project", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TranscodeSeekable_UI: public Ui_TranscodeSeekable_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TRANSCODESEEKABLE_UI_H

