/********************************************************************************
** Form generated from reading UI file 'missingclips_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MISSINGCLIPS_UI_H
#define UI_MISSINGCLIPS_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_MissingClips_UI
{
public:
    QGridLayout *gridLayout;
    QTreeView *treeView;
    QSpacerItem *horizontalSpacer;
    KMessageWidget *infoLabel;
    KMessageWidget *statusLabel;
    QFrame *progressBox;
    QHBoxLayout *horizontalLayout_3;
    QLabel *progressLabel;
    QSpacerItem *horizontalSpacer_2;
    QProgressBar *progressBar;
    QCheckBox *recreateProxies;
    QDialogButtonBox *buttonBox;
    QFrame *actionButtonBox;
    QVBoxLayout *verticalLayout;
    QLabel *label_2;
    QPushButton *manualSearch;
    QPushButton *removeSelected;
    QFrame *line;
    QLabel *label;
    QPushButton *recursiveSearch;
    QPushButton *usePlaceholders;
    QSpacerItem *verticalSpacer;

    void setupUi(QDialog *MissingClips_UI)
    {
        if (MissingClips_UI->objectName().isEmpty())
            MissingClips_UI->setObjectName("MissingClips_UI");
        MissingClips_UI->resize(624, 467);
        gridLayout = new QGridLayout(MissingClips_UI);
        gridLayout->setObjectName("gridLayout");
        treeView = new QTreeView(MissingClips_UI);
        treeView->setObjectName("treeView");

        gridLayout->addWidget(treeView, 3, 1, 1, 3);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 15, 2, 1, 1);

        infoLabel = new KMessageWidget(MissingClips_UI);
        infoLabel->setObjectName("infoLabel");
        infoLabel->setWordWrap(true);
        infoLabel->setCloseButtonVisible(false);

        gridLayout->addWidget(infoLabel, 10, 1, 1, 4);

        statusLabel = new KMessageWidget(MissingClips_UI);
        statusLabel->setObjectName("statusLabel");
        statusLabel->setCloseButtonVisible(false);
        statusLabel->setMessageType(KMessageWidget::Warning);

        gridLayout->addWidget(statusLabel, 12, 1, 1, 4);

        progressBox = new QFrame(MissingClips_UI);
        progressBox->setObjectName("progressBox");
        progressBox->setFrameShape(QFrame::StyledPanel);
        progressBox->setFrameShadow(QFrame::Sunken);
        horizontalLayout_3 = new QHBoxLayout(progressBox);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        progressLabel = new QLabel(progressBox);
        progressLabel->setObjectName("progressLabel");

        horizontalLayout_3->addWidget(progressLabel);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        progressBar = new QProgressBar(progressBox);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(24);

        horizontalLayout_3->addWidget(progressBar);


        gridLayout->addWidget(progressBox, 11, 1, 1, 4);

        recreateProxies = new QCheckBox(MissingClips_UI);
        recreateProxies->setObjectName("recreateProxies");

        gridLayout->addWidget(recreateProxies, 13, 1, 1, 4);

        buttonBox = new QDialogButtonBox(MissingClips_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Abort|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 15, 3, 1, 2);

        actionButtonBox = new QFrame(MissingClips_UI);
        actionButtonBox->setObjectName("actionButtonBox");
        verticalLayout = new QVBoxLayout(actionButtonBox);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        label_2 = new QLabel(actionButtonBox);
        label_2->setObjectName("label_2");

        verticalLayout->addWidget(label_2);

        manualSearch = new QPushButton(actionButtonBox);
        manualSearch->setObjectName("manualSearch");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("find-location");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        manualSearch->setIcon(icon);

        verticalLayout->addWidget(manualSearch);

        removeSelected = new QPushButton(actionButtonBox);
        removeSelected->setObjectName("removeSelected");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        removeSelected->setIcon(icon1);

        verticalLayout->addWidget(removeSelected);

        line = new QFrame(actionButtonBox);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        verticalLayout->addWidget(line);

        label = new QLabel(actionButtonBox);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        recursiveSearch = new QPushButton(actionButtonBox);
        recursiveSearch->setObjectName("recursiveSearch");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("tools-wizard");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        recursiveSearch->setIcon(icon2);

        verticalLayout->addWidget(recursiveSearch);

        usePlaceholders = new QPushButton(actionButtonBox);
        usePlaceholders->setObjectName("usePlaceholders");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("view-preview");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        usePlaceholders->setIcon(icon3);

        verticalLayout->addWidget(usePlaceholders);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        gridLayout->addWidget(actionButtonBox, 3, 4, 1, 1);


        retranslateUi(MissingClips_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MissingClips_UI, qOverload<>(&QDialog::reject));
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MissingClips_UI, qOverload<>(&QDialog::accept));

        QMetaObject::connectSlotsByName(MissingClips_UI);
    } // setupUi

    void retranslateUi(QDialog *MissingClips_UI)
    {
        MissingClips_UI->setWindowTitle(tr2i18n(" Clip Problems", nullptr));
        progressLabel->setText(tr2i18n("TextLabel", nullptr));
        progressBar->setFormat(tr2i18n("%v / %m", nullptr));
        recreateProxies->setText(tr2i18n("Recreate missing proxies", nullptr));
        label_2->setText(tr2i18n("Selected Items:", nullptr));
        manualSearch->setText(tr2i18n("Search Manually", nullptr));
        removeSelected->setText(tr2i18n("Remove", nullptr));
        label->setText(tr2i18n("All Missing Items:", nullptr));
        recursiveSearch->setText(tr2i18n("Search Recursively", nullptr));
        usePlaceholders->setText(tr2i18n("Use Placeholders", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MissingClips_UI: public Ui_MissingClips_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MISSINGCLIPS_UI_H

