/********************************************************************************
** Form generated from reading UI file 'wipeval_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WIPEVAL_UI_H
#define UI_WIPEVAL_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Wipeval_UI
{
public:
    QGridLayout *gridLayout_5;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QLabel *label_3;
    QGridLayout *gridLayout;
    QPushButton *start_up;
    QPushButton *start_left;
    QPushButton *start_center;
    QPushButton *start_right;
    QPushButton *start_down;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSlider *start_transp;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QLabel *label_4;
    QGridLayout *gridLayout_4;
    QPushButton *end_up;
    QPushButton *end_left;
    QPushButton *end_center;
    QPushButton *end_right;
    QPushButton *end_down;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSlider *end_transp;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Wipeval_UI)
    {
        if (Wipeval_UI->objectName().isEmpty())
            Wipeval_UI->setObjectName("Wipeval_UI");
        Wipeval_UI->resize(287, 191);
        gridLayout_5 = new QGridLayout(Wipeval_UI);
        gridLayout_5->setObjectName("gridLayout_5");
        groupBox = new QGroupBox(Wipeval_UI);
        groupBox->setObjectName("groupBox");
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout_2->addWidget(label_3, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        start_up = new QPushButton(groupBox);
        start_up->setObjectName("start_up");
        start_up->setMaximumSize(QSize(30, 16777215));
        start_up->setCheckable(true);
        start_up->setAutoExclusive(true);

        gridLayout->addWidget(start_up, 0, 1, 1, 1);

        start_left = new QPushButton(groupBox);
        start_left->setObjectName("start_left");
        start_left->setMaximumSize(QSize(30, 16777215));
        start_left->setCheckable(true);
        start_left->setAutoExclusive(true);

        gridLayout->addWidget(start_left, 1, 0, 1, 1);

        start_center = new QPushButton(groupBox);
        start_center->setObjectName("start_center");
        start_center->setMaximumSize(QSize(30, 16777215));
        start_center->setCheckable(true);
        start_center->setAutoExclusive(true);

        gridLayout->addWidget(start_center, 1, 1, 1, 1);

        start_right = new QPushButton(groupBox);
        start_right->setObjectName("start_right");
        start_right->setMaximumSize(QSize(30, 16777215));
        start_right->setCheckable(true);
        start_right->setAutoExclusive(true);

        gridLayout->addWidget(start_right, 1, 2, 1, 1);

        start_down = new QPushButton(groupBox);
        start_down->setObjectName("start_down");
        start_down->setMaximumSize(QSize(30, 16777215));
        start_down->setCheckable(true);
        start_down->setAutoExclusive(true);

        gridLayout->addWidget(start_down, 2, 1, 1, 1);


        gridLayout_2->addLayout(gridLayout, 0, 1, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        start_transp = new QSlider(groupBox);
        start_transp->setObjectName("start_transp");
        start_transp->setMaximum(100);
        start_transp->setValue(100);
        start_transp->setOrientation(Qt::Horizontal);

        horizontalLayout->addWidget(start_transp);


        gridLayout_2->addLayout(horizontalLayout, 1, 0, 1, 2);


        gridLayout_5->addWidget(groupBox, 0, 0, 1, 1);

        groupBox_2 = new QGroupBox(Wipeval_UI);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName("gridLayout_3");
        label_4 = new QLabel(groupBox_2);
        label_4->setObjectName("label_4");
        label_4->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);

        gridLayout_3->addWidget(label_4, 0, 0, 1, 1);

        gridLayout_4 = new QGridLayout();
        gridLayout_4->setSpacing(0);
        gridLayout_4->setObjectName("gridLayout_4");
        end_up = new QPushButton(groupBox_2);
        end_up->setObjectName("end_up");
        end_up->setMaximumSize(QSize(30, 16777215));
        end_up->setCheckable(true);
        end_up->setAutoExclusive(true);

        gridLayout_4->addWidget(end_up, 0, 1, 1, 1);

        end_left = new QPushButton(groupBox_2);
        end_left->setObjectName("end_left");
        end_left->setMaximumSize(QSize(30, 16777215));
        end_left->setCheckable(true);
        end_left->setAutoExclusive(true);

        gridLayout_4->addWidget(end_left, 1, 0, 1, 1);

        end_center = new QPushButton(groupBox_2);
        end_center->setObjectName("end_center");
        end_center->setMaximumSize(QSize(30, 16777215));
        end_center->setCheckable(true);
        end_center->setAutoExclusive(true);

        gridLayout_4->addWidget(end_center, 1, 1, 1, 1);

        end_right = new QPushButton(groupBox_2);
        end_right->setObjectName("end_right");
        end_right->setMaximumSize(QSize(30, 16777215));
        end_right->setCheckable(true);
        end_right->setAutoExclusive(true);

        gridLayout_4->addWidget(end_right, 1, 2, 1, 1);

        end_down = new QPushButton(groupBox_2);
        end_down->setObjectName("end_down");
        end_down->setMaximumSize(QSize(30, 16777215));
        end_down->setCheckable(true);
        end_down->setAutoExclusive(true);

        gridLayout_4->addWidget(end_down, 2, 1, 1, 1);


        gridLayout_3->addLayout(gridLayout_4, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        end_transp = new QSlider(groupBox_2);
        end_transp->setObjectName("end_transp");
        end_transp->setMaximum(100);
        end_transp->setValue(100);
        end_transp->setOrientation(Qt::Horizontal);

        horizontalLayout_2->addWidget(end_transp);


        gridLayout_3->addLayout(horizontalLayout_2, 1, 0, 1, 2);


        gridLayout_5->addWidget(groupBox_2, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer, 1, 0, 1, 2);


        retranslateUi(Wipeval_UI);

        QMetaObject::connectSlotsByName(Wipeval_UI);
    } // setupUi

    void retranslateUi(QWidget *Wipeval_UI)
    {
        groupBox->setTitle(QString());
        label_3->setText(tr2i18n("Start", nullptr));
        start_up->setText(QString());
        start_left->setText(QString());
        start_center->setText(QString());
        start_right->setText(QString());
        start_down->setText(QString());
        label->setText(tr2i18n("Transparency:", nullptr));
        groupBox_2->setTitle(QString());
        label_4->setText(tr2i18n("End", nullptr));
        end_up->setText(QString());
        end_left->setText(QString());
        end_center->setText(QString());
        end_right->setText(QString());
        end_down->setText(QString());
        label_2->setText(tr2i18n("Transparency:", nullptr));
        (void)Wipeval_UI;
    } // retranslateUi

};

namespace Ui {
    class Wipeval_UI: public Ui_Wipeval_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WIPEVAL_UI_H

