/********************************************************************************
** Form generated from reading UI file 'configenv_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGENV_UI_H
#define UI_CONFIGENV_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigEnv_UI
{
public:
    QGridLayout *gridLayout;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_4;
    QCheckBox *kcfg_nice_tasks;
    QSpinBox *kcfg_proxythreads;
    QLabel *label_9;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_7;
    QLabel *label_18;
    QSpinBox *kcfg_maxcachesize;
    QLabel *label_17;
    QCheckBox *kcfg_showWelcome;
    QCheckBox *kcfg_checkForUpdate;
    QCheckBox *kcfg_usePowerManagement;
    QHBoxLayout *horizontalLayout_5;
    QCheckBox *dragFromTitlebarOnly;
    KContextualHelpButton *kcontextualhelpbutton;
    QSpacerItem *horizontalSpacer;
    QTabWidget *tabWidget;
    QWidget *tab;
    QFormLayout *formLayout;
    QLabel *label_8;
    KUrlRequester *ffmpegurl;
    QLabel *label_13;
    KUrlRequester *ffplayurl;
    QLabel *label_14;
    KUrlRequester *ffprobeurl;
    QLabel *label;
    KUrlRequester *mltpathurl;
    QLabel *label_2;
    KUrlRequester *rendererpathurl;
    QSpacerItem *verticalSpacer_2;
    QWidget *tab_2;
    QFormLayout *formLayout_3;
    QLabel *label_3;
    KUrlRequester *tmppathurl;
    QLabel *label_10;
    QComboBox *kcfg_capturetoprojectfolder;
    QVBoxLayout *verticalLayout_2;
    QLineEdit *kcfg_captureprojectsubfolder;
    KUrlRequester *capturefolderurl;
    QLabel *label_15;
    QCheckBox *kcfg_librarytodefaultfolder;
    KUrlRequester *libraryfolderurl;
    QLabel *label_16;
    QComboBox *kcfg_videotodefaultfolder;
    KUrlRequester *videofolderurl;
    QSpacerItem *verticalSpacer_3;
    QWidget *tab_3;
    QFormLayout *formLayout_2;
    QLabel *label_4;
    QHBoxLayout *horizontalLayout;
    QLineEdit *kcfg_defaultimageapp;
    QPushButton *kp_image;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *kcfg_defaultaudioapp;
    QPushButton *kp_audio;
    QLabel *label_11;
    QHBoxLayout *horizontalLayout_3;
    QLineEdit *kcfg_glaxnimatePath;
    QPushButton *kp_anim;
    QLabel *label_7;
    QHBoxLayout *horizontalLayout_4;
    QLineEdit *kcfg_defaultvideoapp;
    QPushButton *kp_video;
    QLabel *label_19;
    QSpacerItem *verticalSpacer_4;
    QWidget *tab_4;
    QGridLayout *gridLayout_5;
    QLabel *label_5;
    QLineEdit *kcfg_addedExtensions;
    QLabel *label_12;
    QPlainTextEdit *supportedmimes;

    void setupUi(QWidget *ConfigEnv_UI)
    {
        if (ConfigEnv_UI->objectName().isEmpty())
            ConfigEnv_UI->setObjectName("ConfigEnv_UI");
        ConfigEnv_UI->resize(582, 782);
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ConfigEnv_UI->sizePolicy().hasHeightForWidth());
        ConfigEnv_UI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(ConfigEnv_UI);
        gridLayout->setObjectName("gridLayout");
        groupBox = new QGroupBox(ConfigEnv_UI);
        groupBox->setObjectName("groupBox");
        gridLayout_4 = new QGridLayout(groupBox);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_nice_tasks = new QCheckBox(groupBox);
        kcfg_nice_tasks->setObjectName("kcfg_nice_tasks");

        gridLayout_4->addWidget(kcfg_nice_tasks, 1, 0, 1, 2);

        kcfg_proxythreads = new QSpinBox(groupBox);
        kcfg_proxythreads->setObjectName("kcfg_proxythreads");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_proxythreads->sizePolicy().hasHeightForWidth());
        kcfg_proxythreads->setSizePolicy(sizePolicy1);
        kcfg_proxythreads->setMinimum(1);

        gridLayout_4->addWidget(kcfg_proxythreads, 0, 1, 1, 1);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        gridLayout_4->addWidget(label_9, 0, 0, 1, 1);


        gridLayout->addWidget(groupBox, 0, 0, 1, 1);

        groupBox_2 = new QGroupBox(ConfigEnv_UI);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_7 = new QGridLayout(groupBox_2);
        gridLayout_7->setObjectName("gridLayout_7");
        label_18 = new QLabel(groupBox_2);
        label_18->setObjectName("label_18");

        gridLayout_7->addWidget(label_18, 1, 0, 1, 2);

        kcfg_maxcachesize = new QSpinBox(groupBox_2);
        kcfg_maxcachesize->setObjectName("kcfg_maxcachesize");
        sizePolicy1.setHeightForWidth(kcfg_maxcachesize->sizePolicy().hasHeightForWidth());
        kcfg_maxcachesize->setSizePolicy(sizePolicy1);
        kcfg_maxcachesize->setMinimum(0);
        kcfg_maxcachesize->setMaximum(10000000);

        gridLayout_7->addWidget(kcfg_maxcachesize, 0, 1, 1, 1);

        label_17 = new QLabel(groupBox_2);
        label_17->setObjectName("label_17");

        gridLayout_7->addWidget(label_17, 0, 0, 1, 1);


        gridLayout->addWidget(groupBox_2, 1, 0, 1, 1);

        kcfg_showWelcome = new QCheckBox(ConfigEnv_UI);
        kcfg_showWelcome->setObjectName("kcfg_showWelcome");

        gridLayout->addWidget(kcfg_showWelcome, 2, 0, 1, 1);

        kcfg_checkForUpdate = new QCheckBox(ConfigEnv_UI);
        kcfg_checkForUpdate->setObjectName("kcfg_checkForUpdate");

        gridLayout->addWidget(kcfg_checkForUpdate, 3, 0, 1, 1);

        kcfg_usePowerManagement = new QCheckBox(ConfigEnv_UI);
        kcfg_usePowerManagement->setObjectName("kcfg_usePowerManagement");

        gridLayout->addWidget(kcfg_usePowerManagement, 4, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        dragFromTitlebarOnly = new QCheckBox(ConfigEnv_UI);
        dragFromTitlebarOnly->setObjectName("dragFromTitlebarOnly");

        horizontalLayout_5->addWidget(dragFromTitlebarOnly);

        kcontextualhelpbutton = new KContextualHelpButton(ConfigEnv_UI);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        horizontalLayout_5->addWidget(kcontextualhelpbutton);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout_5, 5, 0, 1, 1);

        tabWidget = new QTabWidget(ConfigEnv_UI);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        formLayout = new QFormLayout(tab);
        formLayout->setObjectName("formLayout");
        label_8 = new QLabel(tab);
        label_8->setObjectName("label_8");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        ffmpegurl = new KUrlRequester(tab);
        ffmpegurl->setObjectName("ffmpegurl");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, ffmpegurl);

        label_13 = new QLabel(tab);
        label_13->setObjectName("label_13");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_13);

        ffplayurl = new KUrlRequester(tab);
        ffplayurl->setObjectName("ffplayurl");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, ffplayurl);

        label_14 = new QLabel(tab);
        label_14->setObjectName("label_14");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_14);

        ffprobeurl = new KUrlRequester(tab);
        ffprobeurl->setObjectName("ffprobeurl");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, ffprobeurl);

        label = new QLabel(tab);
        label->setObjectName("label");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label);

        mltpathurl = new KUrlRequester(tab);
        mltpathurl->setObjectName("mltpathurl");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, mltpathurl);

        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_2);

        rendererpathurl = new KUrlRequester(tab);
        rendererpathurl->setObjectName("rendererpathurl");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, rendererpathurl);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(5, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        formLayout_3 = new QFormLayout(tab_2);
        formLayout_3->setObjectName("formLayout_3");
        label_3 = new QLabel(tab_2);
        label_3->setObjectName("label_3");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        tmppathurl = new KUrlRequester(tab_2);
        tmppathurl->setObjectName("tmppathurl");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, tmppathurl);

        label_10 = new QLabel(tab_2);
        label_10->setObjectName("label_10");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_10);

        kcfg_capturetoprojectfolder = new QComboBox(tab_2);
        kcfg_capturetoprojectfolder->addItem(QString());
        kcfg_capturetoprojectfolder->addItem(QString());
        kcfg_capturetoprojectfolder->addItem(QString());
        kcfg_capturetoprojectfolder->addItem(QString());
        kcfg_capturetoprojectfolder->setObjectName("kcfg_capturetoprojectfolder");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_capturetoprojectfolder);

        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_captureprojectsubfolder = new QLineEdit(tab_2);
        kcfg_captureprojectsubfolder->setObjectName("kcfg_captureprojectsubfolder");

        verticalLayout_2->addWidget(kcfg_captureprojectsubfolder);

        capturefolderurl = new KUrlRequester(tab_2);
        capturefolderurl->setObjectName("capturefolderurl");

        verticalLayout_2->addWidget(capturefolderurl);


        formLayout_3->setLayout(4, QFormLayout::ItemRole::FieldRole, verticalLayout_2);

        label_15 = new QLabel(tab_2);
        label_15->setObjectName("label_15");

        formLayout_3->setWidget(6, QFormLayout::ItemRole::LabelRole, label_15);

        kcfg_librarytodefaultfolder = new QCheckBox(tab_2);
        kcfg_librarytodefaultfolder->setObjectName("kcfg_librarytodefaultfolder");

        formLayout_3->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_librarytodefaultfolder);

        libraryfolderurl = new KUrlRequester(tab_2);
        libraryfolderurl->setObjectName("libraryfolderurl");

        formLayout_3->setWidget(7, QFormLayout::ItemRole::FieldRole, libraryfolderurl);

        label_16 = new QLabel(tab_2);
        label_16->setObjectName("label_16");
        label_16->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);
        label_16->setWordWrap(true);

        formLayout_3->setWidget(9, QFormLayout::ItemRole::LabelRole, label_16);

        kcfg_videotodefaultfolder = new QComboBox(tab_2);
        kcfg_videotodefaultfolder->addItem(QString());
        kcfg_videotodefaultfolder->addItem(QString());
        kcfg_videotodefaultfolder->addItem(QString());
        kcfg_videotodefaultfolder->setObjectName("kcfg_videotodefaultfolder");

        formLayout_3->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_videotodefaultfolder);

        videofolderurl = new KUrlRequester(tab_2);
        videofolderurl->setObjectName("videofolderurl");
        sizePolicy.setHeightForWidth(videofolderurl->sizePolicy().hasHeightForWidth());
        videofolderurl->setSizePolicy(sizePolicy);

        formLayout_3->setWidget(11, QFormLayout::ItemRole::FieldRole, videofolderurl);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(13, QFormLayout::ItemRole::FieldRole, verticalSpacer_3);

        tabWidget->addTab(tab_2, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        formLayout_2 = new QFormLayout(tab_3);
        formLayout_2->setObjectName("formLayout_2");
        label_4 = new QLabel(tab_3);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_defaultimageapp = new QLineEdit(tab_3);
        kcfg_defaultimageapp->setObjectName("kcfg_defaultimageapp");
        kcfg_defaultimageapp->setProperty("showClearButton", QVariant(true));

        horizontalLayout->addWidget(kcfg_defaultimageapp);

        kp_image = new QPushButton(tab_3);
        kp_image->setObjectName("kp_image");

        horizontalLayout->addWidget(kp_image);


        formLayout_2->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_defaultaudioapp = new QLineEdit(tab_3);
        kcfg_defaultaudioapp->setObjectName("kcfg_defaultaudioapp");
        kcfg_defaultaudioapp->setProperty("showClearButton", QVariant(true));

        horizontalLayout_2->addWidget(kcfg_defaultaudioapp);

        kp_audio = new QPushButton(tab_3);
        kp_audio->setObjectName("kp_audio");

        horizontalLayout_2->addWidget(kp_audio);


        formLayout_2->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_11 = new QLabel(tab_3);
        label_11->setObjectName("label_11");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, label_11);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_glaxnimatePath = new QLineEdit(tab_3);
        kcfg_glaxnimatePath->setObjectName("kcfg_glaxnimatePath");

        horizontalLayout_3->addWidget(kcfg_glaxnimatePath);

        kp_anim = new QPushButton(tab_3);
        kp_anim->setObjectName("kp_anim");

        horizontalLayout_3->addWidget(kp_anim);


        formLayout_2->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        label_7 = new QLabel(tab_3);
        label_7->setObjectName("label_7");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_7);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        kcfg_defaultvideoapp = new QLineEdit(tab_3);
        kcfg_defaultvideoapp->setObjectName("kcfg_defaultvideoapp");

        horizontalLayout_4->addWidget(kcfg_defaultvideoapp);

        kp_video = new QPushButton(tab_3);
        kp_video->setObjectName("kp_video");

        horizontalLayout_4->addWidget(kp_video);


        formLayout_2->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        label_19 = new QLabel(tab_3);
        label_19->setObjectName("label_19");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::LabelRole, label_19);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_2->setItem(4, QFormLayout::ItemRole::LabelRole, verticalSpacer_4);

        tabWidget->addTab(tab_3, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        gridLayout_5 = new QGridLayout(tab_4);
        gridLayout_5->setObjectName("gridLayout_5");
        label_5 = new QLabel(tab_4);
        label_5->setObjectName("label_5");

        gridLayout_5->addWidget(label_5, 0, 0, 1, 1);

        kcfg_addedExtensions = new QLineEdit(tab_4);
        kcfg_addedExtensions->setObjectName("kcfg_addedExtensions");
        kcfg_addedExtensions->setPlaceholderText(QString::fromUtf8("*.mp4 *.mov"));

        gridLayout_5->addWidget(kcfg_addedExtensions, 1, 0, 1, 1);

        label_12 = new QLabel(tab_4);
        label_12->setObjectName("label_12");

        gridLayout_5->addWidget(label_12, 2, 0, 1, 1);

        supportedmimes = new QPlainTextEdit(tab_4);
        supportedmimes->setObjectName("supportedmimes");
        supportedmimes->setReadOnly(true);

        gridLayout_5->addWidget(supportedmimes, 3, 0, 1, 1);

        tabWidget->addTab(tab_4, QString());

        gridLayout->addWidget(tabWidget, 6, 0, 1, 1);

        QWidget::setTabOrder(kcfg_proxythreads, kcfg_nice_tasks);
        QWidget::setTabOrder(kcfg_nice_tasks, kcfg_maxcachesize);
        QWidget::setTabOrder(kcfg_maxcachesize, tmppathurl);
        QWidget::setTabOrder(tmppathurl, kcfg_showWelcome);
        QWidget::setTabOrder(kcfg_showWelcome, kcfg_checkForUpdate);
        QWidget::setTabOrder(kcfg_checkForUpdate, kcfg_usePowerManagement);
        QWidget::setTabOrder(kcfg_usePowerManagement, dragFromTitlebarOnly);
        QWidget::setTabOrder(dragFromTitlebarOnly, tabWidget);
        QWidget::setTabOrder(tabWidget, ffmpegurl);
        QWidget::setTabOrder(ffmpegurl, ffplayurl);
        QWidget::setTabOrder(ffplayurl, ffprobeurl);
        QWidget::setTabOrder(ffprobeurl, mltpathurl);
        QWidget::setTabOrder(mltpathurl, rendererpathurl);
        QWidget::setTabOrder(rendererpathurl, kcfg_captureprojectsubfolder);
        QWidget::setTabOrder(kcfg_captureprojectsubfolder, capturefolderurl);
        QWidget::setTabOrder(capturefolderurl, kcfg_librarytodefaultfolder);
        QWidget::setTabOrder(kcfg_librarytodefaultfolder, libraryfolderurl);
        QWidget::setTabOrder(libraryfolderurl, kcfg_videotodefaultfolder);
        QWidget::setTabOrder(kcfg_videotodefaultfolder, videofolderurl);
        QWidget::setTabOrder(videofolderurl, kcfg_defaultimageapp);
        QWidget::setTabOrder(kcfg_defaultimageapp, kp_image);
        QWidget::setTabOrder(kp_image, kcfg_defaultaudioapp);
        QWidget::setTabOrder(kcfg_defaultaudioapp, kp_audio);
        QWidget::setTabOrder(kp_audio, kcfg_glaxnimatePath);
        QWidget::setTabOrder(kcfg_glaxnimatePath, kp_anim);
        QWidget::setTabOrder(kp_anim, kcfg_defaultvideoapp);
        QWidget::setTabOrder(kcfg_defaultvideoapp, kp_video);
        QWidget::setTabOrder(kp_video, kcfg_addedExtensions);
        QWidget::setTabOrder(kcfg_addedExtensions, supportedmimes);
        QWidget::setTabOrder(supportedmimes, kcfg_capturetoprojectfolder);

        retranslateUi(ConfigEnv_UI);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ConfigEnv_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigEnv_UI)
    {
        groupBox->setTitle(tr2i18n("Proxy and Transcode Jobs", nullptr));
        kcfg_nice_tasks->setText(tr2i18n("Use lower CPU priority for proxy and transcode tasks", nullptr));
        label_9->setText(tr2i18n("Concurrent threads:", nullptr));
        groupBox_2->setTitle(tr2i18n("Cached Data", nullptr));
        label_18->setText(tr2i18n("Kdenlive will check this limit every 2 weeks. Set to zero to disable checking.", nullptr));
        kcfg_maxcachesize->setSuffix(tr2i18n(" MiB", nullptr));
        label_17->setText(tr2i18n("Warn if cached data exceeds:", nullptr));
        kcfg_showWelcome->setText(tr2i18n("Show Welcome screen at startup", nullptr));
        kcfg_checkForUpdate->setText(tr2i18n("Check for updates", nullptr));
        kcfg_usePowerManagement->setText(tr2i18n("Prevent sleep when playing and rendering", nullptr));
        dragFromTitlebarOnly->setText(tr2i18n("Drag window from titlebar only", nullptr));
        kcontextualhelpbutton->setContextualHelpText(tr2i18n("This will apply to all KDE applications using the Breeze style.", nullptr));
        label_8->setText(tr2i18n("FFmpeg:", nullptr));
        label_13->setText(tr2i18n("FFplay:", nullptr));
        label_14->setText(tr2i18n("FFprobe:", nullptr));
        label->setText(tr2i18n("MLT profiles folder:", nullptr));
        label_2->setText(tr2i18n("Melt path:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("MLT Environment", nullptr));
        label_3->setText(tr2i18n("Temporary files:", nullptr));
        label_10->setText(tr2i18n("Capture folder:", nullptr));
        kcfg_capturetoprojectfolder->setItemText(0, tr2i18n("Use default folder", nullptr));
        kcfg_capturetoprojectfolder->setItemText(1, tr2i18n("Always use project folder", nullptr));
        kcfg_capturetoprojectfolder->setItemText(2, tr2i18n("Always use custom folder", nullptr));
        kcfg_capturetoprojectfolder->setItemText(3, tr2i18n("Always use a custom subfolder of project folder", nullptr));

        kcfg_captureprojectsubfolder->setPlaceholderText(tr2i18n("Subfolder of project folder", nullptr));
        label_15->setText(tr2i18n("Library folder:", nullptr));
        kcfg_librarytodefaultfolder->setText(tr2i18n("Use default folder", nullptr));
        label_16->setText(tr2i18n("Folder for rendering, titles, scripts:", nullptr));
        kcfg_videotodefaultfolder->setItemText(0, tr2i18n("Use default folder", nullptr));
        kcfg_videotodefaultfolder->setItemText(1, tr2i18n("Always use project folder", nullptr));
        kcfg_videotodefaultfolder->setItemText(2, tr2i18n("Always use custom folder", nullptr));

        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Default Folders", nullptr));
        label_4->setText(tr2i18n("Image editing:", nullptr));
        kcfg_defaultimageapp->setPlaceholderText(tr2i18n("Path to image editing application", nullptr));
        kp_image->setText(tr2i18n("Change\342\200\246", nullptr));
        kcfg_defaultaudioapp->setPlaceholderText(tr2i18n("Path to audio editing application", nullptr));
        kp_audio->setText(tr2i18n("Change\342\200\246", nullptr));
        label_11->setText(tr2i18n("Audio editing:", nullptr));
        kcfg_glaxnimatePath->setPlaceholderText(tr2i18n("Path to Glaxnimate executable", nullptr));
        kp_anim->setText(tr2i18n("Change\342\200\246", nullptr));
        label_7->setText(tr2i18n("Animation editing:", nullptr));
        kcfg_defaultvideoapp->setPlaceholderText(tr2i18n("Path to video editor executable", nullptr));
        kp_video->setText(tr2i18n("Change\342\200\246", nullptr));
        label_19->setText(tr2i18n("Video editing:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Default Apps", nullptr));
        label_5->setText(tr2i18n("Additional clip MIME types", nullptr));
        label_12->setText(tr2i18n("Supported clip MIME types", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Mime types", nullptr));
        (void)ConfigEnv_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigEnv_UI: public Ui_ConfigEnv_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGENV_UI_H

