/********************************************************************************
** Form generated from reading UI file 'configmisc_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGMISC_UI_H
#define UI_CONFIGMISC_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigMisc_UI
{
public:
    QFormLayout *formLayout;
    QLabel *label_11;
    QCheckBox *kcfg_openlastproject;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *kcfg_crashrecovery;
    QSpinBox *kcfg_autosave_time;
    QLabel *label_13;
    QSpinBox *kcfg_autosave_ops;
    QFrame *line;
    QLabel *label_12;
    QCheckBox *kcfg_checkfirstprojectclip;
    QCheckBox *kcfg_keep_original_frame_size;
    QCheckBox *kcfg_automultistreams;
    QCheckBox *kcfg_autoimagesequence;
    QCheckBox *kcfg_use_exiftool;
    QCheckBox *kcfg_use_magicLantern;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_ignoresubdirstructure;
    KContextualHelpButton *kcontextualhelpbutton;
    QFrame *line_2;
    QCheckBox *kcfg_disable_effect_parameters;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *kcfg_enableBuiltInEffects;
    KContextualHelpButton *kcontextualhelpbutton_2;
    QLabel *label_4;
    QComboBox *kcfg_tabposition;
    QFrame *line_3;
    QLabel *label_10;
    QComboBox *preferredcomposite;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QLabel *label_8;
    QLabel *label_5;
    QLineEdit *kcfg_title_duration;
    QLabel *label_2;
    QLineEdit *kcfg_color_duration;
    QLabel *label_6;
    QLineEdit *kcfg_transition_duration;
    QLabel *label_3;
    QLineEdit *kcfg_sequence_duration;
    QLineEdit *kcfg_fade_duration;
    QLineEdit *kcfg_image_duration;
    QLabel *label_7;
    QLineEdit *kcfg_mix_duration;
    QLineEdit *kcfg_subtitle_duration;
    QLabel *label_9;
    QSpacerItem *spacerItem;
    QLabel *label_14;

    void setupUi(QWidget *ConfigMisc_UI)
    {
        if (ConfigMisc_UI->objectName().isEmpty())
            ConfigMisc_UI->setObjectName("ConfigMisc_UI");
        ConfigMisc_UI->resize(785, 709);
        formLayout = new QFormLayout(ConfigMisc_UI);
        formLayout->setObjectName("formLayout");
        label_11 = new QLabel(ConfigMisc_UI);
        label_11->setObjectName("label_11");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_11);

        kcfg_openlastproject = new QCheckBox(ConfigMisc_UI);
        kcfg_openlastproject->setObjectName("kcfg_openlastproject");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_openlastproject);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        kcfg_crashrecovery = new QCheckBox(ConfigMisc_UI);
        kcfg_crashrecovery->setObjectName("kcfg_crashrecovery");

        horizontalLayout_3->addWidget(kcfg_crashrecovery);

        kcfg_autosave_time = new QSpinBox(ConfigMisc_UI);
        kcfg_autosave_time->setObjectName("kcfg_autosave_time");
        kcfg_autosave_time->setMinimum(5);
        kcfg_autosave_time->setMaximum(600);

        horizontalLayout_3->addWidget(kcfg_autosave_time);

        label_13 = new QLabel(ConfigMisc_UI);
        label_13->setObjectName("label_13");

        horizontalLayout_3->addWidget(label_13);

        kcfg_autosave_ops = new QSpinBox(ConfigMisc_UI);
        kcfg_autosave_ops->setObjectName("kcfg_autosave_ops");
        kcfg_autosave_ops->setMinimum(10);
        kcfg_autosave_ops->setMaximum(200);

        horizontalLayout_3->addWidget(kcfg_autosave_ops);


        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, horizontalLayout_3);

        line = new QFrame(ConfigMisc_UI);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(2, QFormLayout::ItemRole::SpanningRole, line);

        label_12 = new QLabel(ConfigMisc_UI);
        label_12->setObjectName("label_12");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_12);

        kcfg_checkfirstprojectclip = new QCheckBox(ConfigMisc_UI);
        kcfg_checkfirstprojectclip->setObjectName("kcfg_checkfirstprojectclip");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_checkfirstprojectclip);

        kcfg_keep_original_frame_size = new QCheckBox(ConfigMisc_UI);
        kcfg_keep_original_frame_size->setObjectName("kcfg_keep_original_frame_size");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_keep_original_frame_size);

        kcfg_automultistreams = new QCheckBox(ConfigMisc_UI);
        kcfg_automultistreams->setObjectName("kcfg_automultistreams");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_automultistreams);

        kcfg_autoimagesequence = new QCheckBox(ConfigMisc_UI);
        kcfg_autoimagesequence->setObjectName("kcfg_autoimagesequence");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_autoimagesequence);

        kcfg_use_exiftool = new QCheckBox(ConfigMisc_UI);
        kcfg_use_exiftool->setObjectName("kcfg_use_exiftool");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_use_exiftool);

        kcfg_use_magicLantern = new QCheckBox(ConfigMisc_UI);
        kcfg_use_magicLantern->setObjectName("kcfg_use_magicLantern");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_use_magicLantern);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_ignoresubdirstructure = new QCheckBox(ConfigMisc_UI);
        kcfg_ignoresubdirstructure->setObjectName("kcfg_ignoresubdirstructure");

        horizontalLayout->addWidget(kcfg_ignoresubdirstructure);

        kcontextualhelpbutton = new KContextualHelpButton(ConfigMisc_UI);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        horizontalLayout->addWidget(kcontextualhelpbutton);


        formLayout->setLayout(9, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        line_2 = new QFrame(ConfigMisc_UI);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(10, QFormLayout::ItemRole::SpanningRole, line_2);

        kcfg_disable_effect_parameters = new QCheckBox(ConfigMisc_UI);
        kcfg_disable_effect_parameters->setObjectName("kcfg_disable_effect_parameters");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_disable_effect_parameters);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(0);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(-1, -1, 0, 0);
        kcfg_enableBuiltInEffects = new QCheckBox(ConfigMisc_UI);
        kcfg_enableBuiltInEffects->setObjectName("kcfg_enableBuiltInEffects");

        horizontalLayout_2->addWidget(kcfg_enableBuiltInEffects);

        kcontextualhelpbutton_2 = new KContextualHelpButton(ConfigMisc_UI);
        kcontextualhelpbutton_2->setObjectName("kcontextualhelpbutton_2");

        horizontalLayout_2->addWidget(kcontextualhelpbutton_2);


        formLayout->setLayout(12, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        label_4 = new QLabel(ConfigMisc_UI);
        label_4->setObjectName("label_4");

        formLayout->setWidget(13, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_tabposition = new QComboBox(ConfigMisc_UI);
        kcfg_tabposition->addItem(QString());
        kcfg_tabposition->addItem(QString());
        kcfg_tabposition->setObjectName("kcfg_tabposition");

        formLayout->setWidget(13, QFormLayout::ItemRole::FieldRole, kcfg_tabposition);

        line_3 = new QFrame(ConfigMisc_UI);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(14, QFormLayout::ItemRole::SpanningRole, line_3);

        label_10 = new QLabel(ConfigMisc_UI);
        label_10->setObjectName("label_10");

        formLayout->setWidget(15, QFormLayout::ItemRole::LabelRole, label_10);

        preferredcomposite = new QComboBox(ConfigMisc_UI);
        preferredcomposite->setObjectName("preferredcomposite");

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, preferredcomposite);

        groupBox = new QGroupBox(ConfigMisc_UI);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_8 = new QLabel(groupBox);
        label_8->setObjectName("label_8");

        gridLayout->addWidget(label_8, 1, 0, 1, 1);

        label_5 = new QLabel(groupBox);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 2, 0, 1, 1);

        kcfg_title_duration = new QLineEdit(groupBox);
        kcfg_title_duration->setObjectName("kcfg_title_duration");

        gridLayout->addWidget(kcfg_title_duration, 1, 1, 1, 1);

        label_2 = new QLabel(groupBox);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 2, 1, 1);

        kcfg_color_duration = new QLineEdit(groupBox);
        kcfg_color_duration->setObjectName("kcfg_color_duration");

        gridLayout->addWidget(kcfg_color_duration, 0, 1, 1, 1);

        label_6 = new QLabel(groupBox);
        label_6->setObjectName("label_6");

        gridLayout->addWidget(label_6, 2, 2, 1, 1);

        kcfg_transition_duration = new QLineEdit(groupBox);
        kcfg_transition_duration->setObjectName("kcfg_transition_duration");

        gridLayout->addWidget(kcfg_transition_duration, 2, 1, 1, 1);

        label_3 = new QLabel(groupBox);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 1, 2, 1, 1);

        kcfg_sequence_duration = new QLineEdit(groupBox);
        kcfg_sequence_duration->setObjectName("kcfg_sequence_duration");

        gridLayout->addWidget(kcfg_sequence_duration, 1, 3, 1, 1);

        kcfg_fade_duration = new QLineEdit(groupBox);
        kcfg_fade_duration->setObjectName("kcfg_fade_duration");

        gridLayout->addWidget(kcfg_fade_duration, 2, 3, 1, 1);

        kcfg_image_duration = new QLineEdit(groupBox);
        kcfg_image_duration->setObjectName("kcfg_image_duration");

        gridLayout->addWidget(kcfg_image_duration, 0, 3, 1, 1);

        label_7 = new QLabel(groupBox);
        label_7->setObjectName("label_7");

        gridLayout->addWidget(label_7, 3, 0, 1, 1);

        kcfg_mix_duration = new QLineEdit(groupBox);
        kcfg_mix_duration->setObjectName("kcfg_mix_duration");

        gridLayout->addWidget(kcfg_mix_duration, 3, 1, 1, 1);

        kcfg_subtitle_duration = new QLineEdit(groupBox);
        kcfg_subtitle_duration->setObjectName("kcfg_subtitle_duration");

        gridLayout->addWidget(kcfg_subtitle_duration, 3, 3, 1, 1);

        label_9 = new QLabel(groupBox);
        label_9->setObjectName("label_9");

        gridLayout->addWidget(label_9, 3, 2, 1, 1);


        formLayout->setWidget(16, QFormLayout::ItemRole::SpanningRole, groupBox);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(17, QFormLayout::ItemRole::LabelRole, spacerItem);

        label_14 = new QLabel(ConfigMisc_UI);
        label_14->setObjectName("label_14");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_14);

        QWidget::setTabOrder(kcfg_openlastproject, kcfg_crashrecovery);
        QWidget::setTabOrder(kcfg_crashrecovery, kcfg_autosave_time);
        QWidget::setTabOrder(kcfg_autosave_time, kcfg_autosave_ops);
        QWidget::setTabOrder(kcfg_autosave_ops, kcfg_checkfirstprojectclip);
        QWidget::setTabOrder(kcfg_checkfirstprojectclip, kcfg_keep_original_frame_size);
        QWidget::setTabOrder(kcfg_keep_original_frame_size, kcfg_automultistreams);
        QWidget::setTabOrder(kcfg_automultistreams, kcfg_autoimagesequence);
        QWidget::setTabOrder(kcfg_autoimagesequence, kcfg_use_exiftool);
        QWidget::setTabOrder(kcfg_use_exiftool, kcfg_use_magicLantern);
        QWidget::setTabOrder(kcfg_use_magicLantern, kcfg_ignoresubdirstructure);
        QWidget::setTabOrder(kcfg_ignoresubdirstructure, kcontextualhelpbutton);
        QWidget::setTabOrder(kcontextualhelpbutton, kcfg_disable_effect_parameters);
        QWidget::setTabOrder(kcfg_disable_effect_parameters, kcfg_enableBuiltInEffects);
        QWidget::setTabOrder(kcfg_enableBuiltInEffects, kcontextualhelpbutton_2);
        QWidget::setTabOrder(kcontextualhelpbutton_2, kcfg_tabposition);
        QWidget::setTabOrder(kcfg_tabposition, preferredcomposite);
        QWidget::setTabOrder(preferredcomposite, kcfg_color_duration);
        QWidget::setTabOrder(kcfg_color_duration, kcfg_title_duration);
        QWidget::setTabOrder(kcfg_title_duration, kcfg_transition_duration);
        QWidget::setTabOrder(kcfg_transition_duration, kcfg_mix_duration);
        QWidget::setTabOrder(kcfg_mix_duration, kcfg_image_duration);
        QWidget::setTabOrder(kcfg_image_duration, kcfg_sequence_duration);
        QWidget::setTabOrder(kcfg_sequence_duration, kcfg_fade_duration);
        QWidget::setTabOrder(kcfg_fade_duration, kcfg_subtitle_duration);

        retranslateUi(ConfigMisc_UI);

        QMetaObject::connectSlotsByName(ConfigMisc_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigMisc_UI)
    {
        label_11->setText(tr2i18n("Project file:", nullptr));
        kcfg_openlastproject->setText(tr2i18n("Open last project on startup", nullptr));
        kcfg_crashrecovery->setText(tr2i18n("Every", nullptr));
        kcfg_autosave_time->setSuffix(tr2i18n(" seconds", nullptr));
        label_13->setText(tr2i18n("or", nullptr));
        kcfg_autosave_ops->setSuffix(tr2i18n(" operations", nullptr));
        label_12->setText(tr2i18n("Clip import:", nullptr));
        kcfg_checkfirstprojectclip->setText(tr2i18n("Check if first added clip matches project profile", nullptr));
        kcfg_keep_original_frame_size->setText(tr2i18n("Keep clip original frame size on import", nullptr));
        kcfg_automultistreams->setText(tr2i18n("Automatically import all streams in multi stream clips", nullptr));
        kcfg_autoimagesequence->setText(tr2i18n("Automatically import image sequences", nullptr));
        kcfg_use_exiftool->setText(tr2i18n("Get clip metadata with exiftool", nullptr));
        kcfg_use_magicLantern->setText(tr2i18n("Get clip metadata created by Magic Lantern", nullptr));
        kcfg_ignoresubdirstructure->setText(tr2i18n("Ignore subfolder structure on import", nullptr));
        kcontextualhelpbutton->setContextualHelpText(tr2i18n("This will import all files into a toplevel folder", nullptr));
        kcfg_disable_effect_parameters->setText(tr2i18n("Disable parameters when the effect is disabled", nullptr));
        kcfg_enableBuiltInEffects->setText(tr2i18n("Enable Built-in Effects", nullptr));
        kcontextualhelpbutton_2->setContextualHelpText(tr2i18n("Enabling built-in effects will add basic effects like volume and transform to all clips for easy access", nullptr));
        label_4->setText(tr2i18n("Tab position:", nullptr));
        kcfg_tabposition->setItemText(0, tr2i18n("Top", nullptr));
        kcfg_tabposition->setItemText(1, tr2i18n("Bottom", nullptr));

        label_10->setText(tr2i18n("Preferred track compositing composition:", nullptr));
        groupBox->setTitle(tr2i18n("Default Durations", nullptr));
        label->setText(tr2i18n("Color clips:", nullptr));
        label_8->setText(tr2i18n("Title clips:", nullptr));
        label_5->setText(tr2i18n("Transitions:", nullptr));
        label_2->setText(tr2i18n("Image clips:", nullptr));
        label_6->setText(tr2i18n("Fades:", nullptr));
        label_3->setText(tr2i18n("Image sequence:", nullptr));
        label_7->setText(tr2i18n("Mixes:", nullptr));
        label_9->setText(tr2i18n("Subtitles:", nullptr));
        label_14->setText(tr2i18n("Auto Save", nullptr));
        (void)ConfigMisc_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigMisc_UI: public Ui_ConfigMisc_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGMISC_UI_H

