/********************************************************************************
** Form generated from reading UI file 'urlval_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_URLVAL_UI_H
#define UI_URLVAL_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_Urlval_UI
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    KUrlRequester *urlwidget;
    QLabel *labelComment;

    void setupUi(QWidget *Urlval_UI)
    {
        if (Urlval_UI->objectName().isEmpty())
            Urlval_UI->setObjectName("Urlval_UI");
        Urlval_UI->resize(239, 52);
        verticalLayout = new QVBoxLayout(Urlval_UI);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        urlwidget = new KUrlRequester(Urlval_UI);
        urlwidget->setObjectName("urlwidget");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(urlwidget->sizePolicy().hasHeightForWidth());
        urlwidget->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(urlwidget);


        verticalLayout->addLayout(horizontalLayout);

        labelComment = new QLabel(Urlval_UI);
        labelComment->setObjectName("labelComment");
        labelComment->setFrameShape(QFrame::NoFrame);
        labelComment->setFrameShadow(QFrame::Plain);
        labelComment->setLineWidth(-1);
        labelComment->setTextFormat(Qt::RichText);
        labelComment->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        labelComment->setWordWrap(true);

        verticalLayout->addWidget(labelComment);


        retranslateUi(Urlval_UI);

        QMetaObject::connectSlotsByName(Urlval_UI);
    } // setupUi

    void retranslateUi(QWidget *Urlval_UI)
    {
        (void)Urlval_UI;
    } // retranslateUi

};

namespace Ui {
    class Urlval_UI: public Ui_Urlval_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // URLVAL_UI_H

