/****************************************************************************
** Meta object code from reading C++ file 'projectclip.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/bin/projectclip.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectclip.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11ProjectClipE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectClip::qt_create_metaobjectdata<qt_meta_tag_ZN11ProjectClipE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectClip",
        "producerChanged",
        "",
        "Mlt::Producer",
        "prod",
        "refreshPropertiesPanel",
        "refreshAnalysisPanel",
        "refreshClipDisplay",
        "thumbReady",
        "QImage",
        "loadPropertiesPanel",
        "audioThumbReady",
        "updateStreamInfo",
        "ix",
        "boundsChanged",
        "QList<QPoint>",
        "bounds",
        "registeredClipChanged",
        "firstFrameExported",
        "masksUpdated",
        "setProperties",
        "QMap<QString,QString>",
        "properties",
        "refreshPanel",
        "updateAudioThumbnail",
        "cachedThumb",
        "deleteProxy",
        "reloadClip",
        "updateJobProgress",
        "ObjectId",
        "ownerId",
        "jobProgress",
        "setThumbnail",
        "in",
        "out",
        "inCache",
        "setSequenceThumbnail",
        "QUuid",
        "uuid",
        "updateProxyProducer",
        "path",
        "updateTimelineClips",
        "QList<int>",
        "roles",
        "setInvalid",
        "setClipStatus",
        "FileStatus::ClipStatus",
        "status",
        "importEffects",
        "std::shared_ptr<Mlt::Producer>",
        "producer",
        "originalDecimalPoint",
        "setProducer",
        "generateThumb",
        "clearTrackProducers",
        "importJsonMarkers",
        "json",
        "checkClipBounds",
        "checkProxy",
        "rebuildProxy",
        "addMask",
        "filterOwner",
        "MaskInfo",
        "mask",
        "autoAdd",
        "removeMask",
        "maskName",
        "getStartTCFromProperties",
        "fetchPixmap",
        "position",
        "refreshIconOverlay"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'producerChanged'
        QtMocHelpers::SignalData<void(const QString &, Mlt::Producer)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 3, 4 },
        }}),
        // Signal 'refreshPropertiesPanel'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshAnalysisPanel'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshClipDisplay'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thumbReady'
        QtMocHelpers::SignalData<void(int, const QImage &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Signal 'loadPropertiesPanel'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioThumbReady'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateStreamInfo'
        QtMocHelpers::SignalData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Signal 'boundsChanged'
        QtMocHelpers::SignalData<void(QVector<QPoint>)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Signal 'registeredClipChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'firstFrameExported'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'masksUpdated'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setProperties'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &, bool)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Bool, 23 },
        }}),
        // Slot 'setProperties'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(20, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'updateAudioThumbnail'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'deleteProxy'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'deleteProxy'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateJobProgress'
        QtMocHelpers::SlotData<void(ObjectId, int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 30 }, { QMetaType::Int, 31 },
        }}),
        // Slot 'updateJobProgress'
        QtMocHelpers::SlotData<void(ObjectId)>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 29, 30 },
        }}),
        // Slot 'updateJobProgress'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'setThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, int, int, bool)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 33 }, { QMetaType::Int, 34 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'setThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, int, int)>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { QMetaType::Int, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'setSequenceThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, const QUuid &, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 37, 38 }, { QMetaType::Bool, 35 },
        }}),
        // Slot 'setSequenceThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, const QUuid &)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 37, 38 },
        }}),
        // Slot 'updateProxyProducer'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 },
        }}),
        // Slot 'updateTimelineClips'
        QtMocHelpers::SlotData<void(const QVector<int> &)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'setInvalid'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setClipStatus'
        QtMocHelpers::SlotData<void(FileStatus::ClipStatus)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 46, 47 },
        }}),
        // Slot 'importEffects'
        QtMocHelpers::SlotData<void(const std::shared_ptr<Mlt::Producer> &, const QString &)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 49, 50 }, { QMetaType::QString, 51 },
        }}),
        // Slot 'importEffects'
        QtMocHelpers::SlotData<void(const std::shared_ptr<Mlt::Producer> &)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>, bool, bool)>(52, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 49, 50 }, { QMetaType::Bool, 53 }, { QMetaType::Bool, 54 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>, bool)>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 49, 50 }, { QMetaType::Bool, 53 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>)>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'importJsonMarkers'
        QtMocHelpers::SlotData<void(const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 56 },
        }}),
        // Slot 'checkClipBounds'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkProxy'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'checkProxy'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'addMask'
        QtMocHelpers::SlotData<void(const ObjectId &, MaskInfo, bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 29, 61 }, { 0x80000000 | 62, 63 }, { QMetaType::Bool, 64 },
        }}),
        // Slot 'addMask'
        QtMocHelpers::SlotData<void(const ObjectId &, MaskInfo)>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 29, 61 }, { 0x80000000 | 62, 63 },
        }}),
        // Slot 'removeMask'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
        // Slot 'getStartTCFromProperties'
        QtMocHelpers::SlotData<int()>(67, 2, QMC::AccessPublic, QMetaType::Int),
        // Slot 'fetchPixmap'
        QtMocHelpers::SlotData<QImage(int)>(68, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 69 },
        }}),
        // Slot 'fetchPixmap'
        QtMocHelpers::SlotData<QImage()>(68, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 9),
        // Slot 'refreshIconOverlay'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectClip, qt_meta_tag_ZN11ProjectClipE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectClip::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractProjectItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ProjectClipE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ProjectClipE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11ProjectClipE_t>.metaTypes,
    nullptr
} };

void ProjectClip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectClip *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->producerChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<Mlt::Producer>>(_a[2]))); break;
        case 1: _t->refreshPropertiesPanel(); break;
        case 2: _t->refreshAnalysisPanel(); break;
        case 3: _t->refreshClipDisplay(); break;
        case 4: _t->thumbReady((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QImage>>(_a[2]))); break;
        case 5: _t->loadPropertiesPanel(); break;
        case 6: _t->audioThumbReady(); break;
        case 7: _t->updateStreamInfo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->boundsChanged((*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[1]))); break;
        case 9: _t->registeredClipChanged(); break;
        case 10: _t->firstFrameExported(); break;
        case 11: _t->masksUpdated(); break;
        case 12: _t->setProperties((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: _t->setProperties((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 14: _t->updateAudioThumbnail((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->deleteProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->deleteProxy(); break;
        case 17: _t->updateJobProgress((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 18: _t->updateJobProgress((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1]))); break;
        case 19: _t->updateJobProgress(); break;
        case 20: _t->setThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 21: _t->setThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 22: _t->setSequenceThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 23: _t->setSequenceThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 24: _t->updateProxyProducer((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->updateTimelineClips((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 26: _t->setInvalid(); break;
        case 27: _t->setClipStatus((*reinterpret_cast<std::add_pointer_t<FileStatus::ClipStatus>>(_a[1]))); break;
        case 28: _t->importEffects((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 29: _t->importEffects((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1]))); break;
        case 30: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: _t->importJsonMarkers((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->checkClipBounds(); break;
        case 35: _t->checkProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->checkProxy(); break;
        case 37: _t->addMask((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MaskInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 38: _t->addMask((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MaskInfo>>(_a[2]))); break;
        case 39: _t->removeMask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 40: { int _r = _t->getStartTCFromProperties();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 41: { QImage _r = _t->fetchPixmap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 42: { QImage _r = _t->fetchPixmap();
            if (_a[0]) *reinterpret_cast<QImage*>(_a[0]) = std::move(_r); }  break;
        case 43: _t->refreshIconOverlay(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 25:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)(const QString & , Mlt::Producer )>(_a, &ProjectClip::producerChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::refreshPropertiesPanel, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::refreshAnalysisPanel, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::refreshClipDisplay, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)(int , const QImage & )>(_a, &ProjectClip::thumbReady, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::loadPropertiesPanel, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::audioThumbReady, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)(int )>(_a, &ProjectClip::updateStreamInfo, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)(QVector<QPoint> )>(_a, &ProjectClip::boundsChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::registeredClipChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::firstFrameExported, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectClip::*)()>(_a, &ProjectClip::masksUpdated, 11))
            return;
    }
}

const QMetaObject *ProjectClip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectClip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11ProjectClipE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "ClipController"))
        return static_cast< ClipController*>(this);
    return AbstractProjectItem::qt_metacast(_clname);
}

int ProjectClip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractProjectItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 44)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 44;
    }
    return _id;
}

// SIGNAL 0
void ProjectClip::producerChanged(const QString & _t1, Mlt::Producer _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ProjectClip::refreshPropertiesPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ProjectClip::refreshAnalysisPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ProjectClip::refreshClipDisplay()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ProjectClip::thumbReady(int _t1, const QImage & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ProjectClip::loadPropertiesPanel()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ProjectClip::audioThumbReady()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ProjectClip::updateStreamInfo(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void ProjectClip::boundsChanged(QVector<QPoint> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ProjectClip::registeredClipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void ProjectClip::firstFrameExported()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ProjectClip::masksUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
