/********************************************************************************
** Form generated from reading UI file 'addtrack_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ADDTRACK_UI_H
#define UI_ADDTRACK_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_AddTrack_UI
{
public:
    QGridLayout *gridLayout;
    KComboBox *before_select;
    QDialogButtonBox *buttonBox;
    KComboBox *comboTracks;
    QHBoxLayout *horizontalLayout_2;
    QLabel *name_label;
    QLineEdit *track_name;
    QSpinBox *tracks_count;
    QLabel *label;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QRadioButton *video_track;
    QRadioButton *audio_track;
    QRadioButton *av_track;
    QRadioButton *arec_track;
    QSpacerItem *horizontalSpacer;
    QListWidget *deleteTracks;

    void setupUi(QDialog *AddTrack_UI)
    {
        if (AddTrack_UI->objectName().isEmpty())
            AddTrack_UI->setObjectName("AddTrack_UI");
        AddTrack_UI->resize(611, 215);
        gridLayout = new QGridLayout(AddTrack_UI);
        gridLayout->setObjectName("gridLayout");
        before_select = new KComboBox(AddTrack_UI);
        before_select->addItem(QString());
        before_select->addItem(QString());
        before_select->setObjectName("before_select");

        gridLayout->addWidget(before_select, 0, 2, 1, 1);

        buttonBox = new QDialogButtonBox(AddTrack_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 4, 3, 1, 1);

        comboTracks = new KComboBox(AddTrack_UI);
        comboTracks->setObjectName("comboTracks");

        gridLayout->addWidget(comboTracks, 0, 3, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        name_label = new QLabel(AddTrack_UI);
        name_label->setObjectName("name_label");

        horizontalLayout_2->addWidget(name_label);

        track_name = new QLineEdit(AddTrack_UI);
        track_name->setObjectName("track_name");

        horizontalLayout_2->addWidget(track_name);


        gridLayout->addLayout(horizontalLayout_2, 3, 0, 1, 4);

        tracks_count = new QSpinBox(AddTrack_UI);
        tracks_count->setObjectName("tracks_count");
        tracks_count->setMinimum(1);
        tracks_count->setValue(1);

        gridLayout->addWidget(tracks_count, 0, 1, 1, 1);

        label = new QLabel(AddTrack_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 10, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        video_track = new QRadioButton(AddTrack_UI);
        video_track->setObjectName("video_track");
        video_track->setChecked(true);

        horizontalLayout->addWidget(video_track);

        audio_track = new QRadioButton(AddTrack_UI);
        audio_track->setObjectName("audio_track");

        horizontalLayout->addWidget(audio_track);

        av_track = new QRadioButton(AddTrack_UI);
        av_track->setObjectName("av_track");

        horizontalLayout->addWidget(av_track);

        arec_track = new QRadioButton(AddTrack_UI);
        arec_track->setObjectName("arec_track");

        horizontalLayout->addWidget(arec_track);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 4);

        deleteTracks = new QListWidget(AddTrack_UI);
        deleteTracks->setObjectName("deleteTracks");

        gridLayout->addWidget(deleteTracks, 1, 0, 1, 4);


        retranslateUi(AddTrack_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, AddTrack_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, AddTrack_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(AddTrack_UI);
    } // setupUi

    void retranslateUi(QDialog *AddTrack_UI)
    {
        before_select->setItemText(0, tr2i18n("Above", nullptr));
        before_select->setItemText(1, tr2i18n("Under", nullptr));

        name_label->setText(tr2i18n("Track name:", nullptr));
        tracks_count->setSuffix(tr2i18n(" track", nullptr));
        label->setText(tr2i18n("Insert:", nullptr));
        video_track->setText(tr2i18n("Video &track", nullptr));
        audio_track->setText(tr2i18n("A&udio track", nullptr));
        av_track->setText(tr2i18n("AV track", nullptr));
        arec_track->setText(tr2i18n("Au&dio record track", nullptr));
        (void)AddTrack_UI;
    } // retranslateUi

};

namespace Ui {
    class AddTrack_UI: public Ui_AddTrack_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ADDTRACK_UI_H

