/****************************************************************************
** Meta object code from reading C++ file 'archivewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/project/dialogs/archivewidget.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'archivewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ArchiveWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ArchiveWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13ArchiveWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ArchiveWidget",
        "archivingFinished",
        "",
        "archiveProgress",
        "extractingFinished",
        "showMessage",
        "slotCheckSpace",
        "slotStartArchiving",
        "firstPass",
        "slotArchivingFinished",
        "KJob*",
        "job",
        "finished",
        "slotArchivingProgress",
        "done",
        "r",
        "closeAccepted",
        "createArchive",
        "slotArchivingIntProgress",
        "slotArchivingBoolFinished",
        "result",
        "errorString",
        "slotStartExtracting",
        "doExtracting",
        "slotExtractingFinished",
        "slotExtractProgress",
        "openArchiveForExtraction",
        "slotDisplayMessage",
        "icon",
        "text",
        "slotJobResult",
        "success",
        "slotProxyOnly",
        "onlyProxy",
        "onlyTimelineItems",
        "onlyTimeline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'archivingFinished'
        QtMocHelpers::SignalData<void(bool, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'archiveProgress'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'extractingFinished'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotCheckSpace'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStartArchiving'
        QtMocHelpers::SlotData<bool(bool)>(7, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 8 },
        }}),
        // Slot 'slotStartArchiving'
        QtMocHelpers::SlotData<bool()>(7, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'slotArchivingFinished'
        QtMocHelpers::SlotData<void(KJob *, bool)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 11 }, { QMetaType::Bool, 12 },
        }}),
        // Slot 'slotArchivingFinished'
        QtMocHelpers::SlotData<void(KJob *)>(9, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotArchivingFinished'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotArchivingProgress'
        QtMocHelpers::SlotData<void(KJob *, qulonglong)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::ULongLong, 2 },
        }}),
        // Slot 'done'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'closeAccepted'
        QtMocHelpers::SlotData<bool()>(16, 2, QMC::AccessPrivate, QMetaType::Bool),
        // Slot 'createArchive'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotArchivingIntProgress'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotArchivingBoolFinished'
        QtMocHelpers::SlotData<void(bool, const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 20 }, { QMetaType::QString, 21 },
        }}),
        // Slot 'slotStartExtracting'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doExtracting'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExtractingFinished'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExtractProgress'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openArchiveForExtraction'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 28 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'slotJobResult'
        QtMocHelpers::SlotData<void(bool, const QString &)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 31 }, { QMetaType::QString, 29 },
        }}),
        // Slot 'slotProxyOnly'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'onlyTimelineItems'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 35 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ArchiveWidget, qt_meta_tag_ZN13ArchiveWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ArchiveWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ArchiveWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ArchiveWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ArchiveWidgetE_t>.metaTypes,
    nullptr
} };

void ArchiveWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ArchiveWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->archivingFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->archiveProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->extractingFinished(); break;
        case 3: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->slotCheckSpace(); break;
        case 5: { bool _r = _t->slotStartArchiving((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->slotStartArchiving();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->slotArchivingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->slotArchivingFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 9: _t->slotArchivingFinished(); break;
        case 10: _t->slotArchivingProgress((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<qulonglong>>(_a[2]))); break;
        case 11: _t->done((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: { bool _r = _t->closeAccepted();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->createArchive(); break;
        case 14: _t->slotArchivingIntProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->slotArchivingBoolFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: _t->slotStartExtracting(); break;
        case 17: _t->doExtracting(); break;
        case 18: _t->slotExtractingFinished(); break;
        case 19: _t->slotExtractProgress(); break;
        case 20: _t->openArchiveForExtraction(); break;
        case 21: _t->slotDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->slotJobResult((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->slotProxyOnly((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->onlyTimelineItems((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ArchiveWidget::*)(bool , const QString & )>(_a, &ArchiveWidget::archivingFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveWidget::*)(int )>(_a, &ArchiveWidget::archiveProgress, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveWidget::*)()>(_a, &ArchiveWidget::extractingFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ArchiveWidget::*)(const QString & , const QString & )>(_a, &ArchiveWidget::showMessage, 3))
            return;
    }
}

const QMetaObject *ArchiveWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ArchiveWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ArchiveWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ArchiveWidget_UI"))
        return static_cast< Ui::ArchiveWidget_UI*>(this);
    return QDialog::qt_metacast(_clname);
}

int ArchiveWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 25)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 25;
    }
    return _id;
}

// SIGNAL 0
void ArchiveWidget::archivingFinished(bool _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ArchiveWidget::archiveProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ArchiveWidget::extractingFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ArchiveWidget::showMessage(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
