/********************************************************************************
** Form generated from reading UI file 'customcamcorderproxy_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMCAMCORDERPROXY_UI_H
#define UI_CUSTOMCAMCORDERPROXY_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_CustomCamcorderProxy_UI
{
public:
    QGridLayout *gridLayout;
    QListWidget *profiles_list;
    QLabel *l_relPathOrigToProxy;
    QLineEdit *le_relPathOrigToProxy;
    QLabel *l_prefix_clip;
    QLineEdit *le_prefix_clip;
    QLabel *l_suffix_clip;
    QLineEdit *le_suffix_clip;
    QLabel *l_relPathProxyToOrig;
    QLineEdit *le_relPathProxyToOrig;
    QLabel *l_prefix_proxy;
    QLineEdit *le_prefix_proxy;
    QLabel *l_suffix_proxy;
    QLineEdit *le_suffix_proxy;
    QToolButton *button_add;
    QToolButton *button_remove;
    QSpacerItem *horizontalSpacer;
    QToolButton *button_reset;
    KMessageWidget *proxy_message;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomCamcorderProxy_UI)
    {
        if (CustomCamcorderProxy_UI->objectName().isEmpty())
            CustomCamcorderProxy_UI->setObjectName("CustomCamcorderProxy_UI");
        CustomCamcorderProxy_UI->resize(382, 502);
        gridLayout = new QGridLayout(CustomCamcorderProxy_UI);
        gridLayout->setObjectName("gridLayout");
        profiles_list = new QListWidget(CustomCamcorderProxy_UI);
        profiles_list->setObjectName("profiles_list");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(profiles_list->sizePolicy().hasHeightForWidth());
        profiles_list->setSizePolicy(sizePolicy);

        gridLayout->addWidget(profiles_list, 0, 0, 13, 4);

        l_relPathOrigToProxy = new QLabel(CustomCamcorderProxy_UI);
        l_relPathOrigToProxy->setObjectName("l_relPathOrigToProxy");

        gridLayout->addWidget(l_relPathOrigToProxy, 0, 4, 1, 1);

        le_relPathOrigToProxy = new QLineEdit(CustomCamcorderProxy_UI);
        le_relPathOrigToProxy->setObjectName("le_relPathOrigToProxy");

        gridLayout->addWidget(le_relPathOrigToProxy, 1, 4, 1, 1);

        l_prefix_clip = new QLabel(CustomCamcorderProxy_UI);
        l_prefix_clip->setObjectName("l_prefix_clip");

        gridLayout->addWidget(l_prefix_clip, 2, 4, 1, 1);

        le_prefix_clip = new QLineEdit(CustomCamcorderProxy_UI);
        le_prefix_clip->setObjectName("le_prefix_clip");

        gridLayout->addWidget(le_prefix_clip, 3, 4, 1, 1);

        l_suffix_clip = new QLabel(CustomCamcorderProxy_UI);
        l_suffix_clip->setObjectName("l_suffix_clip");

        gridLayout->addWidget(l_suffix_clip, 4, 4, 1, 1);

        le_suffix_clip = new QLineEdit(CustomCamcorderProxy_UI);
        le_suffix_clip->setObjectName("le_suffix_clip");

        gridLayout->addWidget(le_suffix_clip, 5, 4, 1, 1);

        l_relPathProxyToOrig = new QLabel(CustomCamcorderProxy_UI);
        l_relPathProxyToOrig->setObjectName("l_relPathProxyToOrig");

        gridLayout->addWidget(l_relPathProxyToOrig, 6, 4, 1, 1);

        le_relPathProxyToOrig = new QLineEdit(CustomCamcorderProxy_UI);
        le_relPathProxyToOrig->setObjectName("le_relPathProxyToOrig");

        gridLayout->addWidget(le_relPathProxyToOrig, 7, 4, 1, 1);

        l_prefix_proxy = new QLabel(CustomCamcorderProxy_UI);
        l_prefix_proxy->setObjectName("l_prefix_proxy");

        gridLayout->addWidget(l_prefix_proxy, 8, 4, 1, 1);

        le_prefix_proxy = new QLineEdit(CustomCamcorderProxy_UI);
        le_prefix_proxy->setObjectName("le_prefix_proxy");

        gridLayout->addWidget(le_prefix_proxy, 9, 4, 1, 1);

        l_suffix_proxy = new QLabel(CustomCamcorderProxy_UI);
        l_suffix_proxy->setObjectName("l_suffix_proxy");

        gridLayout->addWidget(l_suffix_proxy, 10, 4, 1, 1);

        le_suffix_proxy = new QLineEdit(CustomCamcorderProxy_UI);
        le_suffix_proxy->setObjectName("le_suffix_proxy");

        gridLayout->addWidget(le_suffix_proxy, 11, 4, 1, 1);

        button_add = new QToolButton(CustomCamcorderProxy_UI);
        button_add->setObjectName("button_add");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_add->setIcon(icon);

        gridLayout->addWidget(button_add, 13, 0, 1, 1);

        button_remove = new QToolButton(CustomCamcorderProxy_UI);
        button_remove->setObjectName("button_remove");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_remove->setIcon(icon1);

        gridLayout->addWidget(button_remove, 13, 1, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 13, 2, 1, 1);

        button_reset = new QToolButton(CustomCamcorderProxy_UI);
        button_reset->setObjectName("button_reset");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-reset");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_reset->setIcon(icon2);

        gridLayout->addWidget(button_reset, 13, 3, 1, 1);

        proxy_message = new KMessageWidget(CustomCamcorderProxy_UI);
        proxy_message->setObjectName("proxy_message");
        proxy_message->setWordWrap(true);
        proxy_message->setCloseButtonVisible(false);

        gridLayout->addWidget(proxy_message, 14, 0, 1, 5);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 12, 4, 1, 1);

        buttonBox = new QDialogButtonBox(CustomCamcorderProxy_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 15, 0, 1, 5);


        retranslateUi(CustomCamcorderProxy_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomCamcorderProxy_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomCamcorderProxy_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomCamcorderProxy_UI);
    } // setupUi

    void retranslateUi(QDialog *CustomCamcorderProxy_UI)
    {
        CustomCamcorderProxy_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        l_relPathOrigToProxy->setText(tr2i18n("Relative path from clip to proxy:", nullptr));
        l_prefix_clip->setText(tr2i18n("Prefix of clip:", nullptr));
        l_suffix_clip->setText(tr2i18n("Suffix of clip:", nullptr));
        l_relPathProxyToOrig->setText(tr2i18n("Relative path from proxy to clip:", nullptr));
        l_prefix_proxy->setText(tr2i18n("Prefix of proxy:", nullptr));
        l_suffix_proxy->setText(tr2i18n("Suffix of proxy:", nullptr));
#if QT_CONFIG(tooltip)
        button_add->setToolTip(tr2i18n("Add new profile", nullptr));
#endif // QT_CONFIG(tooltip)
        button_add->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        button_remove->setToolTip(tr2i18n("Delete profile", nullptr));
#endif // QT_CONFIG(tooltip)
        button_remove->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        button_reset->setToolTip(tr2i18n("Reset all profiles", nullptr));
#endif // QT_CONFIG(tooltip)
        button_reset->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomCamcorderProxy_UI: public Ui_CustomCamcorderProxy_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMCAMCORDERPROXY_UI_H

