/****************************************************************************
** Meta object code from reading C++ file 'videowidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/monitor/videowidget.h"
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'videowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11VideoWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto VideoWidget::qt_create_metaobjectdata<qt_meta_tag_ZN11VideoWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "VideoWidget",
        "frameDisplayed",
        "",
        "SharedFrame",
        "frame",
        "frameRendered",
        "pos",
        "imageReady",
        "dragStarted",
        "seekTo",
        "x",
        "gpuNotSupported",
        "started",
        "paused",
        "playing",
        "zoomChanged",
        "zoomRatio",
        "monitorPlay",
        "switchFullScreen",
        "minimizeOnly",
        "mouseSeek",
        "eventDelta",
        "modifiers",
        "startDrag",
        "analyseFrame",
        "QImage",
        "showContextMenu",
        "QPoint",
        "lockMonitor",
        "passKeyEvent",
        "QKeyEvent*",
        "panView",
        "diff",
        "reconnectWindow",
        "initialize",
        "beforeRendering",
        "renderVideo",
        "onFrameDisplayed",
        "requestSeek",
        "position",
        "noAudioScrub",
        "setZoom",
        "zoom",
        "force",
        "setOffsetX",
        "horizontalScrollValue",
        "horizontalScrollMaximum",
        "verticalScrollBarWidth",
        "setOffsetY",
        "verticalScrollValue",
        "verticalScrollMaximum",
        "horizontalScrollBarHeight",
        "slotZoom",
        "zoomIn",
        "slotZoomReset",
        "releaseAnalyse",
        "switchPlay",
        "play",
        "speed",
        "reloadProfile",
        "updateScaling",
        "resetAspect",
        "resizeVideo",
        "width",
        "height",
        "reconfigure",
        "refresh",
        "switchRecordState",
        "on",
        "forceRefreshZoom",
        "blankCursor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameDisplayed'
        QtMocHelpers::SignalData<void(const SharedFrame &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'frameRendered'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'imageReady'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragStarted'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekTo'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 },
        }}),
        // Signal 'gpuNotSupported'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'started'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'paused'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'playing'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'zoomChanged'
        QtMocHelpers::SignalData<void(float)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 16 },
        }}),
        // Signal 'monitorPlay'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchFullScreen'
        QtMocHelpers::SignalData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Signal 'switchFullScreen'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'mouseSeek'
        QtMocHelpers::SignalData<void(int, uint)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 }, { QMetaType::UInt, 22 },
        }}),
        // Signal 'startDrag'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'analyseFrame'
        QtMocHelpers::SignalData<void(const QImage &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
        // Signal 'showContextMenu'
        QtMocHelpers::SignalData<void(const QPoint &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 2 },
        }}),
        // Signal 'lockMonitor'
        QtMocHelpers::SignalData<void(bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'passKeyEvent'
        QtMocHelpers::SignalData<void(QKeyEvent *)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 2 },
        }}),
        // Signal 'panView'
        QtMocHelpers::SignalData<void(const QPoint &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 32 },
        }}),
        // Signal 'reconnectWindow'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initialize'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'beforeRendering'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'renderVideo'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onFrameDisplayed'
        QtMocHelpers::SlotData<void(const SharedFrame &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'requestSeek'
        QtMocHelpers::SlotData<void(int, bool)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 }, { QMetaType::Bool, 40 },
        }}),
        // Slot 'requestSeek'
        QtMocHelpers::SlotData<void(int)>(38, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(float, bool)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Float, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'setZoom'
        QtMocHelpers::SlotData<void(float)>(41, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Float, 42 },
        }}),
        // Slot 'setOffsetX'
        QtMocHelpers::SlotData<void(int, int, int)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 45 }, { QMetaType::Int, 46 }, { QMetaType::Int, 47 },
        }}),
        // Slot 'setOffsetY'
        QtMocHelpers::SlotData<void(int, int, int)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 49 }, { QMetaType::Int, 50 }, { QMetaType::Int, 51 },
        }}),
        // Slot 'slotZoom'
        QtMocHelpers::SlotData<void(bool)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 53 },
        }}),
        // Slot 'slotZoomReset'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'releaseAnalyse'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'switchPlay'
        QtMocHelpers::SlotData<bool(bool, double)>(56, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 57 }, { QMetaType::Double, 58 },
        }}),
        // Slot 'switchPlay'
        QtMocHelpers::SlotData<bool(bool)>(56, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 57 },
        }}),
        // Slot 'reloadProfile'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateScaling'
        QtMocHelpers::SlotData<bool()>(60, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'resetAspect'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resizeVideo'
        QtMocHelpers::SlotData<void(int, int)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::Int, 64 },
        }}),
        // Slot 'reconfigure'
        QtMocHelpers::SlotData<int()>(65, 2, QMC::AccessPrivate, QMetaType::Int),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'switchRecordState'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Slot 'forceRefreshZoom'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'blankCursor'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'zoom'
        QtMocHelpers::PropertyData<float>(42, QMetaType::Float, QMC::DefaultPropertyFlags, 9),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<VideoWidget, qt_meta_tag_ZN11VideoWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject VideoWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideoWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideoWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11VideoWidgetE_t>.metaTypes,
    nullptr
} };

void VideoWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<VideoWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 1: _t->frameRendered((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->imageReady(); break;
        case 3: _t->dragStarted(); break;
        case 4: _t->seekTo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->gpuNotSupported(); break;
        case 6: _t->started(); break;
        case 7: _t->paused(); break;
        case 8: _t->playing(); break;
        case 9: _t->zoomChanged((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 10: _t->monitorPlay(); break;
        case 11: _t->switchFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->switchFullScreen(); break;
        case 13: _t->mouseSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 14: _t->startDrag(); break;
        case 15: _t->analyseFrame((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 16: _t->showContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 17: _t->lockMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->passKeyEvent((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 19: _t->panView((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 20: _t->reconnectWindow(); break;
        case 21: _t->initialize(); break;
        case 22: _t->beforeRendering(); break;
        case 23: _t->renderVideo(); break;
        case 24: _t->onFrameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 25: _t->requestSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->requestSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 27: _t->setZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 28: _t->setZoom((*reinterpret_cast<std::add_pointer_t<float>>(_a[1]))); break;
        case 29: _t->setOffsetX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 30: _t->setOffsetY((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 31: _t->slotZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->slotZoomReset(); break;
        case 33: _t->releaseAnalyse(); break;
        case 34: { bool _r = _t->switchPlay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 35: { bool _r = _t->switchPlay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 36: _t->reloadProfile(); break;
        case 37: { bool _r = _t->updateScaling();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: _t->resetAspect(); break;
        case 39: _t->resizeVideo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: { int _r = _t->reconfigure();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 41: _t->refresh(); break;
        case 42: _t->switchRecordState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->forceRefreshZoom(); break;
        case 44: _t->blankCursor(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const SharedFrame & )>(_a, &VideoWidget::frameDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(int )>(_a, &VideoWidget::frameRendered, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::imageReady, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::dragStarted, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(int )>(_a, &VideoWidget::seekTo, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::gpuNotSupported, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::started, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::paused, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::playing, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(float )>(_a, &VideoWidget::zoomChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::monitorPlay, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(bool )>(_a, &VideoWidget::switchFullScreen, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(int , uint )>(_a, &VideoWidget::mouseSeek, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::startDrag, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const QImage & )>(_a, &VideoWidget::analyseFrame, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const QPoint & )>(_a, &VideoWidget::showContextMenu, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(bool )>(_a, &VideoWidget::lockMonitor, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(QKeyEvent * )>(_a, &VideoWidget::passKeyEvent, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)(const QPoint & )>(_a, &VideoWidget::panView, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (VideoWidget::*)()>(_a, &VideoWidget::reconnectWindow, 20))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<float*>(_v) = _t->zoom(); break;
        default: break;
        }
    }
}

const QMetaObject *VideoWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *VideoWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11VideoWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QQuickWidget::qt_metacast(_clname);
}

int VideoWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 45)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 45;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 45)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 45;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void VideoWidget::frameDisplayed(const SharedFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void VideoWidget::frameRendered(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void VideoWidget::imageReady()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void VideoWidget::dragStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void VideoWidget::seekTo(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void VideoWidget::gpuNotSupported()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void VideoWidget::started()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void VideoWidget::paused()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void VideoWidget::playing()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void VideoWidget::zoomChanged(float _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void VideoWidget::monitorPlay()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void VideoWidget::switchFullScreen(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 13
void VideoWidget::mouseSeek(int _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void VideoWidget::startDrag()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void VideoWidget::analyseFrame(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void VideoWidget::showContextMenu(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void VideoWidget::lockMonitor(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 18
void VideoWidget::passKeyEvent(QKeyEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void VideoWidget::panView(const QPoint & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void VideoWidget::reconnectWindow()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
namespace {
struct qt_meta_tag_ZN12RenderThreadE_t {};
} // unnamed namespace

template <> constexpr inline auto RenderThread::qt_create_metaobjectdata<qt_meta_tag_ZN12RenderThreadE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RenderThread"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenderThread, qt_meta_tag_ZN12RenderThreadE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RenderThread::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderThreadE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderThreadE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12RenderThreadE_t>.metaTypes,
    nullptr
} };

void RenderThread::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenderThread *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *RenderThread::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RenderThread::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderThreadE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int RenderThread::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13FrameRendererE_t {};
} // unnamed namespace

template <> constexpr inline auto FrameRenderer::qt_create_metaobjectdata<qt_meta_tag_ZN13FrameRendererE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "FrameRenderer",
        "frameDisplayed",
        "",
        "SharedFrame",
        "frame",
        "imageReady",
        "showFrame",
        "Mlt::Frame"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameDisplayed'
        QtMocHelpers::SignalData<void(const SharedFrame &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'imageReady'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'showFrame'
        QtMocHelpers::MethodData<void(Mlt::Frame)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FrameRenderer, qt_meta_tag_ZN13FrameRendererE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject FrameRenderer::staticMetaObject = { {
    QMetaObject::SuperData::link<QThread::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FrameRendererE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FrameRendererE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13FrameRendererE_t>.metaTypes,
    nullptr
} };

void FrameRenderer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameRenderer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 1: _t->imageReady(); break;
        case 2: _t->showFrame((*reinterpret_cast<std::add_pointer_t<Mlt::Frame>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (FrameRenderer::*)(const SharedFrame & )>(_a, &FrameRenderer::frameDisplayed, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (FrameRenderer::*)()>(_a, &FrameRenderer::imageReady, 1))
            return;
    }
}

const QMetaObject *FrameRenderer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *FrameRenderer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13FrameRendererE_t>.strings))
        return static_cast<void*>(this);
    return QThread::qt_metacast(_clname);
}

int FrameRenderer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QThread::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void FrameRenderer::frameDisplayed(const SharedFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void FrameRenderer::imageReady()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
