/********************************************************************************
** Form generated from reading UI file 'clipjobmanager_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPJOBMANAGER_UI_H
#define UI_CLIPJOBMANAGER_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ClipJobManager_UI
{
public:
    QGridLayout *gridLayout_5;
    QGroupBox *param_box;
    QGridLayout *gridLayout_4;
    QLabel *label_2;
    KUrlRequester *url_binary;
    KMessageWidget *script_message;
    QToolButton *info_button;
    QLabel *label_3;
    QPlainTextEdit *job_params;
    KMessageWidget *info_message;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QPlainTextEdit *param1_list;
    QRadioButton *param1_islist;
    QSpacerItem *verticalSpacer;
    QLineEdit *param1_name;
    QRadioButton *param1_isfile;
    QRadioButton *param1_isframe;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_3;
    QSpacerItem *verticalSpacer_2;
    QPlainTextEdit *param2_list;
    QLineEdit *param2_name;
    QRadioButton *param2_islist;
    QRadioButton *param2_isfile;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_4;
    QLineEdit *destination_pattern;
    QPlainTextEdit *taskDescription;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QToolButton *button_add;
    QToolButton *button_delete;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;
    QGroupBox *folder_box;
    QGridLayout *gridLayout;
    QRadioButton *radio_replace;
    QCheckBox *bin_subfolder;
    QRadioButton *radio_folder;
    QComboBox *combo_folder;
    QLineEdit *folder_name;
    QListWidget *job_list;
    QLabel *label;
    QGroupBox *clip_types;
    QVBoxLayout *verticalLayout;
    QCheckBox *enable_video;
    QCheckBox *enable_audio;
    QCheckBox *enable_image;

    void setupUi(QDialog *ClipJobManager_UI)
    {
        if (ClipJobManager_UI->objectName().isEmpty())
            ClipJobManager_UI->setObjectName("ClipJobManager_UI");
        ClipJobManager_UI->resize(853, 715);
        gridLayout_5 = new QGridLayout(ClipJobManager_UI);
        gridLayout_5->setObjectName("gridLayout_5");
        param_box = new QGroupBox(ClipJobManager_UI);
        param_box->setObjectName("param_box");
        gridLayout_4 = new QGridLayout(param_box);
        gridLayout_4->setObjectName("gridLayout_4");
        label_2 = new QLabel(param_box);
        label_2->setObjectName("label_2");

        gridLayout_4->addWidget(label_2, 0, 0, 1, 2);

        url_binary = new KUrlRequester(param_box);
        url_binary->setObjectName("url_binary");

        gridLayout_4->addWidget(url_binary, 1, 0, 1, 3);

        script_message = new KMessageWidget(param_box);
        script_message->setObjectName("script_message");
        script_message->setCloseButtonVisible(false);
        script_message->setMessageType(KMessageWidget::Warning);

        gridLayout_4->addWidget(script_message, 2, 0, 1, 3);

        info_button = new QToolButton(param_box);
        info_button->setObjectName("info_button");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        info_button->setIcon(icon);
        info_button->setCheckable(true);

        gridLayout_4->addWidget(info_button, 3, 0, 1, 1);

        label_3 = new QLabel(param_box);
        label_3->setObjectName("label_3");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(label_3, 3, 1, 1, 1);

        job_params = new QPlainTextEdit(param_box);
        job_params->setObjectName("job_params");

        gridLayout_4->addWidget(job_params, 4, 0, 1, 3);

        info_message = new KMessageWidget(param_box);
        info_message->setObjectName("info_message");
        info_message->setWordWrap(true);
        info_message->setCloseButtonVisible(false);

        gridLayout_4->addWidget(info_message, 5, 0, 1, 3);

        groupBox_2 = new QGroupBox(param_box);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        param1_list = new QPlainTextEdit(groupBox_2);
        param1_list->setObjectName("param1_list");
        param1_list->setEnabled(false);

        gridLayout_2->addWidget(param1_list, 0, 1, 5, 1);

        param1_islist = new QRadioButton(groupBox_2);
        param1_islist->setObjectName("param1_islist");

        gridLayout_2->addWidget(param1_islist, 2, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 4, 0, 1, 1);

        param1_name = new QLineEdit(groupBox_2);
        param1_name->setObjectName("param1_name");

        gridLayout_2->addWidget(param1_name, 0, 0, 1, 1);

        param1_isfile = new QRadioButton(groupBox_2);
        param1_isfile->setObjectName("param1_isfile");
        param1_isfile->setChecked(true);

        gridLayout_2->addWidget(param1_isfile, 1, 0, 1, 1);

        param1_isframe = new QRadioButton(groupBox_2);
        param1_isframe->setObjectName("param1_isframe");

        gridLayout_2->addWidget(param1_isframe, 3, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_2, 6, 0, 1, 2);

        groupBox_3 = new QGroupBox(param_box);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_3 = new QGridLayout(groupBox_3);
        gridLayout_3->setObjectName("gridLayout_3");
        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer_2, 3, 0, 1, 1);

        param2_list = new QPlainTextEdit(groupBox_3);
        param2_list->setObjectName("param2_list");
        param2_list->setEnabled(false);

        gridLayout_3->addWidget(param2_list, 0, 1, 4, 1);

        param2_name = new QLineEdit(groupBox_3);
        param2_name->setObjectName("param2_name");

        gridLayout_3->addWidget(param2_name, 0, 0, 1, 1);

        param2_islist = new QRadioButton(groupBox_3);
        param2_islist->setObjectName("param2_islist");

        gridLayout_3->addWidget(param2_islist, 2, 0, 1, 1);

        param2_isfile = new QRadioButton(groupBox_3);
        param2_isfile->setObjectName("param2_isfile");
        param2_isfile->setChecked(true);

        gridLayout_3->addWidget(param2_isfile, 1, 0, 1, 1);


        gridLayout_4->addWidget(groupBox_3, 6, 2, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_4 = new QLabel(param_box);
        label_4->setObjectName("label_4");

        horizontalLayout_2->addWidget(label_4);

        destination_pattern = new QLineEdit(param_box);
        destination_pattern->setObjectName("destination_pattern");

        horizontalLayout_2->addWidget(destination_pattern);


        gridLayout_4->addLayout(horizontalLayout_2, 7, 0, 1, 3);


        gridLayout_5->addWidget(param_box, 0, 1, 6, 1);

        taskDescription = new QPlainTextEdit(ClipJobManager_UI);
        taskDescription->setObjectName("taskDescription");

        gridLayout_5->addWidget(taskDescription, 3, 0, 1, 1);

        label_5 = new QLabel(ClipJobManager_UI);
        label_5->setObjectName("label_5");

        gridLayout_5->addWidget(label_5, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        button_add = new QToolButton(ClipJobManager_UI);
        button_add->setObjectName("button_add");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../../../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_add->setIcon(icon1);

        horizontalLayout->addWidget(button_add);

        button_delete = new QToolButton(ClipJobManager_UI);
        button_delete->setObjectName("button_delete");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("../../../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_delete->setIcon(icon2);

        horizontalLayout->addWidget(button_delete);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(ClipJobManager_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        horizontalLayout->addWidget(buttonBox);


        gridLayout_5->addLayout(horizontalLayout, 6, 0, 1, 2);

        folder_box = new QGroupBox(ClipJobManager_UI);
        folder_box->setObjectName("folder_box");
        gridLayout = new QGridLayout(folder_box);
        gridLayout->setObjectName("gridLayout");
        radio_replace = new QRadioButton(folder_box);
        radio_replace->setObjectName("radio_replace");

        gridLayout->addWidget(radio_replace, 0, 0, 1, 2);

        bin_subfolder = new QCheckBox(folder_box);
        bin_subfolder->setObjectName("bin_subfolder");
        bin_subfolder->setEnabled(false);

        gridLayout->addWidget(bin_subfolder, 4, 0, 1, 1);

        radio_folder = new QRadioButton(folder_box);
        radio_folder->setObjectName("radio_folder");

        gridLayout->addWidget(radio_folder, 1, 0, 1, 1);

        combo_folder = new QComboBox(folder_box);
        combo_folder->addItem(QString());
        combo_folder->addItem(QString());
        combo_folder->setObjectName("combo_folder");
        combo_folder->setEnabled(false);

        gridLayout->addWidget(combo_folder, 3, 0, 1, 1);

        folder_name = new QLineEdit(folder_box);
        folder_name->setObjectName("folder_name");
        folder_name->setEnabled(false);

        gridLayout->addWidget(folder_name, 5, 0, 1, 1);


        gridLayout_5->addWidget(folder_box, 5, 0, 1, 1);

        job_list = new QListWidget(ClipJobManager_UI);
        job_list->setObjectName("job_list");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(job_list->sizePolicy().hasHeightForWidth());
        job_list->setSizePolicy(sizePolicy1);

        gridLayout_5->addWidget(job_list, 1, 0, 1, 1);

        label = new QLabel(ClipJobManager_UI);
        label->setObjectName("label");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy2);

        gridLayout_5->addWidget(label, 0, 0, 1, 1);

        clip_types = new QGroupBox(ClipJobManager_UI);
        clip_types->setObjectName("clip_types");
        verticalLayout = new QVBoxLayout(clip_types);
        verticalLayout->setObjectName("verticalLayout");
        enable_video = new QCheckBox(clip_types);
        enable_video->setObjectName("enable_video");

        verticalLayout->addWidget(enable_video);

        enable_audio = new QCheckBox(clip_types);
        enable_audio->setObjectName("enable_audio");

        verticalLayout->addWidget(enable_audio);

        enable_image = new QCheckBox(clip_types);
        enable_image->setObjectName("enable_image");

        verticalLayout->addWidget(enable_image);


        gridLayout_5->addWidget(clip_types, 4, 0, 1, 1);


        retranslateUi(ClipJobManager_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ClipJobManager_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipJobManager_UI, qOverload<>(&QDialog::reject));
        QObject::connect(radio_folder, &QRadioButton::toggled, bin_subfolder, &QCheckBox::setEnabled);
        QObject::connect(radio_folder, &QRadioButton::toggled, combo_folder, &QComboBox::setEnabled);
        QObject::connect(bin_subfolder, &QCheckBox::toggled, folder_name, &QLineEdit::setEnabled);
        QObject::connect(info_button, SIGNAL(toggled(bool)), info_message, SLOT(setVisible(bool)));
        QObject::connect(param1_islist, &QRadioButton::toggled, param1_list, &QPlainTextEdit::setEnabled);
        QObject::connect(param2_islist, &QRadioButton::toggled, param2_list, &QPlainTextEdit::setEnabled);

        QMetaObject::connectSlotsByName(ClipJobManager_UI);
    } // setupUi

    void retranslateUi(QDialog *ClipJobManager_UI)
    {
        ClipJobManager_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        param_box->setTitle(tr2i18n("Job parameters", nullptr));
        label_2->setText(tr2i18n("Executable", nullptr));
        info_button->setText(tr2i18n("...", nullptr));
        label_3->setText(tr2i18n("Arguments", nullptr));
        info_message->setText(tr2i18n("In the arguments, the following options are available: <ul><li><b>{source}</b> will be replaced by the Bin Clip source file path</li><li><b>{param1}</b> will be replaced by the first parameter value</li><li><b>{param2}</b> will be replaced by the second parameter value</li><li><b>{output}</b> will be replaced by the output file name</li></ul>", nullptr));
        groupBox_2->setTitle(tr2i18n("Parameter 1 {param1}", nullptr));
        param1_list->setPlaceholderText(tr2i18n("List of options", nullptr));
        param1_islist->setText(tr2i18n("Request option from list", nullptr));
        param1_name->setPlaceholderText(tr2i18n("Parameter description", nullptr));
        param1_isfile->setText(tr2i18n("Request file path", nullptr));
        param1_isframe->setText(tr2i18n("Current clip frame", nullptr));
        groupBox_3->setTitle(tr2i18n("Parameter 2 {param2}", nullptr));
        param2_list->setPlaceholderText(tr2i18n("List of options", nullptr));
        param2_name->setPlaceholderText(tr2i18n("Parameter description", nullptr));
        param2_islist->setText(tr2i18n("Request option from list", nullptr));
        param2_isfile->setText(tr2i18n("Request file path", nullptr));
        label_4->setText(tr2i18n("Output file extension", nullptr));
        taskDescription->setPlaceholderText(tr2i18n("Optional description that will show up if a parameter is requested", nullptr));
        label_5->setText(tr2i18n("Job Description", nullptr));
        button_add->setText(tr2i18n("...", nullptr));
        button_delete->setText(tr2i18n("...", nullptr));
        folder_box->setTitle(tr2i18n("Project Bin behavior on completion", nullptr));
        radio_replace->setText(tr2i18n("Replace original with result", nullptr));
        bin_subfolder->setText(tr2i18n("Use a subfolder", nullptr));
        radio_folder->setText(tr2i18n("Put resulting clip in a folder", nullptr));
        combo_folder->setItemText(0, tr2i18n("Placed at top level", nullptr));
        combo_folder->setItemText(1, tr2i18n("Placed in the original clip folder", nullptr));

        folder_name->setPlaceholderText(tr2i18n("Folder name", nullptr));
        label->setText(tr2i18n("Custom clip jobs", nullptr));
        clip_types->setTitle(tr2i18n("Applies to", nullptr));
        enable_video->setText(tr2i18n("Video", nullptr));
        enable_audio->setText(tr2i18n("Audio", nullptr));
        enable_image->setText(tr2i18n("Images", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClipJobManager_UI: public Ui_ClipJobManager_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLIPJOBMANAGER_UI_H

