/****************************************************************************
** Meta object code from reading C++ file 'graphicsscenerectmove.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/titler/graphicsscenerectmove.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'graphicsscenerectmove.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MyTextItemE_t {};
} // unnamed namespace

template <> constexpr inline auto MyTextItem::qt_create_metaobjectdata<qt_meta_tag_ZN10MyTextItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MyTextItem",
        "doUpdateGeometry",
        "",
        "updateGeometry"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'doUpdateGeometry'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateGeometry'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MyTextItem, qt_meta_tag_ZN10MyTextItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MyTextItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsTextItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTextItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTextItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MyTextItemE_t>.metaTypes,
    nullptr
} };

void MyTextItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MyTextItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->doUpdateGeometry(); break;
        case 1: _t->updateGeometry(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *MyTextItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MyTextItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTextItemE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsTextItem::qt_metacast(_clname);
}

int MyTextItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsTextItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN21GraphicsSceneRectMoveE_t {};
} // unnamed namespace

template <> constexpr inline auto GraphicsSceneRectMove::qt_create_metaobjectdata<qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GraphicsSceneRectMove",
        "itemMoved",
        "",
        "sceneZoom",
        "newRect",
        "QGraphicsRectItem*",
        "newEllipse",
        "QGraphicsEllipseItem*",
        "newText",
        "MyTextItem*",
        "scalePixmap",
        "QGraphicsItem*",
        "item",
        "scalex",
        "scaley",
        "resizeModes",
        "resize",
        "center",
        "actionFinished",
        "doubleClickEvent",
        "slotUpdateFontSize",
        "s",
        "slotUseGrid",
        "enableGrid"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemMoved'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sceneZoom'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'newRect'
        QtMocHelpers::SignalData<void(QGraphicsRectItem *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'newEllipse'
        QtMocHelpers::SignalData<void(QGraphicsEllipseItem *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Signal 'newText'
        QtMocHelpers::SignalData<void(MyTextItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'scalePixmap'
        QtMocHelpers::SignalData<void(QGraphicsItem *, double, double, enum resizeModes, bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Double, 13 }, { QMetaType::Double, 14 }, { 0x80000000 | 15, 16 },
            { QMetaType::Bool, 17 },
        }}),
        // Signal 'scalePixmap'
        QtMocHelpers::SignalData<void(QGraphicsItem *, double, double, enum resizeModes)>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 11, 12 }, { QMetaType::Double, 13 }, { QMetaType::Double, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'actionFinished'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'doubleClickEvent'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateFontSize'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 21 },
        }}),
        // Slot 'slotUseGrid'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GraphicsSceneRectMove, qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GraphicsSceneRectMove::staticMetaObject = { {
    QMetaObject::SuperData::link<QGraphicsScene::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>.metaTypes,
    nullptr
} };

void GraphicsSceneRectMove::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GraphicsSceneRectMove *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemMoved(); break;
        case 1: _t->sceneZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->newRect((*reinterpret_cast<std::add_pointer_t<QGraphicsRectItem*>>(_a[1]))); break;
        case 3: _t->newEllipse((*reinterpret_cast<std::add_pointer_t<QGraphicsEllipseItem*>>(_a[1]))); break;
        case 4: _t->newText((*reinterpret_cast<std::add_pointer_t<MyTextItem*>>(_a[1]))); break;
        case 5: _t->scalePixmap((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<enum resizeModes>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 6: _t->scalePixmap((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<enum resizeModes>>(_a[4]))); break;
        case 7: _t->actionFinished(); break;
        case 8: _t->doubleClickEvent(); break;
        case 9: _t->slotUpdateFontSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->slotUseGrid((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MyTextItem* >(); break;
            }
            break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)()>(_a, &GraphicsSceneRectMove::itemMoved, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)(bool )>(_a, &GraphicsSceneRectMove::sceneZoom, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)(QGraphicsRectItem * )>(_a, &GraphicsSceneRectMove::newRect, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)(QGraphicsEllipseItem * )>(_a, &GraphicsSceneRectMove::newEllipse, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)(MyTextItem * )>(_a, &GraphicsSceneRectMove::newText, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)(QGraphicsItem * , double , double , resizeModes , bool )>(_a, &GraphicsSceneRectMove::scalePixmap, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)()>(_a, &GraphicsSceneRectMove::actionFinished, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (GraphicsSceneRectMove::*)()>(_a, &GraphicsSceneRectMove::doubleClickEvent, 8))
            return;
    }
}

const QMetaObject *GraphicsSceneRectMove::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GraphicsSceneRectMove::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GraphicsSceneRectMoveE_t>.strings))
        return static_cast<void*>(this);
    return QGraphicsScene::qt_metacast(_clname);
}

int GraphicsSceneRectMove::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QGraphicsScene::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void GraphicsSceneRectMove::itemMoved()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void GraphicsSceneRectMove::sceneZoom(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void GraphicsSceneRectMove::newRect(QGraphicsRectItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void GraphicsSceneRectMove::newEllipse(QGraphicsEllipseItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void GraphicsSceneRectMove::newText(MyTextItem * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void GraphicsSceneRectMove::scalePixmap(QGraphicsItem * _t1, double _t2, double _t3, resizeModes _t4, bool _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 7
void GraphicsSceneRectMove::actionFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void GraphicsSceneRectMove::doubleClickEvent()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
