/****************************************************************************
** Meta object code from reading C++ file 'abstractmonitor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/monitor/abstractmonitor.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractmonitor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AbstractRenderE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractRender::qt_create_metaobjectdata<qt_meta_tag_ZN14AbstractRenderE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractRender",
        "frameUpdated",
        "",
        "QImage",
        "audioSamplesSignal",
        "audioShortVector",
        "scopesClear"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameUpdated'
        QtMocHelpers::SignalData<void(const QImage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'audioSamplesSignal'
        QtMocHelpers::SignalData<void(const audioShortVector &, int, int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'scopesClear'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractRender, qt_meta_tag_ZN14AbstractRenderE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractRender::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractRenderE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractRenderE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AbstractRenderE_t>.metaTypes,
    nullptr
} };

void AbstractRender::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractRender *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameUpdated((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->audioSamplesSignal((*reinterpret_cast<std::add_pointer_t<audioShortVector>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 2: _t->scopesClear(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractRender::*)(const QImage & )>(_a, &AbstractRender::frameUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractRender::*)(const audioShortVector & , int , int , int )>(_a, &AbstractRender::audioSamplesSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractRender::*)()>(_a, &AbstractRender::scopesClear, 2))
            return;
    }
}

const QMetaObject *AbstractRender::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractRender::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AbstractRenderE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractRender::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void AbstractRender::frameUpdated(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractRender::audioSamplesSignal(const audioShortVector & _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void AbstractRender::scopesClear()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN15AbstractMonitorE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractMonitor::qt_create_metaobjectdata<qt_meta_tag_ZN15AbstractMonitorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractMonitor",
        "frameUpdated",
        "",
        "QImage",
        "audioSamplesSignal",
        "audioShortVector",
        "scopesClear",
        "stop",
        "start",
        "slotPlay",
        "slotRewind",
        "speed",
        "slotForward",
        "allowNormalPlay",
        "refreshMonitorIfActive",
        "directUpdate",
        "slotMouseSeek",
        "eventDelta",
        "modifiers",
        "slotActivateMonitor",
        "slotTemporaryActivateMonitor",
        "slotSwitchFullScreen",
        "minimizeOnly"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'frameUpdated'
        QtMocHelpers::SignalData<void(const QImage &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'audioSamplesSignal'
        QtMocHelpers::SignalData<void(const audioShortVector &, int, int, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'scopesClear'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlay'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRewind'
        QtMocHelpers::SlotData<void(double)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 },
        }}),
        // Slot 'slotRewind'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void(double, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 11 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void(double)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Double, 11 },
        }}),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'refreshMonitorIfActive'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'refreshMonitorIfActive'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotMouseSeek'
        QtMocHelpers::SlotData<void(int, uint)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 }, { QMetaType::UInt, 18 },
        }}),
        // Slot 'slotActivateMonitor'
        QtMocHelpers::SlotData<bool()>(19, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotTemporaryActivateMonitor'
        QtMocHelpers::SlotData<bool()>(20, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'slotSwitchFullScreen'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
        // Slot 'slotSwitchFullScreen'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractMonitor, qt_meta_tag_ZN15AbstractMonitorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractMonitor::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractMonitorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractMonitorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15AbstractMonitorE_t>.metaTypes,
    nullptr
} };

void AbstractMonitor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractMonitor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->frameUpdated((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 1: _t->audioSamplesSignal((*reinterpret_cast<std::add_pointer_t<audioShortVector>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 2: _t->scopesClear(); break;
        case 3: _t->stop(); break;
        case 4: _t->start(); break;
        case 5: _t->slotPlay(); break;
        case 6: _t->slotRewind((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 7: _t->slotRewind(); break;
        case 8: _t->slotForward((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->slotForward((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 10: _t->slotForward(); break;
        case 11: _t->refreshMonitorIfActive((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->refreshMonitorIfActive(); break;
        case 13: _t->slotMouseSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 14: { bool _r = _t->slotActivateMonitor();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->slotTemporaryActivateMonitor();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->slotSwitchFullScreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->slotSwitchFullScreen(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractMonitor::*)(const QImage & )>(_a, &AbstractMonitor::frameUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMonitor::*)(const audioShortVector & , int , int , int )>(_a, &AbstractMonitor::audioSamplesSignal, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractMonitor::*)()>(_a, &AbstractMonitor::scopesClear, 2))
            return;
    }
}

const QMetaObject *AbstractMonitor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractMonitor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15AbstractMonitorE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int AbstractMonitor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    return _id;
}

// SIGNAL 0
void AbstractMonitor::frameUpdated(const QImage & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractMonitor::audioSamplesSignal(const audioShortVector & _t1, int _t2, int _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 2
void AbstractMonitor::scopesClear()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
