/********************************************************************************
** Form generated from reading UI file 'clipdurationdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPDURATIONDIALOG_UI_H
#define UI_CLIPDURATIONDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_ClipDurationDialog_UI
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QCheckBox *duration_for_all;
    QLabel *crop_label;
    QLabel *position_label;
    KMessageWidget *mode_info;
    TimecodeDisplay *m_dur;
    QSpacerItem *verticalSpacer;
    TimecodeDisplay *m_pos;
    TimecodeDisplay *m_cropEnd;
    QLabel *duration_label;
    QLabel *end_label;
    TimecodeDisplay *m_cropStart;
    QCheckBox *ripple_resize;

    void setupUi(QDialog *ClipDurationDialog_UI)
    {
        if (ClipDurationDialog_UI->objectName().isEmpty())
            ClipDurationDialog_UI->setObjectName("ClipDurationDialog_UI");
        ClipDurationDialog_UI->resize(467, 302);
        gridLayout = new QGridLayout(ClipDurationDialog_UI);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(ClipDurationDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 9, 0, 1, 2);

        duration_for_all = new QCheckBox(ClipDurationDialog_UI);
        duration_for_all->setObjectName("duration_for_all");

        gridLayout->addWidget(duration_for_all, 5, 0, 1, 2);

        crop_label = new QLabel(ClipDurationDialog_UI);
        crop_label->setObjectName("crop_label");

        gridLayout->addWidget(crop_label, 1, 0, 1, 1);

        position_label = new QLabel(ClipDurationDialog_UI);
        position_label->setObjectName("position_label");

        gridLayout->addWidget(position_label, 0, 0, 1, 1);

        mode_info = new KMessageWidget(ClipDurationDialog_UI);
        mode_info->setObjectName("mode_info");
        mode_info->setWordWrap(true);
        mode_info->setCloseButtonVisible(false);

        gridLayout->addWidget(mode_info, 8, 0, 1, 2);

        m_dur = new TimecodeDisplay(ClipDurationDialog_UI);
        m_dur->setObjectName("m_dur");

        gridLayout->addWidget(m_dur, 2, 1, 1, 1);

        verticalSpacer = new QSpacerItem(218, 2, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 0, 1, 2);

        m_pos = new TimecodeDisplay(ClipDurationDialog_UI);
        m_pos->setObjectName("m_pos");

        gridLayout->addWidget(m_pos, 0, 1, 1, 1);

        m_cropEnd = new TimecodeDisplay(ClipDurationDialog_UI);
        m_cropEnd->setObjectName("m_cropEnd");
        m_cropEnd->setEnabled(true);

        gridLayout->addWidget(m_cropEnd, 4, 1, 1, 1);

        duration_label = new QLabel(ClipDurationDialog_UI);
        duration_label->setObjectName("duration_label");

        gridLayout->addWidget(duration_label, 2, 0, 1, 1);

        end_label = new QLabel(ClipDurationDialog_UI);
        end_label->setObjectName("end_label");

        gridLayout->addWidget(end_label, 4, 0, 1, 1);

        m_cropStart = new TimecodeDisplay(ClipDurationDialog_UI);
        m_cropStart->setObjectName("m_cropStart");

        gridLayout->addWidget(m_cropStart, 1, 1, 1, 1);

        ripple_resize = new QCheckBox(ClipDurationDialog_UI);
        ripple_resize->setObjectName("ripple_resize");

        gridLayout->addWidget(ripple_resize, 6, 0, 1, 1);

        QWidget::setTabOrder(m_pos, m_cropStart);
        QWidget::setTabOrder(m_cropStart, m_dur);
        QWidget::setTabOrder(m_dur, m_cropEnd);
        QWidget::setTabOrder(m_cropEnd, duration_for_all);

        retranslateUi(ClipDurationDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ClipDurationDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipDurationDialog_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClipDurationDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *ClipDurationDialog_UI)
    {
        ClipDurationDialog_UI->setWindowTitle(tr2i18n("Duration", nullptr));
        duration_for_all->setText(tr2i18n("Apply duration to all items", nullptr));
        crop_label->setText(tr2i18n("Crop start:", nullptr));
        position_label->setText(tr2i18n("Position:", nullptr));
        duration_label->setText(tr2i18n("Duration:", nullptr));
        end_label->setText(tr2i18n("Crop end:", nullptr));
        ripple_resize->setText(tr2i18n("Ripple resize", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClipDurationDialog_UI: public Ui_ClipDurationDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLIPDURATIONDIALOG_UI_H

