/********************************************************************************
** Form generated from reading UI file 'audiospectrum_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_AUDIOSPECTRUM_UI_H
#define UI_AUDIOSPECTRUM_UI_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_AudioSpectrum_UI
{
public:
    QGridLayout *gridLayout_2;
    KComboBox *windowSize;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer;
    KComboBox *windowFunction;
    QLabel *labelFFTSize;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelFFTSizeNumber;

    void setupUi(QWidget *AudioSpectrum_UI)
    {
        if (AudioSpectrum_UI->objectName().isEmpty())
            AudioSpectrum_UI->setObjectName("AudioSpectrum_UI");
        AudioSpectrum_UI->resize(400, 300);
        gridLayout_2 = new QGridLayout(AudioSpectrum_UI);
        gridLayout_2->setObjectName("gridLayout_2");
        windowSize = new KComboBox(AudioSpectrum_UI);
        windowSize->setObjectName("windowSize");

        gridLayout_2->addWidget(windowSize, 1, 5, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 1, 3, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 5, 1, 1);

        windowFunction = new KComboBox(AudioSpectrum_UI);
        windowFunction->setObjectName("windowFunction");

        gridLayout_2->addWidget(windowFunction, 1, 4, 1, 1);

        labelFFTSize = new QLabel(AudioSpectrum_UI);
        labelFFTSize->setObjectName("labelFFTSize");
        labelFFTSize->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));

        gridLayout_2->addWidget(labelFFTSize, 1, 1, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 1, 0, 1, 1);

        labelFFTSizeNumber = new QLabel(AudioSpectrum_UI);
        labelFFTSizeNumber->setObjectName("labelFFTSizeNumber");

        gridLayout_2->addWidget(labelFFTSizeNumber, 1, 2, 1, 1);


        retranslateUi(AudioSpectrum_UI);

        QMetaObject::connectSlotsByName(AudioSpectrum_UI);
    } // setupUi

    void retranslateUi(QWidget *AudioSpectrum_UI)
    {
        labelFFTSize->setText(tr2i18n("True FFT size: ", nullptr));
        labelFFTSizeNumber->setText(QString());
        (void)AudioSpectrum_UI;
    } // retranslateUi

};

namespace Ui {
    class AudioSpectrum_UI: public Ui_AudioSpectrum_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // AUDIOSPECTRUM_UI_H

