/****************************************************************************
** Meta object code from reading C++ file 'keyframeview.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/keyframes/view/keyframeview.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyframeview.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12KeyframeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyframeView::qt_create_metaobjectdata<qt_meta_tag_ZN12KeyframeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyframeView",
        "seekToPos",
        "",
        "pos",
        "atKeyframe",
        "isKeyframe",
        "singleKeyframe",
        "modified",
        "activateEffect",
        "updateKeyframeOriginal",
        "goToNext",
        "goToPrevious",
        "slotSetPosition",
        "isInRange",
        "slotDuplicateKeyframe",
        "slotModelChanged",
        "slotModelDisplayChanged",
        "slotOnFocus",
        "slotLoseFocus",
        "slotEditFramesType",
        "QList<int>",
        "frames",
        "type",
        "QPersistentModelIndex",
        "index",
        "initKeyframePos",
        "slotCenterKeyframe"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'atKeyframe'
        QtMocHelpers::SignalData<void(bool, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'modified'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activateEffect'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateKeyframeOriginal'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'goToNext'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goToPrevious'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void(int, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'slotDuplicateKeyframe'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotModelChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotModelDisplayChanged'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotOnFocus'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoseFocus'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditFramesType'
        QtMocHelpers::SlotData<void(QList<int>, int, const QPersistentModelIndex &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Int, 22 }, { 0x80000000 | 23, 24 },
        }}),
        // Slot 'initKeyframePos'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCenterKeyframe'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyframeView, qt_meta_tag_ZN12KeyframeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyframeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KeyframeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KeyframeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12KeyframeViewE_t>.metaTypes,
    nullptr
} };

void KeyframeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyframeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->atKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->modified(); break;
        case 3: _t->activateEffect(); break;
        case 4: _t->updateKeyframeOriginal((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->goToNext(); break;
        case 6: _t->goToPrevious(); break;
        case 7: _t->slotSetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 8: _t->slotDuplicateKeyframe(); break;
        case 9: _t->slotModelChanged(); break;
        case 10: _t->slotModelDisplayChanged(); break;
        case 11: _t->slotOnFocus(); break;
        case 12: _t->slotLoseFocus(); break;
        case 13: _t->slotEditFramesType((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[3]))); break;
        case 14: _t->initKeyframePos(); break;
        case 15: _t->slotCenterKeyframe(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)(int )>(_a, &KeyframeView::seekToPos, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)(bool , bool )>(_a, &KeyframeView::atKeyframe, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)()>(_a, &KeyframeView::modified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)()>(_a, &KeyframeView::activateEffect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)(int )>(_a, &KeyframeView::updateKeyframeOriginal, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)()>(_a, &KeyframeView::goToNext, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeView::*)()>(_a, &KeyframeView::goToPrevious, 6))
            return;
    }
}

const QMetaObject *KeyframeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyframeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12KeyframeViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KeyframeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void KeyframeView::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyframeView::atKeyframe(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void KeyframeView::modified()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KeyframeView::activateEffect()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyframeView::updateKeyframeOriginal(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KeyframeView::goToNext()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KeyframeView::goToPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
