/****************************************************************************
** Meta object code from reading C++ file 'monitorproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/monitor/monitorproxy.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qscreen.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitorproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12MonitorProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto MonitorProxy::qt_create_metaobjectdata<qt_meta_tag_ZN12MonitorProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonitorProxy",
        "positionChanged",
        "",
        "seekFinishedChanged",
        "requestSeek",
        "pos",
        "noAudioScrub",
        "zoneChanged",
        "saveZone",
        "QPoint",
        "zone",
        "saveZoneWithUndo",
        "markerChanged",
        "audioSyncedChanged",
        "rulerHeightChanged",
        "addSnap",
        "removeSnap",
        "triggerAction",
        "name",
        "overlayTypeChanged",
        "showSafezoneChanged",
        "maskOpacityChanged",
        "maskModeChanged",
        "builtinEffectsEnabledChanged",
        "addRemoveKeyframe",
        "addOnly",
        "seekToKeyframe",
        "ix",
        "offset",
        "clipHasAVChanged",
        "clipNameChanged",
        "clipStreamChanged",
        "clipTypeChanged",
        "clipIdChanged",
        "audioThumbChanged",
        "audioThumbFormatChanged",
        "audioThumbNormalizeChanged",
        "profileChanged",
        "timecodeChanged",
        "trimmingTC1Changed",
        "trimmingTC2Changed",
        "speedChanged",
        "clipBoundsChanged",
        "runningJobsChanged",
        "jobsProgressChanged",
        "addTimelineEffect",
        "lastClipsChanged",
        "switchFocusClip",
        "enableTransform",
        "previewOverlayChanged",
        "refreshMask",
        "activeMonitorChanged",
        "isKeyframeChanged",
        "cursorOutsideEffectChanged",
        "dragTypeChanged",
        "rebuildAudio",
        "cid",
        "updateClipBounds",
        "QList<QPoint>",
        "bounds",
        "clipDeleted",
        "documentClosed",
        "extractFrameToFile",
        "frame_position",
        "pathInfo",
        "addToProject",
        "useSourceProfile",
        "updateClipName",
        "id",
        "newName",
        "setPosition",
        "seek",
        "delta",
        "modifiers",
        "getUuid",
        "selectClip",
        "clipBoundary",
        "setZone",
        "in",
        "out",
        "sendUpdate",
        "activateClipMonitor",
        "isClipMonitor",
        "toTimecode",
        "frames",
        "startZoneMove",
        "endZoneMove",
        "switchGrid",
        "fps",
        "setWidgetKeyBinding",
        "text",
        "addEffect",
        "effectData",
        "effectSource",
        "terminateJob",
        "uuid",
        "refreshAudio",
        "resizeMarker",
        "position",
        "duration",
        "isStart",
        "newPosition",
        "createRangeMarkerFromZone",
        "comment",
        "type",
        "profile",
        "seekFinished",
        "zoneIn",
        "zoneOut",
        "audioSynced",
        "rulerHeight",
        "markerComment",
        "markerColor",
        "QColor",
        "timecode",
        "trimmingTC1",
        "trimmingTC2",
        "audioStreams",
        "QList<int>",
        "audioChannels",
        "clipBounds",
        "overlayType",
        "showSafezone",
        "maskOpacity",
        "maskInverted",
        "maskMode",
        "MaskModeType::MaskCreationMode",
        "speed",
        "lastClips",
        "dragType",
        "clipHasAV",
        "clipName",
        "previewOverlay",
        "QUrl",
        "clipStream",
        "clipType",
        "clipId",
        "runningJobs",
        "jobsProgress",
        "jobsUuids",
        "monitorIsActive",
        "isKeyframe",
        "cursorOutsideEffect"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'seekFinishedChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestSeek'
        QtMocHelpers::SignalData<void(int, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'zoneChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveZone'
        QtMocHelpers::SignalData<void(const QPoint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Signal 'saveZoneWithUndo'
        QtMocHelpers::SignalData<void(const QPoint, const QPoint &)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 }, { 0x80000000 | 9, 2 },
        }}),
        // Signal 'markerChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioSyncedChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rulerHeightChanged'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addSnap'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'removeSnap'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'triggerAction'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 18 },
        }}),
        // Signal 'overlayTypeChanged'
        QtMocHelpers::SignalData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSafezoneChanged'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskOpacityChanged'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskModeChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'builtinEffectsEnabledChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addRemoveKeyframe'
        QtMocHelpers::SignalData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Signal 'addRemoveKeyframe'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'seekToKeyframe'
        QtMocHelpers::SignalData<void(int, int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 28 },
        }}),
        // Signal 'clipHasAVChanged'
        QtMocHelpers::SignalData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipNameChanged'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipStreamChanged'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipTypeChanged'
        QtMocHelpers::SignalData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipIdChanged'
        QtMocHelpers::SignalData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioThumbChanged'
        QtMocHelpers::SignalData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioThumbFormatChanged'
        QtMocHelpers::SignalData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioThumbNormalizeChanged'
        QtMocHelpers::SignalData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profileChanged'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timecodeChanged'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trimmingTC1Changed'
        QtMocHelpers::SignalData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trimmingTC2Changed'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speedChanged'
        QtMocHelpers::SignalData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipBoundsChanged'
        QtMocHelpers::SignalData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'runningJobsChanged'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jobsProgressChanged'
        QtMocHelpers::SignalData<void()>(44, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addTimelineEffect'
        QtMocHelpers::SignalData<void(const QStringList &)>(45, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Signal 'lastClipsChanged'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchFocusClip'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableTransform'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewOverlayChanged'
        QtMocHelpers::SignalData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshMask'
        QtMocHelpers::SignalData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activeMonitorChanged'
        QtMocHelpers::SignalData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isKeyframeChanged'
        QtMocHelpers::SignalData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorOutsideEffectChanged'
        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragTypeChanged'
        QtMocHelpers::SignalData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rebuildAudio'
        QtMocHelpers::SignalData<void(int)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 56 },
        }}),
        // Slot 'updateClipBounds'
        QtMocHelpers::SlotData<void(const QVector<QPoint> &)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 58, 59 },
        }}),
        // Slot 'clipDeleted'
        QtMocHelpers::SlotData<void(int)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 56 },
        }}),
        // Slot 'documentClosed'
        QtMocHelpers::SlotData<void()>(61, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'extractFrameToFile'
        QtMocHelpers::SlotData<void(int, const QStringList &, bool, bool)>(62, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::QStringList, 64 }, { QMetaType::Bool, 65 }, { QMetaType::Bool, 66 },
        }}),
        // Slot 'extractFrameToFile'
        QtMocHelpers::SlotData<void(int, const QStringList &, bool)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::QStringList, 64 }, { QMetaType::Bool, 65 },
        }}),
        // Slot 'extractFrameToFile'
        QtMocHelpers::SlotData<void(int, const QStringList &)>(62, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 63 }, { QMetaType::QStringList, 64 },
        }}),
        // Slot 'updateClipName'
        QtMocHelpers::SlotData<void(int, const QString)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 68 }, { QMetaType::QString, 69 },
        }}),
        // Method 'setPosition'
        QtMocHelpers::MethodData<bool(int)>(70, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 5 },
        }}),
        // Method 'seek'
        QtMocHelpers::MethodData<void(int, uint)>(71, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 72 }, { QMetaType::UInt, 73 },
        }}),
        // Method 'getUuid'
        QtMocHelpers::MethodData<QByteArray() const>(74, 2, QMC::AccessPublic, QMetaType::QByteArray),
        // Method 'selectClip'
        QtMocHelpers::MethodData<void(int)>(75, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'clipBoundary'
        QtMocHelpers::MethodData<const QPoint(int)>(76, 2, QMC::AccessPublic, 0x80000000 | 9, {{
            { QMetaType::Int, 27 },
        }}),
        // Method 'setZone'
        QtMocHelpers::MethodData<void(int, int, bool)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 78 }, { QMetaType::Int, 79 }, { QMetaType::Bool, 80 },
        }}),
        // Method 'setZone'
        QtMocHelpers::MethodData<void(int, int)>(77, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 78 }, { QMetaType::Int, 79 },
        }}),
        // Method 'activateClipMonitor'
        QtMocHelpers::MethodData<void(bool)>(81, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 82 },
        }}),
        // Method 'toTimecode'
        QtMocHelpers::MethodData<QString(int) const>(83, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Int, 84 },
        }}),
        // Method 'startZoneMove'
        QtMocHelpers::MethodData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'endZoneMove'
        QtMocHelpers::MethodData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'switchGrid'
        QtMocHelpers::MethodData<void()>(87, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'fps'
        QtMocHelpers::MethodData<double() const>(88, 2, QMC::AccessPublic, QMetaType::Double),
        // Method 'setWidgetKeyBinding'
        QtMocHelpers::MethodData<void(const QString &) const>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 90 },
        }}),
        // Method 'setWidgetKeyBinding'
        QtMocHelpers::MethodData<void() const>(89, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'addEffect'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 92 }, { QMetaType::QString, 93 },
        }}),
        // Method 'terminateJob'
        QtMocHelpers::MethodData<void(const QString &)>(94, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 95 },
        }}),
        // Method 'refreshAudio'
        QtMocHelpers::MethodData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'resizeMarker'
        QtMocHelpers::MethodData<void(int, int, bool, int)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 }, { QMetaType::Bool, 100 }, { QMetaType::Int, 101 },
        }}),
        // Method 'resizeMarker'
        QtMocHelpers::MethodData<void(int, int, bool)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 }, { QMetaType::Bool, 100 },
        }}),
        // Method 'resizeMarker'
        QtMocHelpers::MethodData<void(int, int)>(97, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 98 }, { QMetaType::Int, 99 },
        }}),
        // Method 'createRangeMarkerFromZone'
        QtMocHelpers::MethodData<bool(const QString &, int)>(102, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 103 }, { QMetaType::Int, 104 },
        }}),
        // Method 'createRangeMarkerFromZone'
        QtMocHelpers::MethodData<bool(const QString &)>(102, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 103 },
        }}),
        // Method 'createRangeMarkerFromZone'
        QtMocHelpers::MethodData<bool()>(102, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'position'
        QtMocHelpers::PropertyData<int>(98, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'profile'
        QtMocHelpers::PropertyData<QPoint>(105, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 28),
        // property 'seekFinished'
        QtMocHelpers::PropertyData<int>(106, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'zoneIn'
        QtMocHelpers::PropertyData<int>(107, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'zoneOut'
        QtMocHelpers::PropertyData<int>(108, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'audioSynced'
        QtMocHelpers::PropertyData<bool>(109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'rulerHeight'
        QtMocHelpers::PropertyData<int>(110, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'markerComment'
        QtMocHelpers::PropertyData<QString>(111, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'markerColor'
        QtMocHelpers::PropertyData<QColor>(112, 0x80000000 | 113, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 6),
        // property 'timecode'
        QtMocHelpers::PropertyData<QString>(114, QMetaType::QString, QMC::DefaultPropertyFlags, 29),
        // property 'trimmingTC1'
        QtMocHelpers::PropertyData<QString>(115, QMetaType::QString, QMC::DefaultPropertyFlags, 30),
        // property 'trimmingTC2'
        QtMocHelpers::PropertyData<QString>(116, QMetaType::QString, QMC::DefaultPropertyFlags, 31),
        // property 'audioStreams'
        QtMocHelpers::PropertyData<QList<int>>(117, 0x80000000 | 118, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 25),
        // property 'audioChannels'
        QtMocHelpers::PropertyData<QList<int>>(119, 0x80000000 | 118, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 25),
        // property 'clipBounds'
        QtMocHelpers::PropertyData<int>(120, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 33),
        // property 'overlayType'
        QtMocHelpers::PropertyData<int>(121, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'showSafezone'
        QtMocHelpers::PropertyData<bool>(122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'maskOpacity'
        QtMocHelpers::PropertyData<int>(123, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'maskInverted'
        QtMocHelpers::PropertyData<bool>(124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'maskMode'
        QtMocHelpers::PropertyData<MaskModeType::MaskCreationMode>(125, 0x80000000 | 126, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 15),
        // property 'speed'
        QtMocHelpers::PropertyData<double>(127, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 32),
        // property 'lastClips'
        QtMocHelpers::PropertyData<QStringList>(128, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 37),
        // property 'dragType'
        QtMocHelpers::PropertyData<QString>(129, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 45),
        // property 'clipHasAV'
        QtMocHelpers::PropertyData<bool>(130, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 20),
        // property 'clipName'
        QtMocHelpers::PropertyData<QString>(131, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 21),
        // property 'previewOverlay'
        QtMocHelpers::PropertyData<QUrl>(132, 0x80000000 | 133, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 40),
        // property 'clipStream'
        QtMocHelpers::PropertyData<QString>(134, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 22),
        // property 'clipType'
        QtMocHelpers::PropertyData<int>(135, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 23),
        // property 'clipId'
        QtMocHelpers::PropertyData<int>(136, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 24),
        // property 'runningJobs'
        QtMocHelpers::PropertyData<QStringList>(137, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 34),
        // property 'jobsProgress'
        QtMocHelpers::PropertyData<QList<int>>(138, 0x80000000 | 118, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 35),
        // property 'jobsUuids'
        QtMocHelpers::PropertyData<QStringList>(139, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable, 35),
        // property 'monitorIsActive'
        QtMocHelpers::PropertyData<bool>(140, QMetaType::Bool, QMC::DefaultPropertyFlags, 42),
        // property 'isKeyframe'
        QtMocHelpers::PropertyData<bool>(141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'cursorOutsideEffect'
        QtMocHelpers::PropertyData<bool>(142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonitorProxy, qt_meta_tag_ZN12MonitorProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT static const QMetaObject::SuperData qt_meta_extradata_ZN12MonitorProxyE[] = {
    QMetaObject::SuperData::link<MaskModeType::staticMetaObject>(),
    nullptr
};

Q_CONSTINIT const QMetaObject MonitorProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MonitorProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MonitorProxyE_t>.data,
    qt_static_metacall,
    qt_meta_extradata_ZN12MonitorProxyE,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12MonitorProxyE_t>.metaTypes,
    nullptr
} };

void MonitorProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonitorProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->seekFinishedChanged(); break;
        case 2: _t->requestSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->zoneChanged(); break;
        case 4: _t->saveZone((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 5: _t->saveZoneWithUndo((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2]))); break;
        case 6: _t->markerChanged(); break;
        case 7: _t->audioSyncedChanged(); break;
        case 8: _t->rulerHeightChanged(); break;
        case 9: _t->addSnap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->removeSnap((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->triggerAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->overlayTypeChanged(); break;
        case 13: _t->showSafezoneChanged(); break;
        case 14: _t->maskOpacityChanged(); break;
        case 15: _t->maskModeChanged(); break;
        case 16: _t->builtinEffectsEnabledChanged(); break;
        case 17: _t->addRemoveKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->addRemoveKeyframe(); break;
        case 19: _t->seekToKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 20: _t->clipHasAVChanged(); break;
        case 21: _t->clipNameChanged(); break;
        case 22: _t->clipStreamChanged(); break;
        case 23: _t->clipTypeChanged(); break;
        case 24: _t->clipIdChanged(); break;
        case 25: _t->audioThumbChanged(); break;
        case 26: _t->audioThumbFormatChanged(); break;
        case 27: _t->audioThumbNormalizeChanged(); break;
        case 28: _t->profileChanged(); break;
        case 29: _t->timecodeChanged(); break;
        case 30: _t->trimmingTC1Changed(); break;
        case 31: _t->trimmingTC2Changed(); break;
        case 32: _t->speedChanged(); break;
        case 33: _t->clipBoundsChanged(); break;
        case 34: _t->runningJobsChanged(); break;
        case 35: _t->jobsProgressChanged(); break;
        case 36: _t->addTimelineEffect((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 37: _t->lastClipsChanged(); break;
        case 38: _t->switchFocusClip(); break;
        case 39: _t->enableTransform(); break;
        case 40: _t->previewOverlayChanged(); break;
        case 41: _t->refreshMask(); break;
        case 42: _t->activeMonitorChanged(); break;
        case 43: _t->isKeyframeChanged(); break;
        case 44: _t->cursorOutsideEffectChanged(); break;
        case 45: _t->dragTypeChanged(); break;
        case 46: _t->rebuildAudio((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 47: _t->updateClipBounds((*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[1]))); break;
        case 48: _t->clipDeleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 49: _t->documentClosed(); break;
        case 50: _t->extractFrameToFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 51: _t->extractFrameToFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 52: _t->extractFrameToFile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 53: _t->updateClipName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 54: { bool _r = _t->setPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 55: _t->seek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 56: { QByteArray _r = _t->getUuid();
            if (_a[0]) *reinterpret_cast<QByteArray*>(_a[0]) = std::move(_r); }  break;
        case 57: _t->selectClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 58: { QPoint _r = _t->clipBoundary((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QPoint*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->setZone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 60: _t->setZone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 61: _t->activateClipMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 62: { QString _r = _t->toTimecode((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 63: _t->startZoneMove(); break;
        case 64: _t->endZoneMove(); break;
        case 65: _t->switchGrid(); break;
        case 66: { double _r = _t->fps();
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 67: _t->setWidgetKeyBinding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 68: _t->setWidgetKeyBinding(); break;
        case 69: _t->addEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 70: _t->terminateJob((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 71: _t->refreshAudio(); break;
        case 72: _t->resizeMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 73: _t->resizeMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 74: _t->resizeMarker((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 75: { bool _r = _t->createRangeMarkerFromZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 76: { bool _r = _t->createRangeMarkerFromZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 77: { bool _r = _t->createRangeMarkerFromZone();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int )>(_a, &MonitorProxy::positionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::seekFinishedChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int , bool )>(_a, &MonitorProxy::requestSeek, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::zoneChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(const QPoint )>(_a, &MonitorProxy::saveZone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(const QPoint , const QPoint & )>(_a, &MonitorProxy::saveZoneWithUndo, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::markerChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::audioSyncedChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::rulerHeightChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int )>(_a, &MonitorProxy::addSnap, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int )>(_a, &MonitorProxy::removeSnap, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(const QString & )>(_a, &MonitorProxy::triggerAction, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::overlayTypeChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::showSafezoneChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::maskOpacityChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::maskModeChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::builtinEffectsEnabledChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(bool )>(_a, &MonitorProxy::addRemoveKeyframe, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int , int )>(_a, &MonitorProxy::seekToKeyframe, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipHasAVChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipNameChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipStreamChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipTypeChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipIdChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::audioThumbChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::audioThumbFormatChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::audioThumbNormalizeChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::profileChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::timecodeChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::trimmingTC1Changed, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::trimmingTC2Changed, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::speedChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::clipBoundsChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::runningJobsChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::jobsProgressChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(const QStringList & )>(_a, &MonitorProxy::addTimelineEffect, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::lastClipsChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::switchFocusClip, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::enableTransform, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::previewOverlayChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::refreshMask, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::activeMonitorChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::isKeyframeChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::cursorOutsideEffectChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)()>(_a, &MonitorProxy::dragTypeChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorProxy::*)(int )>(_a, &MonitorProxy::rebuildAudio, 46))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 30:
        case 13:
        case 12:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QList<int> >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_position; break;
        case 1: *reinterpret_cast<QPoint*>(_v) = _t->profile(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->m_seekFinished; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->zoneIn(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->zoneOut(); break;
        case 5: *reinterpret_cast<bool*>(_v) = _t->m_audioSynced; break;
        case 6: *reinterpret_cast<int*>(_v) = _t->rulerHeight(); break;
        case 7: *reinterpret_cast<QString*>(_v) = _t->m_markerComment; break;
        case 8: *reinterpret_cast<QColor*>(_v) = _t->m_markerColor; break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->timecode(); break;
        case 10: *reinterpret_cast<QString*>(_v) = _t->trimmingTC1(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->trimmingTC2(); break;
        case 12: *reinterpret_cast<QList<int>*>(_v) = _t->m_audioStreams; break;
        case 13: *reinterpret_cast<QList<int>*>(_v) = _t->m_audioChannels; break;
        case 14: *reinterpret_cast<int*>(_v) = _t->m_boundsCount; break;
        case 15: *reinterpret_cast<int*>(_v) = _t->overlayType(); break;
        case 16: *reinterpret_cast<bool*>(_v) = _t->showSafezone(); break;
        case 17: *reinterpret_cast<int*>(_v) = _t->maskOpacity(); break;
        case 18: *reinterpret_cast<bool*>(_v) = _t->maskInverted(); break;
        case 19: *reinterpret_cast<MaskModeType::MaskCreationMode*>(_v) = _t->m_maskMode; break;
        case 20: *reinterpret_cast<double*>(_v) = _t->m_speed; break;
        case 21: *reinterpret_cast<QStringList*>(_v) = _t->m_lastClips; break;
        case 22: *reinterpret_cast<QString*>(_v) = _t->m_dragType; break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->m_hasAV; break;
        case 24: *reinterpret_cast<QString*>(_v) = _t->m_clipName; break;
        case 25: *reinterpret_cast<QUrl*>(_v) = _t->m_previewOverlay; break;
        case 26: *reinterpret_cast<QString*>(_v) = _t->m_clipStream; break;
        case 27: *reinterpret_cast<int*>(_v) = _t->m_clipType; break;
        case 28: *reinterpret_cast<int*>(_v) = _t->m_clipId; break;
        case 29: *reinterpret_cast<QStringList*>(_v) = _t->m_runningJobs; break;
        case 30: *reinterpret_cast<QList<int>*>(_v) = _t->m_jobsProgress; break;
        case 31: *reinterpret_cast<QStringList*>(_v) = _t->m_jobsUuids; break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->monitorIsActive(); break;
        case 33: *reinterpret_cast<bool*>(_v) = _t->isKeyframe(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->cursorOutsideEffect(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPosition(*reinterpret_cast<int*>(_v)); break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_seekFinished, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->seekFinishedChanged();
            break;
        case 3: _t->setZoneIn(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setZoneOut(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setAudioSynced(*reinterpret_cast<bool*>(_v)); break;
        case 6: _t->setRulerHeight(*reinterpret_cast<int*>(_v)); break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_markerComment, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->markerChanged();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_markerColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->markerChanged();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->m_audioStreams, *reinterpret_cast<QList<int>*>(_v)))
                Q_EMIT _t->audioThumbChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_audioChannels, *reinterpret_cast<QList<int>*>(_v)))
                Q_EMIT _t->audioThumbChanged();
            break;
        case 14:
            if (QtMocHelpers::setProperty(_t->m_boundsCount, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->clipBoundsChanged();
            break;
        case 15: _t->setOverlayType(*reinterpret_cast<int*>(_v)); break;
        case 16: _t->setShowSafezone(*reinterpret_cast<bool*>(_v)); break;
        case 17: _t->setMaskOpacity(*reinterpret_cast<int*>(_v)); break;
        case 18: _t->setMaskInverted(*reinterpret_cast<bool*>(_v)); break;
        case 19:
            if (QtMocHelpers::setProperty(_t->m_maskMode, *reinterpret_cast<MaskModeType::MaskCreationMode*>(_v)))
                Q_EMIT _t->maskModeChanged();
            break;
        case 20:
            if (QtMocHelpers::setProperty(_t->m_speed, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->speedChanged();
            break;
        case 21:
            if (QtMocHelpers::setProperty(_t->m_lastClips, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->lastClipsChanged();
            break;
        case 22:
            if (QtMocHelpers::setProperty(_t->m_dragType, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->dragTypeChanged();
            break;
        case 23:
            if (QtMocHelpers::setProperty(_t->m_hasAV, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->clipHasAVChanged();
            break;
        case 24:
            if (QtMocHelpers::setProperty(_t->m_clipName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->clipNameChanged();
            break;
        case 25:
            if (QtMocHelpers::setProperty(_t->m_previewOverlay, *reinterpret_cast<QUrl*>(_v)))
                Q_EMIT _t->previewOverlayChanged();
            break;
        case 26:
            if (QtMocHelpers::setProperty(_t->m_clipStream, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->clipStreamChanged();
            break;
        case 27:
            if (QtMocHelpers::setProperty(_t->m_clipType, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->clipTypeChanged();
            break;
        case 28:
            if (QtMocHelpers::setProperty(_t->m_clipId, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->clipIdChanged();
            break;
        case 29:
            if (QtMocHelpers::setProperty(_t->m_runningJobs, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->runningJobsChanged();
            break;
        case 30:
            if (QtMocHelpers::setProperty(_t->m_jobsProgress, *reinterpret_cast<QList<int>*>(_v)))
                Q_EMIT _t->jobsProgressChanged();
            break;
        case 31:
            if (QtMocHelpers::setProperty(_t->m_jobsUuids, *reinterpret_cast<QStringList*>(_v)))
                Q_EMIT _t->jobsProgressChanged();
            break;
        case 33: _t->setIsKeyframe(*reinterpret_cast<bool*>(_v)); break;
        case 34: _t->setCursorOutsideEffect(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MonitorProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MonitorProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12MonitorProxyE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MonitorProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 78)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 78;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 78)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 78;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 35;
    }
    return _id;
}

// SIGNAL 0
void MonitorProxy::positionChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MonitorProxy::seekFinishedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MonitorProxy::requestSeek(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void MonitorProxy::zoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void MonitorProxy::saveZone(const QPoint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MonitorProxy::saveZoneWithUndo(const QPoint _t1, const QPoint & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void MonitorProxy::markerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MonitorProxy::audioSyncedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MonitorProxy::rulerHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void MonitorProxy::addSnap(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void MonitorProxy::removeSnap(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void MonitorProxy::triggerAction(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void MonitorProxy::overlayTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void MonitorProxy::showSafezoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void MonitorProxy::maskOpacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void MonitorProxy::maskModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void MonitorProxy::builtinEffectsEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void MonitorProxy::addRemoveKeyframe(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}

// SIGNAL 19
void MonitorProxy::seekToKeyframe(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void MonitorProxy::clipHasAVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void MonitorProxy::clipNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void MonitorProxy::clipStreamChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void MonitorProxy::clipTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void MonitorProxy::clipIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void MonitorProxy::audioThumbChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void MonitorProxy::audioThumbFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void MonitorProxy::audioThumbNormalizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void MonitorProxy::profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void MonitorProxy::timecodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void MonitorProxy::trimmingTC1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void MonitorProxy::trimmingTC2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void MonitorProxy::speedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void MonitorProxy::clipBoundsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void MonitorProxy::runningJobsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void MonitorProxy::jobsProgressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void MonitorProxy::addTimelineEffect(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 36, nullptr, _t1);
}

// SIGNAL 37
void MonitorProxy::lastClipsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void MonitorProxy::switchFocusClip()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void MonitorProxy::enableTransform()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void MonitorProxy::previewOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void MonitorProxy::refreshMask()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void MonitorProxy::activeMonitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void MonitorProxy::isKeyframeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void MonitorProxy::cursorOutsideEffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void MonitorProxy::dragTypeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void MonitorProxy::rebuildAudio(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 46, nullptr, _t1);
}
QT_WARNING_POP
