/********************************************************************************
** Form generated from reading UI file 'colorplaneexport_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORPLANEEXPORT_UI_H
#define UI_COLORPLANEEXPORT_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSlider>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ColorPlaneExport_UI
{
public:
    QGridLayout *gridLayout;
    QLabel *lblSpace;
    KComboBox *cbColorspace;
    QLabel *lblVariant;
    KComboBox *cbVariant;
    QLabel *lblSliderName;
    QSlider *sliderColor;
    QLabel *lblColNr;
    QLabel *lblScaling;
    QSlider *sliderScaling;
    QLabel *lblScaleNr;
    QLabel *lblRes;
    QLineEdit *tResX;
    QLabel *lblTimes;
    QLineEdit *tResY;
    QLabel *lblSize;
    QLabel *lblFilename;
    KUrlRequester *kurlrequester;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ColorPlaneExport_UI)
    {
        if (ColorPlaneExport_UI->objectName().isEmpty())
            ColorPlaneExport_UI->setObjectName("ColorPlaneExport_UI");
        ColorPlaneExport_UI->resize(551, 239);
        gridLayout = new QGridLayout(ColorPlaneExport_UI);
        gridLayout->setObjectName("gridLayout");
        lblSpace = new QLabel(ColorPlaneExport_UI);
        lblSpace->setObjectName("lblSpace");

        gridLayout->addWidget(lblSpace, 0, 0, 1, 1);

        cbColorspace = new KComboBox(ColorPlaneExport_UI);
        cbColorspace->setObjectName("cbColorspace");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(cbColorspace->sizePolicy().hasHeightForWidth());
        cbColorspace->setSizePolicy(sizePolicy);

        gridLayout->addWidget(cbColorspace, 0, 1, 1, 3);

        lblVariant = new QLabel(ColorPlaneExport_UI);
        lblVariant->setObjectName("lblVariant");
        lblVariant->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblVariant, 1, 1, 1, 2);

        cbVariant = new KComboBox(ColorPlaneExport_UI);
        cbVariant->setObjectName("cbVariant");

        gridLayout->addWidget(cbVariant, 1, 3, 1, 1);

        lblSliderName = new QLabel(ColorPlaneExport_UI);
        lblSliderName->setObjectName("lblSliderName");
        lblSliderName->setText(QString::fromUtf8("(notransl.)"));

        gridLayout->addWidget(lblSliderName, 2, 0, 1, 1);

        sliderColor = new QSlider(ColorPlaneExport_UI);
        sliderColor->setObjectName("sliderColor");
        sliderColor->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(sliderColor, 2, 1, 1, 1);

        lblColNr = new QLabel(ColorPlaneExport_UI);
        lblColNr->setObjectName("lblColNr");
        lblColNr->setText(QString::fromUtf8("(notranslate) Y display"));

        gridLayout->addWidget(lblColNr, 2, 3, 1, 1);

        lblScaling = new QLabel(ColorPlaneExport_UI);
        lblScaling->setObjectName("lblScaling");

        gridLayout->addWidget(lblScaling, 3, 0, 1, 1);

        sliderScaling = new QSlider(ColorPlaneExport_UI);
        sliderScaling->setObjectName("sliderScaling");
        sliderScaling->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(sliderScaling, 3, 1, 1, 1);

        lblScaleNr = new QLabel(ColorPlaneExport_UI);
        lblScaleNr->setObjectName("lblScaleNr");
        lblScaleNr->setText(QString::fromUtf8("(notranslate) % display"));

        gridLayout->addWidget(lblScaleNr, 3, 3, 1, 1);

        lblRes = new QLabel(ColorPlaneExport_UI);
        lblRes->setObjectName("lblRes");

        gridLayout->addWidget(lblRes, 4, 0, 1, 1);

        tResX = new QLineEdit(ColorPlaneExport_UI);
        tResX->setObjectName("tResX");
        tResX->setMaxLength(5);

        gridLayout->addWidget(tResX, 4, 1, 1, 1);

        lblTimes = new QLabel(ColorPlaneExport_UI);
        lblTimes->setObjectName("lblTimes");
        lblTimes->setText(QString::fromUtf8("\303\227"));

        gridLayout->addWidget(lblTimes, 4, 2, 1, 1);

        tResY = new QLineEdit(ColorPlaneExport_UI);
        tResY->setObjectName("tResY");
        tResY->setMaxLength(5);

        gridLayout->addWidget(tResY, 4, 3, 1, 1);

        lblSize = new QLabel(ColorPlaneExport_UI);
        lblSize->setObjectName("lblSize");
        QFont font;
        font.setPointSize(8);
        lblSize->setFont(font);
        lblSize->setText(QString::fromUtf8("(notranslate) Total pixels go here"));
        lblSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);

        gridLayout->addWidget(lblSize, 5, 1, 1, 3);

        lblFilename = new QLabel(ColorPlaneExport_UI);
        lblFilename->setObjectName("lblFilename");

        gridLayout->addWidget(lblFilename, 6, 0, 1, 1);

        kurlrequester = new KUrlRequester(ColorPlaneExport_UI);
        kurlrequester->setObjectName("kurlrequester");
        kurlrequester->setMode(KFile::File|KFile::LocalOnly);

        gridLayout->addWidget(kurlrequester, 6, 1, 1, 3);

        buttonBox = new QDialogButtonBox(ColorPlaneExport_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 7, 1, 1, 3);


        retranslateUi(ColorPlaneExport_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ColorPlaneExport_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ColorPlaneExport_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ColorPlaneExport_UI);
    } // setupUi

    void retranslateUi(QDialog *ColorPlaneExport_UI)
    {
        ColorPlaneExport_UI->setWindowTitle(tr2i18n("Export color plane to PNG", nullptr));
        lblSpace->setText(tr2i18n("Color space", nullptr));
        lblVariant->setText(tr2i18n("Variant", nullptr));
#if QT_CONFIG(whatsthis)
        sliderColor->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        lblScaling->setText(tr2i18n("Scaling", nullptr));
#if QT_CONFIG(tooltip)
        sliderScaling->setToolTip(tr2i18n("How much to zoom in.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        sliderScaling->setWhatsThis(QString());
#endif // QT_CONFIG(whatsthis)
        lblRes->setText(tr2i18n("Resolution", nullptr));
        lblFilename->setText(tr2i18n("Filename", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ColorPlaneExport_UI: public Ui_ColorPlaneExport_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORPLANEEXPORT_UI_H

