/********************************************************************************
** Form generated from reading UI file 'configjogshuttle_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGJOGSHUTTLE_UI_H
#define UI_CONFIGJOGSHUTTLE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigJogShuttle_UI
{
public:
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_enableshuttle;
    QLabel *shuttledisabled;
    QSpacerItem *verticalSpacer;
    QGroupBox *config_group;
    QGridLayout *gridLayout;
    QLineEdit *kcfg_shuttledevice;
    QToolButton *toolBtnReload;
    QLabel *label_2;
    QLabel *label_17;
    QLabel *label_16;
    QComboBox *shuttle1;
    QComboBox *shuttle6;
    QLabel *label_14;
    QLabel *label_9;
    QComboBox *shuttle11;
    QLabel *label_7;
    QLabel *label;
    QLabel *label_5;
    QComboBox *shuttle9;
    QComboBox *shuttle4;
    QComboBox *shuttle12;
    QLabel *label_8;
    QComboBox *shuttle2;
    QComboBox *shuttle10;
    QComboBox *shuttle8;
    QLabel *label_10;
    QLabel *label_4;
    QComboBox *shuttle3;
    QLabel *label_11;
    QLabel *label_12;
    QComboBox *shuttledevicelist;
    QLabel *label_6;
    QComboBox *shuttle7;
    QComboBox *shuttle14;
    QComboBox *shuttle5;
    QComboBox *shuttle13;
    QComboBox *shuttle15;
    QLabel *label_15;
    QLabel *label_3;
    QLabel *label_13;

    void setupUi(QWidget *ConfigJogShuttle_UI)
    {
        if (ConfigJogShuttle_UI->objectName().isEmpty())
            ConfigJogShuttle_UI->setObjectName("ConfigJogShuttle_UI");
        ConfigJogShuttle_UI->resize(455, 749);
        gridLayout_2 = new QGridLayout(ConfigJogShuttle_UI);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, -1, -1);
        kcfg_enableshuttle = new QCheckBox(ConfigJogShuttle_UI);
        kcfg_enableshuttle->setObjectName("kcfg_enableshuttle");

        gridLayout_2->addWidget(kcfg_enableshuttle, 0, 0, 1, 1);

        shuttledisabled = new QLabel(ConfigJogShuttle_UI);
        shuttledisabled->setObjectName("shuttledisabled");

        gridLayout_2->addWidget(shuttledisabled, 1, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 56, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 3, 0, 1, 1);

        config_group = new QGroupBox(ConfigJogShuttle_UI);
        config_group->setObjectName("config_group");
        config_group->setEnabled(false);
        config_group->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        gridLayout = new QGridLayout(config_group);
        gridLayout->setObjectName("gridLayout");
        kcfg_shuttledevice = new QLineEdit(config_group);
        kcfg_shuttledevice->setObjectName("kcfg_shuttledevice");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_shuttledevice->sizePolicy().hasHeightForWidth());
        kcfg_shuttledevice->setSizePolicy(sizePolicy);
        kcfg_shuttledevice->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);

        gridLayout->addWidget(kcfg_shuttledevice, 1, 1, 1, 5);

        toolBtnReload = new QToolButton(config_group);
        toolBtnReload->setObjectName("toolBtnReload");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("view-refresh");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        toolBtnReload->setIcon(icon);

        gridLayout->addWidget(toolBtnReload, 0, 5, 1, 1);

        label_2 = new QLabel(config_group);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 2, 0, 1, 1);

        label_17 = new QLabel(config_group);
        label_17->setObjectName("label_17");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_17->sizePolicy().hasHeightForWidth());
        label_17->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_17, 1, 0, 1, 1);

        label_16 = new QLabel(config_group);
        label_16->setObjectName("label_16");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_16->sizePolicy().hasHeightForWidth());
        label_16->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_16, 16, 0, 1, 1);

        shuttle1 = new QComboBox(config_group);
        shuttle1->setObjectName("shuttle1");
        sizePolicy.setHeightForWidth(shuttle1->sizePolicy().hasHeightForWidth());
        shuttle1->setSizePolicy(sizePolicy);

        gridLayout->addWidget(shuttle1, 2, 1, 1, 5);

        shuttle6 = new QComboBox(config_group);
        shuttle6->setObjectName("shuttle6");

        gridLayout->addWidget(shuttle6, 7, 1, 1, 5);

        label_14 = new QLabel(config_group);
        label_14->setObjectName("label_14");
        sizePolicy2.setHeightForWidth(label_14->sizePolicy().hasHeightForWidth());
        label_14->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_14, 14, 0, 1, 1);

        label_9 = new QLabel(config_group);
        label_9->setObjectName("label_9");
        sizePolicy1.setHeightForWidth(label_9->sizePolicy().hasHeightForWidth());
        label_9->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_9, 9, 0, 1, 1);

        shuttle11 = new QComboBox(config_group);
        shuttle11->setObjectName("shuttle11");

        gridLayout->addWidget(shuttle11, 12, 1, 1, 5);

        label_7 = new QLabel(config_group);
        label_7->setObjectName("label_7");
        sizePolicy1.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_7, 5, 0, 1, 1);

        label = new QLabel(config_group);
        label->setObjectName("label");
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label, 0, 0, 1, 1);

        label_5 = new QLabel(config_group);
        label_5->setObjectName("label_5");
        sizePolicy1.setHeightForWidth(label_5->sizePolicy().hasHeightForWidth());
        label_5->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_5, 6, 0, 1, 1);

        shuttle9 = new QComboBox(config_group);
        shuttle9->setObjectName("shuttle9");

        gridLayout->addWidget(shuttle9, 10, 1, 1, 5);

        shuttle4 = new QComboBox(config_group);
        shuttle4->setObjectName("shuttle4");

        gridLayout->addWidget(shuttle4, 5, 1, 1, 5);

        shuttle12 = new QComboBox(config_group);
        shuttle12->setObjectName("shuttle12");

        gridLayout->addWidget(shuttle12, 13, 1, 1, 5);

        label_8 = new QLabel(config_group);
        label_8->setObjectName("label_8");
        sizePolicy1.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_8, 8, 0, 1, 1);

        shuttle2 = new QComboBox(config_group);
        shuttle2->setObjectName("shuttle2");
        sizePolicy.setHeightForWidth(shuttle2->sizePolicy().hasHeightForWidth());
        shuttle2->setSizePolicy(sizePolicy);

        gridLayout->addWidget(shuttle2, 3, 1, 1, 5);

        shuttle10 = new QComboBox(config_group);
        shuttle10->setObjectName("shuttle10");

        gridLayout->addWidget(shuttle10, 11, 1, 1, 5);

        shuttle8 = new QComboBox(config_group);
        shuttle8->setObjectName("shuttle8");

        gridLayout->addWidget(shuttle8, 9, 1, 1, 5);

        label_10 = new QLabel(config_group);
        label_10->setObjectName("label_10");
        sizePolicy1.setHeightForWidth(label_10->sizePolicy().hasHeightForWidth());
        label_10->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_10, 10, 0, 1, 1);

        label_4 = new QLabel(config_group);
        label_4->setObjectName("label_4");
        sizePolicy1.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_4, 3, 0, 1, 1);

        shuttle3 = new QComboBox(config_group);
        shuttle3->setObjectName("shuttle3");

        gridLayout->addWidget(shuttle3, 4, 1, 1, 5);

        label_11 = new QLabel(config_group);
        label_11->setObjectName("label_11");
        sizePolicy2.setHeightForWidth(label_11->sizePolicy().hasHeightForWidth());
        label_11->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_11, 11, 0, 1, 1);

        label_12 = new QLabel(config_group);
        label_12->setObjectName("label_12");
        sizePolicy2.setHeightForWidth(label_12->sizePolicy().hasHeightForWidth());
        label_12->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_12, 12, 0, 1, 1);

        shuttledevicelist = new QComboBox(config_group);
        shuttledevicelist->setObjectName("shuttledevicelist");
        sizePolicy.setHeightForWidth(shuttledevicelist->sizePolicy().hasHeightForWidth());
        shuttledevicelist->setSizePolicy(sizePolicy);

        gridLayout->addWidget(shuttledevicelist, 0, 1, 1, 4);

        label_6 = new QLabel(config_group);
        label_6->setObjectName("label_6");
        sizePolicy1.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_6, 7, 0, 1, 1);

        shuttle7 = new QComboBox(config_group);
        shuttle7->setObjectName("shuttle7");

        gridLayout->addWidget(shuttle7, 8, 1, 1, 5);

        shuttle14 = new QComboBox(config_group);
        shuttle14->setObjectName("shuttle14");

        gridLayout->addWidget(shuttle14, 15, 1, 1, 5);

        shuttle5 = new QComboBox(config_group);
        shuttle5->setObjectName("shuttle5");

        gridLayout->addWidget(shuttle5, 6, 1, 1, 5);

        shuttle13 = new QComboBox(config_group);
        shuttle13->setObjectName("shuttle13");

        gridLayout->addWidget(shuttle13, 14, 1, 1, 5);

        shuttle15 = new QComboBox(config_group);
        shuttle15->setObjectName("shuttle15");

        gridLayout->addWidget(shuttle15, 16, 1, 1, 5);

        label_15 = new QLabel(config_group);
        label_15->setObjectName("label_15");
        sizePolicy2.setHeightForWidth(label_15->sizePolicy().hasHeightForWidth());
        label_15->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_15, 15, 0, 1, 1);

        label_3 = new QLabel(config_group);
        label_3->setObjectName("label_3");
        sizePolicy1.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(label_3, 4, 0, 1, 1);

        label_13 = new QLabel(config_group);
        label_13->setObjectName("label_13");
        sizePolicy2.setHeightForWidth(label_13->sizePolicy().hasHeightForWidth());
        label_13->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_13, 13, 0, 1, 1);


        gridLayout_2->addWidget(config_group, 2, 0, 1, 1);

        QWidget::setTabOrder(kcfg_enableshuttle, shuttledevicelist);
        QWidget::setTabOrder(shuttledevicelist, toolBtnReload);
        QWidget::setTabOrder(toolBtnReload, kcfg_shuttledevice);
        QWidget::setTabOrder(kcfg_shuttledevice, shuttle1);
        QWidget::setTabOrder(shuttle1, shuttle2);
        QWidget::setTabOrder(shuttle2, shuttle3);
        QWidget::setTabOrder(shuttle3, shuttle4);
        QWidget::setTabOrder(shuttle4, shuttle5);
        QWidget::setTabOrder(shuttle5, shuttle6);
        QWidget::setTabOrder(shuttle6, shuttle7);
        QWidget::setTabOrder(shuttle7, shuttle8);
        QWidget::setTabOrder(shuttle8, shuttle9);
        QWidget::setTabOrder(shuttle9, shuttle10);
        QWidget::setTabOrder(shuttle10, shuttle11);
        QWidget::setTabOrder(shuttle11, shuttle12);
        QWidget::setTabOrder(shuttle12, shuttle13);
        QWidget::setTabOrder(shuttle13, shuttle14);
        QWidget::setTabOrder(shuttle14, shuttle15);

        retranslateUi(ConfigJogShuttle_UI);

        QMetaObject::connectSlotsByName(ConfigJogShuttle_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigJogShuttle_UI)
    {
        kcfg_enableshuttle->setText(tr2i18n("Enable Jog Shuttle device", nullptr));
        shuttledisabled->setText(tr2i18n("Jog Shuttle device disabled.", nullptr));
        config_group->setTitle(tr2i18n("Device Configuration", nullptr));
        kcfg_shuttledevice->setText(QString());
        toolBtnReload->setText(tr2i18n("...", nullptr));
        label_2->setText(tr2i18n("Button  1", nullptr));
        label_17->setText(tr2i18n("Device:", nullptr));
        label_16->setText(tr2i18n("Button 15", nullptr));
        label_14->setText(tr2i18n("Button 13", nullptr));
        label_9->setText(tr2i18n("Button  8", nullptr));
        label_7->setText(tr2i18n("Button  4", nullptr));
        label->setText(tr2i18n("Device name:", nullptr));
        label_5->setText(tr2i18n("Button  5", nullptr));
        label_8->setText(tr2i18n("Button  7", nullptr));
        label_10->setText(tr2i18n("Button  9", nullptr));
        label_4->setText(tr2i18n("Button  2", nullptr));
        label_11->setText(tr2i18n("Button 10", nullptr));
        label_12->setText(tr2i18n("Button 11", nullptr));
        label_6->setText(tr2i18n("Button  6", nullptr));
        label_15->setText(tr2i18n("Button 14", nullptr));
        label_3->setText(tr2i18n("Button  3", nullptr));
        label_13->setText(tr2i18n("Button 12", nullptr));
        (void)ConfigJogShuttle_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigJogShuttle_UI: public Ui_ConfigJogShuttle_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGJOGSHUTTLE_UI_H

