/****************************************************************************
** Meta object code from reading C++ file 'playlistclip.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/bin/playlistclip.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'playlistclip.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12PlaylistClipE_t {};
} // unnamed namespace

template <> constexpr inline auto PlaylistClip::qt_create_metaobjectdata<qt_meta_tag_ZN12PlaylistClipE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PlaylistClip",
        "setProducer",
        "",
        "std::shared_ptr<Mlt::Producer>",
        "producer",
        "generateThumb",
        "clearTrackProducers",
        "setProperties",
        "QMap<QString,QString>",
        "properties",
        "refreshPanel",
        "setSequenceThumbnail",
        "QImage",
        "img",
        "QUuid",
        "uuid",
        "inCache"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>, bool, bool)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>, bool)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'setProducer'
        QtMocHelpers::SlotData<bool(std::shared_ptr<Mlt::Producer>)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'setProperties'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Slot 'setProperties'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(7, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Slot 'setSequenceThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, const QUuid &, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'setSequenceThumbnail'
        QtMocHelpers::SlotData<void(const QImage &, const QUuid &)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 12, 13 }, { 0x80000000 | 14, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PlaylistClip, qt_meta_tag_ZN12PlaylistClipE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PlaylistClip::staticMetaObject = { {
    QMetaObject::SuperData::link<ProjectClip::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistClipE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistClipE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12PlaylistClipE_t>.metaTypes,
    nullptr
} };

void PlaylistClip::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PlaylistClip *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->setProducer((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Producer>>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->setProperties((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->setProperties((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 5: _t->setSequenceThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 6: _t->setSequenceThumbnail((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        default: ;
        }
    }
}

const QMetaObject *PlaylistClip::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PlaylistClip::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12PlaylistClipE_t>.strings))
        return static_cast<void*>(this);
    return ProjectClip::qt_metacast(_clname);
}

int PlaylistClip::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ProjectClip::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
