/****************************************************************************
** Meta object code from reading C++ file 'assetparametermodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/model/assetparametermodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'assetparametermodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AssetParameterModelE_t {};
} // unnamed namespace

template <> constexpr inline auto AssetParameterModel::qt_create_metaobjectdata<qt_meta_tag_ZN19AssetParameterModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AssetParameterModel",
        "modelChanged",
        "",
        "updateChildren",
        "names",
        "compositionTrackChanged",
        "replugEffect",
        "std::shared_ptr<AssetParameterModel>",
        "asset",
        "rebuildEffect",
        "enabledChange",
        "enabled",
        "hideKeyframesChange",
        "showEffectZone",
        "ObjectId",
        "id",
        "std::pair<int,int>",
        "inOut",
        "checked",
        "setParameters",
        "paramVector",
        "params",
        "update",
        "setParametersFromTask",
        "setProgress",
        "progress",
        "setParameter",
        "name",
        "paramValue",
        "QModelIndex",
        "paramIndex",
        "groupedCommand",
        "getKeyframeModel",
        "std::shared_ptr<KeyframeModelList>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateChildren'
        QtMocHelpers::SignalData<void(const QStringList &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 4 },
        }}),
        // Signal 'compositionTrackChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'replugEffect'
        QtMocHelpers::SignalData<void(std::shared_ptr<AssetParameterModel>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'rebuildEffect'
        QtMocHelpers::SignalData<void(std::shared_ptr<AssetParameterModel>)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Signal 'enabledChange'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Signal 'hideKeyframesChange'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'showEffectZone'
        QtMocHelpers::SignalData<void(ObjectId, QPair<int,int>, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 16, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'setParameters'
        QtMocHelpers::SlotData<void(const paramVector &, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'setParameters'
        QtMocHelpers::SlotData<void(const paramVector &)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setParametersFromTask'
        QtMocHelpers::SlotData<void(const paramVector &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'setProgress'
        QtMocHelpers::SlotData<void(int)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Method 'setParameter'
        QtMocHelpers::MethodData<void(const QString &, const QString &, bool, QModelIndex, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 22 }, { 0x80000000 | 29, 30 },
            { QMetaType::Bool, 31 },
        }}),
        // Method 'setParameter'
        QtMocHelpers::MethodData<void(const QString &, const QString &, bool, QModelIndex)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 22 }, { 0x80000000 | 29, 30 },
        }}),
        // Method 'setParameter'
        QtMocHelpers::MethodData<void(const QString &, const QString &, bool)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 }, { QMetaType::Bool, 22 },
        }}),
        // Method 'setParameter'
        QtMocHelpers::MethodData<void(const QString &, const QString &)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 27 }, { QMetaType::QString, 28 },
        }}),
        // Method 'getKeyframeModel'
        QtMocHelpers::MethodData<std::shared_ptr<KeyframeModelList>()>(32, 2, QMC::AccessPublic, 0x80000000 | 33),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AssetParameterModel, qt_meta_tag_ZN19AssetParameterModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AssetParameterModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AssetParameterModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AssetParameterModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AssetParameterModelE_t>.metaTypes,
    nullptr
} };

void AssetParameterModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AssetParameterModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->updateChildren((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 2: _t->compositionTrackChanged(); break;
        case 3: _t->replugEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[1]))); break;
        case 4: _t->rebuildEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[1]))); break;
        case 5: _t->enabledChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->hideKeyframesChange((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->showEffectZone((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->setParameters((*reinterpret_cast<std::add_pointer_t<paramVector>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->setParameters((*reinterpret_cast<std::add_pointer_t<paramVector>>(_a[1]))); break;
        case 10: _t->setParametersFromTask((*reinterpret_cast<std::add_pointer_t<paramVector>>(_a[1]))); break;
        case 11: _t->setProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->setParameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 13: _t->setParameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[4]))); break;
        case 14: _t->setParameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 15: _t->setParameter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 16: { std::shared_ptr<KeyframeModelList> _r = _t->getKeyframeModel();
            if (_a[0]) *reinterpret_cast<std::shared_ptr<KeyframeModelList>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)()>(_a, &AssetParameterModel::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(const QStringList & )>(_a, &AssetParameterModel::updateChildren, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)()>(_a, &AssetParameterModel::compositionTrackChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(std::shared_ptr<AssetParameterModel> )>(_a, &AssetParameterModel::replugEffect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(std::shared_ptr<AssetParameterModel> )>(_a, &AssetParameterModel::rebuildEffect, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(bool )>(_a, &AssetParameterModel::enabledChange, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(bool )>(_a, &AssetParameterModel::hideKeyframesChange, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterModel::*)(ObjectId , QPair<int,int> , bool )>(_a, &AssetParameterModel::showEffectZone, 7))
            return;
    }
}

const QMetaObject *AssetParameterModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AssetParameterModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AssetParameterModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "enable_shared_from_this_virtual<AssetParameterModel>"))
        return static_cast< enable_shared_from_this_virtual<AssetParameterModel>*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int AssetParameterModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void AssetParameterModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void AssetParameterModel::updateChildren(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void AssetParameterModel::compositionTrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void AssetParameterModel::replugEffect(std::shared_ptr<AssetParameterModel> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AssetParameterModel::rebuildEffect(std::shared_ptr<AssetParameterModel> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AssetParameterModel::enabledChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void AssetParameterModel::hideKeyframesChange(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AssetParameterModel::showEffectZone(ObjectId _t1, QPair<int,int> _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
