/********************************************************************************
** Form generated from reading UI file 'clipstabilize_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPSTABILIZE_UI_H
#define UI_CLIPSTABILIZE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ClipStabilize_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QLabel *label_3;
    QWidget *optionsbox;
    QToolButton *preset_button;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QToolButton *config_button;

    void setupUi(QDialog *ClipStabilize_UI)
    {
        if (ClipStabilize_UI->objectName().isEmpty())
            ClipStabilize_UI->setObjectName("ClipStabilize_UI");
        ClipStabilize_UI->resize(277, 214);
        gridLayout = new QGridLayout(ClipStabilize_UI);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 3, 2, 1, 2);

        label_3 = new QLabel(ClipStabilize_UI);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 0, 0, 1, 5);

        optionsbox = new QWidget(ClipStabilize_UI);
        optionsbox->setObjectName("optionsbox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(optionsbox->sizePolicy().hasHeightForWidth());
        optionsbox->setSizePolicy(sizePolicy);

        gridLayout->addWidget(optionsbox, 1, 0, 1, 5);

        preset_button = new QToolButton(ClipStabilize_UI);
        preset_button->setObjectName("preset_button");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("adjustlevels");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        preset_button->setIcon(icon);
        preset_button->setPopupMode(QToolButton::InstantPopup);

        gridLayout->addWidget(preset_button, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ClipStabilize_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Abort|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 4, 1, 1);

        config_button = new QToolButton(ClipStabilize_UI);
        config_button->setObjectName("config_button");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("configure")));
        config_button->setIcon(icon1);

        gridLayout->addWidget(config_button, 3, 1, 1, 1);


        retranslateUi(ClipStabilize_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipStabilize_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClipStabilize_UI);
    } // setupUi

    void retranslateUi(QDialog *ClipStabilize_UI)
    {
        ClipStabilize_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_3->setText(tr2i18n("Options", nullptr));
#if QT_CONFIG(tooltip)
        preset_button->setToolTip(tr2i18n("Presets", nullptr));
#endif // QT_CONFIG(tooltip)
        preset_button->setText(tr2i18n("...", nullptr));
        config_button->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClipStabilize_UI: public Ui_ClipStabilize_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLIPSTABILIZE_UI_H

