/****************************************************************************
** Meta object code from reading C++ file 'abstractscopewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/scopes/abstractscopewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractscopewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19AbstractScopeWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractScopeWidget::qt_create_metaobjectdata<qt_meta_tag_ZN19AbstractScopeWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractScopeWidget",
        "signalHUDRenderingFinished",
        "",
        "mseconds",
        "accelerationFactor",
        "signalScopeRenderingFinished",
        "signalBackgroundRenderingFinished",
        "signalMousePositionChanged",
        "forceUpdate",
        "doUpdate",
        "forceUpdateHUD",
        "forceUpdateScope",
        "forceUpdateBackground",
        "slotContextMenuRequested",
        "QPoint",
        "pos",
        "slotRenderZoneUpdated",
        "slotHUDRenderingFinished",
        "slotScopeRenderingFinished",
        "slotBackgroundRenderingFinished",
        "slotResetRealtimeFactor",
        "realtimeChecked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'signalHUDRenderingFinished'
        QtMocHelpers::SignalData<void(uint, uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'signalScopeRenderingFinished'
        QtMocHelpers::SignalData<void(uint, uint)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'signalBackgroundRenderingFinished'
        QtMocHelpers::SignalData<void(uint, uint)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Signal 'signalMousePositionChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdate'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'forceUpdate'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'forceUpdateHUD'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdateScope'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'forceUpdateBackground'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotContextMenuRequested'
        QtMocHelpers::SlotData<void(const QPoint &)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotRenderZoneUpdated'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotHUDRenderingFinished'
        QtMocHelpers::SlotData<void(uint, uint)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'slotScopeRenderingFinished'
        QtMocHelpers::SlotData<void(uint, uint)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'slotBackgroundRenderingFinished'
        QtMocHelpers::SlotData<void(uint, uint)>(19, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 4 },
        }}),
        // Slot 'slotResetRealtimeFactor'
        QtMocHelpers::SlotData<void(bool)>(20, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 21 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractScopeWidget, qt_meta_tag_ZN19AbstractScopeWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractScopeWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractScopeWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractScopeWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19AbstractScopeWidgetE_t>.metaTypes,
    nullptr
} };

void AbstractScopeWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractScopeWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->signalHUDRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 1: _t->signalScopeRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->signalBackgroundRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 3: _t->signalMousePositionChanged(); break;
        case 4: _t->forceUpdate((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->forceUpdate(); break;
        case 6: _t->forceUpdateHUD(); break;
        case 7: _t->forceUpdateScope(); break;
        case 8: _t->forceUpdateBackground(); break;
        case 9: _t->slotContextMenuRequested((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 10: _t->slotRenderZoneUpdated(); break;
        case 11: _t->slotHUDRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 12: _t->slotScopeRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 13: _t->slotBackgroundRenderingFinished((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 14: _t->slotResetRealtimeFactor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractScopeWidget::*)(uint , uint )>(_a, &AbstractScopeWidget::signalHUDRenderingFinished, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractScopeWidget::*)(uint , uint )>(_a, &AbstractScopeWidget::signalScopeRenderingFinished, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractScopeWidget::*)(uint , uint )>(_a, &AbstractScopeWidget::signalBackgroundRenderingFinished, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractScopeWidget::*)()>(_a, &AbstractScopeWidget::signalMousePositionChanged, 3))
            return;
    }
}

const QMetaObject *AbstractScopeWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractScopeWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19AbstractScopeWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int AbstractScopeWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 15)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 15)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void AbstractScopeWidget::signalHUDRenderingFinished(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void AbstractScopeWidget::signalScopeRenderingFinished(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void AbstractScopeWidget::signalBackgroundRenderingFinished(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void AbstractScopeWidget::signalMousePositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
