/********************************************************************************
** Form generated from reading UI file 'backupdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BACKUPDIALOG_UI_H
#define UI_BACKUPDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "klistwidgetsearchline.h"

QT_BEGIN_NAMESPACE

class Ui_BackupDialog_UI
{
public:
    QGridLayout *gridLayout;
    KListWidgetSearchLine *search_list;
    QListWidget *backup_list;
    QLabel *backup_preview;
    QHBoxLayout *horizontalLayout;
    QLabel *info_label;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *BackupDialog_UI)
    {
        if (BackupDialog_UI->objectName().isEmpty())
            BackupDialog_UI->setObjectName("BackupDialog_UI");
        BackupDialog_UI->resize(430, 252);
        gridLayout = new QGridLayout(BackupDialog_UI);
        gridLayout->setObjectName("gridLayout");
        search_list = new KListWidgetSearchLine(BackupDialog_UI);
        search_list->setObjectName("search_list");

        gridLayout->addWidget(search_list, 0, 0, 1, 1);

        backup_list = new QListWidget(BackupDialog_UI);
        backup_list->setObjectName("backup_list");
        backup_list->setAlternatingRowColors(true);

        gridLayout->addWidget(backup_list, 1, 0, 1, 1);

        backup_preview = new QLabel(BackupDialog_UI);
        backup_preview->setObjectName("backup_preview");
        backup_preview->setFrameShape(QFrame::Shape::Box);

        gridLayout->addWidget(backup_preview, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        info_label = new QLabel(BackupDialog_UI);
        info_label->setObjectName("info_label");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(info_label->sizePolicy().hasHeightForWidth());
        info_label->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(info_label);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        buttonBox = new QDialogButtonBox(BackupDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Open);

        horizontalLayout->addWidget(buttonBox);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 1);


        retranslateUi(BackupDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, BackupDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, BackupDialog_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(BackupDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *BackupDialog_UI)
    {
        BackupDialog_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        search_list->setPlaceholderText(tr2i18n("Search backup", nullptr));
        backup_preview->setText(QString());
        info_label->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class BackupDialog_UI: public Ui_BackupDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BACKUPDIALOG_UI_H

