/********************************************************************************
** Form generated from reading UI file 'editrenderpreset_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITRENDERPRESET_UI_H
#define UI_EDITRENDERPRESET_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_EditRenderPreset_UI
{
public:
    QVBoxLayout *verticalLayout_2;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_3;
    QLabel *groupLabel;
    QLabel *presetNameLabel;
    QComboBox *formatCombo;
    QLineEdit *preset_name;
    QLabel *label_container;
    QLabel *label_4;
    QLineEdit *preset_extension;
    QComboBox *groupName;
    QTabWidget *tabWidget;
    QWidget *video_tab;
    QVBoxLayout *verticalLayout_3;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QHBoxLayout *horizontalLayout;
    QScrollArea *scrollArea_2;
    QWidget *scrollAreaWidgetContents_2;
    QGridLayout *gridLayout;
    QLabel *label_24;
    QComboBox *vCodecCombo;
    QComboBox *scanningCombo;
    QCheckBox *cDar;
    QComboBox *vRateControlCombo;
    QCheckBox *cPar;
    QComboBox *fieldOrderCombo;
    QCheckBox *cField;
    QGroupBox *gFps;
    QHBoxLayout *horizontalLayout_4;
    QSpinBox *framerateNum;
    QLabel *label_8;
    QSpinBox *framerateDen;
    QSpacerItem *horizontalSpacer_3;
    QLabel *vquality_label;
    QGroupBox *gResolution;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *resWidth;
    QLabel *label_9;
    QSpinBox *resHeight;
    QToolButton *linkResoultion;
    QSpacerItem *horizontalSpacer;
    QCheckBox *cScanning;
    QLabel *frameRateDisplay;
    QCheckBox *fixedGop;
    QSpinBox *gopSpinner;
    QSpinBox *default_vbitrate;
    QCheckBox *cFps;
    QLabel *label_3;
    QGroupBox *gDar;
    QHBoxLayout *horizontalLayout_3;
    QSpinBox *displayAspectNum;
    QLabel *label_17;
    QSpinBox *displayAspectDen;
    QSpacerItem *horizontalSpacer_2;
    QSpinBox *bFramesSpinner;
    QLabel *label_2;
    QLabel *label_12;
    QSpacerItem *verticalSpacer_2;
    QCheckBox *cResolution;
    QLabel *label_26;
    QComboBox *parCombo;
    QSpinBox *default_vquality;
    QLabel *label_5;
    QLabel *bFramesLabel;
    QSpinBox *vBuffer;
    QWidget *audio_tab;
    QGridLayout *gridLayout_2;
    QCheckBox *cChannels;
    QComboBox *audioChannels;
    QLabel *label_13;
    QComboBox *aCodecCombo;
    QCheckBox *cSampleR;
    QGroupBox *gSampleR;
    QHBoxLayout *horizontalLayout_6;
    QComboBox *audioSampleRate;
    QLabel *label_20;
    QLabel *label_14;
    QComboBox *aRateControlCombo;
    QLabel *label_18;
    QSpinBox *aBitrate;
    QLabel *label_19;
    QSpinBox *aQuality;
    QSpacerItem *verticalSpacer;
    QWidget *other_tab;
    QVBoxLayout *verticalLayout;
    QLabel *speedsLabel;
    QTextEdit *speeds_list;
    QLabel *label;
    KMessageWidget *overrideParamsWarning;
    QPlainTextEdit *additionalParams;
    QLabel *parametersLabel;
    KMessageWidget *kmessagewidget;
    QPushButton *button_manual;
    QPlainTextEdit *parameters;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *EditRenderPreset_UI)
    {
        if (EditRenderPreset_UI->objectName().isEmpty())
            EditRenderPreset_UI->setObjectName("EditRenderPreset_UI");
        EditRenderPreset_UI->resize(538, 757);
        verticalLayout_2 = new QVBoxLayout(EditRenderPreset_UI);
        verticalLayout_2->setObjectName("verticalLayout_2");
        groupBox = new QGroupBox(EditRenderPreset_UI);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        gridLayout_3 = new QGridLayout(groupBox);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setHorizontalSpacing(6);
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        groupLabel = new QLabel(groupBox);
        groupLabel->setObjectName("groupLabel");

        gridLayout_3->addWidget(groupLabel, 0, 0, 1, 1);

        presetNameLabel = new QLabel(groupBox);
        presetNameLabel->setObjectName("presetNameLabel");

        gridLayout_3->addWidget(presetNameLabel, 1, 0, 1, 1);

        formatCombo = new QComboBox(groupBox);
        formatCombo->setObjectName("formatCombo");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(formatCombo->sizePolicy().hasHeightForWidth());
        formatCombo->setSizePolicy(sizePolicy);

        gridLayout_3->addWidget(formatCombo, 4, 1, 1, 1);

        preset_name = new QLineEdit(groupBox);
        preset_name->setObjectName("preset_name");

        gridLayout_3->addWidget(preset_name, 1, 1, 2, 4);

        label_container = new QLabel(groupBox);
        label_container->setObjectName("label_container");

        gridLayout_3->addWidget(label_container, 4, 0, 1, 1);

        label_4 = new QLabel(groupBox);
        label_4->setObjectName("label_4");

        gridLayout_3->addWidget(label_4, 4, 2, 1, 1);

        preset_extension = new QLineEdit(groupBox);
        preset_extension->setObjectName("preset_extension");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(preset_extension->sizePolicy().hasHeightForWidth());
        preset_extension->setSizePolicy(sizePolicy1);
        preset_extension->setMaxLength(20);

        gridLayout_3->addWidget(preset_extension, 4, 3, 1, 2);

        groupName = new QComboBox(groupBox);
        groupName->setObjectName("groupName");
        sizePolicy.setHeightForWidth(groupName->sizePolicy().hasHeightForWidth());
        groupName->setSizePolicy(sizePolicy);
        groupName->setEditable(true);
        groupName->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout_3->addWidget(groupName, 0, 1, 1, 4);


        verticalLayout_2->addWidget(groupBox);

        tabWidget = new QTabWidget(EditRenderPreset_UI);
        tabWidget->setObjectName("tabWidget");
        video_tab = new QWidget();
        video_tab->setObjectName("video_tab");
        verticalLayout_3 = new QVBoxLayout(video_tab);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(video_tab);
        scrollArea->setObjectName("scrollArea");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy2);
        scrollArea->setFrameShape(QFrame::NoFrame);
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
        scrollArea->setWidgetResizable(true);
        scrollArea->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 518, 457));
        horizontalLayout = new QHBoxLayout(scrollAreaWidgetContents);
        horizontalLayout->setObjectName("horizontalLayout");
        scrollArea_2 = new QScrollArea(scrollAreaWidgetContents);
        scrollArea_2->setObjectName("scrollArea_2");
        scrollArea_2->setFrameShape(QFrame::NoFrame);
        scrollArea_2->setWidgetResizable(true);
        scrollAreaWidgetContents_2 = new QWidget();
        scrollAreaWidgetContents_2->setObjectName("scrollAreaWidgetContents_2");
        scrollAreaWidgetContents_2->setGeometry(QRect(0, 0, 485, 548));
        gridLayout = new QGridLayout(scrollAreaWidgetContents_2);
        gridLayout->setObjectName("gridLayout");
        label_24 = new QLabel(scrollAreaWidgetContents_2);
        label_24->setObjectName("label_24");

        gridLayout->addWidget(label_24, 8, 0, 1, 2);

        vCodecCombo = new QComboBox(scrollAreaWidgetContents_2);
        vCodecCombo->setObjectName("vCodecCombo");
        sizePolicy.setHeightForWidth(vCodecCombo->sizePolicy().hasHeightForWidth());
        vCodecCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(vCodecCombo, 8, 2, 1, 3);

        scanningCombo = new QComboBox(scrollAreaWidgetContents_2);
        scanningCombo->addItem(QString());
        scanningCombo->addItem(QString());
        scanningCombo->setObjectName("scanningCombo");
        scanningCombo->setEnabled(false);
        sizePolicy.setHeightForWidth(scanningCombo->sizePolicy().hasHeightForWidth());
        scanningCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(scanningCombo, 6, 2, 1, 3);

        cDar = new QCheckBox(scrollAreaWidgetContents_2);
        cDar->setObjectName("cDar");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(cDar->sizePolicy().hasHeightForWidth());
        cDar->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cDar, 2, 0, 1, 2);

        vRateControlCombo = new QComboBox(scrollAreaWidgetContents_2);
        vRateControlCombo->setObjectName("vRateControlCombo");
        sizePolicy.setHeightForWidth(vRateControlCombo->sizePolicy().hasHeightForWidth());
        vRateControlCombo->setSizePolicy(sizePolicy);

        gridLayout->addWidget(vRateControlCombo, 9, 2, 1, 3);

        cPar = new QCheckBox(scrollAreaWidgetContents_2);
        cPar->setObjectName("cPar");
        sizePolicy3.setHeightForWidth(cPar->sizePolicy().hasHeightForWidth());
        cPar->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cPar, 1, 0, 1, 2);

        fieldOrderCombo = new QComboBox(scrollAreaWidgetContents_2);
        fieldOrderCombo->addItem(QString());
        fieldOrderCombo->addItem(QString());
        fieldOrderCombo->setObjectName("fieldOrderCombo");
        fieldOrderCombo->setEnabled(false);
        sizePolicy.setHeightForWidth(fieldOrderCombo->sizePolicy().hasHeightForWidth());
        fieldOrderCombo->setSizePolicy(sizePolicy);
        fieldOrderCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(fieldOrderCombo, 7, 2, 1, 3);

        cField = new QCheckBox(scrollAreaWidgetContents_2);
        cField->setObjectName("cField");
        sizePolicy3.setHeightForWidth(cField->sizePolicy().hasHeightForWidth());
        cField->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cField, 7, 0, 1, 2);

        gFps = new QGroupBox(scrollAreaWidgetContents_2);
        gFps->setObjectName("gFps");
        gFps->setEnabled(false);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(gFps->sizePolicy().hasHeightForWidth());
        gFps->setSizePolicy(sizePolicy4);
        gFps->setFlat(true);
        horizontalLayout_4 = new QHBoxLayout(gFps);
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(0, 0, 0, 0);
        framerateNum = new QSpinBox(gFps);
        framerateNum->setObjectName("framerateNum");
        framerateNum->setMinimum(1);
        framerateNum->setMaximum(1000000);

        horizontalLayout_4->addWidget(framerateNum);

        label_8 = new QLabel(gFps);
        label_8->setObjectName("label_8");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy5);
        label_8->setMinimumSize(QSize(10, 0));
        label_8->setText(QString::fromUtf8("/"));
        label_8->setAlignment(Qt::AlignCenter);

        horizontalLayout_4->addWidget(label_8);

        framerateDen = new QSpinBox(gFps);
        framerateDen->setObjectName("framerateDen");
        framerateDen->setMinimum(1);
        framerateDen->setMaximum(9999);

        horizontalLayout_4->addWidget(framerateDen);

        horizontalSpacer_3 = new QSpacerItem(42, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);


        gridLayout->addWidget(gFps, 3, 2, 1, 3);

        vquality_label = new QLabel(scrollAreaWidgetContents_2);
        vquality_label->setObjectName("vquality_label");

        gridLayout->addWidget(vquality_label, 14, 0, 1, 2);

        gResolution = new QGroupBox(scrollAreaWidgetContents_2);
        gResolution->setObjectName("gResolution");
        gResolution->setEnabled(false);
        sizePolicy4.setHeightForWidth(gResolution->sizePolicy().hasHeightForWidth());
        gResolution->setSizePolicy(sizePolicy4);
        gResolution->setMinimumSize(QSize(249, 0));
        gResolution->setFlat(true);
        horizontalLayout_2 = new QHBoxLayout(gResolution);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, -1);
        resWidth = new QSpinBox(gResolution);
        resWidth->setObjectName("resWidth");
        resWidth->setMinimum(1);
        resWidth->setMaximum(8192);
        resWidth->setSingleStep(2);
        resWidth->setValue(1);

        horizontalLayout_2->addWidget(resWidth);

        label_9 = new QLabel(gResolution);
        label_9->setObjectName("label_9");
        label_9->setMinimumSize(QSize(10, 0));
        label_9->setText(QString::fromUtf8("x"));
        label_9->setAlignment(Qt::AlignCenter);

        horizontalLayout_2->addWidget(label_9);

        resHeight = new QSpinBox(gResolution);
        resHeight->setObjectName("resHeight");
        resHeight->setMinimum(1);
        resHeight->setMaximum(8192);
        resHeight->setSingleStep(2);

        horizontalLayout_2->addWidget(resHeight);

        linkResoultion = new QToolButton(gResolution);
        linkResoultion->setObjectName("linkResoultion");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("link");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        linkResoultion->setIcon(icon);
        linkResoultion->setCheckable(true);
        linkResoultion->setAutoRaise(true);

        horizontalLayout_2->addWidget(linkResoultion);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        gridLayout->addWidget(gResolution, 0, 2, 1, 3);

        cScanning = new QCheckBox(scrollAreaWidgetContents_2);
        cScanning->setObjectName("cScanning");
        sizePolicy3.setHeightForWidth(cScanning->sizePolicy().hasHeightForWidth());
        cScanning->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cScanning, 6, 0, 1, 2);

        frameRateDisplay = new QLabel(scrollAreaWidgetContents_2);
        frameRateDisplay->setObjectName("frameRateDisplay");
        frameRateDisplay->setEnabled(true);
        sizePolicy4.setHeightForWidth(frameRateDisplay->sizePolicy().hasHeightForWidth());
        frameRateDisplay->setSizePolicy(sizePolicy4);

        gridLayout->addWidget(frameRateDisplay, 4, 2, 1, 3);

        fixedGop = new QCheckBox(scrollAreaWidgetContents_2);
        fixedGop->setObjectName("fixedGop");
        fixedGop->setEnabled(false);

        gridLayout->addWidget(fixedGop, 15, 4, 1, 1);

        gopSpinner = new QSpinBox(scrollAreaWidgetContents_2);
        gopSpinner->setObjectName("gopSpinner");
        sizePolicy.setHeightForWidth(gopSpinner->sizePolicy().hasHeightForWidth());
        gopSpinner->setSizePolicy(sizePolicy);
        gopSpinner->setMaximum(999);
        gopSpinner->setSingleStep(1);

        gridLayout->addWidget(gopSpinner, 15, 2, 1, 2);

        default_vbitrate = new QSpinBox(scrollAreaWidgetContents_2);
        default_vbitrate->setObjectName("default_vbitrate");
        default_vbitrate->setEnabled(false);
        sizePolicy.setHeightForWidth(default_vbitrate->sizePolicy().hasHeightForWidth());
        default_vbitrate->setSizePolicy(sizePolicy);
        default_vbitrate->setMaximum(500000);

        gridLayout->addWidget(default_vbitrate, 11, 2, 1, 3);

        cFps = new QCheckBox(scrollAreaWidgetContents_2);
        cFps->setObjectName("cFps");
        sizePolicy3.setHeightForWidth(cFps->sizePolicy().hasHeightForWidth());
        cFps->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cFps, 3, 0, 1, 2);

        label_3 = new QLabel(scrollAreaWidgetContents_2);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 4, 0, 1, 2);

        gDar = new QGroupBox(scrollAreaWidgetContents_2);
        gDar->setObjectName("gDar");
        gDar->setEnabled(false);
        sizePolicy4.setHeightForWidth(gDar->sizePolicy().hasHeightForWidth());
        gDar->setSizePolicy(sizePolicy4);
        gDar->setFlat(true);
        horizontalLayout_3 = new QHBoxLayout(gDar);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        horizontalLayout_3->setContentsMargins(0, 0, 0, 0);
        displayAspectNum = new QSpinBox(gDar);
        displayAspectNum->setObjectName("displayAspectNum");
        displayAspectNum->setMinimum(1);
        displayAspectNum->setMaximum(8192);

        horizontalLayout_3->addWidget(displayAspectNum);

        label_17 = new QLabel(gDar);
        label_17->setObjectName("label_17");
        label_17->setMinimumSize(QSize(10, 0));
        label_17->setText(QString::fromUtf8(":"));
        label_17->setAlignment(Qt::AlignCenter);

        horizontalLayout_3->addWidget(label_17);

        displayAspectDen = new QSpinBox(gDar);
        displayAspectDen->setObjectName("displayAspectDen");
        displayAspectDen->setMinimum(1);
        displayAspectDen->setMaximum(8192);

        horizontalLayout_3->addWidget(displayAspectDen);

        horizontalSpacer_2 = new QSpacerItem(76, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);


        gridLayout->addWidget(gDar, 2, 2, 1, 3);

        bFramesSpinner = new QSpinBox(scrollAreaWidgetContents_2);
        bFramesSpinner->setObjectName("bFramesSpinner");
        bFramesSpinner->setEnabled(false);
        sizePolicy.setHeightForWidth(bFramesSpinner->sizePolicy().hasHeightForWidth());
        bFramesSpinner->setSizePolicy(sizePolicy);
        bFramesSpinner->setMinimum(-1);
        bFramesSpinner->setMaximum(8);
        bFramesSpinner->setValue(-1);

        gridLayout->addWidget(bFramesSpinner, 16, 2, 1, 3);

        label_2 = new QLabel(scrollAreaWidgetContents_2);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 11, 0, 1, 1);

        label_12 = new QLabel(scrollAreaWidgetContents_2);
        label_12->setObjectName("label_12");

        gridLayout->addWidget(label_12, 9, 0, 1, 2);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 17, 2, 1, 1);

        cResolution = new QCheckBox(scrollAreaWidgetContents_2);
        cResolution->setObjectName("cResolution");
        sizePolicy3.setHeightForWidth(cResolution->sizePolicy().hasHeightForWidth());
        cResolution->setSizePolicy(sizePolicy3);

        gridLayout->addWidget(cResolution, 0, 0, 1, 2);

        label_26 = new QLabel(scrollAreaWidgetContents_2);
        label_26->setObjectName("label_26");

        gridLayout->addWidget(label_26, 15, 0, 1, 2);

        parCombo = new QComboBox(scrollAreaWidgetContents_2);
        parCombo->setObjectName("parCombo");
        parCombo->setEnabled(false);
        sizePolicy.setHeightForWidth(parCombo->sizePolicy().hasHeightForWidth());
        parCombo->setSizePolicy(sizePolicy);
        parCombo->setSizeAdjustPolicy(QComboBox::AdjustToContents);

        gridLayout->addWidget(parCombo, 1, 2, 1, 3);

        default_vquality = new QSpinBox(scrollAreaWidgetContents_2);
        default_vquality->setObjectName("default_vquality");
        sizePolicy.setHeightForWidth(default_vquality->sizePolicy().hasHeightForWidth());
        default_vquality->setSizePolicy(sizePolicy);
        default_vquality->setMaximum(500000);

        gridLayout->addWidget(default_vquality, 14, 2, 1, 3);

        label_5 = new QLabel(scrollAreaWidgetContents_2);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 13, 0, 1, 1);

        bFramesLabel = new QLabel(scrollAreaWidgetContents_2);
        bFramesLabel->setObjectName("bFramesLabel");

        gridLayout->addWidget(bFramesLabel, 16, 0, 1, 2);

        vBuffer = new QSpinBox(scrollAreaWidgetContents_2);
        vBuffer->setObjectName("vBuffer");
        vBuffer->setEnabled(false);
        sizePolicy.setHeightForWidth(vBuffer->sizePolicy().hasHeightForWidth());
        vBuffer->setSizePolicy(sizePolicy);
        vBuffer->setMaximum(9999);

        gridLayout->addWidget(vBuffer, 13, 2, 1, 3);

        scrollArea_2->setWidget(scrollAreaWidgetContents_2);

        horizontalLayout->addWidget(scrollArea_2);

        scrollArea->setWidget(scrollAreaWidgetContents);

        verticalLayout_3->addWidget(scrollArea);

        tabWidget->addTab(video_tab, QString());
        audio_tab = new QWidget();
        audio_tab->setObjectName("audio_tab");
        gridLayout_2 = new QGridLayout(audio_tab);
        gridLayout_2->setObjectName("gridLayout_2");
        cChannels = new QCheckBox(audio_tab);
        cChannels->setObjectName("cChannels");

        gridLayout_2->addWidget(cChannels, 0, 0, 1, 1);

        audioChannels = new QComboBox(audio_tab);
        audioChannels->setObjectName("audioChannels");
        audioChannels->setEnabled(false);
        sizePolicy.setHeightForWidth(audioChannels->sizePolicy().hasHeightForWidth());
        audioChannels->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(audioChannels, 0, 1, 1, 1);

        label_13 = new QLabel(audio_tab);
        label_13->setObjectName("label_13");

        gridLayout_2->addWidget(label_13, 1, 0, 1, 1);

        aCodecCombo = new QComboBox(audio_tab);
        aCodecCombo->setObjectName("aCodecCombo");

        gridLayout_2->addWidget(aCodecCombo, 1, 1, 1, 1);

        cSampleR = new QCheckBox(audio_tab);
        cSampleR->setObjectName("cSampleR");

        gridLayout_2->addWidget(cSampleR, 2, 0, 1, 1);

        gSampleR = new QGroupBox(audio_tab);
        gSampleR->setObjectName("gSampleR");
        gSampleR->setEnabled(false);
        gSampleR->setFlat(true);
        horizontalLayout_6 = new QHBoxLayout(gSampleR);
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalLayout_6->setContentsMargins(0, 0, 0, 0);
        audioSampleRate = new QComboBox(gSampleR);
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->addItem(QString());
        audioSampleRate->setObjectName("audioSampleRate");
        audioSampleRate->setEditable(true);

        horizontalLayout_6->addWidget(audioSampleRate);

        label_20 = new QLabel(gSampleR);
        label_20->setObjectName("label_20");
        label_20->setEnabled(false);

        horizontalLayout_6->addWidget(label_20);


        gridLayout_2->addWidget(gSampleR, 2, 1, 1, 1);

        label_14 = new QLabel(audio_tab);
        label_14->setObjectName("label_14");

        gridLayout_2->addWidget(label_14, 3, 0, 1, 1);

        aRateControlCombo = new QComboBox(audio_tab);
        aRateControlCombo->setObjectName("aRateControlCombo");

        gridLayout_2->addWidget(aRateControlCombo, 3, 1, 1, 1);

        label_18 = new QLabel(audio_tab);
        label_18->setObjectName("label_18");

        gridLayout_2->addWidget(label_18, 4, 0, 1, 1);

        aBitrate = new QSpinBox(audio_tab);
        aBitrate->setObjectName("aBitrate");
        aBitrate->setMaximum(500000);

        gridLayout_2->addWidget(aBitrate, 4, 1, 1, 1);

        label_19 = new QLabel(audio_tab);
        label_19->setObjectName("label_19");

        gridLayout_2->addWidget(label_19, 5, 0, 1, 1);

        aQuality = new QSpinBox(audio_tab);
        aQuality->setObjectName("aQuality");
        aQuality->setMaximum(500000);

        gridLayout_2->addWidget(aQuality, 5, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 6, 1, 1, 1);

        tabWidget->addTab(audio_tab, QString());
        other_tab = new QWidget();
        other_tab->setObjectName("other_tab");
        verticalLayout = new QVBoxLayout(other_tab);
        verticalLayout->setObjectName("verticalLayout");
        speedsLabel = new QLabel(other_tab);
        speedsLabel->setObjectName("speedsLabel");

        verticalLayout->addWidget(speedsLabel);

        speeds_list = new QTextEdit(other_tab);
        speeds_list->setObjectName("speeds_list");
        speeds_list->setAcceptRichText(false);

        verticalLayout->addWidget(speeds_list);

        label = new QLabel(other_tab);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        overrideParamsWarning = new KMessageWidget(other_tab);
        overrideParamsWarning->setObjectName("overrideParamsWarning");
        overrideParamsWarning->setWordWrap(true);
        overrideParamsWarning->setCloseButtonVisible(false);

        verticalLayout->addWidget(overrideParamsWarning);

        additionalParams = new QPlainTextEdit(other_tab);
        additionalParams->setObjectName("additionalParams");

        verticalLayout->addWidget(additionalParams);

        parametersLabel = new QLabel(other_tab);
        parametersLabel->setObjectName("parametersLabel");
        parametersLabel->setTextFormat(Qt::RichText);
        parametersLabel->setWordWrap(true);
        parametersLabel->setOpenExternalLinks(true);

        verticalLayout->addWidget(parametersLabel);

        kmessagewidget = new KMessageWidget(other_tab);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setWordWrap(true);
        kmessagewidget->setCloseButtonVisible(false);
        kmessagewidget->setMessageType(KMessageWidget::Warning);

        verticalLayout->addWidget(kmessagewidget);

        button_manual = new QPushButton(other_tab);
        button_manual->setObjectName("button_manual");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("data-warning");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_manual->setIcon(icon1);

        verticalLayout->addWidget(button_manual);

        tabWidget->addTab(other_tab, QString());

        verticalLayout_2->addWidget(tabWidget);

        parameters = new QPlainTextEdit(EditRenderPreset_UI);
        parameters->setObjectName("parameters");
        parameters->setReadOnly(true);

        verticalLayout_2->addWidget(parameters);

        buttonBox = new QDialogButtonBox(EditRenderPreset_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Help|QDialogButtonBox::Ok);

        verticalLayout_2->addWidget(buttonBox);


        retranslateUi(EditRenderPreset_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, EditRenderPreset_UI, qOverload<>(&QDialog::reject));
        QObject::connect(cResolution, &QCheckBox::toggled, gResolution, &QGroupBox::setEnabled);
        QObject::connect(cPar, &QCheckBox::toggled, parCombo, &QComboBox::setEnabled);
        QObject::connect(cDar, &QCheckBox::toggled, gDar, &QGroupBox::setEnabled);
        QObject::connect(cFps, &QCheckBox::toggled, gFps, &QGroupBox::setEnabled);
        QObject::connect(cScanning, &QCheckBox::toggled, scanningCombo, &QComboBox::setEnabled);
        QObject::connect(cField, &QCheckBox::toggled, fieldOrderCombo, &QComboBox::setEnabled);
        QObject::connect(cChannels, &QCheckBox::toggled, audioChannels, &QComboBox::setEnabled);
        QObject::connect(cSampleR, &QCheckBox::toggled, gSampleR, &QGroupBox::setEnabled);
        QObject::connect(cScanning, &QCheckBox::toggled, cField, &QCheckBox::setEnabled);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(EditRenderPreset_UI);
    } // setupUi

    void retranslateUi(QDialog *EditRenderPreset_UI)
    {
        EditRenderPreset_UI->setWindowTitle(tr2i18n("Save Render Preset", nullptr));
        groupLabel->setText(tr2i18n("Group:", nullptr));
        presetNameLabel->setText(tr2i18n("Preset name:", nullptr));
        label_container->setText(tr2i18n("Container:", nullptr));
        label_4->setText(tr2i18n("Extension:", nullptr));
        label_24->setText(tr2i18n("Codec:", nullptr));
        scanningCombo->setItemText(0, tr2i18n("Interlaced", nullptr));
        scanningCombo->setItemText(1, tr2i18n("Progressive", nullptr));

        cDar->setText(tr2i18n("Display Aspect Ratio:", nullptr));
        cPar->setText(tr2i18n("Pixel Aspect Ratio:", nullptr));
        fieldOrderCombo->setItemText(0, tr2i18n("Bottom Field First", nullptr));
        fieldOrderCombo->setItemText(1, tr2i18n("Top Field First", nullptr));

        cField->setText(tr2i18n("Field Order:", nullptr));
        vquality_label->setText(tr2i18n("Quality:", nullptr));
        linkResoultion->setText(tr2i18n("...", nullptr));
        cScanning->setText(tr2i18n("Scanning:", nullptr));
        frameRateDisplay->setText(tr2i18n("Placeholder", nullptr));
#if QT_CONFIG(tooltip)
        fixedGop->setToolTip(tr2i18n("A fixed GOP means that keyframes will not be inserted at detected scene changes.", nullptr));
#endif // QT_CONFIG(tooltip)
        fixedGop->setText(tr2i18n("Fixed", nullptr));
        gopSpinner->setSpecialValueText(tr2i18n("Auto", nullptr));
        gopSpinner->setSuffix(tr2i18n(" frame(s)", nullptr));
        default_vbitrate->setSuffix(tr2i18n("k", nullptr));
        cFps->setText(tr2i18n("Frame Rate:", nullptr));
        label_3->setText(tr2i18n("Fields per Second:", nullptr));
        bFramesSpinner->setSpecialValueText(tr2i18n("Auto", nullptr));
        bFramesSpinner->setSuffix(tr2i18n(" frame(s)", nullptr));
        label_2->setText(tr2i18n("Bitrate:", nullptr));
        label_12->setText(tr2i18n("Rate Control:", nullptr));
        cResolution->setText(tr2i18n("Resolution:", nullptr));
#if QT_CONFIG(tooltip)
        label_26->setToolTip(tr2i18n("GOP = Group of Pictures", nullptr));
#endif // QT_CONFIG(tooltip)
        label_26->setText(tr2i18n("GOP:", nullptr));
        label_5->setText(tr2i18n("Buffer Size:", nullptr));
        bFramesLabel->setText(tr2i18n("B Frames:", nullptr));
        vBuffer->setSuffix(tr2i18n(" KiB", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(video_tab), tr2i18n("Video", nullptr));
        cChannels->setText(tr2i18n("Channels:", nullptr));
        label_13->setText(tr2i18n("Codec:", nullptr));
        cSampleR->setText(tr2i18n("Sample Rate:", nullptr));
        audioSampleRate->setItemText(0, tr2i18n("8000", nullptr));
        audioSampleRate->setItemText(1, tr2i18n("12000", nullptr));
        audioSampleRate->setItemText(2, tr2i18n("16000", nullptr));
        audioSampleRate->setItemText(3, tr2i18n("22050", nullptr));
        audioSampleRate->setItemText(4, tr2i18n("32000", nullptr));
        audioSampleRate->setItemText(5, tr2i18n("44100", nullptr));
        audioSampleRate->setItemText(6, tr2i18n("48000", nullptr));
        audioSampleRate->setItemText(7, tr2i18n("96000", nullptr));

        label_20->setText(tr2i18n("Hz", nullptr));
        label_14->setText(tr2i18n("Rate Control:", nullptr));
        label_18->setText(tr2i18n("Bitrate:", nullptr));
        aBitrate->setSuffix(tr2i18n("k", nullptr));
        label_19->setText(tr2i18n("Quality:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(audio_tab), tr2i18n("Audio", nullptr));
        speedsLabel->setText(tr2i18n("Speed options:", nullptr));
#if QT_CONFIG(tooltip)
        speeds_list->setToolTip(tr2i18n("One line of options per speedup step, from slowest to fastest", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Additional Parameters:", nullptr));
        parametersLabel->setText(tr2i18n("<html><head/><body><p>See <a href=\"https://www.mltframework.org/plugins/ConsumerAvformat/\"><span style=\" text-decoration: underline; color:#2980b9;\">MLT documentation</span></a> for reference.</p></body></html>", nullptr));
        kmessagewidget->setText(tr2i18n("Enabling manual editing is for advanced users, you will only be able to edit the settings for this preset in a text box.", nullptr));
        button_manual->setText(tr2i18n("Enable manual editing", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(other_tab), tr2i18n("Other", nullptr));
    } // retranslateUi

};

namespace Ui {
    class EditRenderPreset_UI: public Ui_EditRenderPreset_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITRENDERPRESET_UI_H

