// /qt/qml/org/kde/kdenlive/MonitorOverlay.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_kdenlive_MonitorOverlay_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x9,0x0,0x0,0xc7,0xc7,0xbb,0xa1,
0x89,0x7e,0x1b,0x3a,0x3f,0x9c,0xa,0x2a,
0xc2,0xd2,0xed,0xcd,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0xb8,0x3,0x0,0x0,
0x4,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xd8,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0xe0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xc,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x18,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x38,0x7,0x0,0x0,
0x28,0x1,0x0,0x0,0x88,0x2,0x0,0x0,
0xe8,0x2,0x0,0x0,0x48,0x3,0x0,0x0,
0x98,0x3,0x0,0x0,0xa8,0x3,0x0,0x0,
0x33,0x0,0x0,0x0,0x50,0x0,0x0,0x0,
0xc3,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x40,0x0,0x0,0x0,0x54,0x1,0x0,0x0,
0x33,0x0,0x0,0x0,0x64,0x0,0x0,0x0,
0x33,0x0,0x0,0x0,0x64,0x0,0x0,0x0,
0x63,0x1,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x40,0xf5,0x7f,
0x1c,0x1,0x0,0x0,0x1,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xec,0x0,0x0,0x0,0x6b,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0xf,0x0,
0xff,0xff,0xff,0xff,0xe,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x2f,0x0,0x0,0x0,0x12,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x33,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x35,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x39,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x8,0x0,0x0,0x0,
0x3b,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x3f,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0xb,0x0,0x0,0x0,
0x41,0x0,0x0,0x0,0x1b,0x0,0x0,0x0,
0xd,0x0,0x0,0x0,0x45,0x0,0x0,0x0,
0x1c,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x47,0x0,0x0,0x0,0x1e,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x4b,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x4d,0x0,0x0,0x0,0x22,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x51,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x15,0x0,0x0,0x0,
0x69,0x0,0x0,0x0,0x25,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x12,0x0,0x18,0x7,
0x2e,0x0,0x3c,0x1,0x18,0x8,0x10,0x1,
0x6c,0x8,0x4e,0x1f,0x10,0x2,0x6c,0x8,
0x4e,0x1f,0x10,0x3,0x6c,0x8,0x4e,0x1f,
0x10,0x4,0x6c,0x8,0x4e,0x1f,0x10,0x5,
0x6c,0x8,0x4e,0x1f,0x6,0x6c,0x8,0x4e,
0x20,0x4c,0x1e,0x12,0x10,0x18,0x7,0x4c,
0x1c,0x12,0x11,0x18,0x7,0x4c,0x16,0x12,
0x12,0x18,0x7,0x4c,0x10,0x12,0x13,0x18,
0x7,0x4c,0xa,0x12,0x14,0x18,0x7,0x4c,
0x4,0x12,0x0,0x18,0x7,0x2e,0x2,0x18,
0x8,0x1a,0x7,0xb,0x2e,0x3,0x3c,0x4,
0x18,0xd,0xea,0x0,0x1,0xd,0x18,0xc,
0xac,0x5,0x8,0x2,0xb,0xe,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x8,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x27,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x27,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x27,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x6,0x18,0x7,0xac,0x7,0x7,
0x0,0x0,0x18,0x6,0xd4,0x16,0x6,0x2,
0x50,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0xa,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x28,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x28,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0x8,0x18,0x7,0xac,0x9,0x7,
0x0,0x0,0x18,0x6,0xd4,0x16,0x6,0x2,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x2c,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2c,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xa,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x18,0x4,0x0,0x0,0x20,0x4,0x0,0x0,
0x38,0x4,0x0,0x0,0x48,0x4,0x0,0x0,
0x68,0x4,0x0,0x0,0x78,0x4,0x0,0x0,
0x98,0x4,0x0,0x0,0xb0,0x4,0x0,0x0,
0xe0,0x4,0x0,0x0,0x30,0x5,0x0,0x0,
0x58,0x5,0x0,0x0,0x98,0x5,0x0,0x0,
0xb0,0x5,0x0,0x0,0xc8,0x5,0x0,0x0,
0xe0,0x5,0x0,0x0,0xf0,0x5,0x0,0x0,
0x20,0x6,0x0,0x0,0x50,0x6,0x0,0x0,
0x80,0x6,0x0,0x0,0xa8,0x6,0x0,0x0,
0xe0,0x6,0x0,0x0,0x8,0x7,0x0,0x0,
0x20,0x7,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x6f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x46,0x0,0x72,0x0,0x61,0x0,
0x6d,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x6f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x54,0x0,0x79,0x0,0x70,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x75,0x0,0x70,0x0,
0x64,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x14,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x4f,0x0,0x76,0x0,0x65,0x0,0x72,0x0,
0x6c,0x0,0x61,0x0,0x79,0x0,0x54,0x0,
0x79,0x0,0x70,0x0,0x65,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x23,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x4f,0x0,
0x76,0x0,0x65,0x0,0x72,0x0,0x6c,0x0,
0x61,0x0,0x79,0x0,0x54,0x0,0x79,0x0,
0x70,0x0,0x65,0x0,0x43,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x43,0x0,0x6f,0x0,0x6c,0x0,0x6f,0x0,
0x72,0x0,0x43,0x0,0x68,0x0,0x61,0x0,
0x6e,0x0,0x67,0x0,0x65,0x0,0x64,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x43,0x0,
0x6f,0x0,0x6c,0x0,0x6f,0x0,0x72,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x4c,0x0,0x6f,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6c,0x0,0x6f,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x4f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x53,0x0,0x74,0x0,0x61,0x0,
0x6e,0x0,0x64,0x0,0x61,0x0,0x72,0x0,
0x64,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x4f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x4d,0x0,0x69,0x0,0x6e,0x0,
0x69,0x0,0x6d,0x0,0x61,0x0,0x6c,0x0,
0x2e,0x0,0x71,0x0,0x6d,0x0,0x6c,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x4f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x43,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x2e,0x0,
0x71,0x0,0x6d,0x0,0x6c,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x4f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x43,0x0,0x65,0x0,0x6e,0x0,
0x74,0x0,0x65,0x0,0x72,0x0,0x44,0x0,
0x69,0x0,0x61,0x0,0x67,0x0,0x6f,0x0,
0x6e,0x0,0x61,0x0,0x6c,0x0,0x2e,0x0,
0x71,0x0,0x6d,0x0,0x6c,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x4f,0x0,0x76,0x0,
0x65,0x0,0x72,0x0,0x6c,0x0,0x61,0x0,
0x79,0x0,0x54,0x0,0x68,0x0,0x69,0x0,
0x72,0x0,0x64,0x0,0x73,0x0,0x2e,0x0,
0x71,0x0,0x6d,0x0,0x6c,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x53,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xf,0x2,0x0,0x0,0x30,0x0,0x0,0x0,
0x0,0x1,0x0,0x0,0x70,0x1,0x0,0x0,
0x2,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x1,0x0,0x2,0x0,0x54,0x0,0x0,0x0,
0x58,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x70,0x0,0x0,0x0,
0x70,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0x70,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd0,0x0,0x0,0x0,0x8,0x0,0x10,0x0,
0x9,0x0,0x50,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0xb,0x0,0x50,0x0,0x5,0x0,0x0,0x0,
0x2,0x0,0x0,0x20,0xc,0x0,0x50,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x28,0x0,0x50,0x0,0x28,0x0,0x50,0x1,
0x7,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x27,0x0,0x50,0x0,0x27,0x0,0xb0,0x1,
0x5,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x20,0x1,0xc,0x0,0xf0,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2a,0x0,0x50,0x0,0x2a,0x0,0x50,0x0,
0xb,0x0,0x0,0x0,0xc,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x2a,0x0,0x50,0x0,
0x2b,0x0,0x90,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x0,0x0,0xa,0x0,0x2,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2c,0x0,0x90,0x0,
0x2c,0x0,0x10,0x1,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0xff,0xff,0xff,0xff,0xff,0xff,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x2c,0x0,0x90,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x3,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x2c,0x0,0x10,0x1,
0x2c,0x0,0x70,0x1,0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 0, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// update at line 14, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_4, markStack);
    aotContext->mark(v2_81, markStack);
    aotContext->mark(v2_88, markStack);
    aotContext->mark(v2_90, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QJSValue v2_94;
QObject *v2_4 = nullptr;
QObject *v2_81 = nullptr;
QObject *v2_88 = nullptr;
QUrl c7_81;
QUrl v2_47;
QUrl v2_53;
QUrl v2_59;
QUrl v2_65;
QUrl v2_71;
QUrl v2_77;
QVariant v2_90;
bool v2_12;
bool v2_18;
bool v2_24;
bool v2_30;
bool v2_36;
bool v2_41;
int v2_10;
int v2_16;
int v2_22;
int v2_28;
int v2_34;
int v2_40;
int v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
{
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
while (!aotContext->loadContextIdLookup(0, &s.v2_4)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadContextIdLookup(0);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getObjectLookup(1, s.v2_4, &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetObjectLookup(1, s.v2_4);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadInt
s.v2_10 = 1;
{
}
// generate_CmpStrictEqual
s.v2_12 = s.v2_6 == s.v2_10;
{
}
// generate_JumpTrue
if (s.v2_12) {
    goto label_0;
}
{
}
// generate_LoadInt
s.v2_16 = 2;
{
}
// generate_CmpStrictEqual
s.v2_18 = s.v2_6 == s.v2_16;
{
}
// generate_JumpTrue
if (s.v2_18) {
    goto label_1;
}
{
}
// generate_LoadInt
s.v2_22 = 3;
{
}
// generate_CmpStrictEqual
s.v2_24 = s.v2_6 == s.v2_22;
{
}
// generate_JumpTrue
if (s.v2_24) {
    goto label_2;
}
{
}
// generate_LoadInt
s.v2_28 = 4;
{
}
// generate_CmpStrictEqual
s.v2_30 = s.v2_6 == s.v2_28;
{
}
// generate_JumpTrue
if (s.v2_30) {
    goto label_3;
}
{
}
// generate_LoadInt
s.v2_34 = 5;
{
}
// generate_CmpStrictEqual
s.v2_36 = s.v2_6 == s.v2_34;
{
}
// generate_JumpTrue
if (s.v2_36) {
    goto label_4;
}
{
}
// generate_LoadZero
s.v2_40 = 0;
{
}
// generate_CmpStrictEqual
s.v2_41 = s.v2_6 == s.v2_40;
{
}
// generate_JumpTrue
if (s.v2_41) {
    goto label_5;
}
{
}
// generate_Jump
{
    goto label_5;
}
label_0:;
// generate_LoadRuntimeString
s.v2_47 = QUrl(QStringLiteral("OverlayStandard.qml"));
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c7_81 = s.v2_47;
    goto label_6;
}
label_1:;
// generate_LoadRuntimeString
s.v2_53 = QUrl(QStringLiteral("OverlayMinimal.qml"));
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c7_81 = s.v2_53;
    goto label_6;
}
label_2:;
// generate_LoadRuntimeString
s.v2_59 = QUrl(QStringLiteral("OverlayCenter.qml"));
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c7_81 = s.v2_59;
    goto label_6;
}
label_3:;
// generate_LoadRuntimeString
s.v2_65 = QUrl(QStringLiteral("OverlayCenterDiagonal.qml"));
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c7_81 = s.v2_65;
    goto label_6;
}
label_4:;
// generate_LoadRuntimeString
s.v2_71 = QUrl(QStringLiteral("OverlayThirds.qml"));
{
}
// generate_StoreReg
{
}
// generate_Jump
{
s.c7_81 = s.v2_71;
    goto label_6;
}
label_5:;
// generate_LoadRuntimeString
s.v2_77 = QUrl(QStringLiteral(""));
{
}
// generate_StoreReg
{
s.c7_81 = s.v2_77;
}
label_6:;
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(83);
#endif
while (!aotContext->loadContextIdLookup(2, &s.v2_81)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(83);
#endif
aotContext->initLoadContextIdLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_MoveReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(90);
#endif
while (!aotContext->loadContextIdLookup(3, &s.v2_88)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(90);
#endif
aotContext->initLoadContextIdLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_GetLookup
{
QVariant retrieved;
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(92);
#endif
retrieved = QVariant(aotContext->lookupResultMetaType(4));
while (!aotContext->getObjectLookup(4, s.v2_88, retrieved.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(92);
#endif
aotContext->initGetObjectLookup(4, s.v2_88);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
retrieved = QVariant(aotContext->lookupResultMetaType(4));
}
s.v2_90 = std::move(retrieved);
}
{
}
// generate_StoreReg
{
}
// generate_DefineObjectLiteral
s.v2_94 = aotContext->engine->toScriptValue(QVariantMap {
{ QStringLiteral("color"), std::move(s.v2_90) },
});
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr, &s.c7_81, &s.v2_94};
    return aotContext->callObjectPropertyLookup(5, s.v2_81, args, 2);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(5, s.v2_81, 10);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(105);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(105);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onOverlayTypeChanged at line 39, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_5, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QVariant v2_5;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(6, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(7, s.v2_1, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(7, s.v2_1, 0);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_5 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_5);
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onColorChanged at line 40, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_5, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QVariant v2_5;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(8, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(9, s.v2_1, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(9, s.v2_1, 0);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_5 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_5);
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 44, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(10, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
