/****************************************************************************
** Meta object code from reading C++ file 'keyframemodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/keyframes/model/keyframemodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyframemodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13KeyframeModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyframeModel::qt_create_metaobjectdata<qt_meta_tag_ZN13KeyframeModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyframeModel",
        "modelChanged",
        "",
        "refreshModel",
        "requestModelUpdate",
        "QModelIndex",
        "QList<int>",
        "updateKeyframe",
        "pos",
        "newVal",
        "hasKeyframe",
        "frame",
        "GenTime",
        "realValueFromInternal",
        "internalValue",
        "realValue",
        "normalizedValue",
        "setSelectedKeyframe",
        "ix",
        "add",
        "activeKeyframe",
        "setActiveKeyframe",
        "data",
        "QVariant",
        "index",
        "role"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshModel'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestModelUpdate'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { 0x80000000 | 5, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Method 'updateKeyframe'
        QtMocHelpers::MethodData<bool(int, double)>(7, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 8 }, { QMetaType::Double, 9 },
        }}),
        // Method 'hasKeyframe'
        QtMocHelpers::MethodData<bool(int) const>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 11 },
        }}),
        // Method 'hasKeyframe'
        QtMocHelpers::MethodData<bool(const GenTime &) const>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 12, 8 },
        }}),
        // Method 'realValueFromInternal'
        QtMocHelpers::MethodData<QString(double) const>(13, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 14 },
        }}),
        // Method 'realValue'
        QtMocHelpers::MethodData<QString(double) const>(15, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::Double, 16 },
        }}),
        // Method 'setSelectedKeyframe'
        QtMocHelpers::MethodData<void(int, bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::Bool, 19 },
        }}),
        // Method 'activeKeyframe'
        QtMocHelpers::MethodData<int() const>(20, 2, QMC::AccessPublic, QMetaType::Int),
        // Method 'setActiveKeyframe'
        QtMocHelpers::MethodData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 },
        }}),
        // Method 'data'
        QtMocHelpers::MethodData<QVariant(const QModelIndex &, int) const>(22, 2, QMC::AccessPublic, 0x80000000 | 23, {{
            { 0x80000000 | 5, 24 }, { QMetaType::Int, 25 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyframeModel, qt_meta_tag_ZN13KeyframeModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyframeModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframeModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframeModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13KeyframeModelE_t>.metaTypes,
    nullptr
} };

void KeyframeModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyframeModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->refreshModel(); break;
        case 2: _t->requestModelUpdate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 3: { bool _r = _t->updateKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->hasKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->hasKeyframe((*reinterpret_cast<std::add_pointer_t<GenTime>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: { QString _r = _t->realValueFromInternal((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 7: { QString _r = _t->realValue((*reinterpret_cast<std::add_pointer_t<double>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setSelectedKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: { int _r = _t->activeKeyframe();
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setActiveKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: { QVariant _r = _t->data((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyframeModel::*)()>(_a, &KeyframeModel::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeModel::*)()>(_a, &KeyframeModel::refreshModel, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeModel::*)(const QModelIndex & , const QModelIndex & , const QVector<int> & )>(_a, &KeyframeModel::requestModelUpdate, 2))
            return;
    }
}

const QMetaObject *KeyframeModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyframeModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13KeyframeModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int KeyframeModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void KeyframeModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KeyframeModel::refreshModel()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KeyframeModel::requestModelUpdate(const QModelIndex & _t1, const QModelIndex & _t2, const QVector<int> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
