/********************************************************************************
** Form generated from reading UI file 'archivewidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ARCHIVEWIDGET_UI_H
#define UI_ARCHIVEWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ArchiveWidget_UI
{
public:
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *archive_url;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *compressed_archive;
    QComboBox *compression_type;
    QCheckBox *proxy_only;
    QCheckBox *timeline_archive;
    QHBoxLayout *horizontalLayout_2;
    QLabel *icon_info;
    QLabel *text_info;
    QLabel *project_files;
    QTreeWidget *files_list;
    QHBoxLayout *horizontalLayout_3;
    QProgressBar *progressBar;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ArchiveWidget_UI)
    {
        if (ArchiveWidget_UI->objectName().isEmpty())
            ArchiveWidget_UI->setObjectName("ArchiveWidget_UI");
        ArchiveWidget_UI->resize(313, 341);
        verticalLayout = new QVBoxLayout(ArchiveWidget_UI);
        verticalLayout->setObjectName("verticalLayout");
        groupBox = new QGroupBox(ArchiveWidget_UI);
        groupBox->setObjectName("groupBox");
        groupBox->setFlat(true);
        horizontalLayout = new QHBoxLayout(groupBox);
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        archive_url = new KUrlRequester(groupBox);
        archive_url->setObjectName("archive_url");
        archive_url->setMode(KFile::Directory|KFile::ExistingOnly|KFile::LocalOnly);

        horizontalLayout->addWidget(archive_url);


        verticalLayout->addWidget(groupBox);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        compressed_archive = new QCheckBox(ArchiveWidget_UI);
        compressed_archive->setObjectName("compressed_archive");

        horizontalLayout_4->addWidget(compressed_archive);

        compression_type = new QComboBox(ArchiveWidget_UI);
        compression_type->addItem(QString());
        compression_type->addItem(QString());
        compression_type->setObjectName("compression_type");

        horizontalLayout_4->addWidget(compression_type);


        verticalLayout->addLayout(horizontalLayout_4);

        proxy_only = new QCheckBox(ArchiveWidget_UI);
        proxy_only->setObjectName("proxy_only");

        verticalLayout->addWidget(proxy_only);

        timeline_archive = new QCheckBox(ArchiveWidget_UI);
        timeline_archive->setObjectName("timeline_archive");

        verticalLayout->addWidget(timeline_archive);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        icon_info = new QLabel(ArchiveWidget_UI);
        icon_info->setObjectName("icon_info");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(icon_info->sizePolicy().hasHeightForWidth());
        icon_info->setSizePolicy(sizePolicy);

        horizontalLayout_2->addWidget(icon_info);

        text_info = new QLabel(ArchiveWidget_UI);
        text_info->setObjectName("text_info");

        horizontalLayout_2->addWidget(text_info);


        verticalLayout->addLayout(horizontalLayout_2);

        project_files = new QLabel(ArchiveWidget_UI);
        project_files->setObjectName("project_files");

        verticalLayout->addWidget(project_files);

        files_list = new QTreeWidget(ArchiveWidget_UI);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        files_list->setHeaderItem(__qtreewidgetitem);
        files_list->setObjectName("files_list");
        files_list->setAlternatingRowColors(true);
        files_list->setSelectionBehavior(QAbstractItemView::SelectItems);
        files_list->header()->setVisible(false);

        verticalLayout->addWidget(files_list);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        progressBar = new QProgressBar(ArchiveWidget_UI);
        progressBar->setObjectName("progressBar");
        progressBar->setValue(0);

        horizontalLayout_3->addWidget(progressBar);

        buttonBox = new QDialogButtonBox(ArchiveWidget_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close);

        horizontalLayout_3->addWidget(buttonBox);


        verticalLayout->addLayout(horizontalLayout_3);


        retranslateUi(ArchiveWidget_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ArchiveWidget_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ArchiveWidget_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ArchiveWidget_UI);
    } // setupUi

    void retranslateUi(QDialog *ArchiveWidget_UI)
    {
        ArchiveWidget_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        groupBox->setTitle(QString());
        label->setText(tr2i18n("Archive folder:", nullptr));
        compressed_archive->setText(tr2i18n("Compressed archive:", nullptr));
        compression_type->setItemText(0, tr2i18n("tar.gz", nullptr));
        compression_type->setItemText(1, tr2i18n("zip", nullptr));

        proxy_only->setText(tr2i18n("Archive only proxy clips when available", nullptr));
        timeline_archive->setText(tr2i18n("Archive only timeline clips", nullptr));
        icon_info->setText(QString());
        text_info->setText(QString());
        project_files->setText(QString());
        progressBar->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ArchiveWidget_UI: public Ui_ArchiveWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // ARCHIVEWIDGET_UI_H

