/****************************************************************************
** Meta object code from reading C++ file 'temporarydata.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/project/dialogs/temporarydata.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'temporarydata.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TemporaryDataE_t {};
} // unnamed namespace

template <> constexpr inline auto TemporaryData::qt_create_metaobjectdata<qt_meta_tag_ZN13TemporaryDataE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TemporaryData",
        "disableProxies",
        "",
        "disablePreview",
        "gotProxySize",
        "KIO::filesize_t",
        "total",
        "gotFolderSize",
        "refreshGlobalPie",
        "deletePreview",
        "deleteProjectProxy",
        "deleteProxy",
        "deleteAudio",
        "deleteThumbs",
        "deleteCurrentCacheData",
        "warn",
        "deleteBackup",
        "cleanBackup",
        "openCacheFolder",
        "deleteSelected",
        "cleanCache",
        "cleanProxy",
        "slotCleanUp"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'disableProxies'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disablePreview'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'gotProxySize'
        QtMocHelpers::SlotData<void(KIO::filesize_t)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'gotFolderSize'
        QtMocHelpers::SlotData<void(KIO::filesize_t)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'refreshGlobalPie'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deletePreview'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteProjectProxy'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteProxy'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteAudio'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteThumbs'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteCurrentCacheData'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'deleteCurrentCacheData'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'deleteBackup'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanBackup'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openCacheFolder'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteSelected'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanCache'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanProxy'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCleanUp'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TemporaryData, qt_meta_tag_ZN13TemporaryDataE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TemporaryData::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TemporaryDataE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TemporaryDataE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TemporaryDataE_t>.metaTypes,
    nullptr
} };

void TemporaryData::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TemporaryData *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->disableProxies(); break;
        case 1: _t->disablePreview(); break;
        case 2: _t->gotProxySize((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 3: _t->gotFolderSize((*reinterpret_cast<std::add_pointer_t<KIO::filesize_t>>(_a[1]))); break;
        case 4: _t->refreshGlobalPie(); break;
        case 5: _t->deletePreview(); break;
        case 6: _t->deleteProjectProxy(); break;
        case 7: _t->deleteProxy(); break;
        case 8: _t->deleteAudio(); break;
        case 9: _t->deleteThumbs(); break;
        case 10: _t->deleteCurrentCacheData((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->deleteCurrentCacheData(); break;
        case 12: _t->deleteBackup(); break;
        case 13: _t->cleanBackup(); break;
        case 14: _t->openCacheFolder(); break;
        case 15: _t->deleteSelected(); break;
        case 16: _t->cleanCache(); break;
        case 17: _t->cleanProxy(); break;
        case 18: _t->slotCleanUp(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TemporaryData::*)()>(_a, &TemporaryData::disableProxies, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TemporaryData::*)()>(_a, &TemporaryData::disablePreview, 1))
            return;
    }
}

const QMetaObject *TemporaryData::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TemporaryData::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TemporaryDataE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ManageCache_UI"))
        return static_cast< Ui::ManageCache_UI*>(this);
    return QDialog::qt_metacast(_clname);
}

int TemporaryData::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void TemporaryData::disableProxies()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TemporaryData::disablePreview()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
