/****************************************************************************
** Meta object code from reading C++ file 'automaskhelper.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/keyframes/model/automask/automaskhelper.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'automaskhelper.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14AutomaskHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto AutomaskHelper::qt_create_metaobjectdata<qt_meta_tag_ZN14AutomaskHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AutomaskHelper",
        "showMessage",
        "",
        "message",
        "KMessageWidget::MessageType",
        "type",
        "updateProgress",
        "progress",
        "samJobFinished",
        "processCrashed",
        "generateMask",
        "binId",
        "maskName",
        "maskFile",
        "QPoint",
        "zone",
        "monitorSeek",
        "pos",
        "addMonitorControlPoint",
        "position",
        "QSize",
        "frameSize",
        "xPos",
        "yPos",
        "extend",
        "exclude",
        "moveMonitorControlPoint",
        "ix",
        "addMonitorControlRect",
        "QRect",
        "rect",
        "abortJob",
        "updateMaskParams",
        "generateImage",
        "sceneUpdated",
        "MonitorSceneType",
        "sceneType"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(const QString &, KMessageWidget::MessageType)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 4, 5 },
        }}),
        // Signal 'showMessage'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'updateProgress'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Signal 'samJobFinished'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processCrashed'
        QtMocHelpers::SignalData<void(const QString &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'generateMask'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QPoint &)>(10, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'monitorSeek'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 17 },
        }}),
        // Slot 'addMonitorControlPoint'
        QtMocHelpers::SlotData<void(int, const QSize, int, int, bool, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 22 }, { QMetaType::Int, 23 },
            { QMetaType::Bool, 24 }, { QMetaType::Bool, 25 },
        }}),
        // Slot 'moveMonitorControlPoint'
        QtMocHelpers::SlotData<void(int, int, const QSize, int, int)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 }, { QMetaType::Int, 22 },
            { QMetaType::Int, 23 },
        }}),
        // Slot 'addMonitorControlRect'
        QtMocHelpers::SlotData<void(int, const QSize, const QRect, bool)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 29, 30 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'abortJob'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMaskParams'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'generateImage'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'sceneUpdated'
        QtMocHelpers::SlotData<void(MonitorSceneType)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AutomaskHelper, qt_meta_tag_ZN14AutomaskHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AutomaskHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutomaskHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutomaskHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14AutomaskHelperE_t>.metaTypes,
    nullptr
} };

void AutomaskHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AutomaskHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 1: _t->showMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->samJobFinished(); break;
        case 4: _t->processCrashed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: { bool _r = _t->generateMask((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->monitorSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->addMonitorControlPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 8: _t->moveMonitorControlPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 9: _t->addMonitorControlRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 10: _t->abortJob(); break;
        case 11: _t->updateMaskParams(); break;
        case 12: _t->generateImage(); break;
        case 13: _t->sceneUpdated((*reinterpret_cast<std::add_pointer_t<MonitorSceneType>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AutomaskHelper::*)(const QString & , KMessageWidget::MessageType )>(_a, &AutomaskHelper::showMessage, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutomaskHelper::*)(int )>(_a, &AutomaskHelper::updateProgress, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutomaskHelper::*)()>(_a, &AutomaskHelper::samJobFinished, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AutomaskHelper::*)(const QString & )>(_a, &AutomaskHelper::processCrashed, 4))
            return;
    }
}

const QMetaObject *AutomaskHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AutomaskHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14AutomaskHelperE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AutomaskHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void AutomaskHelper::showMessage(const QString & _t1, KMessageWidget::MessageType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 2
void AutomaskHelper::updateProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void AutomaskHelper::samJobFinished()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AutomaskHelper::processCrashed(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
