/********************************************************************************
** Form generated from reading UI file 'managecache_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGECACHE_UI_H
#define UI_MANAGECACHE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ManageCache_UI
{
public:
    QVBoxLayout *verticalLayout;
    QTabWidget *tabWidget;
    QWidget *projectPage;
    QVBoxLayout *verticalLayout_3;
    QGridLayout *gridLayout;
    QLabel *audioSize;
    QLabel *thumbLabel;
    QToolButton *delCurrent;
    QToolButton *delThumb;
    QLabel *thumbSize;
    QToolButton *delProxy;
    QFrame *seperator1;
    QLabel *previewLabel;
    QToolButton *delAudio;
    QLabel *thumbColor;
    QLabel *proxyColor;
    QLabel *proxySize;
    QLabel *sequenceColor;
    QSpacerItem *verticalSpacer;
    QLabel *label_4;
    QLabel *audioLabel;
    QLabel *currentSize;
    QLabel *previewSize;
    QLabel *currentPath;
    QLabel *sequenceSize;
    QLabel *proxyLabel;
    QLabel *currentLabel;
    QLabel *previewColor;
    QHBoxLayout *currentChartBox;
    QLabel *audioColor;
    QToolButton *delPreview;
    QWidget *globalPage;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QToolButton *help_cached;
    QHBoxLayout *gChartLayout;
    QTreeWidget *listWidget;
    QGridLayout *gridLayout_2;
    QLabel *gTotalLabel;
    QLabel *gTotalSize;
    QSpacerItem *horizontalSpacer_5;
    QLabel *qSelectedLabel;
    QSpacerItem *horizontalSpacer_4;
    QToolButton *gClean;
    QLabel *gSelectedSize;
    QToolButton *gDelete;
    QLabel *gSelectedColor;
    QLabel *gTotalColor;
    QFrame *seperator3;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QSpacerItem *horizontalSpacer_2;
    QLabel *gBackupLabel;
    QLabel *gBackupSize;
    QHBoxLayout *horizontalLayout_3;
    QLabel *gBackupPath;
    QSpacerItem *horizontalSpacer_6;
    QToolButton *gBackupClean;
    QToolButton *gBackupDelete;
    QFrame *seperator2;
    QHBoxLayout *horizontalLayout_4;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer_3;
    QLabel *gProxyLabel;
    QLabel *gProxySize;
    QHBoxLayout *horizontalLayout_5;
    QLabel *gProxyPath;
    QSpacerItem *horizontalSpacer_7;
    QToolButton *gProxyClean;
    QToolButton *gProxyDelete;
    QFrame *seperator4;
    QHBoxLayout *cleanupLayout;
    QLabel *gCleanupLabel;
    QSpinBox *gCleanupSpin;
    KMessageWidget *cache_info;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ManageCache_UI)
    {
        if (ManageCache_UI->objectName().isEmpty())
            ManageCache_UI->setObjectName("ManageCache_UI");
        ManageCache_UI->resize(517, 569);
        verticalLayout = new QVBoxLayout(ManageCache_UI);
        verticalLayout->setObjectName("verticalLayout");
        tabWidget = new QTabWidget(ManageCache_UI);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setTabBarAutoHide(true);
        projectPage = new QWidget();
        projectPage->setObjectName("projectPage");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(projectPage->sizePolicy().hasHeightForWidth());
        projectPage->setSizePolicy(sizePolicy);
        verticalLayout_3 = new QVBoxLayout(projectPage);
        verticalLayout_3->setObjectName("verticalLayout_3");
        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        audioSize = new QLabel(projectPage);
        audioSize->setObjectName("audioSize");

        gridLayout->addWidget(audioSize, 2, 3, 1, 1);

        thumbLabel = new QLabel(projectPage);
        thumbLabel->setObjectName("thumbLabel");

        gridLayout->addWidget(thumbLabel, 3, 2, 1, 1);

        delCurrent = new QToolButton(projectPage);
        delCurrent->setObjectName("delCurrent");
        delCurrent->setEnabled(false);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        delCurrent->setIcon(icon);

        gridLayout->addWidget(delCurrent, 7, 4, 1, 1);

        delThumb = new QToolButton(projectPage);
        delThumb->setObjectName("delThumb");
        delThumb->setEnabled(false);
        delThumb->setIcon(icon);

        gridLayout->addWidget(delThumb, 3, 4, 1, 1);

        thumbSize = new QLabel(projectPage);
        thumbSize->setObjectName("thumbSize");

        gridLayout->addWidget(thumbSize, 3, 3, 1, 1);

        delProxy = new QToolButton(projectPage);
        delProxy->setObjectName("delProxy");
        delProxy->setEnabled(false);
        delProxy->setIcon(icon);

        gridLayout->addWidget(delProxy, 1, 4, 1, 1);

        seperator1 = new QFrame(projectPage);
        seperator1->setObjectName("seperator1");
        seperator1->setFrameShape(QFrame::HLine);
        seperator1->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(seperator1, 6, 0, 1, 5);

        previewLabel = new QLabel(projectPage);
        previewLabel->setObjectName("previewLabel");

        gridLayout->addWidget(previewLabel, 0, 2, 1, 1);

        delAudio = new QToolButton(projectPage);
        delAudio->setObjectName("delAudio");
        delAudio->setEnabled(false);
        delAudio->setIcon(icon);

        gridLayout->addWidget(delAudio, 2, 4, 1, 1);

        thumbColor = new QLabel(projectPage);
        thumbColor->setObjectName("thumbColor");
        thumbColor->setAutoFillBackground(true);

        gridLayout->addWidget(thumbColor, 3, 1, 1, 1);

        proxyColor = new QLabel(projectPage);
        proxyColor->setObjectName("proxyColor");
        proxyColor->setAutoFillBackground(true);

        gridLayout->addWidget(proxyColor, 1, 1, 1, 1);

        proxySize = new QLabel(projectPage);
        proxySize->setObjectName("proxySize");

        gridLayout->addWidget(proxySize, 1, 3, 1, 1);

        sequenceColor = new QLabel(projectPage);
        sequenceColor->setObjectName("sequenceColor");
        sequenceColor->setAutoFillBackground(true);

        gridLayout->addWidget(sequenceColor, 4, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 5, 2, 1, 1);

        label_4 = new QLabel(projectPage);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 4, 2, 1, 1);

        audioLabel = new QLabel(projectPage);
        audioLabel->setObjectName("audioLabel");

        gridLayout->addWidget(audioLabel, 2, 2, 1, 1);

        currentSize = new QLabel(projectPage);
        currentSize->setObjectName("currentSize");

        gridLayout->addWidget(currentSize, 7, 3, 1, 1);

        previewSize = new QLabel(projectPage);
        previewSize->setObjectName("previewSize");

        gridLayout->addWidget(previewSize, 0, 3, 1, 1);

        currentPath = new QLabel(projectPage);
        currentPath->setObjectName("currentPath");

        gridLayout->addWidget(currentPath, 8, 0, 1, 5);

        sequenceSize = new QLabel(projectPage);
        sequenceSize->setObjectName("sequenceSize");

        gridLayout->addWidget(sequenceSize, 4, 3, 1, 1);

        proxyLabel = new QLabel(projectPage);
        proxyLabel->setObjectName("proxyLabel");

        gridLayout->addWidget(proxyLabel, 1, 2, 1, 1);

        currentLabel = new QLabel(projectPage);
        currentLabel->setObjectName("currentLabel");

        gridLayout->addWidget(currentLabel, 7, 0, 1, 3);

        previewColor = new QLabel(projectPage);
        previewColor->setObjectName("previewColor");
        previewColor->setAutoFillBackground(true);

        gridLayout->addWidget(previewColor, 0, 1, 1, 1);

        currentChartBox = new QHBoxLayout();
        currentChartBox->setObjectName("currentChartBox");

        gridLayout->addLayout(currentChartBox, 0, 0, 6, 1);

        audioColor = new QLabel(projectPage);
        audioColor->setObjectName("audioColor");
        audioColor->setAutoFillBackground(true);

        gridLayout->addWidget(audioColor, 2, 1, 1, 1);

        delPreview = new QToolButton(projectPage);
        delPreview->setObjectName("delPreview");
        delPreview->setEnabled(false);
        delPreview->setIcon(icon);

        gridLayout->addWidget(delPreview, 0, 4, 1, 1);


        verticalLayout_3->addLayout(gridLayout);

        tabWidget->addTab(projectPage, QString());
        globalPage = new QWidget();
        globalPage->setObjectName("globalPage");
        verticalLayout_2 = new QVBoxLayout(globalPage);
        verticalLayout_2->setObjectName("verticalLayout_2");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(globalPage);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        horizontalSpacer = new QSpacerItem(337, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        help_cached = new QToolButton(globalPage);
        help_cached->setObjectName("help_cached");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        help_cached->setIcon(icon1);
        help_cached->setAutoRaise(true);

        horizontalLayout->addWidget(help_cached);


        verticalLayout_2->addLayout(horizontalLayout);

        gChartLayout = new QHBoxLayout();
        gChartLayout->setObjectName("gChartLayout");
        listWidget = new QTreeWidget(globalPage);
        listWidget->setObjectName("listWidget");
        listWidget->setAlternatingRowColors(true);
        listWidget->setSelectionMode(QAbstractItemView::ExtendedSelection);
        listWidget->setRootIsDecorated(false);
        listWidget->setSortingEnabled(true);

        gChartLayout->addWidget(listWidget);


        verticalLayout_2->addLayout(gChartLayout);

        gridLayout_2 = new QGridLayout();
        gridLayout_2->setObjectName("gridLayout_2");
        gTotalLabel = new QLabel(globalPage);
        gTotalLabel->setObjectName("gTotalLabel");

        gridLayout_2->addWidget(gTotalLabel, 0, 1, 1, 1);

        gTotalSize = new QLabel(globalPage);
        gTotalSize->setObjectName("gTotalSize");

        gridLayout_2->addWidget(gTotalSize, 0, 2, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 1, 3, 1, 1);

        qSelectedLabel = new QLabel(globalPage);
        qSelectedLabel->setObjectName("qSelectedLabel");

        gridLayout_2->addWidget(qSelectedLabel, 1, 1, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_4, 0, 3, 1, 1);

        gClean = new QToolButton(globalPage);
        gClean->setObjectName("gClean");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-clear-history");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        gClean->setIcon(icon2);

        gridLayout_2->addWidget(gClean, 0, 4, 1, 1);

        gSelectedSize = new QLabel(globalPage);
        gSelectedSize->setObjectName("gSelectedSize");

        gridLayout_2->addWidget(gSelectedSize, 1, 2, 1, 1);

        gDelete = new QToolButton(globalPage);
        gDelete->setObjectName("gDelete");
        gDelete->setIcon(icon);

        gridLayout_2->addWidget(gDelete, 1, 4, 1, 1);

        gSelectedColor = new QLabel(globalPage);
        gSelectedColor->setObjectName("gSelectedColor");
        gSelectedColor->setAutoFillBackground(true);

        gridLayout_2->addWidget(gSelectedColor, 1, 0, 1, 1);

        gTotalColor = new QLabel(globalPage);
        gTotalColor->setObjectName("gTotalColor");
        gTotalColor->setAutoFillBackground(true);

        gridLayout_2->addWidget(gTotalColor, 0, 0, 1, 1);


        verticalLayout_2->addLayout(gridLayout_2);

        seperator3 = new QFrame(globalPage);
        seperator3->setObjectName("seperator3");
        seperator3->setFrameShape(QFrame::HLine);
        seperator3->setFrameShadow(QFrame::Raised);

        verticalLayout_2->addWidget(seperator3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(globalPage);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        horizontalSpacer_2 = new QSpacerItem(186, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_2);

        gBackupLabel = new QLabel(globalPage);
        gBackupLabel->setObjectName("gBackupLabel");

        horizontalLayout_2->addWidget(gBackupLabel);

        gBackupSize = new QLabel(globalPage);
        gBackupSize->setObjectName("gBackupSize");

        horizontalLayout_2->addWidget(gBackupSize);


        verticalLayout_2->addLayout(horizontalLayout_2);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        gBackupPath = new QLabel(globalPage);
        gBackupPath->setObjectName("gBackupPath");

        horizontalLayout_3->addWidget(gBackupPath);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_6);

        gBackupClean = new QToolButton(globalPage);
        gBackupClean->setObjectName("gBackupClean");
        gBackupClean->setIcon(icon2);

        horizontalLayout_3->addWidget(gBackupClean);

        gBackupDelete = new QToolButton(globalPage);
        gBackupDelete->setObjectName("gBackupDelete");
        gBackupDelete->setIcon(icon);

        horizontalLayout_3->addWidget(gBackupDelete);


        verticalLayout_2->addLayout(horizontalLayout_3);

        seperator2 = new QFrame(globalPage);
        seperator2->setObjectName("seperator2");
        seperator2->setFrameShape(QFrame::HLine);
        seperator2->setFrameShadow(QFrame::Raised);

        verticalLayout_2->addWidget(seperator2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        label_3 = new QLabel(globalPage);
        label_3->setObjectName("label_3");

        horizontalLayout_4->addWidget(label_3);

        horizontalSpacer_3 = new QSpacerItem(186, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_3);

        gProxyLabel = new QLabel(globalPage);
        gProxyLabel->setObjectName("gProxyLabel");

        horizontalLayout_4->addWidget(gProxyLabel);

        gProxySize = new QLabel(globalPage);
        gProxySize->setObjectName("gProxySize");

        horizontalLayout_4->addWidget(gProxySize);


        verticalLayout_2->addLayout(horizontalLayout_4);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        gProxyPath = new QLabel(globalPage);
        gProxyPath->setObjectName("gProxyPath");

        horizontalLayout_5->addWidget(gProxyPath);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_7);

        gProxyClean = new QToolButton(globalPage);
        gProxyClean->setObjectName("gProxyClean");
        gProxyClean->setIcon(icon2);

        horizontalLayout_5->addWidget(gProxyClean);

        gProxyDelete = new QToolButton(globalPage);
        gProxyDelete->setObjectName("gProxyDelete");
        gProxyDelete->setIcon(icon);

        horizontalLayout_5->addWidget(gProxyDelete);


        verticalLayout_2->addLayout(horizontalLayout_5);

        seperator4 = new QFrame(globalPage);
        seperator4->setObjectName("seperator4");
        seperator4->setFrameShape(QFrame::HLine);
        seperator4->setFrameShadow(QFrame::Raised);

        verticalLayout_2->addWidget(seperator4);

        cleanupLayout = new QHBoxLayout();
        cleanupLayout->setObjectName("cleanupLayout");
        gCleanupLabel = new QLabel(globalPage);
        gCleanupLabel->setObjectName("gCleanupLabel");

        cleanupLayout->addWidget(gCleanupLabel);

        gCleanupSpin = new QSpinBox(globalPage);
        gCleanupSpin->setObjectName("gCleanupSpin");
        gCleanupSpin->setMinimum(1);
        gCleanupSpin->setMaximum(48);
        gCleanupSpin->setValue(6);

        cleanupLayout->addWidget(gCleanupSpin);


        verticalLayout_2->addLayout(cleanupLayout);

        cache_info = new KMessageWidget(globalPage);
        cache_info->setObjectName("cache_info");
        cache_info->setWordWrap(true);
        cache_info->setCloseButtonVisible(false);
        cache_info->setMessageType(KMessageWidget::Warning);

        verticalLayout_2->addWidget(cache_info);

        tabWidget->addTab(globalPage, QString());

        verticalLayout->addWidget(tabWidget);

        buttonBox = new QDialogButtonBox(ManageCache_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(ManageCache_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ManageCache_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ManageCache_UI, qOverload<>(&QDialog::reject));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ManageCache_UI);
    } // setupUi

    void retranslateUi(QDialog *ManageCache_UI)
    {
        ManageCache_UI->setWindowTitle(tr2i18n("Manage Cache Data", nullptr));
#if QT_CONFIG(accessibility)
        projectPage->setAccessibleName(tr2i18n("Current Project", nullptr));
#endif // QT_CONFIG(accessibility)
        audioSize->setText(tr2i18n("0 B", nullptr));
        thumbLabel->setText(tr2i18n("Video thumbnails:", nullptr));
        delCurrent->setText(tr2i18n("...", nullptr));
        delThumb->setText(tr2i18n("...", nullptr));
        thumbSize->setText(tr2i18n("0 B", nullptr));
        delProxy->setText(tr2i18n("...", nullptr));
        previewLabel->setText(tr2i18n("Timeline preview:", nullptr));
        delAudio->setText(tr2i18n("...", nullptr));
        thumbColor->setText(QString());
        proxyColor->setText(QString());
        proxySize->setText(tr2i18n("0 B", nullptr));
        sequenceColor->setText(QString());
        label_4->setText(tr2i18n("Sequences", nullptr));
        audioLabel->setText(tr2i18n("Audio thumbnails:", nullptr));
        currentSize->setText(tr2i18n("0 B", nullptr));
        previewSize->setText(tr2i18n("0 B", nullptr));
#if QT_CONFIG(tooltip)
        currentPath->setToolTip(tr2i18n("Click to open cache folder.", nullptr));
#endif // QT_CONFIG(tooltip)
        currentPath->setText(tr2i18n("<a href='#'>/home/user/.cache/kdenlive/1617522274308</a>", nullptr));
        sequenceSize->setText(tr2i18n("0 B", nullptr));
        proxyLabel->setText(tr2i18n("Proxy clips:", nullptr));
        currentLabel->setText(tr2i18n("Project total cache data:", nullptr));
        previewColor->setText(QString());
        audioColor->setText(QString());
        delPreview->setText(tr2i18n("...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(projectPage), tr2i18n("Current Project", nullptr));
#if QT_CONFIG(accessibility)
        globalPage->setAccessibleName(tr2i18n("Current Project", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(accessibility)
        globalPage->setAccessibleDescription(tr2i18n("Current Project", nullptr));
#endif // QT_CONFIG(accessibility)
#if QT_CONFIG(tooltip)
        label->setToolTip(tr2i18n("Cached data is composed of clip thumbnails (audio and video) and timeline preview videos. Deleting is safe, all data can be recreated on project opening.", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(tr2i18n("Cache data", nullptr));
        help_cached->setText(tr2i18n("...", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = listWidget->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("Date", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Size", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Folder", nullptr));
        gTotalLabel->setText(tr2i18n("Total cached data:", nullptr));
        gTotalSize->setText(tr2i18n("Calculating...", nullptr));
        qSelectedLabel->setText(tr2i18n("Selected cached data:", nullptr));
#if QT_CONFIG(tooltip)
        gClean->setToolTip(tr2i18n("Cleanup unused cache.", nullptr));
#endif // QT_CONFIG(tooltip)
        gSelectedSize->setText(tr2i18n("Calculating...", nullptr));
#if QT_CONFIG(tooltip)
        gDelete->setToolTip(tr2i18n("Delete selected cache.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_2->setText(tr2i18n("Backup data", nullptr));
        gBackupLabel->setText(tr2i18n("Total size:", nullptr));
        gBackupSize->setText(tr2i18n("Calculating...", nullptr));
#if QT_CONFIG(tooltip)
        gBackupPath->setToolTip(tr2i18n("Click to open backup folder.", nullptr));
#endif // QT_CONFIG(tooltip)
        gBackupPath->setText(tr2i18n("<a href='#'>/home/user/.local/share/kdenlive/.backup</a>", nullptr));
#if QT_CONFIG(tooltip)
        gBackupClean->setToolTip(tr2i18n("Cleanup old backups.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gBackupDelete->setToolTip(tr2i18n("Delete all backup data.", nullptr));
#endif // QT_CONFIG(tooltip)
        label_3->setText(tr2i18n("Proxy clip data", nullptr));
        gProxyLabel->setText(tr2i18n("Total size:", nullptr));
        gProxySize->setText(tr2i18n("Calculating...", nullptr));
#if QT_CONFIG(tooltip)
        gProxyPath->setToolTip(tr2i18n("Click to open proxy folder.", nullptr));
#endif // QT_CONFIG(tooltip)
        gProxyPath->setText(tr2i18n("<a href='#'>/home/user/.cache/kdenlive/proxy</a>", nullptr));
#if QT_CONFIG(tooltip)
        gProxyClean->setToolTip(tr2i18n("Cleanup old proxy file.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gProxyDelete->setToolTip(tr2i18n("Delete all proxy clips.", nullptr));
#endif // QT_CONFIG(tooltip)
        gCleanupLabel->setText(tr2i18n("Cleanup will delete data older than:", nullptr));
        gCleanupSpin->setSuffix(tr2i18n(" months", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(globalPage), tr2i18n("All Projects", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManageCache_UI: public Ui_ManageCache_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGECACHE_UI_H

