/********************************************************************************
** Form generated from reading UI file 'guideslist_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUIDESLIST_UI_H
#define UI_GUIDESLIST_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ksqueezedtextlabel.h"
#include "widgets/markercategorybutton.h"

QT_BEGIN_NAMESPACE

class Ui_GuidesList_UI
{
public:
    QGridLayout *gridLayout;
    QLineEdit *filter_line;
    QListView *guides_list;
    QHBoxLayout *horizontalLayout_2;
    KSqueezedTextLabel *guideslist_label;
    QToolButton *show_all;
    MarkerCategoryButton *show_categories;
    QToolButton *sort_guides;
    QHBoxLayout *horizontalLayout;
    QToolButton *guide_add;
    QToolButton *guide_edit;
    QToolButton *guide_delete;
    QToolButton *default_category;
    QToolButton *guides_lock;
    QToolButton *thumbs_refresh;
    QSpacerItem *horizontalSpacer;
    QToolButton *guides_settings;

    void setupUi(QWidget *GuidesList_UI)
    {
        if (GuidesList_UI->objectName().isEmpty())
            GuidesList_UI->setObjectName("GuidesList_UI");
        GuidesList_UI->resize(267, 288);
        gridLayout = new QGridLayout(GuidesList_UI);
        gridLayout->setObjectName("gridLayout");
        filter_line = new QLineEdit(GuidesList_UI);
        filter_line->setObjectName("filter_line");
        filter_line->setClearButtonEnabled(true);

        gridLayout->addWidget(filter_line, 1, 0, 1, 1);

        guides_list = new QListView(GuidesList_UI);
        guides_list->setObjectName("guides_list");
        guides_list->setAlternatingRowColors(true);

        gridLayout->addWidget(guides_list, 2, 0, 1, 3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        guideslist_label = new KSqueezedTextLabel(GuidesList_UI);
        guideslist_label->setObjectName("guideslist_label");

        horizontalLayout_2->addWidget(guideslist_label);

        show_all = new QToolButton(GuidesList_UI);
        show_all->setObjectName("show_all");
        QIcon icon(QIcon::fromTheme(QIcon::ThemeIcon::EditSelectAll));
        show_all->setIcon(icon);
        show_all->setCheckable(true);
        show_all->setAutoRaise(true);

        horizontalLayout_2->addWidget(show_all);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 3);

        show_categories = new MarkerCategoryButton(GuidesList_UI);
        show_categories->setObjectName("show_categories");

        gridLayout->addWidget(show_categories, 1, 1, 1, 1);

        sort_guides = new QToolButton(GuidesList_UI);
        sort_guides->setObjectName("sort_guides");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("view-sort")));
        sort_guides->setIcon(icon1);
        sort_guides->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        sort_guides->setAutoRaise(true);

        gridLayout->addWidget(sort_guides, 1, 2, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        guide_add = new QToolButton(GuidesList_UI);
        guide_add->setObjectName("guide_add");
        QIcon icon2;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        guide_add->setIcon(icon2);
        guide_add->setPopupMode(QToolButton::ToolButtonPopupMode::DelayedPopup);
        guide_add->setAutoRaise(true);

        horizontalLayout->addWidget(guide_add);

        guide_edit = new QToolButton(GuidesList_UI);
        guide_edit->setObjectName("guide_edit");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        guide_edit->setIcon(icon3);
        guide_edit->setAutoRaise(true);

        horizontalLayout->addWidget(guide_edit);

        guide_delete = new QToolButton(GuidesList_UI);
        guide_delete->setObjectName("guide_delete");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        guide_delete->setIcon(icon4);
        guide_delete->setAutoRaise(true);

        horizontalLayout->addWidget(guide_delete);

        default_category = new QToolButton(GuidesList_UI);
        default_category->setObjectName("default_category");
        default_category->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        default_category->setAutoRaise(true);

        horizontalLayout->addWidget(default_category);

        guides_lock = new QToolButton(GuidesList_UI);
        guides_lock->setObjectName("guides_lock");
        guides_lock->setCheckable(true);
        guides_lock->setAutoRaise(true);

        horizontalLayout->addWidget(guides_lock);

        thumbs_refresh = new QToolButton(GuidesList_UI);
        thumbs_refresh->setObjectName("thumbs_refresh");
        QIcon icon5(QIcon::fromTheme(QIcon::ThemeIcon::ViewRefresh));
        thumbs_refresh->setIcon(icon5);
        thumbs_refresh->setAutoRaise(true);

        horizontalLayout->addWidget(thumbs_refresh);

        horizontalSpacer = new QSpacerItem(77, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        guides_settings = new QToolButton(GuidesList_UI);
        guides_settings->setObjectName("guides_settings");
        QIcon icon6;
        iconThemeName = QString::fromUtf8("application-menu");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon6 = QIcon::fromTheme(iconThemeName);
        } else {
            icon6.addFile(QString::fromUtf8("../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        guides_settings->setIcon(icon6);
        guides_settings->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        guides_settings->setAutoRaise(true);

        horizontalLayout->addWidget(guides_settings);


        gridLayout->addLayout(horizontalLayout, 3, 0, 1, 3);

        QWidget::setTabOrder(filter_line, show_categories);
        QWidget::setTabOrder(show_categories, sort_guides);
        QWidget::setTabOrder(sort_guides, guides_list);
        QWidget::setTabOrder(guides_list, guide_add);
        QWidget::setTabOrder(guide_add, guide_edit);
        QWidget::setTabOrder(guide_edit, guide_delete);
        QWidget::setTabOrder(guide_delete, default_category);
        QWidget::setTabOrder(default_category, guides_settings);

        retranslateUi(GuidesList_UI);

        QMetaObject::connectSlotsByName(GuidesList_UI);
    } // setupUi

    void retranslateUi(QWidget *GuidesList_UI)
    {
        filter_line->setPlaceholderText(tr2i18n("Search Markers", nullptr));
        guideslist_label->setText(tr2i18n("KSqueezedTextLabel", nullptr));
        show_all->setText(tr2i18n("...", nullptr));
        sort_guides->setText(tr2i18n("...", nullptr));
        guide_add->setText(tr2i18n("...", nullptr));
        guide_edit->setText(tr2i18n("...", nullptr));
        guide_delete->setText(tr2i18n("...", nullptr));
        default_category->setText(tr2i18n("...", nullptr));
        guides_lock->setText(tr2i18n("...", nullptr));
        thumbs_refresh->setText(tr2i18n("...", nullptr));
        guides_settings->setText(tr2i18n("...", nullptr));
        (void)GuidesList_UI;
    } // retranslateUi

};

namespace Ui {
    class GuidesList_UI: public Ui_GuidesList_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GUIDESLIST_UI_H

