/********************************************************************************
** Form generated from reading UI file 'guidecategories_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GUIDECATEGORIES_UI_H
#define UI_GUIDECATEGORIES_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_GuideCategories_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QListWidget *guides_list;
    QPushButton *guide_delete;
    QPushButton *guide_add;
    QPushButton *guide_edit;
    QLabel *label;

    void setupUi(QWidget *GuideCategories_UI)
    {
        if (GuideCategories_UI->objectName().isEmpty())
            GuideCategories_UI->setObjectName("GuideCategories_UI");
        GuideCategories_UI->resize(463, 398);
        gridLayout = new QGridLayout(GuideCategories_UI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        verticalSpacer = new QSpacerItem(20, 275, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 1, 1, 1);

        guides_list = new QListWidget(GuideCategories_UI);
        guides_list->setObjectName("guides_list");

        gridLayout->addWidget(guides_list, 1, 0, 4, 1);

        guide_delete = new QPushButton(GuideCategories_UI);
        guide_delete->setObjectName("guide_delete");

        gridLayout->addWidget(guide_delete, 3, 1, 1, 1);

        guide_add = new QPushButton(GuideCategories_UI);
        guide_add->setObjectName("guide_add");

        gridLayout->addWidget(guide_add, 1, 1, 1, 1);

        guide_edit = new QPushButton(GuideCategories_UI);
        guide_edit->setObjectName("guide_edit");

        gridLayout->addWidget(guide_edit, 2, 1, 1, 1);

        label = new QLabel(GuideCategories_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 2);


        retranslateUi(GuideCategories_UI);

        QMetaObject::connectSlotsByName(GuideCategories_UI);
    } // setupUi

    void retranslateUi(QWidget *GuideCategories_UI)
    {
        guide_delete->setText(tr2i18n("Delete category", nullptr));
        guide_add->setText(tr2i18n("Add category", nullptr));
        guide_edit->setText(tr2i18n("Edit category", nullptr));
        label->setText(tr2i18n("Markers Categories", nullptr));
        (void)GuideCategories_UI;
    } // retranslateUi

};

namespace Ui {
    class GuideCategories_UI: public Ui_GuideCategories_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GUIDECATEGORIES_UI_H

