/********************************************************************************
** Form generated from reading UI file 'configcolors_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGCOLORS_UI_H
#define UI_CONFIGCOLORS_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigColors_UI
{
public:
    QFormLayout *formLayout;
    QLabel *label_audio_thumbs;
    QHBoxLayout *horizontalLayout;
    KColorButton *kcfg_thumbColor1;
    KColorButton *kcfg_thumbColor2;
    QLabel *label_monitor_overlay;
    KColorButton *kcfg_overlayColor;
    QLabel *label_monitor_bg;
    KColorButton *kcfg_window_background;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QSpinBox *kcfg_monitorGridH;
    QLabel *label_2;
    QSpinBox *kcfg_monitorGridV;
    QFrame *guides_box;
    QSpacerItem *verticalSpacer;
    QLabel *label_3;
    KColorButton *kcfg_safeColor;

    void setupUi(QWidget *ConfigColors_UI)
    {
        if (ConfigColors_UI->objectName().isEmpty())
            ConfigColors_UI->setObjectName("ConfigColors_UI");
        ConfigColors_UI->resize(393, 244);
        formLayout = new QFormLayout(ConfigColors_UI);
        formLayout->setObjectName("formLayout");
        label_audio_thumbs = new QLabel(ConfigColors_UI);
        label_audio_thumbs->setObjectName("label_audio_thumbs");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_audio_thumbs);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_thumbColor1 = new KColorButton(ConfigColors_UI);
        kcfg_thumbColor1->setObjectName("kcfg_thumbColor1");

        horizontalLayout->addWidget(kcfg_thumbColor1);

        kcfg_thumbColor2 = new KColorButton(ConfigColors_UI);
        kcfg_thumbColor2->setObjectName("kcfg_thumbColor2");

        horizontalLayout->addWidget(kcfg_thumbColor2);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_monitor_overlay = new QLabel(ConfigColors_UI);
        label_monitor_overlay->setObjectName("label_monitor_overlay");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_monitor_overlay);

        kcfg_overlayColor = new KColorButton(ConfigColors_UI);
        kcfg_overlayColor->setObjectName("kcfg_overlayColor");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_overlayColor);

        label_monitor_bg = new QLabel(ConfigColors_UI);
        label_monitor_bg->setObjectName("label_monitor_bg");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_monitor_bg);

        kcfg_window_background = new KColorButton(ConfigColors_UI);
        kcfg_window_background->setObjectName("kcfg_window_background");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_window_background);

        label = new QLabel(ConfigColors_UI);
        label->setObjectName("label");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_monitorGridH = new QSpinBox(ConfigColors_UI);
        kcfg_monitorGridH->setObjectName("kcfg_monitorGridH");
        kcfg_monitorGridH->setMinimum(2);
        kcfg_monitorGridH->setMaximum(2000);

        horizontalLayout_2->addWidget(kcfg_monitorGridH);

        label_2 = new QLabel(ConfigColors_UI);
        label_2->setObjectName("label_2");
        label_2->setText(QString::fromUtf8("x"));

        horizontalLayout_2->addWidget(label_2);

        kcfg_monitorGridV = new QSpinBox(ConfigColors_UI);
        kcfg_monitorGridV->setObjectName("kcfg_monitorGridV");
        kcfg_monitorGridV->setMinimum(2);
        kcfg_monitorGridV->setMaximum(2000);

        horizontalLayout_2->addWidget(kcfg_monitorGridV);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        guides_box = new QFrame(ConfigColors_UI);
        guides_box->setObjectName("guides_box");
        guides_box->setMinimumSize(QSize(20, 20));
        guides_box->setFrameShape(QFrame::Shape::NoFrame);
        guides_box->setFrameShadow(QFrame::Shadow::Raised);

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, guides_box);

        verticalSpacer = new QSpacerItem(20, 248, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(6, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        label_3 = new QLabel(ConfigColors_UI);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_safeColor = new KColorButton(ConfigColors_UI);
        kcfg_safeColor->setObjectName("kcfg_safeColor");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_safeColor);


        retranslateUi(ConfigColors_UI);

        QMetaObject::connectSlotsByName(ConfigColors_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigColors_UI)
    {
        label_audio_thumbs->setText(tr2i18n("Audio thumbnail colors:", nullptr));
        label_monitor_overlay->setText(tr2i18n("Monitor composition guides:", nullptr));
        label_monitor_bg->setText(tr2i18n("Monitor background color:", nullptr));
        label->setText(tr2i18n("Monitor grid", nullptr));
        label_3->setText(tr2i18n("Monitor safe zone:", nullptr));
        (void)ConfigColors_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigColors_UI: public Ui_ConfigColors_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGCOLORS_UI_H

