/********************************************************************************
** Form generated from reading UI file 'titlewidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TITLEWIDGET_UI_H
#define UI_TITLEWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGraphicsView>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "kcombobox.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_TitleWidget_UI
{
public:
    QGridLayout *gridLayout_7;
    QHBoxLayout *horizontalLayout;
    QToolButton *buttonFitZoom;
    QToolButton *buttonRealSize;
    QFrame *line_8;
    QSlider *zoom_slider;
    QSpinBox *zoom_spin;
    QFrame *line_7;
    QLabel *label_2;
    QCheckBox *displayBg;
    QFrame *timecode_frame;
    QComboBox *bgBox;
    QFrame *line_6;
    QSpacerItem *horizontalSpacer_2;
    QToolButton *createButton;
    QPushButton *cancelButton;
    QFrame *frame_properties;
    QGridLayout *gridLayout;
    QToolButton *zBottom;
    QToolButton *zUp;
    QSpinBox *value_h;
    QToolButton *zTop;
    QSpinBox *value_y;
    QPushButton *origin_y_top;
    QSpinBox *value_x;
    QSpinBox *zValue;
    QLabel *label_width;
    QLabel *label_zIndex;
    QSpinBox *value_w;
    QToolButton *zDown;
    QLabel *label_height;
    QPushButton *origin_x_left;
    QSplitter *splitter;
    QWidget *verticalLayoutWidget;
    QGridLayout *grid_main;
    QCheckBox *use_grid;
    QToolButton *buttonSelectRects;
    QToolButton *buttonSelectImages;
    QToolButton *buttonSelectText;
    QSpinBox *hguides;
    QSpinBox *vguides;
    QVBoxLayout *messageLayout;
    QGraphicsView *graphicsView;
    QToolButton *buttonUnselectAll;
    QSpacerItem *spacerBottomStack;
    QCheckBox *show_guides;
    QToolButton *buttonSelectAll;
    KColorButton *guideColor;
    QWidget *verticalLayoutWidget_2;
    QGridLayout *grid_settings;
    QSpinBox *itemzoom;
    QLabel *label_rotate;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label_rotateX;
    QSpinBox *itemrotatex;
    QLabel *label_rotateY;
    QSpinBox *itemrotatey;
    QLabel *label_rotateZ;
    QSpinBox *itemrotatez;
    QLabel *label_duration;
    QLabel *label_itemzoom;
    QFrame *align_frame;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *itemleft;
    QToolButton *itemhcenter;
    QToolButton *itemright;
    QToolButton *itemtop;
    QToolButton *itemvcenter;
    QToolButton *itembottom;
    QSpacerItem *horizontalSpacer;
    TimecodeDisplay *m_duration;
    QTabWidget *tabWidget;
    QWidget *tab_properties;
    QGridLayout *gridLayout_10;
    QStackedWidget *toolbar_stack;
    QWidget *text;
    QGridLayout *gridLayout_11;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_9;
    QGroupBox *shadowBox;
    QGridLayout *gridLayout_3;
    QLabel *label_blur;
    QSpinBox *blur_radius;
    KColorButton *shadowColor;
    QLabel *label_offset;
    QSpinBox *shadowX;
    QSpinBox *shadowY;
    QToolButton *buttonInsertUnicode;
    QToolButton *buttonAlignCenter;
    QLabel *label_lineSpacing;
    QFontComboBox *font_family;
    QRadioButton *gradient_color;
    KComboBox *font_weight_box;
    QRadioButton *plain_color;
    QComboBox *gradients_combo;
    QLabel *label_outline;
    QGroupBox *typewriterBox;
    QGridLayout *gridLayout_12;
    QLabel *label_variation;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_4;
    QRadioButton *tw_rd_char;
    QRadioButton *tw_rd_word;
    QRadioButton *tw_rd_line;
    QRadioButton *tw_rd_custom;
    QLabel *label_frameStep;
    QSpinBox *tw_sb_sigma;
    QLabel *label_seed;
    QSpinBox *tw_sb_seed;
    QSpinBox *tw_sb_step;
    QSpinBox *letter_spacing;
    QToolButton *edit_gradient;
    KColorButton *textOutlineColor;
    KColorButton *fontColorButton;
    QToolButton *buttonItalic;
    QLabel *label_letterSpacing;
    QSpinBox *font_size;
    QLabel *label_textAlign;
    QToolButton *buttonAlignRight;
    QToolButton *buttonAlignLeft;
    QSpacerItem *verticalSpacer_4;
    QToolButton *buttonUnder;
    QSpinBox *line_spacing;
    QSpinBox *textOutline;
    QWidget *rectangle;
    QGridLayout *gridLayout_2;
    QRadioButton *plain_rect;
    KColorButton *rectBColor;
    QRadioButton *gradient_rect;
    QComboBox *gradients_rect_combo;
    QToolButton *edit_rect_gradient;
    QSpacerItem *horizontalSpacer_5;
    QLabel *label_border;
    KColorButton *rectFColor;
    QLabel *label_borderWidth;
    QSpinBox *rectLineWidth;
    QSpacerItem *verticalSpacer_5;
    QWidget *Image;
    QGridLayout *gridLayout_15;
    QCheckBox *preserveAspectRatio;
    QSpacerItem *verticalSpacer_6;
    QWidget *tab_background;
    QGridLayout *gridLayout_5;
    QSpacerItem *verticalSpacer_3;
    QSlider *bgAlphaSlider;
    QSpinBox *backgroundAlpha;
    KColorButton *backgroundColor;
    QWidget *tab_animation;
    QGridLayout *gridLayout_6;
    QToolButton *anim_end;
    QSpacerItem *verticalSpacer;
    QToolButton *anim_start;
    QSpacerItem *horizontalSpacer_6;
    QGroupBox *align_box;
    QGridLayout *gridLayout_8;
    QCheckBox *keep_aspect;
    QHBoxLayout *horizontalLayout_5;
    QLabel *label_7;
    QToolButton *resize50;
    QToolButton *resize100;
    QToolButton *resize200;
    QSpacerItem *horizontalSpacer_7;
    QWidget *tab_patterns;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_template;
    KComboBox *templateBox;
    QLabel *label;
    QListView *patternsList;
    QHBoxLayout *horizontalLayout_4;
    QToolButton *btn_add;
    QToolButton *btn_remove;
    QToolButton *btn_removeAll;
    QSpacerItem *horizontalSpacer_4;
    QSlider *scaleSlider;
    QFrame *frame_toolbar;

    void setupUi(QDialog *TitleWidget_UI)
    {
        if (TitleWidget_UI->objectName().isEmpty())
            TitleWidget_UI->setObjectName("TitleWidget_UI");
        TitleWidget_UI->resize(1044, 852);
        gridLayout_7 = new QGridLayout(TitleWidget_UI);
        gridLayout_7->setObjectName("gridLayout_7");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        buttonFitZoom = new QToolButton(TitleWidget_UI);
        buttonFitZoom->setObjectName("buttonFitZoom");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("zoom-fit-best")));
        buttonFitZoom->setIcon(icon);
        buttonFitZoom->setAutoRaise(true);

        horizontalLayout->addWidget(buttonFitZoom);

        buttonRealSize = new QToolButton(TitleWidget_UI);
        buttonRealSize->setObjectName("buttonRealSize");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("zoom-original")));
        buttonRealSize->setIcon(icon1);
        buttonRealSize->setAutoRaise(true);

        horizontalLayout->addWidget(buttonRealSize);

        line_8 = new QFrame(TitleWidget_UI);
        line_8->setObjectName("line_8");
        line_8->setFrameShape(QFrame::Shape::VLine);
        line_8->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line_8);

        zoom_slider = new QSlider(TitleWidget_UI);
        zoom_slider->setObjectName("zoom_slider");
        zoom_slider->setMinimumSize(QSize(100, 0));
        zoom_slider->setMaximumSize(QSize(150, 16777215));
        zoom_slider->setMinimum(1);
        zoom_slider->setMaximum(1000);
        zoom_slider->setPageStep(30);
        zoom_slider->setOrientation(Qt::Orientation::Horizontal);

        horizontalLayout->addWidget(zoom_slider);

        zoom_spin = new QSpinBox(TitleWidget_UI);
        zoom_spin->setObjectName("zoom_spin");
        zoom_spin->setKeyboardTracking(false);
        zoom_spin->setMinimum(1);
        zoom_spin->setMaximum(1000);

        horizontalLayout->addWidget(zoom_spin);

        line_7 = new QFrame(TitleWidget_UI);
        line_7->setObjectName("line_7");
        line_7->setFrameShape(QFrame::Shape::VLine);
        line_7->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line_7);

        label_2 = new QLabel(TitleWidget_UI);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        displayBg = new QCheckBox(TitleWidget_UI);
        displayBg->setObjectName("displayBg");

        horizontalLayout->addWidget(displayBg);

        timecode_frame = new QFrame(TitleWidget_UI);
        timecode_frame->setObjectName("timecode_frame");
        timecode_frame->setFrameShape(QFrame::Shape::NoFrame);
        timecode_frame->setFrameShadow(QFrame::Shadow::Raised);

        horizontalLayout->addWidget(timecode_frame);

        bgBox = new QComboBox(TitleWidget_UI);
        bgBox->addItem(QString());
        bgBox->addItem(QString());
        bgBox->addItem(QString());
        bgBox->setObjectName("bgBox");

        horizontalLayout->addWidget(bgBox);

        line_6 = new QFrame(TitleWidget_UI);
        line_6->setObjectName("line_6");
        line_6->setFrameShape(QFrame::Shape::VLine);
        line_6->setFrameShadow(QFrame::Shadow::Sunken);

        horizontalLayout->addWidget(line_6);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);

        createButton = new QToolButton(TitleWidget_UI);
        createButton->setObjectName("createButton");
        createButton->setPopupMode(QToolButton::ToolButtonPopupMode::MenuButtonPopup);
        createButton->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextOnly);

        horizontalLayout->addWidget(createButton);

        cancelButton = new QPushButton(TitleWidget_UI);
        cancelButton->setObjectName("cancelButton");

        horizontalLayout->addWidget(cancelButton);


        gridLayout_7->addLayout(horizontalLayout, 9, 0, 1, 9);

        frame_properties = new QFrame(TitleWidget_UI);
        frame_properties->setObjectName("frame_properties");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(frame_properties->sizePolicy().hasHeightForWidth());
        frame_properties->setSizePolicy(sizePolicy);
        frame_properties->setFrameShape(QFrame::Shape::NoFrame);
        frame_properties->setFrameShadow(QFrame::Shadow::Plain);
        gridLayout = new QGridLayout(frame_properties);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(0);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        zBottom = new QToolButton(frame_properties);
        zBottom->setObjectName("zBottom");

        gridLayout->addWidget(zBottom, 0, 11, 1, 1);

        zUp = new QToolButton(frame_properties);
        zUp->setObjectName("zUp");

        gridLayout->addWidget(zUp, 0, 8, 1, 1);

        value_h = new QSpinBox(frame_properties);
        value_h->setObjectName("value_h");
        value_h->setMinimum(0);
        value_h->setMaximum(99999);

        gridLayout->addWidget(value_h, 0, 7, 1, 1);

        zTop = new QToolButton(frame_properties);
        zTop->setObjectName("zTop");

        gridLayout->addWidget(zTop, 0, 10, 1, 1);

        value_y = new QSpinBox(frame_properties);
        value_y->setObjectName("value_y");
        value_y->setMinimum(-99999);
        value_y->setMaximum(99999);

        gridLayout->addWidget(value_y, 0, 3, 1, 1);

        origin_y_top = new QPushButton(frame_properties);
        origin_y_top->setObjectName("origin_y_top");
        origin_y_top->setCheckable(true);
        origin_y_top->setChecked(false);

        gridLayout->addWidget(origin_y_top, 0, 2, 1, 1);

        value_x = new QSpinBox(frame_properties);
        value_x->setObjectName("value_x");
        value_x->setMinimum(-99999);
        value_x->setMaximum(99999);

        gridLayout->addWidget(value_x, 0, 1, 1, 1);

        zValue = new QSpinBox(frame_properties);
        zValue->setObjectName("zValue");
        zValue->setMinimum(-5000);
        zValue->setMaximum(5000);

        gridLayout->addWidget(zValue, 0, 13, 1, 1);

        label_width = new QLabel(frame_properties);
        label_width->setObjectName("label_width");

        gridLayout->addWidget(label_width, 0, 4, 1, 1);

        label_zIndex = new QLabel(frame_properties);
        label_zIndex->setObjectName("label_zIndex");

        gridLayout->addWidget(label_zIndex, 0, 12, 1, 1);

        value_w = new QSpinBox(frame_properties);
        value_w->setObjectName("value_w");
        value_w->setMinimum(0);
        value_w->setMaximum(99999);

        gridLayout->addWidget(value_w, 0, 5, 1, 1);

        zDown = new QToolButton(frame_properties);
        zDown->setObjectName("zDown");

        gridLayout->addWidget(zDown, 0, 9, 1, 1);

        label_height = new QLabel(frame_properties);
        label_height->setObjectName("label_height");

        gridLayout->addWidget(label_height, 0, 6, 1, 1);

        origin_x_left = new QPushButton(frame_properties);
        origin_x_left->setObjectName("origin_x_left");
        origin_x_left->setCheckable(true);
        origin_x_left->setChecked(false);

        gridLayout->addWidget(origin_x_left, 0, 0, 1, 1);


        gridLayout_7->addWidget(frame_properties, 0, 8, 1, 1);

        splitter = new QSplitter(TitleWidget_UI);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Horizontal);
        verticalLayoutWidget = new QWidget(splitter);
        verticalLayoutWidget->setObjectName("verticalLayoutWidget");
        grid_main = new QGridLayout(verticalLayoutWidget);
        grid_main->setObjectName("grid_main");
        grid_main->setVerticalSpacing(0);
        grid_main->setContentsMargins(0, 0, 0, 0);
        use_grid = new QCheckBox(verticalLayoutWidget);
        use_grid->setObjectName("use_grid");

        grid_main->addWidget(use_grid, 3, 5, 1, 1);

        buttonSelectRects = new QToolButton(verticalLayoutWidget);
        buttonSelectRects->setObjectName("buttonSelectRects");
        buttonSelectRects->setEnabled(false);

        grid_main->addWidget(buttonSelectRects, 3, 4, 1, 1);

        buttonSelectImages = new QToolButton(verticalLayoutWidget);
        buttonSelectImages->setObjectName("buttonSelectImages");
        buttonSelectImages->setEnabled(false);

        grid_main->addWidget(buttonSelectImages, 3, 0, 1, 1);

        buttonSelectText = new QToolButton(verticalLayoutWidget);
        buttonSelectText->setObjectName("buttonSelectText");
        buttonSelectText->setEnabled(false);

        grid_main->addWidget(buttonSelectText, 3, 1, 1, 1);

        hguides = new QSpinBox(verticalLayoutWidget);
        hguides->setObjectName("hguides");
        hguides->setEnabled(false);
        hguides->setValue(2);

        grid_main->addWidget(hguides, 3, 8, 1, 1);

        vguides = new QSpinBox(verticalLayoutWidget);
        vguides->setObjectName("vguides");
        vguides->setEnabled(false);
        vguides->setMaximum(99);
        vguides->setValue(3);

        grid_main->addWidget(vguides, 3, 7, 1, 1);

        messageLayout = new QVBoxLayout();
        messageLayout->setSpacing(0);
        messageLayout->setObjectName("messageLayout");
        graphicsView = new QGraphicsView(verticalLayoutWidget);
        graphicsView->setObjectName("graphicsView");

        messageLayout->addWidget(graphicsView);


        grid_main->addLayout(messageLayout, 0, 0, 1, 11);

        buttonUnselectAll = new QToolButton(verticalLayoutWidget);
        buttonUnselectAll->setObjectName("buttonUnselectAll");
        buttonUnselectAll->setEnabled(false);

        grid_main->addWidget(buttonUnselectAll, 3, 2, 1, 1);

        spacerBottomStack = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        grid_main->addItem(spacerBottomStack, 3, 10, 1, 1);

        show_guides = new QCheckBox(verticalLayoutWidget);
        show_guides->setObjectName("show_guides");

        grid_main->addWidget(show_guides, 3, 6, 1, 1);

        buttonSelectAll = new QToolButton(verticalLayoutWidget);
        buttonSelectAll->setObjectName("buttonSelectAll");

        grid_main->addWidget(buttonSelectAll, 3, 3, 1, 1);

        guideColor = new KColorButton(verticalLayoutWidget);
        guideColor->setObjectName("guideColor");
        guideColor->setEnabled(false);
        guideColor->setAutoDefault(false);
        guideColor->setFlat(false);
        guideColor->setColor(QColor(255, 0, 0));
        guideColor->setDefaultColor(QColor(255, 0, 0));

        grid_main->addWidget(guideColor, 3, 9, 1, 1);

        splitter->addWidget(verticalLayoutWidget);
        verticalLayoutWidget_2 = new QWidget(splitter);
        verticalLayoutWidget_2->setObjectName("verticalLayoutWidget_2");
        grid_settings = new QGridLayout(verticalLayoutWidget_2);
        grid_settings->setObjectName("grid_settings");
        grid_settings->setContentsMargins(6, 0, 6, 0);
        itemzoom = new QSpinBox(verticalLayoutWidget_2);
        itemzoom->setObjectName("itemzoom");
        itemzoom->setMaximum(100000);
        itemzoom->setValue(1);

        grid_settings->addWidget(itemzoom, 1, 1, 1, 1);

        label_rotate = new QLabel(verticalLayoutWidget_2);
        label_rotate->setObjectName("label_rotate");

        grid_settings->addWidget(label_rotate, 2, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label_rotateX = new QLabel(verticalLayoutWidget_2);
        label_rotateX->setObjectName("label_rotateX");

        horizontalLayout_3->addWidget(label_rotateX);

        itemrotatex = new QSpinBox(verticalLayoutWidget_2);
        itemrotatex->setObjectName("itemrotatex");
        sizePolicy.setHeightForWidth(itemrotatex->sizePolicy().hasHeightForWidth());
        itemrotatex->setSizePolicy(sizePolicy);
        itemrotatex->setMinimum(-360);
        itemrotatex->setMaximum(360);

        horizontalLayout_3->addWidget(itemrotatex);

        label_rotateY = new QLabel(verticalLayoutWidget_2);
        label_rotateY->setObjectName("label_rotateY");
        label_rotateY->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(label_rotateY);

        itemrotatey = new QSpinBox(verticalLayoutWidget_2);
        itemrotatey->setObjectName("itemrotatey");
        sizePolicy.setHeightForWidth(itemrotatey->sizePolicy().hasHeightForWidth());
        itemrotatey->setSizePolicy(sizePolicy);
        itemrotatey->setMinimum(-360);
        itemrotatey->setMaximum(360);

        horizontalLayout_3->addWidget(itemrotatey);

        label_rotateZ = new QLabel(verticalLayoutWidget_2);
        label_rotateZ->setObjectName("label_rotateZ");
        label_rotateZ->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(label_rotateZ);

        itemrotatez = new QSpinBox(verticalLayoutWidget_2);
        itemrotatez->setObjectName("itemrotatez");
        sizePolicy.setHeightForWidth(itemrotatez->sizePolicy().hasHeightForWidth());
        itemrotatez->setSizePolicy(sizePolicy);
        itemrotatez->setMinimum(-360);
        itemrotatez->setMaximum(360);

        horizontalLayout_3->addWidget(itemrotatez);


        grid_settings->addLayout(horizontalLayout_3, 2, 1, 1, 1);

        label_duration = new QLabel(verticalLayoutWidget_2);
        label_duration->setObjectName("label_duration");

        grid_settings->addWidget(label_duration, 0, 0, 1, 1);

        label_itemzoom = new QLabel(verticalLayoutWidget_2);
        label_itemzoom->setObjectName("label_itemzoom");

        grid_settings->addWidget(label_itemzoom, 1, 0, 1, 1);

        align_frame = new QFrame(verticalLayoutWidget_2);
        align_frame->setObjectName("align_frame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(align_frame->sizePolicy().hasHeightForWidth());
        align_frame->setSizePolicy(sizePolicy1);
        align_frame->setFrameShape(QFrame::Shape::NoFrame);
        align_frame->setFrameShadow(QFrame::Shadow::Plain);
        horizontalLayout_2 = new QHBoxLayout(align_frame);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalLayout_2->setContentsMargins(0, 0, 0, 0);
        itemleft = new QToolButton(align_frame);
        itemleft->setObjectName("itemleft");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("align-horizontal-left")));
        itemleft->setIcon(icon2);

        horizontalLayout_2->addWidget(itemleft);

        itemhcenter = new QToolButton(align_frame);
        itemhcenter->setObjectName("itemhcenter");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("align-horizontal-center")));
        itemhcenter->setIcon(icon3);

        horizontalLayout_2->addWidget(itemhcenter);

        itemright = new QToolButton(align_frame);
        itemright->setObjectName("itemright");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("align-horizontal-right")));
        itemright->setIcon(icon4);

        horizontalLayout_2->addWidget(itemright);

        itemtop = new QToolButton(align_frame);
        itemtop->setObjectName("itemtop");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("align-vertical-top")));
        itemtop->setIcon(icon5);

        horizontalLayout_2->addWidget(itemtop);

        itemvcenter = new QToolButton(align_frame);
        itemvcenter->setObjectName("itemvcenter");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("align-vertical-center")));
        itemvcenter->setIcon(icon6);

        horizontalLayout_2->addWidget(itemvcenter);

        itembottom = new QToolButton(align_frame);
        itembottom->setObjectName("itembottom");
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("align-vertical-bottom")));
        itembottom->setIcon(icon7);

        horizontalLayout_2->addWidget(itembottom);

        horizontalSpacer = new QSpacerItem(150, 20, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);


        grid_settings->addWidget(align_frame, 3, 0, 1, 2);

        m_duration = new TimecodeDisplay(verticalLayoutWidget_2);
        m_duration->setObjectName("m_duration");

        grid_settings->addWidget(m_duration, 0, 1, 1, 1);

        tabWidget = new QTabWidget(verticalLayoutWidget_2);
        tabWidget->setObjectName("tabWidget");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(tabWidget->sizePolicy().hasHeightForWidth());
        tabWidget->setSizePolicy(sizePolicy2);
        tabWidget->setTabPosition(QTabWidget::TabPosition::North);
        tabWidget->setElideMode(Qt::TextElideMode::ElideNone);
        tab_properties = new QWidget();
        tab_properties->setObjectName("tab_properties");
        gridLayout_10 = new QGridLayout(tab_properties);
        gridLayout_10->setObjectName("gridLayout_10");
        toolbar_stack = new QStackedWidget(tab_properties);
        toolbar_stack->setObjectName("toolbar_stack");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(toolbar_stack->sizePolicy().hasHeightForWidth());
        toolbar_stack->setSizePolicy(sizePolicy3);
        text = new QWidget();
        text->setObjectName("text");
        gridLayout_11 = new QGridLayout(text);
        gridLayout_11->setSpacing(0);
        gridLayout_11->setObjectName("gridLayout_11");
        gridLayout_11->setContentsMargins(0, 0, 0, -1);
        scrollArea = new QScrollArea(text);
        scrollArea->setObjectName("scrollArea");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy4);
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setSizeAdjustPolicy(QAbstractScrollArea::SizeAdjustPolicy::AdjustToContents);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 341, 678));
        gridLayout_9 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_9->setSpacing(4);
        gridLayout_9->setObjectName("gridLayout_9");
        gridLayout_9->setContentsMargins(0, 0, 0, 0);
        shadowBox = new QGroupBox(scrollAreaWidgetContents);
        shadowBox->setObjectName("shadowBox");
        shadowBox->setCheckable(true);
        shadowBox->setChecked(false);
        gridLayout_3 = new QGridLayout(shadowBox);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setVerticalSpacing(0);
        label_blur = new QLabel(shadowBox);
        label_blur->setObjectName("label_blur");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(label_blur->sizePolicy().hasHeightForWidth());
        label_blur->setSizePolicy(sizePolicy5);

        gridLayout_3->addWidget(label_blur, 0, 0, 1, 1);

        blur_radius = new QSpinBox(shadowBox);
        blur_radius->setObjectName("blur_radius");
        blur_radius->setValue(3);

        gridLayout_3->addWidget(blur_radius, 0, 1, 1, 1);

        shadowColor = new KColorButton(shadowBox);
        shadowColor->setObjectName("shadowColor");
        QSizePolicy sizePolicy6(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Preferred);
        sizePolicy6.setHorizontalStretch(0);
        sizePolicy6.setVerticalStretch(0);
        sizePolicy6.setHeightForWidth(shadowColor->sizePolicy().hasHeightForWidth());
        shadowColor->setSizePolicy(sizePolicy6);
        shadowColor->setColor(QColor(0, 0, 0, 100));
        shadowColor->setAlphaChannelEnabled(true);

        gridLayout_3->addWidget(shadowColor, 0, 2, 1, 1);

        label_offset = new QLabel(shadowBox);
        label_offset->setObjectName("label_offset");
        sizePolicy5.setHeightForWidth(label_offset->sizePolicy().hasHeightForWidth());
        label_offset->setSizePolicy(sizePolicy5);

        gridLayout_3->addWidget(label_offset, 1, 0, 1, 1);

        shadowX = new QSpinBox(shadowBox);
        shadowX->setObjectName("shadowX");
        shadowX->setMinimum(-100);
        shadowX->setMaximum(100);
        shadowX->setValue(3);

        gridLayout_3->addWidget(shadowX, 1, 1, 1, 1);

        shadowY = new QSpinBox(shadowBox);
        shadowY->setObjectName("shadowY");
        shadowY->setMinimum(-100);
        shadowY->setMaximum(100);
        shadowY->setValue(3);

        gridLayout_3->addWidget(shadowY, 1, 2, 1, 1);


        gridLayout_9->addWidget(shadowBox, 5, 0, 1, 7);

        buttonInsertUnicode = new QToolButton(scrollAreaWidgetContents);
        buttonInsertUnicode->setObjectName("buttonInsertUnicode");

        gridLayout_9->addWidget(buttonInsertUnicode, 2, 6, 1, 1);

        buttonAlignCenter = new QToolButton(scrollAreaWidgetContents);
        buttonAlignCenter->setObjectName("buttonAlignCenter");
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("format-justify-center")));
        buttonAlignCenter->setIcon(icon8);
        buttonAlignCenter->setCheckable(true);
        buttonAlignCenter->setAutoExclusive(true);

        gridLayout_9->addWidget(buttonAlignCenter, 6, 3, 1, 1);

        label_lineSpacing = new QLabel(scrollAreaWidgetContents);
        label_lineSpacing->setObjectName("label_lineSpacing");

        gridLayout_9->addWidget(label_lineSpacing, 8, 0, 1, 1);

        font_family = new QFontComboBox(scrollAreaWidgetContents);
        font_family->setObjectName("font_family");
        QSizePolicy sizePolicy7(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy7.setHorizontalStretch(0);
        sizePolicy7.setVerticalStretch(0);
        sizePolicy7.setHeightForWidth(font_family->sizePolicy().hasHeightForWidth());
        font_family->setSizePolicy(sizePolicy7);

        gridLayout_9->addWidget(font_family, 0, 0, 1, 7);

        gradient_color = new QRadioButton(scrollAreaWidgetContents);
        gradient_color->setObjectName("gradient_color");
        QSizePolicy sizePolicy8(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy8.setHorizontalStretch(0);
        sizePolicy8.setVerticalStretch(0);
        sizePolicy8.setHeightForWidth(gradient_color->sizePolicy().hasHeightForWidth());
        gradient_color->setSizePolicy(sizePolicy8);

        gridLayout_9->addWidget(gradient_color, 3, 0, 1, 1);

        font_weight_box = new KComboBox(scrollAreaWidgetContents);
        font_weight_box->setObjectName("font_weight_box");

        gridLayout_9->addWidget(font_weight_box, 1, 2, 1, 3);

        plain_color = new QRadioButton(scrollAreaWidgetContents);
        plain_color->setObjectName("plain_color");
        sizePolicy8.setHeightForWidth(plain_color->sizePolicy().hasHeightForWidth());
        plain_color->setSizePolicy(sizePolicy8);
        plain_color->setChecked(true);

        gridLayout_9->addWidget(plain_color, 2, 0, 1, 1);

        gradients_combo = new QComboBox(scrollAreaWidgetContents);
        gradients_combo->setObjectName("gradients_combo");
        gradients_combo->setEnabled(false);

        gridLayout_9->addWidget(gradients_combo, 3, 2, 1, 4);

        label_outline = new QLabel(scrollAreaWidgetContents);
        label_outline->setObjectName("label_outline");
        sizePolicy5.setHeightForWidth(label_outline->sizePolicy().hasHeightForWidth());
        label_outline->setSizePolicy(sizePolicy5);

        gridLayout_9->addWidget(label_outline, 4, 0, 1, 1);

        typewriterBox = new QGroupBox(scrollAreaWidgetContents);
        typewriterBox->setObjectName("typewriterBox");
        typewriterBox->setCheckable(true);
        typewriterBox->setChecked(false);
        gridLayout_12 = new QGridLayout(typewriterBox);
        gridLayout_12->setObjectName("gridLayout_12");
        label_variation = new QLabel(typewriterBox);
        label_variation->setObjectName("label_variation");

        gridLayout_12->addWidget(label_variation, 0, 2, 1, 1);

        groupBox_2 = new QGroupBox(typewriterBox);
        groupBox_2->setObjectName("groupBox_2");
        groupBox_2->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);
        groupBox_2->setFlat(true);
        gridLayout_4 = new QGridLayout(groupBox_2);
        gridLayout_4->setObjectName("gridLayout_4");
        tw_rd_char = new QRadioButton(groupBox_2);
        tw_rd_char->setObjectName("tw_rd_char");
        tw_rd_char->setChecked(true);

        gridLayout_4->addWidget(tw_rd_char, 0, 0, 1, 1);

        tw_rd_word = new QRadioButton(groupBox_2);
        tw_rd_word->setObjectName("tw_rd_word");

        gridLayout_4->addWidget(tw_rd_word, 0, 1, 1, 1);

        tw_rd_line = new QRadioButton(groupBox_2);
        tw_rd_line->setObjectName("tw_rd_line");

        gridLayout_4->addWidget(tw_rd_line, 1, 0, 1, 1);

        tw_rd_custom = new QRadioButton(groupBox_2);
        tw_rd_custom->setObjectName("tw_rd_custom");

        gridLayout_4->addWidget(tw_rd_custom, 1, 1, 1, 1);


        gridLayout_12->addWidget(groupBox_2, 2, 0, 1, 4);

        label_frameStep = new QLabel(typewriterBox);
        label_frameStep->setObjectName("label_frameStep");

        gridLayout_12->addWidget(label_frameStep, 0, 0, 1, 1);

        tw_sb_sigma = new QSpinBox(typewriterBox);
        tw_sb_sigma->setObjectName("tw_sb_sigma");
        tw_sb_sigma->setMaximum(240);

        gridLayout_12->addWidget(tw_sb_sigma, 0, 3, 1, 1);

        label_seed = new QLabel(typewriterBox);
        label_seed->setObjectName("label_seed");

        gridLayout_12->addWidget(label_seed, 1, 2, 1, 1);

        tw_sb_seed = new QSpinBox(typewriterBox);
        tw_sb_seed->setObjectName("tw_sb_seed");
        tw_sb_seed->setMaximum(9999);

        gridLayout_12->addWidget(tw_sb_seed, 1, 3, 1, 1);

        tw_sb_step = new QSpinBox(typewriterBox);
        tw_sb_step->setObjectName("tw_sb_step");
        tw_sb_step->setMinimum(1);
        tw_sb_step->setMaximum(240);
        tw_sb_step->setValue(2);

        gridLayout_12->addWidget(tw_sb_step, 0, 1, 1, 1);


        gridLayout_9->addWidget(typewriterBox, 9, 0, 1, 7);

        letter_spacing = new QSpinBox(scrollAreaWidgetContents);
        letter_spacing->setObjectName("letter_spacing");
        letter_spacing->setMinimum(-500);
        letter_spacing->setMaximum(500);

        gridLayout_9->addWidget(letter_spacing, 7, 2, 1, 3);

        edit_gradient = new QToolButton(scrollAreaWidgetContents);
        edit_gradient->setObjectName("edit_gradient");
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        edit_gradient->setIcon(icon9);

        gridLayout_9->addWidget(edit_gradient, 3, 6, 1, 1);

        textOutlineColor = new KColorButton(scrollAreaWidgetContents);
        textOutlineColor->setObjectName("textOutlineColor");
        sizePolicy6.setHeightForWidth(textOutlineColor->sizePolicy().hasHeightForWidth());
        textOutlineColor->setSizePolicy(sizePolicy6);
        textOutlineColor->setColor(QColor(0, 0, 0));

        gridLayout_9->addWidget(textOutlineColor, 4, 5, 1, 2);

        fontColorButton = new KColorButton(scrollAreaWidgetContents);
        fontColorButton->setObjectName("fontColorButton");
        sizePolicy6.setHeightForWidth(fontColorButton->sizePolicy().hasHeightForWidth());
        fontColorButton->setSizePolicy(sizePolicy6);
        fontColorButton->setFlat(false);
        fontColorButton->setColor(QColor(255, 255, 255));
        fontColorButton->setDefaultColor(QColor(255, 255, 255));

        gridLayout_9->addWidget(fontColorButton, 2, 2, 1, 3);

        buttonItalic = new QToolButton(scrollAreaWidgetContents);
        buttonItalic->setObjectName("buttonItalic");
        QIcon icon10(QIcon::fromTheme(QString::fromUtf8("format-text-italic")));
        buttonItalic->setIcon(icon10);
        buttonItalic->setCheckable(true);

        gridLayout_9->addWidget(buttonItalic, 1, 6, 1, 1);

        label_letterSpacing = new QLabel(scrollAreaWidgetContents);
        label_letterSpacing->setObjectName("label_letterSpacing");

        gridLayout_9->addWidget(label_letterSpacing, 7, 0, 1, 1);

        font_size = new QSpinBox(scrollAreaWidgetContents);
        font_size->setObjectName("font_size");
        sizePolicy7.setHeightForWidth(font_size->sizePolicy().hasHeightForWidth());
        font_size->setSizePolicy(sizePolicy7);
        font_size->setMinimum(8);
        font_size->setMaximum(10000);
        font_size->setValue(20);

        gridLayout_9->addWidget(font_size, 1, 0, 1, 1);

        label_textAlign = new QLabel(scrollAreaWidgetContents);
        label_textAlign->setObjectName("label_textAlign");

        gridLayout_9->addWidget(label_textAlign, 6, 0, 1, 1);

        buttonAlignRight = new QToolButton(scrollAreaWidgetContents);
        buttonAlignRight->setObjectName("buttonAlignRight");
        QIcon icon11(QIcon::fromTheme(QString::fromUtf8("format-justify-right")));
        buttonAlignRight->setIcon(icon11);
        buttonAlignRight->setCheckable(true);
        buttonAlignRight->setChecked(false);
        buttonAlignRight->setAutoExclusive(true);

        gridLayout_9->addWidget(buttonAlignRight, 6, 4, 1, 1);

        buttonAlignLeft = new QToolButton(scrollAreaWidgetContents);
        buttonAlignLeft->setObjectName("buttonAlignLeft");
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("format-justify-left")));
        buttonAlignLeft->setIcon(icon12);
        buttonAlignLeft->setCheckable(true);
        buttonAlignLeft->setChecked(false);
        buttonAlignLeft->setAutoExclusive(true);

        gridLayout_9->addWidget(buttonAlignLeft, 6, 2, 1, 1);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_4, 10, 0, 1, 1);

        buttonUnder = new QToolButton(scrollAreaWidgetContents);
        buttonUnder->setObjectName("buttonUnder");
        QIcon icon13(QIcon::fromTheme(QString::fromUtf8("format-text-underline")));
        buttonUnder->setIcon(icon13);
        buttonUnder->setCheckable(true);

        gridLayout_9->addWidget(buttonUnder, 1, 5, 1, 1);

        line_spacing = new QSpinBox(scrollAreaWidgetContents);
        line_spacing->setObjectName("line_spacing");
        line_spacing->setEnabled(true);
        line_spacing->setMinimum(-5000);
        line_spacing->setMaximum(5000);

        gridLayout_9->addWidget(line_spacing, 8, 2, 1, 3);

        textOutline = new QSpinBox(scrollAreaWidgetContents);
        textOutline->setObjectName("textOutline");
        textOutline->setMaximum(5000);

        gridLayout_9->addWidget(textOutline, 4, 2, 1, 3);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_11->addWidget(scrollArea, 11, 0, 1, 1);

        toolbar_stack->addWidget(text);
        rectangle = new QWidget();
        rectangle->setObjectName("rectangle");
        gridLayout_2 = new QGridLayout(rectangle);
        gridLayout_2->setObjectName("gridLayout_2");
        plain_rect = new QRadioButton(rectangle);
        plain_rect->setObjectName("plain_rect");
        plain_rect->setChecked(true);

        gridLayout_2->addWidget(plain_rect, 0, 0, 1, 1);

        rectBColor = new KColorButton(rectangle);
        rectBColor->setObjectName("rectBColor");
        sizePolicy6.setHeightForWidth(rectBColor->sizePolicy().hasHeightForWidth());
        rectBColor->setSizePolicy(sizePolicy6);
        rectBColor->setColor(QColor(0, 0, 0));
        rectBColor->setDefaultColor(QColor(0, 0, 0));

        gridLayout_2->addWidget(rectBColor, 0, 1, 1, 1);

        gradient_rect = new QRadioButton(rectangle);
        gradient_rect->setObjectName("gradient_rect");

        gridLayout_2->addWidget(gradient_rect, 1, 0, 1, 1);

        gradients_rect_combo = new QComboBox(rectangle);
        gradients_rect_combo->setObjectName("gradients_rect_combo");
        gradients_rect_combo->setEnabled(false);

        gridLayout_2->addWidget(gradients_rect_combo, 1, 1, 1, 1);

        edit_rect_gradient = new QToolButton(rectangle);
        edit_rect_gradient->setObjectName("edit_rect_gradient");
        edit_rect_gradient->setIcon(icon9);

        gridLayout_2->addWidget(edit_rect_gradient, 1, 2, 1, 1);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_5, 1, 3, 1, 1);

        label_border = new QLabel(rectangle);
        label_border->setObjectName("label_border");

        gridLayout_2->addWidget(label_border, 2, 0, 1, 1);

        rectFColor = new KColorButton(rectangle);
        rectFColor->setObjectName("rectFColor");
        sizePolicy6.setHeightForWidth(rectFColor->sizePolicy().hasHeightForWidth());
        rectFColor->setSizePolicy(sizePolicy6);
        rectFColor->setColor(QColor(0, 0, 0));
        rectFColor->setDefaultColor(QColor(0, 0, 0));

        gridLayout_2->addWidget(rectFColor, 2, 1, 1, 1);

        label_borderWidth = new QLabel(rectangle);
        label_borderWidth->setObjectName("label_borderWidth");

        gridLayout_2->addWidget(label_borderWidth, 3, 0, 1, 1);

        rectLineWidth = new QSpinBox(rectangle);
        rectLineWidth->setObjectName("rectLineWidth");
        rectLineWidth->setMaximum(5000);

        gridLayout_2->addWidget(rectLineWidth, 3, 1, 1, 1);

        verticalSpacer_5 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_5, 4, 0, 1, 1);

        toolbar_stack->addWidget(rectangle);
        Image = new QWidget();
        Image->setObjectName("Image");
        gridLayout_15 = new QGridLayout(Image);
        gridLayout_15->setObjectName("gridLayout_15");
        preserveAspectRatio = new QCheckBox(Image);
        preserveAspectRatio->setObjectName("preserveAspectRatio");
        preserveAspectRatio->setEnabled(true);
        preserveAspectRatio->setChecked(true);

        gridLayout_15->addWidget(preserveAspectRatio, 0, 0, 1, 1);

        verticalSpacer_6 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_15->addItem(verticalSpacer_6, 1, 0, 1, 1);

        toolbar_stack->addWidget(Image);

        gridLayout_10->addWidget(toolbar_stack, 1, 2, 1, 1);

        tabWidget->addTab(tab_properties, QString());
        tab_background = new QWidget();
        tab_background->setObjectName("tab_background");
        gridLayout_5 = new QGridLayout(tab_background);
        gridLayout_5->setObjectName("gridLayout_5");
        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_5->addItem(verticalSpacer_3, 2, 0, 1, 1);

        bgAlphaSlider = new QSlider(tab_background);
        bgAlphaSlider->setObjectName("bgAlphaSlider");
        bgAlphaSlider->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_5->addWidget(bgAlphaSlider, 1, 0, 1, 1);

        backgroundAlpha = new QSpinBox(tab_background);
        backgroundAlpha->setObjectName("backgroundAlpha");
        backgroundAlpha->setMaximum(256);

        gridLayout_5->addWidget(backgroundAlpha, 1, 1, 1, 1);

        backgroundColor = new KColorButton(tab_background);
        backgroundColor->setObjectName("backgroundColor");
        sizePolicy6.setHeightForWidth(backgroundColor->sizePolicy().hasHeightForWidth());
        backgroundColor->setSizePolicy(sizePolicy6);
        backgroundColor->setColor(QColor(0, 0, 0));
        backgroundColor->setDefaultColor(QColor(0, 0, 0));

        gridLayout_5->addWidget(backgroundColor, 0, 0, 1, 2);

        tabWidget->addTab(tab_background, QString());
        tab_animation = new QWidget();
        tab_animation->setObjectName("tab_animation");
        gridLayout_6 = new QGridLayout(tab_animation);
        gridLayout_6->setObjectName("gridLayout_6");
        anim_end = new QToolButton(tab_animation);
        anim_end->setObjectName("anim_end");
        anim_end->setCheckable(true);

        gridLayout_6->addWidget(anim_end, 0, 1, 1, 1);

        verticalSpacer = new QSpacerItem(20, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer, 2, 0, 1, 2);

        anim_start = new QToolButton(tab_animation);
        anim_start->setObjectName("anim_start");
        anim_start->setCheckable(true);

        gridLayout_6->addWidget(anim_start, 0, 0, 1, 1);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_6, 0, 2, 1, 1);

        align_box = new QGroupBox(tab_animation);
        align_box->setObjectName("align_box");
        gridLayout_8 = new QGridLayout(align_box);
        gridLayout_8->setObjectName("gridLayout_8");
        keep_aspect = new QCheckBox(align_box);
        keep_aspect->setObjectName("keep_aspect");

        gridLayout_8->addWidget(keep_aspect, 0, 0, 1, 1);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        label_7 = new QLabel(align_box);
        label_7->setObjectName("label_7");

        horizontalLayout_5->addWidget(label_7);

        resize50 = new QToolButton(align_box);
        resize50->setObjectName("resize50");

        horizontalLayout_5->addWidget(resize50);

        resize100 = new QToolButton(align_box);
        resize100->setObjectName("resize100");

        horizontalLayout_5->addWidget(resize100);

        resize200 = new QToolButton(align_box);
        resize200->setObjectName("resize200");

        horizontalLayout_5->addWidget(resize200);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_7);


        gridLayout_8->addLayout(horizontalLayout_5, 1, 0, 1, 1);


        gridLayout_6->addWidget(align_box, 1, 0, 1, 3);

        tabWidget->addTab(tab_animation, QString());
        tab_patterns = new QWidget();
        tab_patterns->setObjectName("tab_patterns");
        verticalLayout = new QVBoxLayout(tab_patterns);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_template = new QLabel(tab_patterns);
        label_template->setObjectName("label_template");
        sizePolicy7.setHeightForWidth(label_template->sizePolicy().hasHeightForWidth());
        label_template->setSizePolicy(sizePolicy7);

        horizontalLayout_6->addWidget(label_template);

        templateBox = new KComboBox(tab_patterns);
        templateBox->setObjectName("templateBox");
        sizePolicy.setHeightForWidth(templateBox->sizePolicy().hasHeightForWidth());
        templateBox->setSizePolicy(sizePolicy);
        templateBox->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_6->addWidget(templateBox);


        verticalLayout->addLayout(horizontalLayout_6);

        label = new QLabel(tab_patterns);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        patternsList = new QListView(tab_patterns);
        patternsList->setObjectName("patternsList");
        patternsList->setSelectionMode(QAbstractItemView::SelectionMode::SingleSelection);
        patternsList->setSpacing(4);
        patternsList->setViewMode(QListView::ViewMode::IconMode);
        patternsList->setUniformItemSizes(true);

        verticalLayout->addWidget(patternsList);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        btn_add = new QToolButton(tab_patterns);
        btn_add->setObjectName("btn_add");
        btn_add->setEnabled(false);
        QIcon icon14(QIcon::fromTheme(QString::fromUtf8("list-add")));
        btn_add->setIcon(icon14);

        horizontalLayout_4->addWidget(btn_add);

        btn_remove = new QToolButton(tab_patterns);
        btn_remove->setObjectName("btn_remove");
        btn_remove->setEnabled(false);
        QIcon icon15(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        btn_remove->setIcon(icon15);

        horizontalLayout_4->addWidget(btn_remove);

        btn_removeAll = new QToolButton(tab_patterns);
        btn_removeAll->setObjectName("btn_removeAll");
        QIcon icon16(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        btn_removeAll->setIcon(icon16);

        horizontalLayout_4->addWidget(btn_removeAll);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        scaleSlider = new QSlider(tab_patterns);
        scaleSlider->setObjectName("scaleSlider");
        scaleSlider->setOrientation(Qt::Orientation::Horizontal);

        horizontalLayout_4->addWidget(scaleSlider);


        verticalLayout->addLayout(horizontalLayout_4);

        tabWidget->addTab(tab_patterns, QString());

        grid_settings->addWidget(tabWidget, 4, 0, 1, 2);

        splitter->addWidget(verticalLayoutWidget_2);

        gridLayout_7->addWidget(splitter, 8, 0, 1, 9);

        frame_toolbar = new QFrame(TitleWidget_UI);
        frame_toolbar->setObjectName("frame_toolbar");
        QSizePolicy sizePolicy9(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy9.setHorizontalStretch(0);
        sizePolicy9.setVerticalStretch(0);
        sizePolicy9.setHeightForWidth(frame_toolbar->sizePolicy().hasHeightForWidth());
        frame_toolbar->setSizePolicy(sizePolicy9);
        frame_toolbar->setFrameShape(QFrame::Shape::StyledPanel);
        frame_toolbar->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_7->addWidget(frame_toolbar, 0, 0, 1, 1);

        QWidget::setTabOrder(origin_x_left, value_x);
        QWidget::setTabOrder(value_x, origin_y_top);
        QWidget::setTabOrder(origin_y_top, value_y);
        QWidget::setTabOrder(value_y, value_w);
        QWidget::setTabOrder(value_w, value_h);
        QWidget::setTabOrder(value_h, zUp);
        QWidget::setTabOrder(zUp, zDown);
        QWidget::setTabOrder(zDown, zTop);
        QWidget::setTabOrder(zTop, zBottom);
        QWidget::setTabOrder(zBottom, zValue);
        QWidget::setTabOrder(zValue, buttonSelectImages);
        QWidget::setTabOrder(buttonSelectImages, buttonSelectText);
        QWidget::setTabOrder(buttonSelectText, buttonUnselectAll);
        QWidget::setTabOrder(buttonUnselectAll, buttonSelectAll);
        QWidget::setTabOrder(buttonSelectAll, buttonSelectRects);
        QWidget::setTabOrder(buttonSelectRects, use_grid);
        QWidget::setTabOrder(use_grid, show_guides);
        QWidget::setTabOrder(show_guides, vguides);
        QWidget::setTabOrder(vguides, hguides);
        QWidget::setTabOrder(hguides, guideColor);
        QWidget::setTabOrder(guideColor, buttonFitZoom);
        QWidget::setTabOrder(buttonFitZoom, buttonRealSize);
        QWidget::setTabOrder(buttonRealSize, zoom_slider);
        QWidget::setTabOrder(zoom_slider, zoom_spin);
        QWidget::setTabOrder(zoom_spin, displayBg);
        QWidget::setTabOrder(displayBg, bgBox);
        QWidget::setTabOrder(bgBox, createButton);
        QWidget::setTabOrder(createButton, cancelButton);
        QWidget::setTabOrder(cancelButton, itemrotatex);
        QWidget::setTabOrder(itemrotatex, itemrotatey);
        QWidget::setTabOrder(itemrotatey, itemrotatez);
        QWidget::setTabOrder(itemrotatez, rectBColor);
        QWidget::setTabOrder(rectBColor, gradient_rect);
        QWidget::setTabOrder(gradient_rect, scrollArea);
        QWidget::setTabOrder(scrollArea, font_size);
        QWidget::setTabOrder(font_size, font_weight_box);
        QWidget::setTabOrder(font_weight_box, buttonUnder);
        QWidget::setTabOrder(buttonUnder, buttonItalic);
        QWidget::setTabOrder(buttonItalic, plain_color);
        QWidget::setTabOrder(plain_color, fontColorButton);
        QWidget::setTabOrder(fontColorButton, buttonInsertUnicode);
        QWidget::setTabOrder(buttonInsertUnicode, gradient_color);
        QWidget::setTabOrder(gradient_color, gradients_combo);
        QWidget::setTabOrder(gradients_combo, edit_gradient);
        QWidget::setTabOrder(edit_gradient, textOutline);
        QWidget::setTabOrder(textOutline, textOutlineColor);
        QWidget::setTabOrder(textOutlineColor, shadowBox);
        QWidget::setTabOrder(shadowBox, blur_radius);
        QWidget::setTabOrder(blur_radius, shadowColor);
        QWidget::setTabOrder(shadowColor, shadowX);
        QWidget::setTabOrder(shadowX, shadowY);
        QWidget::setTabOrder(shadowY, buttonAlignLeft);
        QWidget::setTabOrder(buttonAlignLeft, buttonAlignCenter);
        QWidget::setTabOrder(buttonAlignCenter, buttonAlignRight);
        QWidget::setTabOrder(buttonAlignRight, letter_spacing);
        QWidget::setTabOrder(letter_spacing, line_spacing);
        QWidget::setTabOrder(line_spacing, backgroundColor);
        QWidget::setTabOrder(backgroundColor, bgAlphaSlider);
        QWidget::setTabOrder(bgAlphaSlider, backgroundAlpha);
        QWidget::setTabOrder(backgroundAlpha, anim_start);
        QWidget::setTabOrder(anim_start, anim_end);
        QWidget::setTabOrder(anim_end, keep_aspect);
        QWidget::setTabOrder(keep_aspect, resize50);
        QWidget::setTabOrder(resize50, resize100);
        QWidget::setTabOrder(resize100, resize200);
        QWidget::setTabOrder(resize200, patternsList);
        QWidget::setTabOrder(patternsList, btn_add);
        QWidget::setTabOrder(btn_add, btn_remove);
        QWidget::setTabOrder(btn_remove, btn_removeAll);
        QWidget::setTabOrder(btn_removeAll, scaleSlider);
        QWidget::setTabOrder(scaleSlider, rectFColor);
        QWidget::setTabOrder(rectFColor, font_family);
        QWidget::setTabOrder(font_family, gradients_rect_combo);
        QWidget::setTabOrder(gradients_rect_combo, preserveAspectRatio);
        QWidget::setTabOrder(preserveAspectRatio, edit_rect_gradient);
        QWidget::setTabOrder(edit_rect_gradient, rectLineWidth);
        QWidget::setTabOrder(rectLineWidth, plain_rect);

        retranslateUi(TitleWidget_UI);
        QObject::connect(show_guides, &QCheckBox::toggled, hguides, &QSpinBox::setEnabled);
        QObject::connect(show_guides, &QCheckBox::toggled, vguides, &QSpinBox::setEnabled);
        QObject::connect(show_guides, SIGNAL(toggled(bool)), guideColor, SLOT(setEnabled(bool)));
        QObject::connect(plain_color, SIGNAL(toggled(bool)), fontColorButton, SLOT(setEnabled(bool)));
        QObject::connect(gradient_color, &QRadioButton::toggled, gradients_combo, &QComboBox::setEnabled);
        QObject::connect(gradient_rect, &QRadioButton::toggled, gradients_rect_combo, &QComboBox::setEnabled);
        QObject::connect(bgAlphaSlider, &QSlider::valueChanged, backgroundAlpha, &QSpinBox::setValue);
        QObject::connect(plain_rect, SIGNAL(toggled(bool)), rectBColor, SLOT(setEnabled(bool)));
        QObject::connect(backgroundAlpha, &QSpinBox::valueChanged, bgAlphaSlider, &QSlider::setValue);

        tabWidget->setCurrentIndex(0);
        toolbar_stack->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(TitleWidget_UI);
    } // setupUi

    void retranslateUi(QDialog *TitleWidget_UI)
    {
        TitleWidget_UI->setWindowTitle(tr2i18n("Title Clip", nullptr));
        buttonFitZoom->setText(tr2i18n("V", nullptr));
        buttonRealSize->setText(tr2i18n("V", nullptr));
        zoom_spin->setSuffix(tr2i18n("%", nullptr));
        label_2->setText(tr2i18n("Background", nullptr));
        displayBg->setText(tr2i18n("Show timeline", nullptr));
        bgBox->setItemText(0, tr2i18n("Checkered", nullptr));
        bgBox->setItemText(1, tr2i18n("Black", nullptr));
        bgBox->setItemText(2, tr2i18n("White", nullptr));

        createButton->setText(tr2i18n("Create", nullptr));
        cancelButton->setText(tr2i18n("Cancel", nullptr));
        zBottom->setText(QString());
        zUp->setText(QString());
        zTop->setText(QString());
        origin_y_top->setText(tr2i18n("+Y", nullptr));
        label_width->setText(tr2i18n("W:", nullptr));
        label_zIndex->setText(tr2i18n("Z-Index:", nullptr));
        zDown->setText(QString());
        label_height->setText(tr2i18n("H:", nullptr));
        origin_x_left->setText(tr2i18n("+X", nullptr));
        use_grid->setText(tr2i18n("Use grid", nullptr));
        buttonSelectRects->setText(tr2i18n("R", nullptr));
        buttonSelectImages->setText(tr2i18n("I", nullptr));
        buttonSelectText->setText(tr2i18n("T", nullptr));
#if QT_CONFIG(tooltip)
        hguides->setToolTip(tr2i18n("Horizontal guides.", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        vguides->setToolTip(tr2i18n("Vertical guides.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonUnselectAll->setText(tr2i18n("N", nullptr));
        show_guides->setText(tr2i18n("Show guides:", nullptr));
#if QT_CONFIG(whatsthis)
        buttonSelectAll->setWhatsThis(tr2i18n("Selects all items on the canvas.", nullptr));
#endif // QT_CONFIG(whatsthis)
        buttonSelectAll->setText(tr2i18n("A", nullptr));
        label_rotate->setText(tr2i18n("Rotate", nullptr));
        label_rotateX->setText(tr2i18n("X:", nullptr));
        label_rotateY->setText(tr2i18n("Y:", nullptr));
        label_rotateZ->setText(tr2i18n("Z:", nullptr));
        label_duration->setText(tr2i18n("Duration:", nullptr));
        label_itemzoom->setText(tr2i18n("Zoom:", nullptr));
#if QT_CONFIG(tooltip)
        itemleft->setToolTip(tr2i18n("Align item to left.", nullptr));
#endif // QT_CONFIG(tooltip)
        itemleft->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        itemhcenter->setToolTip(tr2i18n("Align item horizontally.", nullptr));
#endif // QT_CONFIG(tooltip)
        itemhcenter->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        itemright->setToolTip(tr2i18n("Align item to right.", nullptr));
#endif // QT_CONFIG(tooltip)
        itemright->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        itemtop->setToolTip(tr2i18n("Align item to top.", nullptr));
#endif // QT_CONFIG(tooltip)
        itemtop->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        itemvcenter->setToolTip(tr2i18n("Align item vertically.", nullptr));
#endif // QT_CONFIG(tooltip)
        itemvcenter->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        itembottom->setToolTip(tr2i18n("Align item to bottom.", nullptr));
#endif // QT_CONFIG(tooltip)
        itembottom->setText(tr2i18n("...", nullptr));
        shadowBox->setTitle(tr2i18n("Sha&dow", nullptr));
        label_blur->setText(tr2i18n("Blur:", nullptr));
        label_offset->setText(tr2i18n("Offset:", nullptr));
        buttonInsertUnicode->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonAlignCenter->setToolTip(tr2i18n("Align center.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAlignCenter->setText(tr2i18n("...", nullptr));
        label_lineSpacing->setText(tr2i18n("Line spacing:", nullptr));
        gradient_color->setText(tr2i18n("&Gradient:", nullptr));
        plain_color->setText(tr2i18n("Sol&id color:", nullptr));
        label_outline->setText(tr2i18n("Outline:", nullptr));
        typewriterBox->setTitle(tr2i18n("&Typewriter effect", nullptr));
        label_variation->setText(tr2i18n("Variation:", nullptr));
        groupBox_2->setTitle(tr2i18n("Expansion Mode", nullptr));
        tw_rd_char->setText(tr2i18n("B&y char", nullptr));
        tw_rd_word->setText(tr2i18n("By &word", nullptr));
        tw_rd_line->setText(tr2i18n("By &line", nullptr));
        tw_rd_custom->setText(tr2i18n("Custo&m", nullptr));
        label_frameStep->setText(tr2i18n("Frame step:", nullptr));
        label_seed->setText(tr2i18n("Seed:", nullptr));
        edit_gradient->setText(tr2i18n("...", nullptr));
        buttonItalic->setText(tr2i18n("...", nullptr));
        label_letterSpacing->setText(tr2i18n("Letter spacing:", nullptr));
        label_textAlign->setText(tr2i18n("Align:", nullptr));
#if QT_CONFIG(tooltip)
        buttonAlignRight->setToolTip(tr2i18n("Align right.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAlignRight->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonAlignLeft->setToolTip(tr2i18n("Align left.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonAlignLeft->setText(tr2i18n("...", nullptr));
        buttonUnder->setText(tr2i18n("...", nullptr));
        plain_rect->setText(tr2i18n("So&lid color:", nullptr));
        gradient_rect->setText(tr2i18n("&Gradient:", nullptr));
        edit_rect_gradient->setText(tr2i18n("...", nullptr));
        label_border->setText(tr2i18n("Border ", nullptr));
        label_borderWidth->setText(tr2i18n("Border width", nullptr));
        preserveAspectRatio->setText(tr2i18n("Preserve aspect ratio", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_properties), tr2i18n("Properties", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_background), tr2i18n("Background", nullptr));
        anim_end->setText(tr2i18n("Edit end viewport", nullptr));
        anim_start->setText(tr2i18n("Edit start viewport", nullptr));
        align_box->setTitle(QString());
        keep_aspect->setText(tr2i18n("Keep aspect ratio", nullptr));
        label_7->setText(tr2i18n("Resize", nullptr));
        resize50->setText(tr2i18n("50%", nullptr));
        resize100->setText(tr2i18n("100%", nullptr));
        resize200->setText(tr2i18n("200%", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_animation), tr2i18n("Animation", nullptr));
        label_template->setText(tr2i18n("Load template:", nullptr));
        label->setText(tr2i18n("Patterns", nullptr));
#if QT_CONFIG(tooltip)
        btn_add->setToolTip(tr2i18n("Add pattern.", nullptr));
#endif // QT_CONFIG(tooltip)
        btn_add->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        btn_remove->setToolTip(tr2i18n("Delete pattern.", nullptr));
#endif // QT_CONFIG(tooltip)
        btn_remove->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        btn_removeAll->setToolTip(tr2i18n("Delete all patterns.", nullptr));
#endif // QT_CONFIG(tooltip)
        btn_removeAll->setText(tr2i18n("...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_patterns), tr2i18n("Templates", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TitleWidget_UI: public Ui_TitleWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TITLEWIDGET_UI_H

