/********************************************************************************
** Form generated from reading UI file 'markerdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MARKERDIALOG_UI_H
#define UI_MARKERDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kcollapsiblegroupbox.h"
#include "widgets/markercategorychooser.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_MarkerDialog_UI
{
public:
    QGridLayout *gridLayout_3;
    QDialogButtonBox *buttonBox;
    KCollapsibleGroupBox *multimarker_box;
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout_3;
    QLabel *clip_filesize_5;
    QSpinBox *occurrences;
    QSpacerItem *horizontalSpacer_2;
    QLabel *clip_filesize_4;
    TimecodeDisplay *interval;
    QLabel *clip_thumb;
    QGridLayout *gridLayout;
    TimecodeDisplay *m_duration;
    QLabel *label_category;
    TimecodeDisplay *m_end;
    QLineEdit *marker_comment;
    QLabel *clip_filesize_2;
    QLabel *label_duration;
    QLabel *label_end_time;
    QLabel *clip_filesize_3;
    QSpacerItem *verticalSpacer_2;
    MarkerCategoryChooser *marker_category;
    QCheckBox *range_marker_checkbox;
    QHBoxLayout *horizontalLayout;
    TimecodeDisplay *m_in;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *verticalSpacer_3;

    void setupUi(QDialog *MarkerDialog_UI)
    {
        if (MarkerDialog_UI->objectName().isEmpty())
            MarkerDialog_UI->setObjectName("MarkerDialog_UI");
        MarkerDialog_UI->resize(327, 311);
        MarkerDialog_UI->setMinimumSize(QSize(0, 0));
        gridLayout_3 = new QGridLayout(MarkerDialog_UI);
        gridLayout_3->setObjectName("gridLayout_3");
        buttonBox = new QDialogButtonBox(MarkerDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout_3->addWidget(buttonBox, 2, 1, 1, 1);

        multimarker_box = new KCollapsibleGroupBox(MarkerDialog_UI);
        multimarker_box->setObjectName("multimarker_box");
        multimarker_box->setExpanded(false);
        verticalLayout = new QVBoxLayout(multimarker_box);
        verticalLayout->setObjectName("verticalLayout");
        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        clip_filesize_5 = new QLabel(multimarker_box);
        clip_filesize_5->setObjectName("clip_filesize_5");

        horizontalLayout_3->addWidget(clip_filesize_5);

        occurrences = new QSpinBox(multimarker_box);
        occurrences->setObjectName("occurrences");
        occurrences->setMinimum(2);

        horizontalLayout_3->addWidget(occurrences);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_2);

        clip_filesize_4 = new QLabel(multimarker_box);
        clip_filesize_4->setObjectName("clip_filesize_4");

        horizontalLayout_3->addWidget(clip_filesize_4);

        interval = new TimecodeDisplay(multimarker_box);
        interval->setObjectName("interval");

        horizontalLayout_3->addWidget(interval);


        verticalLayout->addLayout(horizontalLayout_3);


        gridLayout_3->addWidget(multimarker_box, 1, 0, 1, 2);

        clip_thumb = new QLabel(MarkerDialog_UI);
        clip_thumb->setObjectName("clip_thumb");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(clip_thumb->sizePolicy().hasHeightForWidth());
        clip_thumb->setSizePolicy(sizePolicy);
        clip_thumb->setFrameShape(QFrame::Shape::Box);
        clip_thumb->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout_3->addWidget(clip_thumb, 0, 0, 1, 1);

        gridLayout = new QGridLayout();
        gridLayout->setObjectName("gridLayout");
        m_duration = new TimecodeDisplay(MarkerDialog_UI);
        m_duration->setObjectName("m_duration");
        m_duration->setEnabled(false);

        gridLayout->addWidget(m_duration, 3, 1, 1, 1);

        label_category = new QLabel(MarkerDialog_UI);
        label_category->setObjectName("label_category");

        gridLayout->addWidget(label_category, 5, 0, 1, 1);

        m_end = new TimecodeDisplay(MarkerDialog_UI);
        m_end->setObjectName("m_end");
        m_end->setEnabled(false);

        gridLayout->addWidget(m_end, 2, 1, 1, 1);

        marker_comment = new QLineEdit(MarkerDialog_UI);
        marker_comment->setObjectName("marker_comment");

        gridLayout->addWidget(marker_comment, 4, 1, 1, 1);

        clip_filesize_2 = new QLabel(MarkerDialog_UI);
        clip_filesize_2->setObjectName("clip_filesize_2");

        gridLayout->addWidget(clip_filesize_2, 0, 0, 1, 1);

        label_duration = new QLabel(MarkerDialog_UI);
        label_duration->setObjectName("label_duration");
        label_duration->setEnabled(false);

        gridLayout->addWidget(label_duration, 3, 0, 1, 1);

        label_end_time = new QLabel(MarkerDialog_UI);
        label_end_time->setObjectName("label_end_time");
        label_end_time->setEnabled(false);

        gridLayout->addWidget(label_end_time, 2, 0, 1, 1);

        clip_filesize_3 = new QLabel(MarkerDialog_UI);
        clip_filesize_3->setObjectName("clip_filesize_3");

        gridLayout->addWidget(clip_filesize_3, 4, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_2, 7, 1, 1, 1);

        marker_category = new MarkerCategoryChooser(MarkerDialog_UI);
        marker_category->setObjectName("marker_category");
        marker_category->setProperty("allowAll", QVariant(false));

        gridLayout->addWidget(marker_category, 5, 1, 1, 1);

        range_marker_checkbox = new QCheckBox(MarkerDialog_UI);
        range_marker_checkbox->setObjectName("range_marker_checkbox");

        gridLayout->addWidget(range_marker_checkbox, 1, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_in = new TimecodeDisplay(MarkerDialog_UI);
        m_in->setObjectName("m_in");

        horizontalLayout->addWidget(m_in);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);


        gridLayout->addLayout(horizontalLayout, 0, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 6, 1, 1, 1);


        gridLayout_3->addLayout(gridLayout, 0, 1, 1, 1);


        retranslateUi(MarkerDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, MarkerDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, MarkerDialog_UI, qOverload<>(&QDialog::reject));
        QObject::connect(range_marker_checkbox, &QCheckBox::toggled, label_end_time, &QLabel::setEnabled);
        QObject::connect(range_marker_checkbox, SIGNAL(toggled(bool)), m_end, SLOT(setEnabled(bool)));
        QObject::connect(range_marker_checkbox, &QCheckBox::toggled, label_duration, &QLabel::setEnabled);
        QObject::connect(range_marker_checkbox, SIGNAL(toggled(bool)), m_duration, SLOT(setEnabled(bool)));

        QMetaObject::connectSlotsByName(MarkerDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *MarkerDialog_UI)
    {
        MarkerDialog_UI->setWindowTitle(tr2i18n("Marker", nullptr));
        multimarker_box->setTitle(tr2i18n("Add multiple markers", nullptr));
        clip_filesize_5->setText(tr2i18n("Count", nullptr));
        clip_filesize_4->setText(tr2i18n("Interval", nullptr));
        clip_thumb->setText(tr2i18n("Image preview", nullptr));
        label_category->setText(tr2i18n("Category", nullptr));
        clip_filesize_2->setText(tr2i18n("Position", nullptr));
        label_duration->setText(tr2i18n("Duration", nullptr));
        label_end_time->setText(tr2i18n("End Time", nullptr));
        clip_filesize_3->setText(tr2i18n("Comment", nullptr));
        range_marker_checkbox->setText(tr2i18n("Range Marker", nullptr));
    } // retranslateUi

};

namespace Ui {
    class MarkerDialog_UI: public Ui_MarkerDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MARKERDIALOG_UI_H

