/****************************************************************************
** Meta object code from reading C++ file 'subtitlemodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/bin/model/subtitlemodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'subtitlemodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13SubtitleModelE_t {};
} // unnamed namespace

template <> constexpr inline auto SubtitleModel::qt_create_metaobjectdata<qt_meta_tag_ZN13SubtitleModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SubtitleModel",
        "modelChanged",
        "",
        "updateSubtitleStyle",
        "activeSubLayerChanged",
        "showSubtitleManager",
        "page",
        "parseSubtitle",
        "workPath",
        "jsontoSubtitle",
        "QJsonArray",
        "data",
        "setText",
        "id",
        "text",
        "editSubtitle",
        "newText",
        "oldText",
        "resizeSubtitle",
        "layer",
        "startFrame",
        "endFrame",
        "oldEndFrame",
        "refreshModel",
        "addSubtitle",
        "startframe",
        "deleteSubtitle",
        "frameframe",
        "endframe"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateSubtitleStyle'
        QtMocHelpers::SignalData<void(const QString)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'activeSubLayerChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSubtitleManager'
        QtMocHelpers::SignalData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'parseSubtitle'
        QtMocHelpers::SlotData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 8 },
        }}),
        // Slot 'jsontoSubtitle'
        QtMocHelpers::SlotData<void(const QJsonArray &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Slot 'setText'
        QtMocHelpers::SlotData<bool(int, const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 14 },
        }}),
        // Method 'editSubtitle'
        QtMocHelpers::MethodData<void(int, const QString &, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { QMetaType::QString, 16 }, { QMetaType::QString, 17 },
        }}),
        // Method 'resizeSubtitle'
        QtMocHelpers::MethodData<void(int, int, int, int, bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 20 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
            { QMetaType::Bool, 23 },
        }}),
        // Method 'addSubtitle'
        QtMocHelpers::MethodData<void(int, int, QString)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 25 }, { QMetaType::Int, 19 }, { QMetaType::QString, 14 },
        }}),
        // Method 'addSubtitle'
        QtMocHelpers::MethodData<void(int, int)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 25 }, { QMetaType::Int, 19 },
        }}),
        // Method 'addSubtitle'
        QtMocHelpers::MethodData<void(int)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 25 },
        }}),
        // Method 'addSubtitle'
        QtMocHelpers::MethodData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Method 'deleteSubtitle'
        QtMocHelpers::MethodData<void(int, int, int, const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Int, 27 }, { QMetaType::Int, 28 }, { QMetaType::QString, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubtitleModel, qt_meta_tag_ZN13SubtitleModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SubtitleModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SubtitleModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SubtitleModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SubtitleModelE_t>.metaTypes,
    nullptr
} };

void SubtitleModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubtitleModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->updateSubtitleStyle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->activeSubLayerChanged(); break;
        case 3: _t->showSubtitleManager((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->parseSubtitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->jsontoSubtitle((*reinterpret_cast<std::add_pointer_t<QJsonArray>>(_a[1]))); break;
        case 6: { bool _r = _t->setText((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: _t->editSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 8: _t->resizeSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 9: _t->addSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 10: _t->addSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 11: _t->addSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->addSubtitle(); break;
        case 13: _t->deleteSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SubtitleModel::*)()>(_a, &SubtitleModel::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubtitleModel::*)(const QString )>(_a, &SubtitleModel::updateSubtitleStyle, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubtitleModel::*)()>(_a, &SubtitleModel::activeSubLayerChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubtitleModel::*)(int )>(_a, &SubtitleModel::showSubtitleManager, 3))
            return;
    }
}

const QMetaObject *SubtitleModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubtitleModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SubtitleModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int SubtitleModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void SubtitleModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void SubtitleModel::updateSubtitleStyle(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SubtitleModel::activeSubLayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void SubtitleModel::showSubtitleManager(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
