/********************************************************************************
** Form generated from reading UI file 'collapsiblewidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLLAPSIBLEWIDGET_UI_H
#define UI_COLLAPSIBLEWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_CollapsibleWidget_UI
{
public:
    QVBoxLayout *verticalLayout;
    QFrame *border_frame;
    QFrame *decoframe;
    QGridLayout *gridLayout_2;
    QFrame *frame;
    QHBoxLayout *horizontalLayout;
    QToolButton *collapseButton;
    QSpacerItem *horizontalSpacer;
    QToolButton *keyframesButton;
    QToolButton *inOutButton;
    QToolButton *enabledButton;
    QToolButton *presetButton;
    QToolButton *infoButton;
    QToolButton *buttonUp;
    QToolButton *buttonDown;
    QToolButton *buttonDel;
    QFrame *zoneFrame;
    QFrame *widgetFrame;

    void setupUi(QWidget *CollapsibleWidget_UI)
    {
        if (CollapsibleWidget_UI->objectName().isEmpty())
            CollapsibleWidget_UI->setObjectName("CollapsibleWidget_UI");
        CollapsibleWidget_UI->resize(309, 82);
        verticalLayout = new QVBoxLayout(CollapsibleWidget_UI);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        border_frame = new QFrame(CollapsibleWidget_UI);
        border_frame->setObjectName("border_frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(border_frame->sizePolicy().hasHeightForWidth());
        border_frame->setSizePolicy(sizePolicy);
        border_frame->setMinimumSize(QSize(0, 2));
        border_frame->setMaximumSize(QSize(16777215, 2));
        border_frame->setFrameShape(QFrame::Shape::Panel);
        border_frame->setFrameShadow(QFrame::Shadow::Plain);
        border_frame->setLineWidth(2);
        border_frame->setMidLineWidth(0);

        verticalLayout->addWidget(border_frame);

        decoframe = new QFrame(CollapsibleWidget_UI);
        decoframe->setObjectName("decoframe");
        decoframe->setAutoFillBackground(true);
        decoframe->setFrameShape(QFrame::Shape::NoFrame);
        decoframe->setFrameShadow(QFrame::Shadow::Plain);
        decoframe->setLineWidth(0);
        gridLayout_2 = new QGridLayout(decoframe);
        gridLayout_2->setSpacing(0);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        frame = new QFrame(decoframe);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setFrameShape(QFrame::Shape::NoFrame);
        frame->setFrameShadow(QFrame::Shadow::Plain);
        horizontalLayout = new QHBoxLayout(frame);
        horizontalLayout->setSpacing(0);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        collapseButton = new QToolButton(frame);
        collapseButton->setObjectName("collapseButton");
        collapseButton->setAutoRaise(true);
        collapseButton->setArrowType(Qt::ArrowType::NoArrow);

        horizontalLayout->addWidget(collapseButton);

        horizontalSpacer = new QSpacerItem(80, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer);

        keyframesButton = new QToolButton(frame);
        keyframesButton->setObjectName("keyframesButton");
        keyframesButton->setAutoRaise(true);

        horizontalLayout->addWidget(keyframesButton);

        inOutButton = new QToolButton(frame);
        inOutButton->setObjectName("inOutButton");
        inOutButton->setAutoRaise(true);

        horizontalLayout->addWidget(inOutButton);

        enabledButton = new QToolButton(frame);
        enabledButton->setObjectName("enabledButton");
        enabledButton->setCheckable(true);
        enabledButton->setAutoRaise(true);

        horizontalLayout->addWidget(enabledButton);

        presetButton = new QToolButton(frame);
        presetButton->setObjectName("presetButton");
        presetButton->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        presetButton->setAutoRaise(true);

        horizontalLayout->addWidget(presetButton);

        infoButton = new QToolButton(frame);
        infoButton->setObjectName("infoButton");
        infoButton->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        infoButton->setAutoRaise(true);

        horizontalLayout->addWidget(infoButton);

        buttonUp = new QToolButton(frame);
        buttonUp->setObjectName("buttonUp");
        buttonUp->setAutoRaise(true);

        horizontalLayout->addWidget(buttonUp);

        buttonDown = new QToolButton(frame);
        buttonDown->setObjectName("buttonDown");
        buttonDown->setAutoRaise(true);

        horizontalLayout->addWidget(buttonDown);

        buttonDel = new QToolButton(frame);
        buttonDel->setObjectName("buttonDel");
        buttonDel->setAutoRaise(true);

        horizontalLayout->addWidget(buttonDel);


        gridLayout_2->addWidget(frame, 0, 0, 1, 1);

        zoneFrame = new QFrame(decoframe);
        zoneFrame->setObjectName("zoneFrame");
        zoneFrame->setFrameShape(QFrame::Shape::StyledPanel);
        zoneFrame->setFrameShadow(QFrame::Shadow::Raised);
        zoneFrame->setMidLineWidth(0);

        gridLayout_2->addWidget(zoneFrame, 1, 0, 1, 1);

        widgetFrame = new QFrame(decoframe);
        widgetFrame->setObjectName("widgetFrame");
        widgetFrame->setFrameShape(QFrame::Shape::NoFrame);
        widgetFrame->setFrameShadow(QFrame::Shadow::Plain);

        gridLayout_2->addWidget(widgetFrame, 2, 0, 1, 1);


        verticalLayout->addWidget(decoframe);


        retranslateUi(CollapsibleWidget_UI);

        QMetaObject::connectSlotsByName(CollapsibleWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *CollapsibleWidget_UI)
    {
        collapseButton->setText(tr2i18n("...", nullptr));
        keyframesButton->setText(tr2i18n("...", nullptr));
        inOutButton->setText(tr2i18n("...", nullptr));
        enabledButton->setText(tr2i18n("...", nullptr));
        presetButton->setText(tr2i18n("...", nullptr));
        infoButton->setText(tr2i18n("...", nullptr));
        buttonUp->setText(tr2i18n("...", nullptr));
        buttonDown->setText(tr2i18n("...", nullptr));
        buttonDel->setText(tr2i18n("...", nullptr));
        (void)CollapsibleWidget_UI;
    } // retranslateUi

};

namespace Ui {
    class CollapsibleWidget_UI: public Ui_CollapsibleWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLLAPSIBLEWIDGET_UI_H

