/****************************************************************************
** Meta object code from reading C++ file 'timelinetabs.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/timeline2/view/timelinetabs.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinetabs.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12TimelineTabsE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineTabs::qt_create_metaobjectdata<qt_meta_tag_ZN12TimelineTabsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineTabs",
        "changeZoom",
        "",
        "value",
        "zoomOnMouse",
        "fitZoom",
        "showTransitionModel",
        "tid",
        "std::shared_ptr<AssetParameterModel>",
        "showMixModel",
        "cid",
        "refreshOnly",
        "showItemEffectStack",
        "clipName",
        "std::shared_ptr<EffectStackModel>",
        "QSize",
        "size",
        "showKeyframes",
        "showSubtitle",
        "itemId",
        "updateAssetPosition",
        "QUuid",
        "uuid",
        "updateZoom",
        "addTimeline",
        "TimelineWidget*",
        "ix",
        "tabName",
        "std::shared_ptr<TimelineItemModel>",
        "timelineModel",
        "MonitorProxy*",
        "proxy",
        "openInMonitor",
        "connectCurrent",
        "doConnectCurrent",
        "closeTimelineByIndex",
        "closeTimelineTab",
        "checkActiveClosed",
        "renameTab",
        "name",
        "slotNextSequence",
        "slotPreviousSequence",
        "onTabBarDoubleClicked",
        "index",
        "saveTimelinePreview",
        "path"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'changeZoom'
        QtMocHelpers::SignalData<void(int, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'fitZoom'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTransitionModel'
        QtMocHelpers::SignalData<void(int, std::shared_ptr<AssetParameterModel>)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 }, { 0x80000000 | 8, 2 },
        }}),
        // Signal 'showMixModel'
        QtMocHelpers::SignalData<void(int, std::shared_ptr<AssetParameterModel>, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 10 }, { 0x80000000 | 8, 2 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'showItemEffectStack'
        QtMocHelpers::SignalData<void(const QString &, std::shared_ptr<EffectStackModel>, QSize, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 14, 2 }, { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'showSubtitle'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'updateAssetPosition'
        QtMocHelpers::SignalData<void(int, const QUuid)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { 0x80000000 | 21, 22 },
        }}),
        // Signal 'updateZoom'
        QtMocHelpers::SignalData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'addTimeline'
        QtMocHelpers::SlotData<TimelineWidget *(const QUuid, int, const QString &, std::shared_ptr<TimelineItemModel>, MonitorProxy *, bool)>(24, 2, QMC::AccessPublic, 0x80000000 | 25, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Int, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
            { 0x80000000 | 30, 31 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'addTimeline'
        QtMocHelpers::SlotData<TimelineWidget *(const QUuid, int, const QString &, std::shared_ptr<TimelineItemModel>, MonitorProxy *)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 25, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Int, 26 }, { QMetaType::QString, 27 }, { 0x80000000 | 28, 29 },
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'connectCurrent'
        QtMocHelpers::SlotData<void(int)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'doConnectCurrent'
        QtMocHelpers::SlotData<void(int, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 }, { QMetaType::Bool, 32 },
        }}),
        // Slot 'doConnectCurrent'
        QtMocHelpers::SlotData<void(int)>(34, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'closeTimelineByIndex'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'closeTimelineTab'
        QtMocHelpers::SlotData<void(const QUuid, bool)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'closeTimelineTab'
        QtMocHelpers::SlotData<void(const QUuid)>(36, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 21, 22 },
        }}),
        // Slot 'renameTab'
        QtMocHelpers::SlotData<void(const QUuid &, const QString &)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::QString, 39 },
        }}),
        // Slot 'slotNextSequence'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPreviousSequence'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onTabBarDoubleClicked'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'saveTimelinePreview'
        QtMocHelpers::SlotData<void(const QString &)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 45 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineTabs, qt_meta_tag_ZN12TimelineTabsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineTabs::staticMetaObject = { {
    QMetaObject::SuperData::link<QTabWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineTabsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineTabsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12TimelineTabsE_t>.metaTypes,
    nullptr
} };

void TimelineTabs::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineTabs *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->changeZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->fitZoom(); break;
        case 2: _t->showTransitionModel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[2]))); break;
        case 3: _t->showMixModel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 4: _t->showItemEffectStack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectStackModel>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 5: _t->showSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->updateAssetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 7: _t->updateZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: { TimelineWidget* _r = _t->addTimeline((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<TimelineItemModel>>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<MonitorProxy*>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<TimelineWidget**>(_a[0]) = std::move(_r); }  break;
        case 9: { TimelineWidget* _r = _t->addTimeline((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<TimelineItemModel>>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<MonitorProxy*>>(_a[5])));
            if (_a[0]) *reinterpret_cast<TimelineWidget**>(_a[0]) = std::move(_r); }  break;
        case 10: _t->connectCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->doConnectCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 12: _t->doConnectCurrent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->closeTimelineByIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->closeTimelineTab((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->closeTimelineTab((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 16: _t->renameTab((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->slotNextSequence(); break;
        case 18: _t->slotPreviousSequence(); break;
        case 19: _t->onTabBarDoubleClicked((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->saveTimelinePreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int , bool )>(_a, &TimelineTabs::changeZoom, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)()>(_a, &TimelineTabs::fitZoom, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int , std::shared_ptr<AssetParameterModel> )>(_a, &TimelineTabs::showTransitionModel, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int , std::shared_ptr<AssetParameterModel> , bool )>(_a, &TimelineTabs::showMixModel, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(const QString & , std::shared_ptr<EffectStackModel> , QSize , bool )>(_a, &TimelineTabs::showItemEffectStack, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int )>(_a, &TimelineTabs::showSubtitle, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int , const QUuid )>(_a, &TimelineTabs::updateAssetPosition, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineTabs::*)(int )>(_a, &TimelineTabs::updateZoom, 7))
            return;
    }
}

const QMetaObject *TimelineTabs::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineTabs::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12TimelineTabsE_t>.strings))
        return static_cast<void*>(this);
    return QTabWidget::qt_metacast(_clname);
}

int TimelineTabs::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTabWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void TimelineTabs::changeZoom(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void TimelineTabs::fitZoom()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineTabs::showTransitionModel(int _t1, std::shared_ptr<AssetParameterModel> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void TimelineTabs::showMixModel(int _t1, std::shared_ptr<AssetParameterModel> _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void TimelineTabs::showItemEffectStack(const QString & _t1, std::shared_ptr<EffectStackModel> _t2, QSize _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 5
void TimelineTabs::showSubtitle(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TimelineTabs::updateAssetPosition(int _t1, const QUuid _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void TimelineTabs::updateZoom(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
