/********************************************************************************
** Form generated from reading UI file 'multiswitchparamwidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MULTISWITCHPARAMWIDGET_UI_H
#define UI_MULTISWITCHPARAMWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_MultiSwitchParamWidget_UI
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout;
    QCheckBox *m_checkBox;
    QComboBox *methodCombo;
    QWidget *m_widgetComment;
    QGridLayout *gridLayout_2;
    QLabel *m_labelComment;

    void setupUi(QWidget *MultiSwitchParamWidget_UI)
    {
        if (MultiSwitchParamWidget_UI->objectName().isEmpty())
            MultiSwitchParamWidget_UI->setObjectName("MultiSwitchParamWidget_UI");
        MultiSwitchParamWidget_UI->resize(217, 65);
        gridLayout = new QGridLayout(MultiSwitchParamWidget_UI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        m_checkBox = new QCheckBox(MultiSwitchParamWidget_UI);
        m_checkBox->setObjectName("m_checkBox");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_checkBox->sizePolicy().hasHeightForWidth());
        m_checkBox->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(m_checkBox);

        methodCombo = new QComboBox(MultiSwitchParamWidget_UI);
        methodCombo->setObjectName("methodCombo");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(methodCombo->sizePolicy().hasHeightForWidth());
        methodCombo->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(methodCombo);


        gridLayout->addLayout(horizontalLayout, 0, 0, 1, 1);

        m_widgetComment = new QWidget(MultiSwitchParamWidget_UI);
        m_widgetComment->setObjectName("m_widgetComment");
        gridLayout_2 = new QGridLayout(m_widgetComment);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        m_labelComment = new QLabel(m_widgetComment);
        m_labelComment->setObjectName("m_labelComment");
        m_labelComment->setFrameShape(QFrame::StyledPanel);
        m_labelComment->setFrameShadow(QFrame::Raised);
        m_labelComment->setTextFormat(Qt::RichText);
        m_labelComment->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignTop);
        m_labelComment->setWordWrap(true);

        gridLayout_2->addWidget(m_labelComment, 0, 0, 1, 1);


        gridLayout->addWidget(m_widgetComment, 1, 0, 1, 1);


        retranslateUi(MultiSwitchParamWidget_UI);

        QMetaObject::connectSlotsByName(MultiSwitchParamWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *MultiSwitchParamWidget_UI)
    {
        m_checkBox->setText(QString());
        (void)MultiSwitchParamWidget_UI;
    } // retranslateUi

};

namespace Ui {
    class MultiSwitchParamWidget_UI: public Ui_MultiSwitchParamWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MULTISWITCHPARAMWIDGET_UI_H

