/********************************************************************************
** Form generated from reading UI file 'timeremap_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TIMEREMAP_UI_H
#define UI_TIMEREMAP_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "widgets/precisionspinbox.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_TimeRemap_UI
{
public:
    QGridLayout *gridLayout_3;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_2;
    QFrame *remap_box;
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_6;
    QLabel *label_6;
    QToolButton *button_center_top;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QVBoxLayout *remapLayout;
    QHBoxLayout *horizontalLayout_7;
    QLabel *label_5;
    QToolButton *button_center;
    QSpacerItem *horizontalSpacer_3;
    QHBoxLayout *horizontalLayout_8;
    QToolButton *button_prev;
    QToolButton *button_add;
    QToolButton *button_next;
    QSpacerItem *horizontalSpacer_4;
    QFrame *info_frame;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_9;
    QLabel *label_sourceTC;
    TimecodeDisplay *m_in;
    QHBoxLayout *horizontalLayout_10;
    QLabel *label_outputTC;
    TimecodeDisplay *m_out;
    QHBoxLayout *horizontalLayout_11;
    QLabel *label_9;
    PrecisionSpinBox *speedBefore;
    QHBoxLayout *horizontalLayout_12;
    QLabel *label_10;
    PrecisionSpinBox *speedAfter;
    QHBoxLayout *horizontalLayout_13;
    QCheckBox *pitch_compensate;
    QCheckBox *frame_blending;
    QHBoxLayout *horizontalLayout_14;
    QCheckBox *move_next;
    QToolButton *button_del;
    KMessageWidget *warningMessage;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *TimeRemap_UI)
    {
        if (TimeRemap_UI->objectName().isEmpty())
            TimeRemap_UI->setObjectName("TimeRemap_UI");
        TimeRemap_UI->resize(323, 360);
        gridLayout_3 = new QGridLayout(TimeRemap_UI);
        gridLayout_3->setSpacing(0);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(TimeRemap_UI);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 323, 360));
        gridLayout_2 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_2->setObjectName("gridLayout_2");
        remap_box = new QFrame(scrollAreaWidgetContents);
        remap_box->setObjectName("remap_box");
        remap_box->setFrameShape(QFrame::Shape::NoFrame);
        remap_box->setFrameShadow(QFrame::Shadow::Plain);
        gridLayout = new QGridLayout(remap_box);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        label_6 = new QLabel(remap_box);
        label_6->setObjectName("label_6");

        horizontalLayout_6->addWidget(label_6);

        button_center_top = new QToolButton(remap_box);
        button_center_top->setObjectName("button_center_top");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("align-horizontal-center")));
        button_center_top->setIcon(icon);
        button_center_top->setAutoRaise(true);

        horizontalLayout_6->addWidget(button_center_top);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout_6, 0, 0, 1, 1);

        remapLayout = new QVBoxLayout();
        remapLayout->setObjectName("remapLayout");

        gridLayout->addLayout(remapLayout, 1, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        label_5 = new QLabel(remap_box);
        label_5->setObjectName("label_5");

        horizontalLayout_7->addWidget(label_5);

        button_center = new QToolButton(remap_box);
        button_center->setObjectName("button_center");
        button_center->setIcon(icon);
        button_center->setAutoRaise(true);

        horizontalLayout_7->addWidget(button_center);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_3);


        gridLayout->addLayout(horizontalLayout_7, 2, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        button_prev = new QToolButton(remap_box);
        button_prev->setObjectName("button_prev");
        button_prev->setAutoRaise(true);

        horizontalLayout_8->addWidget(button_prev);

        button_add = new QToolButton(remap_box);
        button_add->setObjectName("button_add");
        button_add->setAutoRaise(true);

        horizontalLayout_8->addWidget(button_add);

        button_next = new QToolButton(remap_box);
        button_next->setObjectName("button_next");
        button_next->setAutoRaise(true);

        horizontalLayout_8->addWidget(button_next);

        horizontalSpacer_4 = new QSpacerItem(28, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_8->addItem(horizontalSpacer_4);


        gridLayout->addLayout(horizontalLayout_8, 3, 0, 1, 1);

        info_frame = new QFrame(remap_box);
        info_frame->setObjectName("info_frame");
        info_frame->setFrameShape(QFrame::Shape::NoFrame);
        info_frame->setFrameShadow(QFrame::Shadow::Raised);
        verticalLayout_2 = new QVBoxLayout(info_frame);
        verticalLayout_2->setSpacing(0);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        label_sourceTC = new QLabel(info_frame);
        label_sourceTC->setObjectName("label_sourceTC");

        horizontalLayout_9->addWidget(label_sourceTC);

        m_in = new TimecodeDisplay(info_frame);
        m_in->setObjectName("m_in");

        horizontalLayout_9->addWidget(m_in);


        verticalLayout_2->addLayout(horizontalLayout_9);

        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        label_outputTC = new QLabel(info_frame);
        label_outputTC->setObjectName("label_outputTC");

        horizontalLayout_10->addWidget(label_outputTC);

        m_out = new TimecodeDisplay(info_frame);
        m_out->setObjectName("m_out");

        horizontalLayout_10->addWidget(m_out);


        verticalLayout_2->addLayout(horizontalLayout_10);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        label_9 = new QLabel(info_frame);
        label_9->setObjectName("label_9");

        horizontalLayout_11->addWidget(label_9);

        speedBefore = new PrecisionSpinBox(info_frame);
        speedBefore->setObjectName("speedBefore");

        horizontalLayout_11->addWidget(speedBefore);


        verticalLayout_2->addLayout(horizontalLayout_11);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        label_10 = new QLabel(info_frame);
        label_10->setObjectName("label_10");

        horizontalLayout_12->addWidget(label_10);

        speedAfter = new PrecisionSpinBox(info_frame);
        speedAfter->setObjectName("speedAfter");

        horizontalLayout_12->addWidget(speedAfter);


        verticalLayout_2->addLayout(horizontalLayout_12);


        gridLayout->addWidget(info_frame, 4, 0, 1, 1);

        horizontalLayout_13 = new QHBoxLayout();
        horizontalLayout_13->setObjectName("horizontalLayout_13");
        pitch_compensate = new QCheckBox(remap_box);
        pitch_compensate->setObjectName("pitch_compensate");
        pitch_compensate->setChecked(true);
        pitch_compensate->setTristate(false);

        horizontalLayout_13->addWidget(pitch_compensate);

        frame_blending = new QCheckBox(remap_box);
        frame_blending->setObjectName("frame_blending");

        horizontalLayout_13->addWidget(frame_blending);


        gridLayout->addLayout(horizontalLayout_13, 6, 0, 1, 1);

        horizontalLayout_14 = new QHBoxLayout();
        horizontalLayout_14->setObjectName("horizontalLayout_14");
        move_next = new QCheckBox(remap_box);
        move_next->setObjectName("move_next");
        move_next->setChecked(true);

        horizontalLayout_14->addWidget(move_next);

        button_del = new QToolButton(remap_box);
        button_del->setObjectName("button_del");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        button_del->setIcon(icon1);

        horizontalLayout_14->addWidget(button_del);


        gridLayout->addLayout(horizontalLayout_14, 7, 0, 1, 1);


        gridLayout_2->addWidget(remap_box, 1, 0, 1, 1);

        warningMessage = new KMessageWidget(scrollAreaWidgetContents);
        warningMessage->setObjectName("warningMessage");
        warningMessage->setWordWrap(true);
        warningMessage->setCloseButtonVisible(false);
        warningMessage->setMessageType(KMessageWidget::MessageType::Warning);

        gridLayout_2->addWidget(warningMessage, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 2, 0, 1, 1);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout_3->addWidget(scrollArea, 0, 0, 1, 1);


        retranslateUi(TimeRemap_UI);

        QMetaObject::connectSlotsByName(TimeRemap_UI);
    } // setupUi

    void retranslateUi(QWidget *TimeRemap_UI)
    {
        label_6->setText(tr2i18n("Source clip", nullptr));
        button_center_top->setText(tr2i18n("...", nullptr));
        label_5->setText(tr2i18n("Output", nullptr));
        button_center->setText(tr2i18n("...", nullptr));
        button_prev->setText(tr2i18n("...", nullptr));
        button_add->setText(tr2i18n("...", nullptr));
        button_next->setText(tr2i18n("...", nullptr));
        label_sourceTC->setText(tr2i18n("Source time", nullptr));
        label_outputTC->setText(tr2i18n("Output time", nullptr));
        label_9->setText(tr2i18n("Speed before", nullptr));
        label_10->setText(tr2i18n("After", nullptr));
        pitch_compensate->setText(tr2i18n("Pitch compensation", nullptr));
        frame_blending->setText(tr2i18n("Frame blending", nullptr));
        move_next->setText(tr2i18n("Preserve speed of next keyframes", nullptr));
        button_del->setText(tr2i18n("...", nullptr));
        (void)TimeRemap_UI;
    } // retranslateUi

};

namespace Ui {
    class TimeRemap_UI: public Ui_TimeRemap_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TIMEREMAP_UI_H

