/****************************************************************************
** Meta object code from reading C++ file 'keyframecontainer.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/view/widgets/keyframecontainer.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'keyframecontainer.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17KeyframeContainerE_t {};
} // unnamed namespace

template <> constexpr inline auto KeyframeContainer::qt_create_metaobjectdata<qt_meta_tag_ZN17KeyframeContainerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KeyframeContainer",
        "addIndex",
        "",
        "QPersistentModelIndex",
        "ix",
        "setKeyframes",
        "updateEffectKeyframe",
        "atkeyframe",
        "outside",
        "goToNext",
        "goToPrevious",
        "addRemove",
        "addOnly",
        "onCurveEditorView",
        "onKeyframeView",
        "seekToPos",
        "activateEffect",
        "updateHeight",
        "slotRefresh",
        "slotInitMonitor",
        "active",
        "sendStandardCommand",
        "command",
        "slotAddRemove",
        "slotGoToNext",
        "slotGoToPrev",
        "slotSetPosition",
        "pos",
        "update",
        "slotRemoveKeyframe",
        "QList<int>",
        "positions",
        "slotAddKeyframe",
        "disconnectEffectStack",
        "slotRefreshParams",
        "slotAtKeyframe",
        "atKeyframe",
        "singleKeyframe",
        "slotEditKeyframeType",
        "QAction*",
        "action",
        "slotUpdateKeyframesFromMonitor",
        "index",
        "QVariant",
        "res",
        "slotPasteKeyframeFromClipBoard",
        "slotCopySelectedKeyframes",
        "slotCopyKeyframes",
        "slotCopyValueAtCursorPos",
        "slotImportKeyframes",
        "slotRemoveNextKeyframes",
        "slotSeekToKeyframe",
        "offset",
        "slotSeekToPos",
        "slotToggleView",
        "monitorSeek"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addIndex'
        QtMocHelpers::SignalData<void(QPersistentModelIndex)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'setKeyframes'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'updateEffectKeyframe'
        QtMocHelpers::SignalData<void(bool, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'goToNext'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'goToPrevious'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addRemove'
        QtMocHelpers::SignalData<void(bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Signal 'addRemove'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'onCurveEditorView'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onKeyframeView'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'activateEffect'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateHeight'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInitMonitor'
        QtMocHelpers::SlotData<void(bool, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 }, { QMetaType::Bool, 2 },
        }}),
        // Slot 'sendStandardCommand'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 22 },
        }}),
        // Slot 'slotAddRemove'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 12 },
        }}),
        // Slot 'slotGoToNext'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotGoToPrev'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void(int, bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 27 }, { QMetaType::Bool, 28 },
        }}),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void(int)>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotRemoveKeyframe'
        QtMocHelpers::SlotData<void(const QVector<int> &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'slotAddKeyframe'
        QtMocHelpers::SlotData<bool(int)>(32, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'slotAddKeyframe'
        QtMocHelpers::SlotData<bool()>(32, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'disconnectEffectStack'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefreshParams'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAtKeyframe'
        QtMocHelpers::SlotData<void(bool, bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 36 }, { QMetaType::Bool, 37 },
        }}),
        // Slot 'slotEditKeyframeType'
        QtMocHelpers::SlotData<void(QAction *)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 39, 40 },
        }}),
        // Slot 'slotUpdateKeyframesFromMonitor'
        QtMocHelpers::SlotData<void(const QPersistentModelIndex &, const QVariant &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 42 }, { 0x80000000 | 43, 44 },
        }}),
        // Slot 'slotPasteKeyframeFromClipBoard'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopySelectedKeyframes'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyKeyframes'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyValueAtCursorPos'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportKeyframes'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveNextKeyframes'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSeekToKeyframe'
        QtMocHelpers::SlotData<void(int, int)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 52 },
        }}),
        // Slot 'slotSeekToPos'
        QtMocHelpers::SlotData<void(int)>(53, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
        // Slot 'slotToggleView'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'monitorSeek'
        QtMocHelpers::SlotData<void(int)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 27 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KeyframeContainer, qt_meta_tag_ZN17KeyframeContainerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KeyframeContainer::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyframeContainerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyframeContainerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17KeyframeContainerE_t>.metaTypes,
    nullptr
} };

void KeyframeContainer::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KeyframeContainer *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addIndex((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1]))); break;
        case 1: _t->setKeyframes((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->updateEffectKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 3: _t->goToNext(); break;
        case 4: _t->goToPrevious(); break;
        case 5: _t->addRemove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->addRemove(); break;
        case 7: _t->onCurveEditorView(); break;
        case 8: _t->onKeyframeView(); break;
        case 9: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->activateEffect(); break;
        case 11: _t->updateHeight(); break;
        case 12: _t->slotRefresh(); break;
        case 13: _t->slotInitMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->sendStandardCommand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->slotAddRemove((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slotGoToNext(); break;
        case 17: _t->slotGoToPrev(); break;
        case 18: _t->slotSetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 19: _t->slotSetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->slotSetPosition(); break;
        case 21: _t->slotRemoveKeyframe((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 22: { bool _r = _t->slotAddKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->slotAddKeyframe();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: _t->disconnectEffectStack(); break;
        case 25: _t->slotRefreshParams(); break;
        case 26: _t->slotAtKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 27: _t->slotEditKeyframeType((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 28: _t->slotUpdateKeyframesFromMonitor((*reinterpret_cast<std::add_pointer_t<QPersistentModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 29: _t->slotPasteKeyframeFromClipBoard(); break;
        case 30: _t->slotCopySelectedKeyframes(); break;
        case 31: _t->slotCopyKeyframes(); break;
        case 32: _t->slotCopyValueAtCursorPos(); break;
        case 33: _t->slotImportKeyframes(); break;
        case 34: _t->slotRemoveNextKeyframes(); break;
        case 35: _t->slotSeekToKeyframe((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 36: _t->slotSeekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 37: _t->slotToggleView(); break;
        case 38: _t->monitorSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 27:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)(QPersistentModelIndex )>(_a, &KeyframeContainer::addIndex, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)(const QString & )>(_a, &KeyframeContainer::setKeyframes, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)(bool , bool )>(_a, &KeyframeContainer::updateEffectKeyframe, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::goToNext, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::goToPrevious, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)(bool )>(_a, &KeyframeContainer::addRemove, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::onCurveEditorView, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::onKeyframeView, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)(int )>(_a, &KeyframeContainer::seekToPos, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::activateEffect, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KeyframeContainer::*)()>(_a, &KeyframeContainer::updateHeight, 11))
            return;
    }
}

const QMetaObject *KeyframeContainer::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KeyframeContainer::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17KeyframeContainerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KeyframeContainer::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 39)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 39;
    }
    return _id;
}

// SIGNAL 0
void KeyframeContainer::addIndex(QPersistentModelIndex _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void KeyframeContainer::setKeyframes(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KeyframeContainer::updateEffectKeyframe(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void KeyframeContainer::goToNext()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KeyframeContainer::goToPrevious()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KeyframeContainer::addRemove(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 7
void KeyframeContainer::onCurveEditorView()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KeyframeContainer::onKeyframeView()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KeyframeContainer::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void KeyframeContainer::activateEffect()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KeyframeContainer::updateHeight()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
