/****************************************************************************
** Meta object code from reading C++ file 'assetparameterview.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/view/assetparameterview.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'assetparameterview.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18AssetParameterViewE_t {};
} // unnamed namespace

template <> constexpr inline auto AssetParameterView::qt_create_metaobjectdata<qt_meta_tag_ZN18AssetParameterViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AssetParameterView",
        "seekToPos",
        "",
        "initKeyframeView",
        "active",
        "outside",
        "updatePresets",
        "presetName",
        "updateHeight",
        "activateEffect",
        "nextKeyframe",
        "previousKeyframe",
        "addRemoveKeyframe",
        "addOnly",
        "saveEffect",
        "sendStandardCommand",
        "command",
        "slotRefresh",
        "toggleKeyframes",
        "enable",
        "resetValues",
        "slotSavePreset",
        "slotLoadPreset",
        "slotUpdatePreset",
        "slotDeleteCurrentPreset",
        "slotDeletePreset",
        "commitChanges",
        "QModelIndex",
        "index",
        "value",
        "storeUndo",
        "commitMultipleChanges",
        "QList<QModelIndex>",
        "indexes",
        "values",
        "disableCurrentFilter",
        "disable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'initKeyframeView'
        QtMocHelpers::SignalData<void(bool, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'updatePresets'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'updatePresets'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'updateHeight'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'activateEffect'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nextKeyframe'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previousKeyframe'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addRemoveKeyframe'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'addRemoveKeyframe'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'saveEffect'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sendStandardCommand'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 },
        }}),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'toggleKeyframes'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 19 },
        }}),
        // Slot 'resetValues'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSavePreset'
        QtMocHelpers::SlotData<void(QString)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'slotSavePreset'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotLoadPreset'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdatePreset'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeleteCurrentPreset'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDeletePreset'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'commitChanges'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QString &, bool)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 27, 28 }, { QMetaType::QString, 29 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'commitMultipleChanges'
        QtMocHelpers::SlotData<void(const QList<QModelIndex> &, const QStringList &, bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::QStringList, 34 }, { QMetaType::Bool, 30 },
        }}),
        // Slot 'disableCurrentFilter'
        QtMocHelpers::SlotData<void(bool)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 36 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AssetParameterView, qt_meta_tag_ZN18AssetParameterViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AssetParameterView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AssetParameterViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AssetParameterViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18AssetParameterViewE_t>.metaTypes,
    nullptr
} };

void AssetParameterView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AssetParameterView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->initKeyframeView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->updatePresets((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updatePresets(); break;
        case 4: _t->updateHeight(); break;
        case 5: _t->activateEffect(); break;
        case 6: _t->nextKeyframe(); break;
        case 7: _t->previousKeyframe(); break;
        case 8: _t->addRemoveKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->addRemoveKeyframe(); break;
        case 10: _t->saveEffect(); break;
        case 11: _t->sendStandardCommand((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->slotRefresh(); break;
        case 13: _t->toggleKeyframes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->resetValues(); break;
        case 15: _t->slotSavePreset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->slotSavePreset(); break;
        case 17: _t->slotLoadPreset(); break;
        case 18: _t->slotUpdatePreset(); break;
        case 19: _t->slotDeleteCurrentPreset(); break;
        case 20: _t->slotDeletePreset((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->commitChanges((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 22: _t->commitMultipleChanges((*reinterpret_cast<std::add_pointer_t<QList<QModelIndex>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 23: _t->disableCurrentFilter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)(int )>(_a, &AssetParameterView::seekToPos, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)(bool , bool )>(_a, &AssetParameterView::initKeyframeView, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)(const QString & )>(_a, &AssetParameterView::updatePresets, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)()>(_a, &AssetParameterView::updateHeight, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)()>(_a, &AssetParameterView::activateEffect, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)()>(_a, &AssetParameterView::nextKeyframe, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)()>(_a, &AssetParameterView::previousKeyframe, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)(bool )>(_a, &AssetParameterView::addRemoveKeyframe, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)()>(_a, &AssetParameterView::saveEffect, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AssetParameterView::*)(int )>(_a, &AssetParameterView::sendStandardCommand, 11))
            return;
    }
}

const QMetaObject *AssetParameterView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AssetParameterView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18AssetParameterViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int AssetParameterView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void AssetParameterView::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AssetParameterView::initKeyframeView(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void AssetParameterView::updatePresets(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 4
void AssetParameterView::updateHeight()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void AssetParameterView::activateEffect()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AssetParameterView::nextKeyframe()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void AssetParameterView::previousKeyframe()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void AssetParameterView::addRemoveKeyframe(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 10
void AssetParameterView::saveEffect()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void AssetParameterView::sendStandardCommand(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
