/********************************************************************************
** Form generated from reading UI file 'renderwidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RENDERWIDGET_UI_H
#define UI_RENDERWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeView>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"
#include "kcombobox.h"
#include "kmessagewidget.h"
#include "kseparator.h"
#include "kurlrequester.h"
#include "widgets/markercategorychooser.h"

QT_BEGIN_NAMESPACE

class Ui_RenderWidget_UI
{
public:
    QVBoxLayout *verticalLayout_3;
    QTabWidget *tabWidget;
    QWidget *renderTab;
    QHBoxLayout *horizontalLayout1;
    QFrame *baseGroup;
    QGridLayout *gridLayout_2;
    KMessageWidget *infoMessage;
    QGroupBox *guide_zone_box;
    QGridLayout *gridLayout1;
    QLabel *toLabel;
    KComboBox *guide_start;
    QLabel *fromLabel;
    KComboBox *guide_end;
    QHBoxLayout *outfileGroup;
    QLabel *outfileLabel;
    KUrlRequester *out_file;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *options;
    QFrame *formatGroup;
    QVBoxLayout *verticalLayout3;
    QHBoxLayout *formatTools;
    QLabel *formatLabel;
    QLineEdit *searchLine;
    QSpacerItem *formatSpace;
    QGroupBox *buttonBox;
    QHBoxLayout *horizontalLayout;
    QToolButton *buttonNew;
    KNSWidgets::Button *m_knsbutton;
    KSeparator *kseparator;
    QToolButton *buttonSaveAs;
    QToolButton *buttonEdit;
    QToolButton *buttonDelete;
    QTreeView *profileTree;
    QHBoxLayout *targetGroup;
    QPushButton *buttonRender;
    QPushButton *buttonGenerateScript;
    QSpacerItem *targetSpace;
    QPushButton *buttonClose;
    QHBoxLayout *zoneGroup;
    QRadioButton *render_full;
    QRadioButton *render_zone;
    QRadioButton *render_guide;
    QSpacerItem *zoneSpace;
    QGroupBox *guide_multi_box;
    QHBoxLayout *horizontalLayout_3;
    QLabel *label;
    MarkerCategoryChooser *guideCategoryChooser;
    QScrollArea *optionsGroup;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout;
    QGroupBox *video_box;
    QFormLayout *formLayout_4;
    QCheckBox *render_full_color;
    QCheckBox *render_at_preview_res;
    QCheckBox *proxy_render;
    QLabel *label_5;
    QCheckBox *rescale;
    QHBoxLayout *rescale_box;
    QSpinBox *rescale_width;
    QLabel *xLabel;
    QSpinBox *rescale_height;
    QSpacerItem *rescaleSpace;
    QLabel *label_2;
    KComboBox *tc_type;
    QComboBox *interp_type;
    QLabel *label_7;
    QComboBox *deinterlacer_type;
    QLabel *label_8;
    QLabel *label_9;
    QComboBox *aspect_ratio_type;
    QGroupBox *audio_box;
    QFormLayout *formLayout;
    QCheckBox *stemAudioExport;
    QGroupBox *qualityGroup;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *sliderGroup;
    QLabel *label_4;
    QSlider *quality;
    QLabel *qualityPercent;
    QLabel *label_6;
    QGroupBox *encoder_box;
    QFormLayout *formLayout_2;
    QLabel *speedLabel;
    QSlider *speed;
    QLabel *threadsLabel;
    QSpinBox *encoder_threads;
    QGroupBox *processing_box;
    QFormLayout *formLayout_3;
    QLabel *label_3;
    QSpinBox *processing_threads;
    KMessageWidget *processing_warning;
    QCheckBox *checkTwoPass;
    QHBoxLayout *horizontalLayout_4;
    QCheckBox *export_meta;
    QLabel *edit_metadata;
    QSpacerItem *horizontalSpacer;
    QCheckBox *embed_subtitles;
    QCheckBox *open_browser;
    QCheckBox *play_after;
    QCheckBox *keep_log_files;
    QCheckBox *add_to_bin;
    QTextEdit *advanced_params;
    QWidget *jobTab;
    QGridLayout *gridLayout2;
    QPushButton *abort_job;
    QToolButton *shareButton;
    QPushButton *start_job;
    QPushButton *clean_up;
    QPushButton *buttonClose2;
    QSplitter *splitter;
    QTreeWidget *running_jobs;
    QGroupBox *error_box;
    QGridLayout *gridLayout3;
    QTextEdit *error_log;
    QLabel *errorLabel_2;
    QToolButton *hide_log;
    QSpacerItem *jobSpace;
    QCheckBox *shutdown;
    KMessageWidget *jobInfo;
    QWidget *scriptsTab;
    QGridLayout *gridLayout4;
    QTreeWidget *scripts_list;
    QPushButton *start_script;
    QPushButton *delete_script;
    QSpacerItem *scriptsSpace;
    QPushButton *buttonClose3;

    void setupUi(QDialog *RenderWidget_UI)
    {
        if (RenderWidget_UI->objectName().isEmpty())
            RenderWidget_UI->setObjectName("RenderWidget_UI");
        RenderWidget_UI->resize(960, 745);
        verticalLayout_3 = new QVBoxLayout(RenderWidget_UI);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        tabWidget = new QTabWidget(RenderWidget_UI);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);
        renderTab = new QWidget();
        renderTab->setObjectName("renderTab");
        horizontalLayout1 = new QHBoxLayout(renderTab);
        horizontalLayout1->setObjectName("horizontalLayout1");
        baseGroup = new QFrame(renderTab);
        baseGroup->setObjectName("baseGroup");
        gridLayout_2 = new QGridLayout(baseGroup);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setContentsMargins(0, 0, 0, 0);
        infoMessage = new KMessageWidget(baseGroup);
        infoMessage->setObjectName("infoMessage");
        infoMessage->setWordWrap(true);
        infoMessage->setCloseButtonVisible(false);

        gridLayout_2->addWidget(infoMessage, 8, 0, 1, 1);

        guide_zone_box = new QGroupBox(baseGroup);
        guide_zone_box->setObjectName("guide_zone_box");
        gridLayout1 = new QGridLayout(guide_zone_box);
        gridLayout1->setObjectName("gridLayout1");
        toLabel = new QLabel(guide_zone_box);
        toLabel->setObjectName("toLabel");

        gridLayout1->addWidget(toLabel, 0, 2, 1, 1);

        guide_start = new KComboBox(guide_zone_box);
        guide_start->setObjectName("guide_start");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(guide_start->sizePolicy().hasHeightForWidth());
        guide_start->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(guide_start, 0, 1, 1, 1);

        fromLabel = new QLabel(guide_zone_box);
        fromLabel->setObjectName("fromLabel");

        gridLayout1->addWidget(fromLabel, 0, 0, 1, 1);

        guide_end = new KComboBox(guide_zone_box);
        guide_end->setObjectName("guide_end");
        sizePolicy.setHeightForWidth(guide_end->sizePolicy().hasHeightForWidth());
        guide_end->setSizePolicy(sizePolicy);

        gridLayout1->addWidget(guide_end, 0, 3, 1, 1);


        gridLayout_2->addWidget(guide_zone_box, 4, 0, 1, 1);

        outfileGroup = new QHBoxLayout();
        outfileGroup->setObjectName("outfileGroup");
        outfileLabel = new QLabel(baseGroup);
        outfileLabel->setObjectName("outfileLabel");

        outfileGroup->addWidget(outfileLabel);

        out_file = new KUrlRequester(baseGroup);
        out_file->setObjectName("out_file");
        out_file->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        out_file->setMode(KFile::Mode::File|KFile::Mode::LocalOnly);
        out_file->setAcceptMode(QFileDialog::AcceptMode::AcceptSave);

        outfileGroup->addWidget(out_file);


        gridLayout_2->addLayout(outfileGroup, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        options = new QCheckBox(baseGroup);
        options->setObjectName("options");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(options->sizePolicy().hasHeightForWidth());
        options->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(options);


        gridLayout_2->addLayout(horizontalLayout_2, 7, 0, 1, 1);

        formatGroup = new QFrame(baseGroup);
        formatGroup->setObjectName("formatGroup");
        formatGroup->setFrameShape(QFrame::Shape::StyledPanel);
        formatGroup->setFrameShadow(QFrame::Shadow::Raised);
        verticalLayout3 = new QVBoxLayout(formatGroup);
        verticalLayout3->setObjectName("verticalLayout3");
        formatTools = new QHBoxLayout();
        formatTools->setObjectName("formatTools");
        formatLabel = new QLabel(formatGroup);
        formatLabel->setObjectName("formatLabel");

        formatTools->addWidget(formatLabel);

        searchLine = new QLineEdit(formatGroup);
        searchLine->setObjectName("searchLine");

        formatTools->addWidget(searchLine);

        formatSpace = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        formatTools->addItem(formatSpace);

        buttonBox = new QGroupBox(formatGroup);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setMinimumSize(QSize(0, 0));
        buttonBox->setFlat(true);
        horizontalLayout = new QHBoxLayout(buttonBox);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        buttonNew = new QToolButton(buttonBox);
        buttonNew->setObjectName("buttonNew");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        buttonNew->setIcon(icon);
        buttonNew->setAutoRaise(true);

        horizontalLayout->addWidget(buttonNew);

        m_knsbutton = new KNSWidgets::Button(buttonBox);
        m_knsbutton->setObjectName("m_knsbutton");
        m_knsbutton->setFlat(true);

        horizontalLayout->addWidget(m_knsbutton);

        kseparator = new KSeparator(buttonBox);
        kseparator->setObjectName("kseparator");
        kseparator->setFrameShape(QFrame::Shape::VLine);

        horizontalLayout->addWidget(kseparator);

        buttonSaveAs = new QToolButton(buttonBox);
        buttonSaveAs->setObjectName("buttonSaveAs");
        buttonSaveAs->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("document-save-as")));
        buttonSaveAs->setIcon(icon1);
        buttonSaveAs->setAutoRaise(true);

        horizontalLayout->addWidget(buttonSaveAs);

        buttonEdit = new QToolButton(buttonBox);
        buttonEdit->setObjectName("buttonEdit");
        buttonEdit->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("document-edit")));
        buttonEdit->setIcon(icon2);
        buttonEdit->setAutoRaise(true);

        horizontalLayout->addWidget(buttonEdit);

        buttonDelete = new QToolButton(buttonBox);
        buttonDelete->setObjectName("buttonDelete");
        buttonDelete->setEnabled(false);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("delete")));
        buttonDelete->setIcon(icon3);
        buttonDelete->setAutoRaise(true);

        horizontalLayout->addWidget(buttonDelete);


        formatTools->addWidget(buttonBox);


        verticalLayout3->addLayout(formatTools);

        profileTree = new QTreeView(formatGroup);
        profileTree->setObjectName("profileTree");
        profileTree->header()->setVisible(false);

        verticalLayout3->addWidget(profileTree);


        gridLayout_2->addWidget(formatGroup, 1, 0, 1, 1);

        targetGroup = new QHBoxLayout();
        targetGroup->setObjectName("targetGroup");
        buttonRender = new QPushButton(baseGroup);
        buttonRender->setObjectName("buttonRender");

        targetGroup->addWidget(buttonRender);

        buttonGenerateScript = new QPushButton(baseGroup);
        buttonGenerateScript->setObjectName("buttonGenerateScript");

        targetGroup->addWidget(buttonGenerateScript);

        targetSpace = new QSpacerItem(221, 24, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        targetGroup->addItem(targetSpace);

        buttonClose = new QPushButton(baseGroup);
        buttonClose->setObjectName("buttonClose");

        targetGroup->addWidget(buttonClose);


        gridLayout_2->addLayout(targetGroup, 9, 0, 1, 1);

        zoneGroup = new QHBoxLayout();
        zoneGroup->setObjectName("zoneGroup");
        render_full = new QRadioButton(baseGroup);
        render_full->setObjectName("render_full");
        render_full->setChecked(true);

        zoneGroup->addWidget(render_full);

        render_zone = new QRadioButton(baseGroup);
        render_zone->setObjectName("render_zone");

        zoneGroup->addWidget(render_zone);

        render_guide = new QRadioButton(baseGroup);
        render_guide->setObjectName("render_guide");

        zoneGroup->addWidget(render_guide);

        zoneSpace = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        zoneGroup->addItem(zoneSpace);


        gridLayout_2->addLayout(zoneGroup, 3, 0, 1, 1);

        guide_multi_box = new QGroupBox(baseGroup);
        guide_multi_box->setObjectName("guide_multi_box");
        guide_multi_box->setCheckable(true);
        guide_multi_box->setChecked(false);
        horizontalLayout_3 = new QHBoxLayout(guide_multi_box);
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        label = new QLabel(guide_multi_box);
        label->setObjectName("label");

        horizontalLayout_3->addWidget(label);

        guideCategoryChooser = new MarkerCategoryChooser(guide_multi_box);
        guideCategoryChooser->setObjectName("guideCategoryChooser");
        sizePolicy.setHeightForWidth(guideCategoryChooser->sizePolicy().hasHeightForWidth());
        guideCategoryChooser->setSizePolicy(sizePolicy);
        guideCategoryChooser->setProperty("onlyUsed", QVariant(true));

        horizontalLayout_3->addWidget(guideCategoryChooser);


        gridLayout_2->addWidget(guide_multi_box, 5, 0, 1, 1);


        horizontalLayout1->addWidget(baseGroup);

        optionsGroup = new QScrollArea(renderTab);
        optionsGroup->setObjectName("optionsGroup");
        optionsGroup->setFrameShape(QFrame::Shape::NoFrame);
        optionsGroup->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAsNeeded);
        optionsGroup->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        optionsGroup->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 385, 1220));
        verticalLayout = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        video_box = new QGroupBox(scrollAreaWidgetContents);
        video_box->setObjectName("video_box");
        video_box->setCheckable(true);
        formLayout_4 = new QFormLayout(video_box);
        formLayout_4->setObjectName("formLayout_4");
        render_full_color = new QCheckBox(video_box);
        render_full_color->setObjectName("render_full_color");

        formLayout_4->setWidget(2, QFormLayout::ItemRole::FieldRole, render_full_color);

        render_at_preview_res = new QCheckBox(video_box);
        render_at_preview_res->setObjectName("render_at_preview_res");

        formLayout_4->setWidget(4, QFormLayout::ItemRole::FieldRole, render_at_preview_res);

        proxy_render = new QCheckBox(video_box);
        proxy_render->setObjectName("proxy_render");

        formLayout_4->setWidget(5, QFormLayout::ItemRole::FieldRole, proxy_render);

        label_5 = new QLabel(video_box);
        label_5->setObjectName("label_5");

        formLayout_4->setWidget(6, QFormLayout::ItemRole::LabelRole, label_5);

        rescale = new QCheckBox(video_box);
        rescale->setObjectName("rescale");

        formLayout_4->setWidget(6, QFormLayout::ItemRole::FieldRole, rescale);

        rescale_box = new QHBoxLayout();
        rescale_box->setObjectName("rescale_box");
        rescale_width = new QSpinBox(video_box);
        rescale_width->setObjectName("rescale_width");
        rescale_width->setMinimum(1);
        rescale_width->setMaximum(10000);

        rescale_box->addWidget(rescale_width);

        xLabel = new QLabel(video_box);
        xLabel->setObjectName("xLabel");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(xLabel->sizePolicy().hasHeightForWidth());
        xLabel->setSizePolicy(sizePolicy2);

        rescale_box->addWidget(xLabel);

        rescale_height = new QSpinBox(video_box);
        rescale_height->setObjectName("rescale_height");
        rescale_height->setMinimum(1);
        rescale_height->setMaximum(10000);

        rescale_box->addWidget(rescale_height);

        rescaleSpace = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        rescale_box->addItem(rescaleSpace);


        formLayout_4->setLayout(7, QFormLayout::ItemRole::FieldRole, rescale_box);

        label_2 = new QLabel(video_box);
        label_2->setObjectName("label_2");

        formLayout_4->setWidget(8, QFormLayout::ItemRole::LabelRole, label_2);

        tc_type = new KComboBox(video_box);
        tc_type->setObjectName("tc_type");
        tc_type->setEnabled(true);

        formLayout_4->setWidget(8, QFormLayout::ItemRole::FieldRole, tc_type);

        interp_type = new QComboBox(video_box);
        interp_type->setObjectName("interp_type");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::FieldRole, interp_type);

        label_7 = new QLabel(video_box);
        label_7->setObjectName("label_7");

        formLayout_4->setWidget(0, QFormLayout::ItemRole::LabelRole, label_7);

        deinterlacer_type = new QComboBox(video_box);
        deinterlacer_type->setObjectName("deinterlacer_type");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::FieldRole, deinterlacer_type);

        label_8 = new QLabel(video_box);
        label_8->setObjectName("label_8");

        formLayout_4->setWidget(1, QFormLayout::ItemRole::LabelRole, label_8);

        label_9 = new QLabel(video_box);
        label_9->setObjectName("label_9");

        formLayout_4->setWidget(9, QFormLayout::ItemRole::LabelRole, label_9);

        aspect_ratio_type = new QComboBox(video_box);
        aspect_ratio_type->setObjectName("aspect_ratio_type");

        formLayout_4->setWidget(9, QFormLayout::ItemRole::FieldRole, aspect_ratio_type);


        verticalLayout->addWidget(video_box);

        audio_box = new QGroupBox(scrollAreaWidgetContents);
        audio_box->setObjectName("audio_box");
        audio_box->setCheckable(true);
        formLayout = new QFormLayout(audio_box);
        formLayout->setObjectName("formLayout");
        stemAudioExport = new QCheckBox(audio_box);
        stemAudioExport->setObjectName("stemAudioExport");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, stemAudioExport);


        verticalLayout->addWidget(audio_box);

        qualityGroup = new QGroupBox(scrollAreaWidgetContents);
        qualityGroup->setObjectName("qualityGroup");
        qualityGroup->setCheckable(true);
        qualityGroup->setChecked(false);
        verticalLayout_2 = new QVBoxLayout(qualityGroup);
        verticalLayout_2->setObjectName("verticalLayout_2");
        sliderGroup = new QHBoxLayout();
        sliderGroup->setObjectName("sliderGroup");
        label_4 = new QLabel(qualityGroup);
        label_4->setObjectName("label_4");

        sliderGroup->addWidget(label_4);

        quality = new QSlider(qualityGroup);
        quality->setObjectName("quality");
        sizePolicy.setHeightForWidth(quality->sizePolicy().hasHeightForWidth());
        quality->setSizePolicy(sizePolicy);
        quality->setMinimum(0);
        quality->setMaximum(4);
        quality->setValue(3);
        quality->setOrientation(Qt::Orientation::Horizontal);

        sliderGroup->addWidget(quality);

        qualityPercent = new QLabel(qualityGroup);
        qualityPercent->setObjectName("qualityPercent");

        sliderGroup->addWidget(qualityPercent);

        label_6 = new QLabel(qualityGroup);
        label_6->setObjectName("label_6");

        sliderGroup->addWidget(label_6);


        verticalLayout_2->addLayout(sliderGroup);


        verticalLayout->addWidget(qualityGroup);

        encoder_box = new QGroupBox(scrollAreaWidgetContents);
        encoder_box->setObjectName("encoder_box");
        formLayout_2 = new QFormLayout(encoder_box);
        formLayout_2->setObjectName("formLayout_2");
        speedLabel = new QLabel(encoder_box);
        speedLabel->setObjectName("speedLabel");

        formLayout_2->setWidget(1, QFormLayout::ItemRole::LabelRole, speedLabel);

        speed = new QSlider(encoder_box);
        speed->setObjectName("speed");
        sizePolicy.setHeightForWidth(speed->sizePolicy().hasHeightForWidth());
        speed->setSizePolicy(sizePolicy);
        speed->setMaximum(1);
        speed->setPageStep(2);
        speed->setValue(1);
        speed->setOrientation(Qt::Orientation::Horizontal);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, speed);

        threadsLabel = new QLabel(encoder_box);
        threadsLabel->setObjectName("threadsLabel");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, threadsLabel);

        encoder_threads = new QSpinBox(encoder_box);
        encoder_threads->setObjectName("encoder_threads");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(encoder_threads->sizePolicy().hasHeightForWidth());
        encoder_threads->setSizePolicy(sizePolicy3);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, encoder_threads);


        verticalLayout->addWidget(encoder_box);

        processing_box = new QGroupBox(scrollAreaWidgetContents);
        processing_box->setObjectName("processing_box");
        processing_box->setCheckable(true);
        formLayout_3 = new QFormLayout(processing_box);
        formLayout_3->setObjectName("formLayout_3");
        label_3 = new QLabel(processing_box);
        label_3->setObjectName("label_3");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, label_3);

        processing_threads = new QSpinBox(processing_box);
        processing_threads->setObjectName("processing_threads");
        processing_threads->setMinimum(1);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, processing_threads);

        processing_warning = new KMessageWidget(processing_box);
        processing_warning->setObjectName("processing_warning");
        processing_warning->setWordWrap(true);
        processing_warning->setCloseButtonVisible(false);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::SpanningRole, processing_warning);


        verticalLayout->addWidget(processing_box);

        checkTwoPass = new QCheckBox(scrollAreaWidgetContents);
        checkTwoPass->setObjectName("checkTwoPass");

        verticalLayout->addWidget(checkTwoPass);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        export_meta = new QCheckBox(scrollAreaWidgetContents);
        export_meta->setObjectName("export_meta");

        horizontalLayout_4->addWidget(export_meta);

        edit_metadata = new QLabel(scrollAreaWidgetContents);
        edit_metadata->setObjectName("edit_metadata");

        horizontalLayout_4->addWidget(edit_metadata);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer);


        verticalLayout->addLayout(horizontalLayout_4);

        embed_subtitles = new QCheckBox(scrollAreaWidgetContents);
        embed_subtitles->setObjectName("embed_subtitles");

        verticalLayout->addWidget(embed_subtitles);

        open_browser = new QCheckBox(scrollAreaWidgetContents);
        open_browser->setObjectName("open_browser");

        verticalLayout->addWidget(open_browser);

        play_after = new QCheckBox(scrollAreaWidgetContents);
        play_after->setObjectName("play_after");

        verticalLayout->addWidget(play_after);

        keep_log_files = new QCheckBox(scrollAreaWidgetContents);
        keep_log_files->setObjectName("keep_log_files");

        verticalLayout->addWidget(keep_log_files);

        add_to_bin = new QCheckBox(scrollAreaWidgetContents);
        add_to_bin->setObjectName("add_to_bin");

        verticalLayout->addWidget(add_to_bin);

        advanced_params = new QTextEdit(scrollAreaWidgetContents);
        advanced_params->setObjectName("advanced_params");
        advanced_params->setReadOnly(true);
        advanced_params->setAcceptRichText(false);

        verticalLayout->addWidget(advanced_params);

        optionsGroup->setWidget(scrollAreaWidgetContents);

        horizontalLayout1->addWidget(optionsGroup);

        tabWidget->addTab(renderTab, QString());
        jobTab = new QWidget();
        jobTab->setObjectName("jobTab");
        gridLayout2 = new QGridLayout(jobTab);
        gridLayout2->setObjectName("gridLayout2");
        abort_job = new QPushButton(jobTab);
        abort_job->setObjectName("abort_job");
        abort_job->setEnabled(false);

        gridLayout2->addWidget(abort_job, 4, 0, 1, 1);

        shareButton = new QToolButton(jobTab);
        shareButton->setObjectName("shareButton");
        shareButton->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        shareButton->setToolButtonStyle(Qt::ToolButtonStyle::ToolButtonTextBesideIcon);
        shareButton->setArrowType(Qt::ArrowType::DownArrow);

        gridLayout2->addWidget(shareButton, 4, 4, 1, 1);

        start_job = new QPushButton(jobTab);
        start_job->setObjectName("start_job");
        start_job->setEnabled(false);

        gridLayout2->addWidget(start_job, 4, 1, 1, 1);

        clean_up = new QPushButton(jobTab);
        clean_up->setObjectName("clean_up");
        clean_up->setEnabled(false);

        gridLayout2->addWidget(clean_up, 4, 2, 1, 1);

        buttonClose2 = new QPushButton(jobTab);
        buttonClose2->setObjectName("buttonClose2");

        gridLayout2->addWidget(buttonClose2, 4, 5, 1, 1);

        splitter = new QSplitter(jobTab);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Orientation::Vertical);
        running_jobs = new QTreeWidget(splitter);
        running_jobs->setObjectName("running_jobs");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(running_jobs->sizePolicy().hasHeightForWidth());
        running_jobs->setSizePolicy(sizePolicy4);
        running_jobs->setAlternatingRowColors(true);
        running_jobs->setRootIsDecorated(false);
        running_jobs->setAllColumnsShowFocus(true);
        running_jobs->setHeaderHidden(true);
        running_jobs->setColumnCount(0);
        splitter->addWidget(running_jobs);
        error_box = new QGroupBox(splitter);
        error_box->setObjectName("error_box");
        QSizePolicy sizePolicy5(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy5.setHorizontalStretch(0);
        sizePolicy5.setVerticalStretch(0);
        sizePolicy5.setHeightForWidth(error_box->sizePolicy().hasHeightForWidth());
        error_box->setSizePolicy(sizePolicy5);
        gridLayout3 = new QGridLayout(error_box);
        gridLayout3->setObjectName("gridLayout3");
        error_log = new QTextEdit(error_box);
        error_log->setObjectName("error_log");
        error_log->setReadOnly(true);

        gridLayout3->addWidget(error_log, 1, 0, 1, 2);

        errorLabel_2 = new QLabel(error_box);
        errorLabel_2->setObjectName("errorLabel_2");

        gridLayout3->addWidget(errorLabel_2, 0, 0, 1, 1);

        hide_log = new QToolButton(error_box);
        hide_log->setObjectName("hide_log");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("go-down")));
        hide_log->setIcon(icon4);

        gridLayout3->addWidget(hide_log, 0, 1, 1, 1);

        splitter->addWidget(error_box);

        gridLayout2->addWidget(splitter, 0, 0, 1, 6);

        jobSpace = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout2->addItem(jobSpace, 4, 3, 1, 1);

        shutdown = new QCheckBox(jobTab);
        shutdown->setObjectName("shutdown");

        gridLayout2->addWidget(shutdown, 3, 0, 1, 6);

        jobInfo = new KMessageWidget(jobTab);
        jobInfo->setObjectName("jobInfo");
        jobInfo->setCloseButtonVisible(false);

        gridLayout2->addWidget(jobInfo, 2, 0, 1, 6);

        tabWidget->addTab(jobTab, QString());
        scriptsTab = new QWidget();
        scriptsTab->setObjectName("scriptsTab");
        gridLayout4 = new QGridLayout(scriptsTab);
        gridLayout4->setObjectName("gridLayout4");
        scripts_list = new QTreeWidget(scriptsTab);
        scripts_list->setObjectName("scripts_list");
        sizePolicy4.setHeightForWidth(scripts_list->sizePolicy().hasHeightForWidth());
        scripts_list->setSizePolicy(sizePolicy4);
        scripts_list->setAlternatingRowColors(true);
        scripts_list->setRootIsDecorated(false);
        scripts_list->setAllColumnsShowFocus(true);
        scripts_list->setColumnCount(0);

        gridLayout4->addWidget(scripts_list, 0, 0, 1, 4);

        start_script = new QPushButton(scriptsTab);
        start_script->setObjectName("start_script");

        gridLayout4->addWidget(start_script, 1, 0, 1, 1);

        delete_script = new QPushButton(scriptsTab);
        delete_script->setObjectName("delete_script");

        gridLayout4->addWidget(delete_script, 1, 1, 1, 1);

        scriptsSpace = new QSpacerItem(85, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout4->addItem(scriptsSpace, 1, 2, 1, 1);

        buttonClose3 = new QPushButton(scriptsTab);
        buttonClose3->setObjectName("buttonClose3");

        gridLayout4->addWidget(buttonClose3, 1, 3, 1, 1);

        tabWidget->addTab(scriptsTab, QString());

        verticalLayout_3->addWidget(tabWidget);

        QWidget::setTabOrder(tabWidget, out_file);
        QWidget::setTabOrder(out_file, searchLine);
        QWidget::setTabOrder(searchLine, profileTree);
        QWidget::setTabOrder(profileTree, buttonNew);
        QWidget::setTabOrder(buttonNew, m_knsbutton);
        QWidget::setTabOrder(m_knsbutton, buttonSaveAs);
        QWidget::setTabOrder(buttonSaveAs, buttonEdit);
        QWidget::setTabOrder(buttonEdit, buttonDelete);
        QWidget::setTabOrder(buttonDelete, render_full);
        QWidget::setTabOrder(render_full, render_zone);
        QWidget::setTabOrder(render_zone, render_guide);
        QWidget::setTabOrder(render_guide, guide_start);
        QWidget::setTabOrder(guide_start, guide_end);
        QWidget::setTabOrder(guide_end, guide_multi_box);
        QWidget::setTabOrder(guide_multi_box, guideCategoryChooser);
        QWidget::setTabOrder(guideCategoryChooser, options);
        QWidget::setTabOrder(options, interp_type);
        QWidget::setTabOrder(interp_type, deinterlacer_type);
        QWidget::setTabOrder(deinterlacer_type, render_full_color);
        QWidget::setTabOrder(render_full_color, render_at_preview_res);
        QWidget::setTabOrder(render_at_preview_res, proxy_render);
        QWidget::setTabOrder(proxy_render, rescale);
        QWidget::setTabOrder(rescale, rescale_width);
        QWidget::setTabOrder(rescale_width, rescale_height);
        QWidget::setTabOrder(rescale_height, tc_type);
        QWidget::setTabOrder(tc_type, aspect_ratio_type);
        QWidget::setTabOrder(aspect_ratio_type, audio_box);
        QWidget::setTabOrder(audio_box, stemAudioExport);
        QWidget::setTabOrder(stemAudioExport, qualityGroup);
        QWidget::setTabOrder(qualityGroup, quality);
        QWidget::setTabOrder(quality, speed);
        QWidget::setTabOrder(speed, encoder_threads);
        QWidget::setTabOrder(encoder_threads, processing_box);
        QWidget::setTabOrder(processing_box, processing_threads);
        QWidget::setTabOrder(processing_threads, checkTwoPass);
        QWidget::setTabOrder(checkTwoPass, export_meta);
        QWidget::setTabOrder(export_meta, embed_subtitles);
        QWidget::setTabOrder(embed_subtitles, open_browser);
        QWidget::setTabOrder(open_browser, play_after);
        QWidget::setTabOrder(play_after, keep_log_files);
        QWidget::setTabOrder(keep_log_files, add_to_bin);
        QWidget::setTabOrder(add_to_bin, advanced_params);
        QWidget::setTabOrder(advanced_params, buttonRender);
        QWidget::setTabOrder(buttonRender, buttonGenerateScript);
        QWidget::setTabOrder(buttonGenerateScript, buttonClose);
        QWidget::setTabOrder(buttonClose, running_jobs);
        QWidget::setTabOrder(running_jobs, error_log);
        QWidget::setTabOrder(error_log, hide_log);
        QWidget::setTabOrder(hide_log, abort_job);
        QWidget::setTabOrder(abort_job, start_job);
        QWidget::setTabOrder(start_job, clean_up);
        QWidget::setTabOrder(clean_up, shutdown);
        QWidget::setTabOrder(shutdown, shareButton);
        QWidget::setTabOrder(shareButton, buttonClose2);
        QWidget::setTabOrder(buttonClose2, scripts_list);
        QWidget::setTabOrder(scripts_list, start_script);
        QWidget::setTabOrder(start_script, delete_script);
        QWidget::setTabOrder(delete_script, buttonClose3);

        retranslateUi(RenderWidget_UI);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(RenderWidget_UI);
    } // setupUi

    void retranslateUi(QDialog *RenderWidget_UI)
    {
        RenderWidget_UI->setWindowTitle(tr2i18n("Rendering", nullptr));
        guide_zone_box->setTitle(QString());
        toLabel->setText(tr2i18n("to", nullptr));
        fromLabel->setText(tr2i18n("From", nullptr));
        outfileLabel->setText(tr2i18n("Output file", nullptr));
#if QT_CONFIG(tooltip)
        out_file->setToolTip(tr2i18n("Select output destination", nullptr));
#endif // QT_CONFIG(tooltip)
        options->setText(tr2i18n("More options", nullptr));
        formatLabel->setText(tr2i18n("Presets", nullptr));
        buttonBox->setTitle(QString());
#if QT_CONFIG(tooltip)
        buttonNew->setToolTip(tr2i18n("Create new preset", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonNew->setText(tr2i18n("&Save", nullptr));
#if QT_CONFIG(tooltip)
        m_knsbutton->setToolTip(tr2i18n("Download New Render Presets\342\200\246", nullptr));
#endif // QT_CONFIG(tooltip)
        m_knsbutton->setText(QString());
        m_knsbutton->setProperty("configFile", QVariant(tr2i18n(":data/kdenlive_renderprofiles.knsrc", nullptr)));
#if QT_CONFIG(tooltip)
        buttonSaveAs->setToolTip(tr2i18n("Save current preset as new custom preset", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonSaveAs->setText(tr2i18n("&Favorite", nullptr));
#if QT_CONFIG(tooltip)
        buttonEdit->setToolTip(tr2i18n("Edit preset", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonEdit->setText(tr2i18n("&Edit", nullptr));
#if QT_CONFIG(tooltip)
        buttonDelete->setToolTip(tr2i18n("Delete preset", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonDelete->setText(tr2i18n("&Delete", nullptr));
        buttonRender->setText(tr2i18n("Render to File", nullptr));
        buttonGenerateScript->setText(tr2i18n("Generate Script", nullptr));
        buttonClose->setText(tr2i18n("Close", nullptr));
        render_full->setText(tr2i18n("Fu&ll project", nullptr));
        render_zone->setText(tr2i18n("Selected &zone", nullptr));
        render_guide->setText(tr2i18n("&Marker zone", nullptr));
        guide_multi_box->setTitle(tr2i18n("Markers Multi-Export", nullptr));
        label->setText(tr2i18n("Markers to use as separator:", nullptr));
        video_box->setTitle(tr2i18n("Video", nullptr));
        render_full_color->setText(tr2i18n("Render full color range", nullptr));
        render_at_preview_res->setText(tr2i18n("Render at Preview Resolution", nullptr));
        proxy_render->setText(tr2i18n("Use Proxy Clips", nullptr));
        label_5->setText(tr2i18n("Rescale:", nullptr));
        rescale->setText(tr2i18n("Enabled", nullptr));
        xLabel->setText(tr2i18n("x", nullptr));
        label_2->setText(tr2i18n("Overlay:", nullptr));
        label_7->setText(tr2i18n("Interpolation", nullptr));
        label_8->setText(tr2i18n("Deinterlacer", nullptr));
        label_9->setText(tr2i18n("Aspect Ratio:", nullptr));
        audio_box->setTitle(tr2i18n("Audio", nullptr));
        stemAudioExport->setText(tr2i18n("Separate file for each audio track", nullptr));
        qualityGroup->setTitle(tr2i18n("Custom Quality", nullptr));
        label_4->setText(tr2i18n("Low", nullptr));
#if QT_CONFIG(tooltip)
        quality->setToolTip(tr2i18n("Compromise file size versus quality.", nullptr));
#endif // QT_CONFIG(tooltip)
        qualityPercent->setText(tr2i18n("75%", nullptr));
        label_6->setText(tr2i18n("High", nullptr));
        encoder_box->setTitle(tr2i18n("Encoder", nullptr));
#if QT_CONFIG(tooltip)
        speedLabel->setToolTip(tr2i18n("For a given quality, tune the compromise between encoding time and output file size (faster encoding ends with larger file).", nullptr));
#endif // QT_CONFIG(tooltip)
        speedLabel->setText(tr2i18n("Speed:", nullptr));
#if QT_CONFIG(tooltip)
        speed->setToolTip(tr2i18n("For a given quality, tune the compromise between encoding time and output file size (faster encoding ends with larger file).", nullptr));
#endif // QT_CONFIG(tooltip)
        threadsLabel->setText(tr2i18n("Threads:", nullptr));
#if QT_CONFIG(tooltip)
        encoder_threads->setToolTip(tr2i18n("Encoding threads", nullptr));
#endif // QT_CONFIG(tooltip)
        encoder_threads->setSpecialValueText(tr2i18n("Auto", nullptr));
        processing_box->setTitle(tr2i18n("Parallel Processing", nullptr));
        label_3->setText(tr2i18n("Threads:", nullptr));
        processing_warning->setText(tr2i18n("Parallel processing may cause render artifacts", nullptr));
        checkTwoPass->setText(tr2i18n("2 pass", nullptr));
        export_meta->setText(tr2i18n("Export metadata", nullptr));
        edit_metadata->setText(tr2i18n("<a href=\"#\">Edit metadata</a>", nullptr));
#if QT_CONFIG(tooltip)
        embed_subtitles->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        embed_subtitles->setText(tr2i18n("Embed subtitles instead of burning them", nullptr));
        open_browser->setText(tr2i18n("Open folder after export", nullptr));
        play_after->setText(tr2i18n("Play after render", nullptr));
        keep_log_files->setText(tr2i18n("Keep log files", nullptr));
        add_to_bin->setText(tr2i18n("Add to Project Bin", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(renderTab), tr2i18n("Render Project", nullptr));
        abort_job->setText(tr2i18n("Abort Job", nullptr));
        shareButton->setText(tr2i18n("Share", nullptr));
        start_job->setText(tr2i18n("Start Job", nullptr));
        clean_up->setText(tr2i18n("Clean Up", nullptr));
        buttonClose2->setText(tr2i18n("Close", nullptr));
        error_box->setTitle(QString());
        errorLabel_2->setText(tr2i18n("Error Log", nullptr));
        hide_log->setText(tr2i18n("...", nullptr));
        shutdown->setText(tr2i18n("Shutdown computer after renderings", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(jobTab), tr2i18n("Job Queue", nullptr));
        start_script->setText(tr2i18n("Start Script", nullptr));
        delete_script->setText(tr2i18n("Delete Script", nullptr));
        buttonClose3->setText(tr2i18n("Close", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(scriptsTab), tr2i18n("Scripts", nullptr));
    } // retranslateUi

};

namespace Ui {
    class RenderWidget_UI: public Ui_RenderWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RENDERWIDGET_UI_H

