/********************************************************************************
** Form generated from reading UI file 'profiledialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROFILEDIALOG_UI_H
#define UI_PROFILEDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ProfilesDialog_UI
{
public:
    QGridLayout *gridLayout_2;
    QToolButton *button_create;
    QLabel *label;
    QToolButton *button_delete;
    QGroupBox *properties;
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    KComboBox *colorspace;
    QLabel *label_2;
    QSpinBox *size_h;
    QComboBox *scanning;
    QLabel *aspect_num;
    QComboBox *field_order;
    QSpinBox *size_w;
    QLabel *label_6;
    QLabel *label_5;
    QLabel *label_8;
    KMessageWidget *effect_warning;
    QLabel *label_scanning;
    QLabel *fields;
    QLabel *label_field_order;
    QSpinBox *display_den;
    QLabel *label_11;
    QSpinBox *frame_den;
    QSpinBox *display_num;
    QLabel *aspect_den;
    QLabel *label_7;
    QLabel *label_3;
    QLabel *label_dar;
    QLabel *label_4;
    QLineEdit *description;
    QLabel *label_12;
    QSpinBox *frame_num;
    QLabel *label_9;
    QSpacerItem *horizontalSpacer;
    QToolButton *button_save;
    QSpacerItem *horizontalSpacer_2;
    QDialogButtonBox *buttonBox;
    QComboBox *profiles_list;
    QPushButton *button_default;
    KMessageWidget *info_message;

    void setupUi(QDialog *ProfilesDialog_UI)
    {
        if (ProfilesDialog_UI->objectName().isEmpty())
            ProfilesDialog_UI->setObjectName("ProfilesDialog_UI");
        ProfilesDialog_UI->resize(594, 690);
        gridLayout_2 = new QGridLayout(ProfilesDialog_UI);
        gridLayout_2->setObjectName("gridLayout_2");
        button_create = new QToolButton(ProfilesDialog_UI);
        button_create->setObjectName("button_create");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("document-new")));
        button_create->setIcon(icon);

        gridLayout_2->addWidget(button_create, 0, 4, 1, 1);

        label = new QLabel(ProfilesDialog_UI);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        button_delete = new QToolButton(ProfilesDialog_UI);
        button_delete->setObjectName("button_delete");
        button_delete->setEnabled(false);
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("delete")));
        button_delete->setIcon(icon1);

        gridLayout_2->addWidget(button_delete, 0, 6, 1, 1);

        properties = new QGroupBox(ProfilesDialog_UI);
        properties->setObjectName("properties");
        gridLayout = new QGridLayout(properties);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(105, 17, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 13, 0, 1, 2);

        colorspace = new KComboBox(properties);
        colorspace->setObjectName("colorspace");

        gridLayout->addWidget(colorspace, 9, 1, 1, 3);

        label_2 = new QLabel(properties);
        label_2->setObjectName("label_2");
        label_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        size_h = new QSpinBox(properties);
        size_h->setObjectName("size_h");
        size_h->setMinimum(1);
        size_h->setMaximum(10000);

        gridLayout->addWidget(size_h, 1, 3, 1, 1);

        scanning = new QComboBox(properties);
        scanning->addItem(QString());
        scanning->addItem(QString());
        scanning->setObjectName("scanning");

        gridLayout->addWidget(scanning, 10, 1, 1, 3);

        aspect_num = new QLabel(properties);
        aspect_num->setObjectName("aspect_num");
        aspect_num->setText(QString::fromUtf8("1"));

        gridLayout->addWidget(aspect_num, 3, 1, 1, 1);

        field_order = new QComboBox(properties);
        field_order->addItem(QString());
        field_order->addItem(QString());
        field_order->setObjectName("field_order");

        gridLayout->addWidget(field_order, 11, 1, 1, 3);

        size_w = new QSpinBox(properties);
        size_w->setObjectName("size_w");
        size_w->setMinimum(1);
        size_w->setMaximum(10000);

        gridLayout->addWidget(size_w, 1, 1, 1, 1);

        label_6 = new QLabel(properties);
        label_6->setObjectName("label_6");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_6->sizePolicy().hasHeightForWidth());
        label_6->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_6, 1, 2, 1, 1);

        label_5 = new QLabel(properties);
        label_5->setObjectName("label_5");
        label_5->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        label_8 = new QLabel(properties);
        label_8->setObjectName("label_8");
        sizePolicy.setHeightForWidth(label_8->sizePolicy().hasHeightForWidth());
        label_8->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_8, 2, 2, 1, 1);

        effect_warning = new KMessageWidget(properties);
        effect_warning->setObjectName("effect_warning");
        effect_warning->setWordWrap(true);
        effect_warning->setCloseButtonVisible(false);

        gridLayout->addWidget(effect_warning, 12, 1, 1, 3);

        label_scanning = new QLabel(properties);
        label_scanning->setObjectName("label_scanning");
        label_scanning->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_scanning, 10, 0, 1, 1);

        fields = new QLabel(properties);
        fields->setObjectName("fields");
        fields->setFrameShape(QFrame::Shape::NoFrame);
        fields->setText(QString::fromUtf8("interl: 2*fps"));

        gridLayout->addWidget(fields, 5, 3, 1, 1);

        label_field_order = new QLabel(properties);
        label_field_order->setObjectName("label_field_order");
        label_field_order->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_field_order, 11, 0, 1, 1);

        display_den = new QSpinBox(properties);
        display_den->setObjectName("display_den");
        display_den->setMinimum(1);
        display_den->setMaximum(10000);

        gridLayout->addWidget(display_den, 2, 3, 1, 1);

        label_11 = new QLabel(properties);
        label_11->setObjectName("label_11");
        label_11->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_11, 5, 0, 1, 1);

        frame_den = new QSpinBox(properties);
        frame_den->setObjectName("frame_den");
        frame_den->setMinimum(1);
        frame_den->setMaximum(10000);

        gridLayout->addWidget(frame_den, 4, 3, 1, 1);

        display_num = new QSpinBox(properties);
        display_num->setObjectName("display_num");
        display_num->setMinimum(1);
        display_num->setMaximum(10000);

        gridLayout->addWidget(display_num, 2, 1, 1, 1);

        aspect_den = new QLabel(properties);
        aspect_den->setObjectName("aspect_den");

        gridLayout->addWidget(aspect_den, 3, 3, 1, 1);

        label_7 = new QLabel(properties);
        label_7->setObjectName("label_7");
        sizePolicy.setHeightForWidth(label_7->sizePolicy().hasHeightForWidth());
        label_7->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_7, 3, 2, 1, 1);

        label_3 = new QLabel(properties);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_3, 4, 0, 1, 1);

        label_dar = new QLabel(properties);
        label_dar->setObjectName("label_dar");
        label_dar->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_dar, 2, 0, 1, 1);

        label_4 = new QLabel(properties);
        label_4->setObjectName("label_4");
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_4, 4, 2, 1, 1);

        description = new QLineEdit(properties);
        description->setObjectName("description");

        gridLayout->addWidget(description, 0, 1, 1, 3);

        label_12 = new QLabel(properties);
        label_12->setObjectName("label_12");
        label_12->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_12, 9, 0, 1, 1);

        frame_num = new QSpinBox(properties);
        frame_num->setObjectName("frame_num");
        frame_num->setMinimum(1);
        frame_num->setMaximum(500000);

        gridLayout->addWidget(frame_num, 4, 1, 1, 1);

        label_9 = new QLabel(properties);
        label_9->setObjectName("label_9");
        label_9->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(label_9, 3, 0, 1, 1);


        gridLayout_2->addWidget(properties, 1, 0, 1, 8);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 3, 1, 1);

        button_save = new QToolButton(ProfilesDialog_UI);
        button_save->setObjectName("button_save");
        button_save->setEnabled(false);
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("document-save")));
        button_save->setIcon(icon2);

        gridLayout_2->addWidget(button_save, 0, 5, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 3, 3, 1, 2);

        buttonBox = new QDialogButtonBox(ProfilesDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Close);

        gridLayout_2->addWidget(buttonBox, 3, 5, 1, 3);

        profiles_list = new QComboBox(ProfilesDialog_UI);
        profiles_list->setObjectName("profiles_list");

        gridLayout_2->addWidget(profiles_list, 0, 1, 1, 1);

        button_default = new QPushButton(ProfilesDialog_UI);
        button_default->setObjectName("button_default");

        gridLayout_2->addWidget(button_default, 3, 0, 1, 3);

        info_message = new KMessageWidget(ProfilesDialog_UI);
        info_message->setObjectName("info_message");
        info_message->setWordWrap(true);

        gridLayout_2->addWidget(info_message, 2, 0, 1, 8);

        QWidget::setTabOrder(profiles_list, button_create);
        QWidget::setTabOrder(button_create, button_save);
        QWidget::setTabOrder(button_save, button_delete);
        QWidget::setTabOrder(button_delete, description);
        QWidget::setTabOrder(description, size_w);
        QWidget::setTabOrder(size_w, size_h);
        QWidget::setTabOrder(size_h, display_num);
        QWidget::setTabOrder(display_num, display_den);
        QWidget::setTabOrder(display_den, frame_num);
        QWidget::setTabOrder(frame_num, frame_den);
        QWidget::setTabOrder(frame_den, colorspace);
        QWidget::setTabOrder(colorspace, scanning);
        QWidget::setTabOrder(scanning, field_order);
        QWidget::setTabOrder(field_order, button_default);

        retranslateUi(ProfilesDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ProfilesDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ProfilesDialog_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ProfilesDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *ProfilesDialog_UI)
    {
        ProfilesDialog_UI->setWindowTitle(tr2i18n("Profiles", nullptr));
#if QT_CONFIG(tooltip)
        button_create->setToolTip(tr2i18n("Create  new profile", nullptr));
#endif // QT_CONFIG(tooltip)
        button_create->setText(tr2i18n("C", nullptr));
        label->setText(tr2i18n("Profile:", nullptr));
#if QT_CONFIG(tooltip)
        button_delete->setToolTip(tr2i18n("Delete profile", nullptr));
#endif // QT_CONFIG(tooltip)
        button_delete->setText(tr2i18n("D", nullptr));
        properties->setTitle(tr2i18n("Properties", nullptr));
        label_2->setText(tr2i18n("Description:", nullptr));
        scanning->setItemText(0, tr2i18n("Interlaced", nullptr));
        scanning->setItemText(1, tr2i18n("Progressive", nullptr));

        field_order->setItemText(0, tr2i18n("Top Field First", nullptr));
        field_order->setItemText(1, tr2i18n("Bottom Field First", nullptr));

        label_6->setText(tr2i18n("x", nullptr));
        label_5->setText(tr2i18n("Size:", nullptr));
        label_8->setText(tr2i18n("/", nullptr));
        effect_warning->setText(tr2i18n("The \"avfilter.fieldorder\" effect is internally used to set the field order, but the effect was not found.\n"
"This feature will not work as expected.", nullptr));
        label_scanning->setText(tr2i18n("Scanning:", nullptr));
        label_field_order->setText(tr2i18n("Field order:", nullptr));
        label_11->setText(tr2i18n("Fields per second:", nullptr));
        aspect_den->setText(tr2i18n("1", nullptr));
        label_7->setText(tr2i18n("/", nullptr));
        label_3->setText(tr2i18n("Frame rate:", nullptr));
        label_dar->setText(tr2i18n("Display aspect ratio:", nullptr));
        label_4->setText(tr2i18n("/", nullptr));
        label_12->setText(tr2i18n("Colorspace:", nullptr));
        label_9->setText(tr2i18n("Pixel aspect ratio:", nullptr));
#if QT_CONFIG(tooltip)
        button_save->setToolTip(tr2i18n("Save profile", nullptr));
#endif // QT_CONFIG(tooltip)
        button_save->setText(tr2i18n("S", nullptr));
        button_default->setText(tr2i18n("Use as default", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProfilesDialog_UI: public Ui_ProfilesDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROFILEDIALOG_UI_H

