/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<clipboardproxy.hpp>)
#  include <clipboardproxy.hpp>
#endif
#if __has_include(<definitions.h>)
#  include <definitions.h>
#endif
#if __has_include(<kdenlivesettings.h>)
#  include <kdenlivesettings.h>
#endif
#if __has_include(<timelineplayhead.h>)
#  include <timelineplayhead.h>
#endif
#if __has_include(<timelinerecwaveform.h>)
#  include <timelinerecwaveform.h>
#endif
#if __has_include(<timelinetriangle.h>)
#  include <timelinetriangle.h>
#endif
#if __has_include(<timelinewaveform.h>)
#  include <timelinewaveform.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_kde_kdenlive()
{
    qmlRegisterModule("org.kde.kdenlive", 254, 0);
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &AssetListType::staticMetaObject;},
            "AssetListType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&AssetListType::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &AssetListType::staticMetaObject, nullptr);
    qmlRegisterEnum<AssetListType::AssetType>("AssetListType::AssetType");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ClipType::staticMetaObject;},
            "ClipType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ClipType::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &ClipType::staticMetaObject, nullptr);
    qmlRegisterEnum<ClipType::ProducerType>("ClipType::ProducerType");
    qmlRegisterTypesAndRevisions<ClipboardProxy>("org.kde.kdenlive", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &FileStatus::staticMetaObject;},
            "FileStatus");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&FileStatus::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &FileStatus::staticMetaObject, nullptr);
    qmlRegisterEnum<FileStatus::ClipStatus>("FileStatus::ClipStatus");
    qmlRegisterTypesAndRevisions<KdenliveSettings>("org.kde.kdenlive", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &KeyframeType::staticMetaObject;},
            "KeyframeType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&KeyframeType::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &KeyframeType::staticMetaObject, nullptr);
    qmlRegisterEnum<KeyframeType::KeyframeEnum>("KeyframeType::KeyframeEnum");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &MaskModeType::staticMetaObject;},
            "MaskModeType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&MaskModeType::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &MaskModeType::staticMetaObject, nullptr);
    qmlRegisterEnum<MaskModeType::MaskCreationMode>("MaskModeType::MaskCreationMode");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &PlaylistState::staticMetaObject;},
            "PlaylistState");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&PlaylistState::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &PlaylistState::staticMetaObject, nullptr);
    qmlRegisterEnum<PlaylistState::ClipState>("PlaylistState::ClipState");
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &SpeechToTextEngine::staticMetaObject;},
            "SpeechToTextEngine");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&SpeechToTextEngine::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &SpeechToTextEngine::staticMetaObject, nullptr);
    qmlRegisterEnum<SpeechToTextEngine::EngineType>("SpeechToTextEngine::EngineType");
    qmlRegisterTypesAndRevisions<TimelinePlayhead>("org.kde.kdenlive", 254);
    qmlRegisterAnonymousType<QQuickItem, 254>("org.kde.kdenlive", 254);
    qmlRegisterTypesAndRevisions<TimelineRecWaveform>("org.kde.kdenlive", 254);
    qmlRegisterTypesAndRevisions<TimelineTriangle>("org.kde.kdenlive", 254);
    qmlRegisterTypesAndRevisions<TimelineWaveform>("org.kde.kdenlive", 254);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &ToolType::staticMetaObject;},
            "ToolType");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&ToolType::staticMetaObject, "org.kde.kdenlive", 254, nullptr, &ToolType::staticMetaObject, nullptr);
    qmlRegisterEnum<ToolType::ProjectTool>("ToolType::ProjectTool");
    QT_WARNING_POP
    qmlRegisterModule("org.kde.kdenlive", 254, 254);
}

static const QQmlModuleRegistration orgkdekdenliveRegistration("org.kde.kdenlive", qml_register_types_org_kde_kdenlive);
