/********************************************************************************
** Form generated from reading UI file 'colorclip_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_COLORCLIP_UI_H
#define UI_COLORCLIP_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "kcolorcombo.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_ColorClip_UI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_name;
    QLineEdit *clip_name;
    QLabel *label_color;
    QLabel *label_duration;
    QDialogButtonBox *buttonBox;
    KColorCombo *clip_color;
    QSpacerItem *spacerItem;
    TimecodeDisplay *clip_duration;

    void setupUi(QDialog *ColorClip_UI)
    {
        if (ColorClip_UI->objectName().isEmpty())
            ColorClip_UI->setObjectName("ColorClip_UI");
        ColorClip_UI->resize(239, 152);
        gridLayout = new QGridLayout(ColorClip_UI);
        gridLayout->setObjectName("gridLayout");
        label_name = new QLabel(ColorClip_UI);
        label_name->setObjectName("label_name");

        gridLayout->addWidget(label_name, 0, 0, 1, 1);

        clip_name = new QLineEdit(ColorClip_UI);
        clip_name->setObjectName("clip_name");

        gridLayout->addWidget(clip_name, 0, 1, 1, 1);

        label_color = new QLabel(ColorClip_UI);
        label_color->setObjectName("label_color");

        gridLayout->addWidget(label_color, 1, 0, 1, 1);

        label_duration = new QLabel(ColorClip_UI);
        label_duration->setObjectName("label_duration");

        gridLayout->addWidget(label_duration, 2, 0, 1, 1);

        buttonBox = new QDialogButtonBox(ColorClip_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 4, 0, 1, 3);

        clip_color = new KColorCombo(ColorClip_UI);
        clip_color->setObjectName("clip_color");

        gridLayout->addWidget(clip_color, 1, 1, 1, 1);

        spacerItem = new QSpacerItem(20, 31, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(spacerItem, 3, 1, 1, 1);

        clip_duration = new TimecodeDisplay(ColorClip_UI);
        clip_duration->setObjectName("clip_duration");

        gridLayout->addWidget(clip_duration, 2, 1, 1, 1);


        retranslateUi(ColorClip_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ColorClip_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ColorClip_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ColorClip_UI);
    } // setupUi

    void retranslateUi(QDialog *ColorClip_UI)
    {
        ColorClip_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_name->setText(tr2i18n("Name:", nullptr));
        label_color->setText(tr2i18n("Clip color:", nullptr));
        label_duration->setText(tr2i18n("Duration:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ColorClip_UI: public Ui_ColorClip_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // COLORCLIP_UI_H

