/********************************************************************************
** Form generated from reading UI file 'slideshowclip_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SLIDESHOWCLIP_UI_H
#define UI_SLIDESHOWCLIP_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_SlideshowClip_UI
{
public:
    QGridLayout *gridLayout_4;
    QListWidget *icon_list;
    KComboBox *animation;
    QCheckBox *slide_crop;
    QLabel *label_3;
    QLabel *label_2;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *clip_duration;
    QSpinBox *clip_duration_frames;
    QSlider *luma_softness;
    QHBoxLayout *horizontalLayout;
    QLineEdit *luma_duration;
    QSpinBox *luma_duration_frames;
    QCheckBox *luma_fade;
    QCheckBox *slide_fade;
    KComboBox *luma_file;
    QLabel *label_softness;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QRadioButton *method_mime;
    QRadioButton *method_pattern;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_4;
    KUrlRequester *folder_url;
    KComboBox *image_type;
    QWidget *page_2;
    QGridLayout *gridLayout_3;
    QLabel *label_5;
    QSpacerItem *verticalSpacer;
    KUrlRequester *pattern_url;
    QDialogButtonBox *buttonBox;
    QCheckBox *slide_loop;
    QLineEdit *clip_name;
    QHBoxLayout *horizontalLayout_3;
    QCheckBox *show_thumbs;
    QSpacerItem *horizontalSpacer;
    QLabel *label_info;
    KComboBox *clip_duration_format;
    QLabel *label_6;
    QCheckBox *low_pass;

    void setupUi(QDialog *SlideshowClip_UI)
    {
        if (SlideshowClip_UI->objectName().isEmpty())
            SlideshowClip_UI->setObjectName("SlideshowClip_UI");
        SlideshowClip_UI->resize(401, 689);
        gridLayout_4 = new QGridLayout(SlideshowClip_UI);
        gridLayout_4->setObjectName("gridLayout_4");
        gridLayout_4->setVerticalSpacing(6);
        icon_list = new QListWidget(SlideshowClip_UI);
        icon_list->setObjectName("icon_list");

        gridLayout_4->addWidget(icon_list, 12, 0, 1, 4);

        animation = new KComboBox(SlideshowClip_UI);
        animation->setObjectName("animation");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(animation->sizePolicy().hasHeightForWidth());
        animation->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(animation, 10, 2, 1, 2);

        slide_crop = new QCheckBox(SlideshowClip_UI);
        slide_crop->setObjectName("slide_crop");

        gridLayout_4->addWidget(slide_crop, 4, 0, 1, 2);

        label_3 = new QLabel(SlideshowClip_UI);
        label_3->setObjectName("label_3");

        gridLayout_4->addWidget(label_3, 0, 0, 1, 1);

        label_2 = new QLabel(SlideshowClip_UI);
        label_2->setObjectName("label_2");

        gridLayout_4->addWidget(label_2, 2, 0, 1, 2);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        clip_duration = new QLineEdit(SlideshowClip_UI);
        clip_duration->setObjectName("clip_duration");

        horizontalLayout_2->addWidget(clip_duration);

        clip_duration_frames = new QSpinBox(SlideshowClip_UI);
        clip_duration_frames->setObjectName("clip_duration_frames");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(clip_duration_frames->sizePolicy().hasHeightForWidth());
        clip_duration_frames->setSizePolicy(sizePolicy1);
        clip_duration_frames->setMinimum(1);
        clip_duration_frames->setMaximum(256000);

        horizontalLayout_2->addWidget(clip_duration_frames);


        gridLayout_4->addLayout(horizontalLayout_2, 2, 2, 1, 1);

        luma_softness = new QSlider(SlideshowClip_UI);
        luma_softness->setObjectName("luma_softness");
        luma_softness->setEnabled(false);
        luma_softness->setMaximum(100);
        luma_softness->setOrientation(Qt::Orientation::Horizontal);

        gridLayout_4->addWidget(luma_softness, 8, 2, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        luma_duration = new QLineEdit(SlideshowClip_UI);
        luma_duration->setObjectName("luma_duration");

        horizontalLayout->addWidget(luma_duration);

        luma_duration_frames = new QSpinBox(SlideshowClip_UI);
        luma_duration_frames->setObjectName("luma_duration_frames");
        luma_duration_frames->setEnabled(false);
        sizePolicy1.setHeightForWidth(luma_duration_frames->sizePolicy().hasHeightForWidth());
        luma_duration_frames->setSizePolicy(sizePolicy1);
        luma_duration_frames->setMinimum(1);
        luma_duration_frames->setMaximum(256000);

        horizontalLayout->addWidget(luma_duration_frames);


        gridLayout_4->addLayout(horizontalLayout, 5, 2, 1, 2);

        luma_fade = new QCheckBox(SlideshowClip_UI);
        luma_fade->setObjectName("luma_fade");
        luma_fade->setEnabled(false);

        gridLayout_4->addWidget(luma_fade, 7, 0, 1, 1);

        slide_fade = new QCheckBox(SlideshowClip_UI);
        slide_fade->setObjectName("slide_fade");

        gridLayout_4->addWidget(slide_fade, 5, 0, 1, 1);

        luma_file = new KComboBox(SlideshowClip_UI);
        luma_file->setObjectName("luma_file");
        luma_file->setEnabled(false);

        gridLayout_4->addWidget(luma_file, 7, 2, 1, 2);

        label_softness = new QLabel(SlideshowClip_UI);
        label_softness->setObjectName("label_softness");
        label_softness->setEnabled(false);

        gridLayout_4->addWidget(label_softness, 8, 0, 1, 1);

        groupBox = new QGroupBox(SlideshowClip_UI);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setVerticalSpacing(0);
        method_mime = new QRadioButton(groupBox);
        method_mime->setObjectName("method_mime");
        method_mime->setChecked(true);

        gridLayout->addWidget(method_mime, 0, 0, 1, 1);

        method_pattern = new QRadioButton(groupBox);
        method_pattern->setObjectName("method_pattern");

        gridLayout->addWidget(method_pattern, 0, 1, 1, 1);

        stackedWidget = new QStackedWidget(groupBox);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        gridLayout_2 = new QGridLayout(page);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(page);
        label->setObjectName("label");

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_2, 2, 2, 1, 1);

        label_4 = new QLabel(page);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 1, 0, 1, 1);

        folder_url = new KUrlRequester(page);
        folder_url->setObjectName("folder_url");

        gridLayout_2->addWidget(folder_url, 0, 1, 1, 2);

        image_type = new KComboBox(page);
        image_type->setObjectName("image_type");

        gridLayout_2->addWidget(image_type, 1, 1, 1, 2);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_3 = new QGridLayout(page_2);
        gridLayout_3->setObjectName("gridLayout_3");
        label_5 = new QLabel(page_2);
        label_5->setObjectName("label_5");

        gridLayout_3->addWidget(label_5, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_3->addItem(verticalSpacer, 1, 2, 1, 1);

        pattern_url = new KUrlRequester(page_2);
        pattern_url->setObjectName("pattern_url");

        gridLayout_3->addWidget(pattern_url, 0, 1, 1, 2);

        stackedWidget->addWidget(page_2);

        gridLayout->addWidget(stackedWidget, 1, 0, 1, 2);


        gridLayout_4->addWidget(groupBox, 1, 0, 1, 4);

        buttonBox = new QDialogButtonBox(SlideshowClip_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout_4->addWidget(buttonBox, 14, 2, 1, 2);

        slide_loop = new QCheckBox(SlideshowClip_UI);
        slide_loop->setObjectName("slide_loop");

        gridLayout_4->addWidget(slide_loop, 3, 0, 1, 1);

        clip_name = new QLineEdit(SlideshowClip_UI);
        clip_name->setObjectName("clip_name");

        gridLayout_4->addWidget(clip_name, 0, 1, 1, 3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        show_thumbs = new QCheckBox(SlideshowClip_UI);
        show_thumbs->setObjectName("show_thumbs");

        horizontalLayout_3->addWidget(show_thumbs);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer);

        label_info = new QLabel(SlideshowClip_UI);
        label_info->setObjectName("label_info");

        horizontalLayout_3->addWidget(label_info);


        gridLayout_4->addLayout(horizontalLayout_3, 13, 0, 1, 4);

        clip_duration_format = new KComboBox(SlideshowClip_UI);
        clip_duration_format->setObjectName("clip_duration_format");

        gridLayout_4->addWidget(clip_duration_format, 2, 3, 1, 1);

        label_6 = new QLabel(SlideshowClip_UI);
        label_6->setObjectName("label_6");

        gridLayout_4->addWidget(label_6, 10, 0, 1, 1);

        low_pass = new QCheckBox(SlideshowClip_UI);
        low_pass->setObjectName("low_pass");
        low_pass->setEnabled(false);

        gridLayout_4->addWidget(low_pass, 11, 0, 1, 4);


        retranslateUi(SlideshowClip_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SlideshowClip_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SlideshowClip_UI, qOverload<>(&QDialog::reject));

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SlideshowClip_UI);
    } // setupUi

    void retranslateUi(QDialog *SlideshowClip_UI)
    {
        SlideshowClip_UI->setWindowTitle(tr2i18n("Slideshow Clip", nullptr));
        slide_crop->setText(tr2i18n("Center crop", nullptr));
        label_3->setText(tr2i18n("Name:", nullptr));
        label_2->setText(tr2i18n("Frame duration:", nullptr));
        luma_fade->setText(tr2i18n("Wipe:", nullptr));
        slide_fade->setText(tr2i18n("Dissolve:", nullptr));
        label_softness->setText(tr2i18n("Softness:", nullptr));
        groupBox->setTitle(tr2i18n("Image Selection Method", nullptr));
        method_mime->setText(tr2i18n("&MIME type", nullptr));
        method_pattern->setText(tr2i18n("Fi&lename pattern", nullptr));
        label->setText(tr2i18n("Folder:", nullptr));
        label_4->setText(tr2i18n("Image type:", nullptr));
        label_5->setText(tr2i18n("First frame:", nullptr));
        slide_loop->setText(tr2i18n("Loop", nullptr));
        show_thumbs->setText(tr2i18n("Show thumbnails", nullptr));
        label_info->setText(tr2i18n("No image found", nullptr));
        label_6->setText(tr2i18n("Animation:", nullptr));
        low_pass->setText(tr2i18n("Low pass", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SlideshowClip_UI: public Ui_SlideshowClip_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SLIDESHOWCLIP_UI_H

