/****************************************************************************
** Meta object code from reading C++ file 'effectstackmodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/effects/effectstack/model/effectstackmodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'effectstackmodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16EffectStackModelE_t {};
} // unnamed namespace

template <> constexpr inline auto EffectStackModel::qt_create_metaobjectdata<qt_meta_tag_ZN16EffectStackModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EffectStackModel",
        "modelChanged",
        "",
        "enabledStateChanged",
        "updateMasterZones",
        "currentChanged",
        "QModelIndex",
        "ix",
        "active",
        "customDataChanged",
        "QList<int>",
        "roles",
        "removeEffect",
        "std::shared_ptr<EffectItemModel>",
        "effect",
        "removeEffectWithUndo",
        "assetId",
        "QString&",
        "effectName",
        "assetRow",
        "Fun&",
        "undo",
        "redo",
        "moveEffectByRow",
        "destRow",
        "srcRow",
        "setBuildInSize",
        "QSize",
        "size",
        "replugEffect",
        "std::shared_ptr<AssetParameterModel>",
        "asset",
        "updateEffectZones",
        "adjust",
        "effectId",
        "value",
        "hasFilter",
        "getFilterParam",
        "paramName",
        "getEffectKeyframeModel",
        "KeyframeModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'modelChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enabledStateChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateMasterZones'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentChanged'
        QtMocHelpers::SignalData<void(QModelIndex, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'customDataChanged'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 6, 2 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'customDataChanged'
        QtMocHelpers::SignalData<void(const QModelIndex &, const QModelIndex &)>(9, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Slot 'removeEffect'
        QtMocHelpers::SlotData<void(const std::shared_ptr<EffectItemModel> &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'removeEffectWithUndo'
        QtMocHelpers::SlotData<void(const QString &, QString &, int, Fun &, Fun &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { 0x80000000 | 20, 21 },
            { 0x80000000 | 20, 22 },
        }}),
        // Slot 'removeEffectWithUndo'
        QtMocHelpers::SlotData<void(const std::shared_ptr<EffectItemModel> &, QString &, Fun &, Fun &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 20, 21 }, { 0x80000000 | 20, 22 },
        }}),
        // Slot 'moveEffectByRow'
        QtMocHelpers::SlotData<void(int, int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'setBuildInSize'
        QtMocHelpers::SlotData<void(const QSize)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 27, 28 },
        }}),
        // Slot 'replugEffect'
        QtMocHelpers::SlotData<void(const std::shared_ptr<AssetParameterModel> &)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 30, 31 },
        }}),
        // Slot 'updateEffectZones'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Method 'adjust'
        QtMocHelpers::MethodData<void(const QString &, const QString &, double)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QString, 18 }, { QMetaType::Double, 35 },
        }}),
        // Method 'hasFilter'
        QtMocHelpers::MethodData<bool(const QString &) const>(36, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 34 },
        }}),
        // Method 'getFilterParam'
        QtMocHelpers::MethodData<double(const QString &, const QString &)>(37, 2, QMC::AccessPublic, QMetaType::Double, {{
            { QMetaType::QString, 34 }, { QMetaType::QString, 38 },
        }}),
        // Method 'getEffectKeyframeModel'
        QtMocHelpers::MethodData<KeyframeModel *()>(39, 2, QMC::AccessPublic, 0x80000000 | 40),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EffectStackModel, qt_meta_tag_ZN16EffectStackModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EffectStackModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTreeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16EffectStackModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16EffectStackModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16EffectStackModelE_t>.metaTypes,
    nullptr
} };

void EffectStackModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EffectStackModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->modelChanged(); break;
        case 1: _t->enabledStateChanged(); break;
        case 2: _t->updateMasterZones(); break;
        case 3: _t->currentChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 4: _t->customDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 5: _t->customDataChanged((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 6: _t->removeEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1]))); break;
        case 7: _t->removeEffectWithUndo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Fun&>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<Fun&>>(_a[5]))); break;
        case 8: _t->removeEffectWithUndo((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<Fun&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<Fun&>>(_a[4]))); break;
        case 9: _t->moveEffectByRow((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->setBuildInSize((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 11: _t->replugEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[1]))); break;
        case 12: _t->updateEffectZones(); break;
        case 13: _t->adjust((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3]))); break;
        case 14: { bool _r = _t->hasFilter((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { double _r = _t->getFilterParam((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<double*>(_a[0]) = std::move(_r); }  break;
        case 16: { KeyframeModel* _r = _t->getEffectKeyframeModel();
            if (_a[0]) *reinterpret_cast<KeyframeModel**>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EffectStackModel::*)()>(_a, &EffectStackModel::modelChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackModel::*)()>(_a, &EffectStackModel::enabledStateChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackModel::*)()>(_a, &EffectStackModel::updateMasterZones, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackModel::*)(QModelIndex , bool )>(_a, &EffectStackModel::currentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackModel::*)(const QModelIndex & , const QModelIndex & , const QList<int> & )>(_a, &EffectStackModel::customDataChanged, 4))
            return;
    }
}

const QMetaObject *EffectStackModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EffectStackModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16EffectStackModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTreeModel::qt_metacast(_clname);
}

int EffectStackModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTreeModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void EffectStackModel::modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void EffectStackModel::enabledStateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void EffectStackModel::updateMasterZones()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void EffectStackModel::currentChanged(QModelIndex _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void EffectStackModel::customDataChanged(const QModelIndex & _t1, const QModelIndex & _t2, const QList<int> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2, _t3);
}
QT_WARNING_POP
