/****************************************************************************
** Meta object code from reading C++ file 'kdenlivedoc.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/doc/kdenlivedoc.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdenlivedoc.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11KdenliveDocE_t {};
} // unnamed namespace

template <> constexpr inline auto KdenliveDoc::qt_create_metaobjectdata<qt_meta_tag_ZN11KdenliveDocE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KdenliveDoc",
        "resetProjectList",
        "",
        "docModified",
        "selectLastAddedClip",
        "startAutoSave",
        "reloadEffects",
        "paths",
        "removeInvalidUndo",
        "ix",
        "updateCompositionMode",
        "slotCreateTextTemplateClip",
        "group",
        "groupId",
        "QUrl",
        "path",
        "setModified",
        "mod",
        "proxyClipsById",
        "QMap<QString,QString>",
        "ids",
        "proxy",
        "proxyPath",
        "slotProxyCurrentItem",
        "doProxy",
        "QList<std::shared_ptr<ProjectClip>>",
        "clipList",
        "force",
        "QUndoCommand*",
        "masterCommand",
        "slotAutoSave",
        "scene",
        "switchProfile",
        "ProfileParam*",
        "pf",
        "clipName",
        "slotModified",
        "slotSwitchProfile",
        "profile_path",
        "reloadThumbs",
        "checkPreviewStack",
        "slotMoveFinished",
        "KJob*",
        "job",
        "saveGuideCategories",
        "cleanupBackupFiles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'resetProjectList'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'docModified'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'selectLastAddedClip'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'startAutoSave'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadEffects'
        QtMocHelpers::SignalData<void(const QStringList &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 },
        }}),
        // Signal 'removeInvalidUndo'
        QtMocHelpers::SignalData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Signal 'updateCompositionMode'
        QtMocHelpers::SignalData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotCreateTextTemplateClip'
        QtMocHelpers::SlotData<void(const QString &, const QString &, QUrl)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 }, { QMetaType::QString, 13 }, { 0x80000000 | 14, 15 },
        }}),
        // Slot 'setModified'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'setModified'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'proxyClipsById'
        QtMocHelpers::SlotData<QMap<QString,QString>(const QStringList &, bool, const QMap<QString,QString> &)>(18, 2, QMC::AccessPublic, 0x80000000 | 19, {{
            { QMetaType::QStringList, 20 }, { QMetaType::Bool, 21 }, { 0x80000000 | 19, 22 },
        }}),
        // Slot 'proxyClipsById'
        QtMocHelpers::SlotData<QMap<QString,QString>(const QStringList &, bool)>(18, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 19, {{
            { QMetaType::QStringList, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'slotProxyCurrentItem'
        QtMocHelpers::SlotData<void(bool, QList<std::shared_ptr<ProjectClip>>, bool, QUndoCommand *)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 }, { 0x80000000 | 25, 26 }, { QMetaType::Bool, 27 }, { 0x80000000 | 28, 29 },
        }}),
        // Slot 'slotProxyCurrentItem'
        QtMocHelpers::SlotData<void(bool, QList<std::shared_ptr<ProjectClip>>, bool)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 24 }, { 0x80000000 | 25, 26 }, { QMetaType::Bool, 27 },
        }}),
        // Slot 'slotProxyCurrentItem'
        QtMocHelpers::SlotData<void(bool, QList<std::shared_ptr<ProjectClip>>)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 24 }, { 0x80000000 | 25, 26 },
        }}),
        // Slot 'slotProxyCurrentItem'
        QtMocHelpers::SlotData<void(bool)>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slotAutoSave'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'switchProfile'
        QtMocHelpers::SlotData<void(ProfileParam *, const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { QMetaType::QString, 35 },
        }}),
        // Slot 'slotModified'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchProfile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 38 }, { QMetaType::Bool, 39 },
        }}),
        // Slot 'checkPreviewStack'
        QtMocHelpers::SlotData<void(int)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 9 },
        }}),
        // Slot 'slotMoveFinished'
        QtMocHelpers::SlotData<void(KJob *)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'saveGuideCategories'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'cleanupBackupFiles'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KdenliveDoc, qt_meta_tag_ZN11KdenliveDocE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KdenliveDoc::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KdenliveDocE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KdenliveDocE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11KdenliveDocE_t>.metaTypes,
    nullptr
} };

void KdenliveDoc::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KdenliveDoc *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->resetProjectList(); break;
        case 1: _t->docModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->selectLastAddedClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->startAutoSave(); break;
        case 4: _t->reloadEffects((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->removeInvalidUndo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->updateCompositionMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->slotCreateTextTemplateClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[3]))); break;
        case 8: _t->setModified((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->setModified(); break;
        case 10: { QMap<QString,QString> _r = _t->proxyClipsById((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QMap<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 11: { QMap<QString,QString> _r = _t->proxyClipsById((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QMap<QString,QString>*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->slotProxyCurrentItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<std::shared_ptr<ProjectClip>>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUndoCommand*>>(_a[4]))); break;
        case 13: _t->slotProxyCurrentItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<std::shared_ptr<ProjectClip>>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 14: _t->slotProxyCurrentItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<std::shared_ptr<ProjectClip>>>>(_a[2]))); break;
        case 15: _t->slotProxyCurrentItem((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->slotAutoSave((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->switchProfile((*reinterpret_cast<std::add_pointer_t<ProfileParam*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->slotModified(); break;
        case 19: _t->slotSwitchProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 20: _t->checkPreviewStack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 21: _t->slotMoveFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 22: _t->saveGuideCategories(); break;
        case 23: _t->cleanupBackupFiles(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 21:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)()>(_a, &KdenliveDoc::resetProjectList, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)(bool )>(_a, &KdenliveDoc::docModified, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)(const QString & )>(_a, &KdenliveDoc::selectLastAddedClip, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)()>(_a, &KdenliveDoc::startAutoSave, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)(const QStringList & )>(_a, &KdenliveDoc::reloadEffects, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)(int )>(_a, &KdenliveDoc::removeInvalidUndo, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveDoc::*)(bool )>(_a, &KdenliveDoc::updateCompositionMode, 6))
            return;
    }
}

const QMetaObject *KdenliveDoc::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KdenliveDoc::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11KdenliveDocE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int KdenliveDoc::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 24)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 24;
    }
    return _id;
}

// SIGNAL 0
void KdenliveDoc::resetProjectList()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KdenliveDoc::docModified(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void KdenliveDoc::selectLastAddedClip(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void KdenliveDoc::startAutoSave()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KdenliveDoc::reloadEffects(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void KdenliveDoc::removeInvalidUndo(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KdenliveDoc::updateCompositionMode(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}
QT_WARNING_POP
