/****************************************************************************
** Meta object code from reading C++ file 'librarywidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/library/librarywidget.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'librarywidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11LibraryTreeE_t {};
} // unnamed namespace

template <> constexpr inline auto LibraryTree::qt_create_metaobjectdata<qt_meta_tag_ZN11LibraryTreeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LibraryTree",
        "moveData",
        "",
        "QList<QUrl>",
        "importSequence",
        "slotUpdateThumb",
        "path",
        "iconPath",
        "QPixmap",
        "pix"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'moveData'
        QtMocHelpers::SignalData<void(const QList<QUrl> &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'importSequence'
        QtMocHelpers::SignalData<void(const QStringList &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotUpdateThumb'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'slotUpdateThumb'
        QtMocHelpers::SlotData<void(const QString &, const QPixmap &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { 0x80000000 | 8, 9 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LibraryTree, qt_meta_tag_ZN11LibraryTreeE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LibraryTree::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LibraryTreeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LibraryTreeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11LibraryTreeE_t>.metaTypes,
    nullptr
} };

void LibraryTree::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LibraryTree *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->moveData((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->importSequence((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->slotUpdateThumb((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->slotUpdateThumb((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LibraryTree::*)(const QList<QUrl> & , const QString & )>(_a, &LibraryTree::moveData, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibraryTree::*)(const QStringList & , const QString & )>(_a, &LibraryTree::importSequence, 1))
            return;
    }
}

const QMetaObject *LibraryTree::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LibraryTree::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11LibraryTreeE_t>.strings))
        return static_cast<void*>(this);
    return QTreeWidget::qt_metacast(_clname);
}

int LibraryTree::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void LibraryTree::moveData(const QList<QUrl> & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void LibraryTree::importSequence(const QStringList & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN13LibraryWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto LibraryWidget::qt_create_metaobjectdata<qt_meta_tag_ZN13LibraryWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LibraryWidget",
        "addProjectClips",
        "",
        "QList<QUrl>",
        "thumbReady",
        "enableAddSelection",
        "saveTimelineSelection",
        "QDir",
        "slotAddToLibrary",
        "slotUpdateLibraryPath",
        "slotAddToProject",
        "slotDeleteFromLibrary",
        "updateActions",
        "slotAddFolder",
        "slotOpenFolder",
        "slotRenameItem",
        "slotMoveData",
        "slotSaveSequence",
        "info",
        "dest",
        "slotItemEdited",
        "QTreeWidgetItem*",
        "item",
        "column",
        "slotDownloadFinished",
        "KJob*",
        "slotDownloadProgress",
        "slotGotPreview",
        "KFileItem",
        "QPixmap",
        "pix",
        "slotItemsAdded",
        "QUrl",
        "url",
        "KFileItemList",
        "list",
        "slotItemsDeleted",
        "slotClearAll"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addProjectClips'
        QtMocHelpers::SignalData<void(const QList<QUrl> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'thumbReady'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'enableAddSelection'
        QtMocHelpers::SignalData<void(bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'saveTimelineSelection'
        QtMocHelpers::SignalData<void(QDir)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotAddToLibrary'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateLibraryPath'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddToProject'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteFromLibrary'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateActions'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddFolder'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenFolder'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameItem'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveData'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, QString)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Slot 'slotSaveSequence'
        QtMocHelpers::SlotData<void(const QStringList &, QString)>(17, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 18 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'slotItemEdited'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(20, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 21, 22 }, { QMetaType::Int, 23 },
        }}),
        // Slot 'slotDownloadFinished'
        QtMocHelpers::SlotData<void(KJob *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 2 },
        }}),
        // Slot 'slotDownloadProgress'
        QtMocHelpers::SlotData<void(KJob *, int)>(26, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotGotPreview'
        QtMocHelpers::SlotData<void(const KFileItem &, const QPixmap &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 22 }, { 0x80000000 | 29, 30 },
        }}),
        // Slot 'slotItemsAdded'
        QtMocHelpers::SlotData<void(const QUrl &, const KFileItemList &)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { 0x80000000 | 34, 35 },
        }}),
        // Slot 'slotItemsDeleted'
        QtMocHelpers::SlotData<void(const KFileItemList &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 34, 35 },
        }}),
        // Slot 'slotClearAll'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LibraryWidget, qt_meta_tag_ZN13LibraryWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LibraryWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LibraryWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LibraryWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13LibraryWidgetE_t>.metaTypes,
    nullptr
} };

void LibraryWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LibraryWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addProjectClips((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 1: _t->thumbReady((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 2: _t->enableAddSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->saveTimelineSelection((*reinterpret_cast<std::add_pointer_t<QDir>>(_a[1]))); break;
        case 4: _t->slotAddToLibrary(); break;
        case 5: _t->slotUpdateLibraryPath(); break;
        case 6: _t->slotAddToProject(); break;
        case 7: _t->slotDeleteFromLibrary(); break;
        case 8: _t->updateActions(); break;
        case 9: _t->slotAddFolder(); break;
        case 10: _t->slotOpenFolder(); break;
        case 11: _t->slotRenameItem(); break;
        case 12: _t->slotMoveData((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->slotSaveSequence((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->slotItemEdited((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 15: _t->slotDownloadFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 16: _t->slotDownloadProgress((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->slotGotPreview((*reinterpret_cast<std::add_pointer_t<KFileItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 18: _t->slotItemsAdded((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[2]))); break;
        case 19: _t->slotItemsDeleted((*reinterpret_cast<std::add_pointer_t<KFileItemList>>(_a[1]))); break;
        case 20: _t->slotClearAll(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KFileItem >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LibraryWidget::*)(const QList<QUrl> & )>(_a, &LibraryWidget::addProjectClips, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibraryWidget::*)(const QString & , const QString & )>(_a, &LibraryWidget::thumbReady, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibraryWidget::*)(bool )>(_a, &LibraryWidget::enableAddSelection, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LibraryWidget::*)(QDir )>(_a, &LibraryWidget::saveTimelineSelection, 3))
            return;
    }
}

const QMetaObject *LibraryWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LibraryWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13LibraryWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int LibraryWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void LibraryWidget::addProjectClips(const QList<QUrl> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void LibraryWidget::thumbReady(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void LibraryWidget::enableAddSelection(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void LibraryWidget::saveTimelineSelection(QDir _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}
QT_WARNING_POP
