/****************************************************************************
** Meta object code from reading C++ file 'monitormanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/monitor/monitormanager.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'monitormanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14MonitorManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto MonitorManager::qt_create_metaobjectdata<qt_meta_tag_ZN14MonitorManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MonitorManager",
        "checkColorScopes",
        "",
        "clearScopes",
        "checkScopes",
        "addEffect",
        "QDomElement",
        "updateOverlayInfos",
        "frameDisplayed",
        "SharedFrame",
        "cleanMixer",
        "updatePreviewScaling",
        "scalingChanged",
        "activateMonitor",
        "Kdenlive::MonitorId",
        "name",
        "raiseMonitor",
        "quickSwitch",
        "slotPlay",
        "slotPause",
        "slotPlayZone",
        "slotPlayZoneFromCursor",
        "slotLoopZone",
        "slotRewind",
        "speed",
        "slotForward",
        "slotRewindOneFrame",
        "slotForwardOneFrame",
        "slotRewindOneSecond",
        "slotForwardOneSecond",
        "slotStart",
        "slotEnd",
        "slotZoneStart",
        "slotZoneEnd",
        "slotSetInPoint",
        "slotSetOutPoint",
        "focusProjectMonitor",
        "refreshProjectMonitor",
        "directUpdate",
        "slowUpdate",
        "refreshProjectRange",
        "std::pair<int,int>",
        "range",
        "forceRefresh",
        "refreshClipMonitor",
        "slotSwitchFullscreen",
        "slotSwitchMonitors",
        "activateClip",
        "slotUpdateAudioMonitoring",
        "slotExtractCurrentFrame",
        "slotExtractCurrentFrameToProject",
        "slotExtractCurrentFrameToClipboard",
        "updateBgColor",
        "slotStartMultiTrackMode",
        "slotStopMultiTrackMode",
        "slotPerformMultiTrackMode",
        "markMonitorDirty",
        "QUuid",
        "uuid",
        "slotSetDeinterlacer",
        "ix",
        "slotSetInterpolation",
        "slotMuteCurrentMonitor",
        "active",
        "slotProgressivePlay",
        "slotZoomIn",
        "slotZoomOut",
        "slotZoomReset",
        "forceProjectMonitorRefresh",
        "slotToggleEffectScene",
        "enable"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'checkColorScopes'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearScopes'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkScopes'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addEffect'
        QtMocHelpers::SignalData<void(const QDomElement &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 },
        }}),
        // Signal 'updateOverlayInfos'
        QtMocHelpers::SignalData<void(int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'frameDisplayed'
        QtMocHelpers::SignalData<void(const SharedFrame &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 2 },
        }}),
        // Signal 'cleanMixer'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePreviewScaling'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scalingChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'activateMonitor'
        QtMocHelpers::SlotData<bool(Kdenlive::MonitorId, bool, bool)>(13, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Bool, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Slot 'activateMonitor'
        QtMocHelpers::SlotData<bool(Kdenlive::MonitorId, bool)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'activateMonitor'
        QtMocHelpers::SlotData<bool(Kdenlive::MonitorId)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotPlay'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPause'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlayZone'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPlayZoneFromCursor'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoopZone'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRewind'
        QtMocHelpers::SlotData<void(double)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 24 },
        }}),
        // Slot 'slotRewind'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void(double)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 24 },
        }}),
        // Slot 'slotForward'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotRewindOneFrame'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotForwardOneFrame'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRewindOneSecond'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotForwardOneSecond'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStart'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEnd'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoneStart'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoneEnd'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetInPoint'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSetOutPoint'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'focusProjectMonitor'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refreshProjectMonitor'
        QtMocHelpers::SlotData<void(bool, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 }, { QMetaType::Bool, 39 },
        }}),
        // Slot 'refreshProjectMonitor'
        QtMocHelpers::SlotData<void(bool)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'refreshProjectMonitor'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'refreshProjectRange'
        QtMocHelpers::SlotData<void(QPair<int,int>, bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 41, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'refreshProjectRange'
        QtMocHelpers::SlotData<void(QPair<int,int>)>(40, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 41, 42 },
        }}),
        // Slot 'refreshClipMonitor'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 38 },
        }}),
        // Slot 'refreshClipMonitor'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSwitchFullscreen'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchMonitors'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 47 },
        }}),
        // Slot 'slotUpdateAudioMonitoring'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExtractCurrentFrame'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExtractCurrentFrameToProject'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExtractCurrentFrameToClipboard'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateBgColor'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStartMultiTrackMode'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotStopMultiTrackMode'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPerformMultiTrackMode'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'markMonitorDirty'
        QtMocHelpers::SlotData<void(Kdenlive::MonitorId, const QUuid)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 57, 58 },
        }}),
        // Slot 'slotSetDeinterlacer'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 60 },
        }}),
        // Slot 'slotSetInterpolation'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 60 },
        }}),
        // Slot 'slotMuteCurrentMonitor'
        QtMocHelpers::SlotData<void(bool)>(62, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 63 },
        }}),
        // Slot 'slotProgressivePlay'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 63 },
        }}),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomReset'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'forceProjectMonitorRefresh'
        QtMocHelpers::SlotData<void()>(68, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleEffectScene'
        QtMocHelpers::SlotData<void(bool)>(69, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 70 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MonitorManager, qt_meta_tag_ZN14MonitorManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MonitorManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MonitorManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MonitorManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14MonitorManagerE_t>.metaTypes,
    nullptr
} };

void MonitorManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MonitorManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkColorScopes(); break;
        case 1: _t->clearScopes(); break;
        case 2: _t->checkScopes(); break;
        case 3: _t->addEffect((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1]))); break;
        case 4: _t->updateOverlayInfos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->frameDisplayed((*reinterpret_cast<std::add_pointer_t<SharedFrame>>(_a[1]))); break;
        case 6: _t->cleanMixer(); break;
        case 7: _t->updatePreviewScaling(); break;
        case 8: _t->scalingChanged(); break;
        case 9: { bool _r = _t->activateMonitor((*reinterpret_cast<std::add_pointer_t<Kdenlive::MonitorId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->activateMonitor((*reinterpret_cast<std::add_pointer_t<Kdenlive::MonitorId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->activateMonitor((*reinterpret_cast<std::add_pointer_t<Kdenlive::MonitorId>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->slotPlay(); break;
        case 13: _t->slotPause(); break;
        case 14: _t->slotPlayZone(); break;
        case 15: _t->slotPlayZoneFromCursor(); break;
        case 16: _t->slotLoopZone(); break;
        case 17: _t->slotRewind((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 18: _t->slotRewind(); break;
        case 19: _t->slotForward((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 20: _t->slotForward(); break;
        case 21: _t->slotRewindOneFrame(); break;
        case 22: _t->slotForwardOneFrame(); break;
        case 23: _t->slotRewindOneSecond(); break;
        case 24: _t->slotForwardOneSecond(); break;
        case 25: _t->slotStart(); break;
        case 26: _t->slotEnd(); break;
        case 27: _t->slotZoneStart(); break;
        case 28: _t->slotZoneEnd(); break;
        case 29: _t->slotSetInPoint(); break;
        case 30: _t->slotSetOutPoint(); break;
        case 31: _t->focusProjectMonitor(); break;
        case 32: _t->refreshProjectMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 33: _t->refreshProjectMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 34: _t->refreshProjectMonitor(); break;
        case 35: _t->refreshProjectRange((*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 36: _t->refreshProjectRange((*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[1]))); break;
        case 37: _t->refreshClipMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->refreshClipMonitor(); break;
        case 39: _t->slotSwitchFullscreen(); break;
        case 40: _t->slotSwitchMonitors((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->slotUpdateAudioMonitoring(); break;
        case 42: _t->slotExtractCurrentFrame(); break;
        case 43: _t->slotExtractCurrentFrameToProject(); break;
        case 44: _t->slotExtractCurrentFrameToClipboard(); break;
        case 45: _t->updateBgColor(); break;
        case 46: _t->slotStartMultiTrackMode(); break;
        case 47: _t->slotStopMultiTrackMode(); break;
        case 48: _t->slotPerformMultiTrackMode(); break;
        case 49: _t->markMonitorDirty((*reinterpret_cast<std::add_pointer_t<Kdenlive::MonitorId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 50: _t->slotSetDeinterlacer((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 51: _t->slotSetInterpolation((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->slotMuteCurrentMonitor((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 53: _t->slotProgressivePlay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 54: _t->slotZoomIn(); break;
        case 55: _t->slotZoomOut(); break;
        case 56: _t->slotZoomReset(); break;
        case 57: _t->forceProjectMonitorRefresh(); break;
        case 58: _t->slotToggleEffectScene((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::checkColorScopes, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::clearScopes, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::checkScopes, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)(const QDomElement & )>(_a, &MonitorManager::addEffect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)(int , int )>(_a, &MonitorManager::updateOverlayInfos, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)(const SharedFrame & )>(_a, &MonitorManager::frameDisplayed, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::cleanMixer, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::updatePreviewScaling, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MonitorManager::*)()>(_a, &MonitorManager::scalingChanged, 8))
            return;
    }
}

const QMetaObject *MonitorManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MonitorManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14MonitorManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int MonitorManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 59)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 59;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 59)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 59;
    }
    return _id;
}

// SIGNAL 0
void MonitorManager::checkColorScopes()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MonitorManager::clearScopes()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MonitorManager::checkScopes()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MonitorManager::addEffect(const QDomElement & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MonitorManager::updateOverlayInfos(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void MonitorManager::frameDisplayed(const SharedFrame & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void MonitorManager::cleanMixer()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MonitorManager::updatePreviewScaling()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void MonitorManager::scalingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
