/********************************************************************************
** Form generated from reading UI file 'editsubstyle_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSUBSTYLE_UI_H
#define UI_EDITSUBSTYLE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"

QT_BEGIN_NAMESPACE

class Ui_SubtitleStyleEdit_UI
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QLabel *labelName;
    QLineEdit *editName;
    QSpacerItem *horizontalSpacer;
    QLabel *preview;
    QHBoxLayout *horizontalLayout_3;
    QLabel *labelFont;
    QLabel *labelFontName;
    QToolButton *buttonSelectFont;
    QDoubleSpinBox *spinFontSize;
    QPushButton *buttonPrimaryColor;
    QLabel *labelSecondaryColor;
    KContextualHelpButton *kcontextualhelpbutton;
    QPushButton *buttonSecondaryColor;
    QSpinBox *spinOutline;
    QPushButton *buttonOutlineColor;
    QSpinBox *spinShadow;
    QPushButton *buttonBackColor;
    QLabel *labelBoarderStyle;
    QComboBox *comboBorderStyle;
    QComboBox *comboAlignment;
    QLabel *labelAngle;
    QDoubleSpinBox *spinAngle;
    QLabel *labelSpacing;
    QDoubleSpinBox *spinSpacing;
    QLabel *labelMarginL;
    QSpinBox *spinMarginL;
    QSpinBox *spinMarginR;
    QLabel *labelMarginV;
    QSpinBox *spinMarginV;
    QLabel *labelScaleX;
    QDoubleSpinBox *spinScaleX;
    QDoubleSpinBox *spinScaleY;
    QSpacerItem *verticalSpacer;
    QPushButton *buttonPreview;
    QLineEdit *editPreview;
    QDialogButtonBox *buttonBox;
    QLabel *labelColor;
    QLabel *labelColor_2;
    QLabel *labelColor_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *checkBold;
    QCheckBox *checkItalic;
    QCheckBox *checkUnderline;
    QCheckBox *checkStrikeOut;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelMarginR;
    QLabel *labelAlignment;
    QLabel *labelScaleY;

    void setupUi(QDialog *SubtitleStyleEdit_UI)
    {
        if (SubtitleStyleEdit_UI->objectName().isEmpty())
            SubtitleStyleEdit_UI->setObjectName("SubtitleStyleEdit_UI");
        SubtitleStyleEdit_UI->resize(623, 564);
        gridLayout = new QGridLayout(SubtitleStyleEdit_UI);
        gridLayout->setObjectName("gridLayout");
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        labelName = new QLabel(SubtitleStyleEdit_UI);
        labelName->setObjectName("labelName");

        horizontalLayout_2->addWidget(labelName);

        editName = new QLineEdit(SubtitleStyleEdit_UI);
        editName->setObjectName("editName");

        horizontalLayout_2->addWidget(editName);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 6);

        horizontalSpacer = new QSpacerItem(20, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 6, 1, 1);

        preview = new QLabel(SubtitleStyleEdit_UI);
        preview->setObjectName("preview");
        preview->setEnabled(true);
        preview->setFrameShape(QFrame::Shape::Box);
        preview->setScaledContents(true);
        preview->setAlignment(Qt::AlignmentFlag::AlignCenter);

        gridLayout->addWidget(preview, 0, 7, 12, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        labelFont = new QLabel(SubtitleStyleEdit_UI);
        labelFont->setObjectName("labelFont");

        horizontalLayout_3->addWidget(labelFont);

        labelFontName = new QLabel(SubtitleStyleEdit_UI);
        labelFontName->setObjectName("labelFontName");
        labelFontName->setFrameShape(QFrame::Shape::NoFrame);
        labelFontName->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_3->addWidget(labelFontName);

        buttonSelectFont = new QToolButton(SubtitleStyleEdit_UI);
        buttonSelectFont->setObjectName("buttonSelectFont");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("font-enable")));
        buttonSelectFont->setIcon(icon);

        horizontalLayout_3->addWidget(buttonSelectFont);

        spinFontSize = new QDoubleSpinBox(SubtitleStyleEdit_UI);
        spinFontSize->setObjectName("spinFontSize");
        spinFontSize->setMaximum(10000.000000000000000);

        horizontalLayout_3->addWidget(spinFontSize);


        gridLayout->addLayout(horizontalLayout_3, 1, 0, 1, 6);

        buttonPrimaryColor = new QPushButton(SubtitleStyleEdit_UI);
        buttonPrimaryColor->setObjectName("buttonPrimaryColor");

        gridLayout->addWidget(buttonPrimaryColor, 3, 2, 1, 1);

        labelSecondaryColor = new QLabel(SubtitleStyleEdit_UI);
        labelSecondaryColor->setObjectName("labelSecondaryColor");
        labelSecondaryColor->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelSecondaryColor, 3, 3, 1, 1);

        kcontextualhelpbutton = new KContextualHelpButton(SubtitleStyleEdit_UI);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        gridLayout->addWidget(kcontextualhelpbutton, 3, 4, 1, 1);

        buttonSecondaryColor = new QPushButton(SubtitleStyleEdit_UI);
        buttonSecondaryColor->setObjectName("buttonSecondaryColor");

        gridLayout->addWidget(buttonSecondaryColor, 3, 5, 1, 1);

        spinOutline = new QSpinBox(SubtitleStyleEdit_UI);
        spinOutline->setObjectName("spinOutline");
        spinOutline->setMaximum(100000);

        gridLayout->addWidget(spinOutline, 4, 2, 1, 1);

        buttonOutlineColor = new QPushButton(SubtitleStyleEdit_UI);
        buttonOutlineColor->setObjectName("buttonOutlineColor");

        gridLayout->addWidget(buttonOutlineColor, 4, 3, 1, 3);

        spinShadow = new QSpinBox(SubtitleStyleEdit_UI);
        spinShadow->setObjectName("spinShadow");
        spinShadow->setMaximum(100000);

        gridLayout->addWidget(spinShadow, 5, 2, 1, 1);

        buttonBackColor = new QPushButton(SubtitleStyleEdit_UI);
        buttonBackColor->setObjectName("buttonBackColor");

        gridLayout->addWidget(buttonBackColor, 5, 3, 1, 3);

        labelBoarderStyle = new QLabel(SubtitleStyleEdit_UI);
        labelBoarderStyle->setObjectName("labelBoarderStyle");
        labelBoarderStyle->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelBoarderStyle, 6, 0, 1, 2);

        comboBorderStyle = new QComboBox(SubtitleStyleEdit_UI);
        comboBorderStyle->setObjectName("comboBorderStyle");

        gridLayout->addWidget(comboBorderStyle, 6, 2, 1, 1);

        comboAlignment = new QComboBox(SubtitleStyleEdit_UI);
        comboAlignment->setObjectName("comboAlignment");

        gridLayout->addWidget(comboAlignment, 6, 5, 1, 1);

        labelAngle = new QLabel(SubtitleStyleEdit_UI);
        labelAngle->setObjectName("labelAngle");
        labelAngle->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelAngle, 7, 1, 1, 1);

        spinAngle = new QDoubleSpinBox(SubtitleStyleEdit_UI);
        spinAngle->setObjectName("spinAngle");
        spinAngle->setMinimum(-360.000000000000000);
        spinAngle->setMaximum(360.000000000000000);

        gridLayout->addWidget(spinAngle, 7, 2, 1, 1);

        labelSpacing = new QLabel(SubtitleStyleEdit_UI);
        labelSpacing->setObjectName("labelSpacing");
        labelSpacing->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelSpacing, 7, 3, 1, 2);

        spinSpacing = new QDoubleSpinBox(SubtitleStyleEdit_UI);
        spinSpacing->setObjectName("spinSpacing");
        spinSpacing->setMinimum(0.000000000000000);
        spinSpacing->setMaximum(1000000.000000000000000);

        gridLayout->addWidget(spinSpacing, 7, 5, 1, 1);

        labelMarginL = new QLabel(SubtitleStyleEdit_UI);
        labelMarginL->setObjectName("labelMarginL");
        labelMarginL->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelMarginL, 8, 1, 1, 1);

        spinMarginL = new QSpinBox(SubtitleStyleEdit_UI);
        spinMarginL->setObjectName("spinMarginL");
        spinMarginL->setMinimum(-100000);
        spinMarginL->setMaximum(100000);

        gridLayout->addWidget(spinMarginL, 8, 2, 1, 1);

        spinMarginR = new QSpinBox(SubtitleStyleEdit_UI);
        spinMarginR->setObjectName("spinMarginR");
        spinMarginR->setMinimum(-100000);
        spinMarginR->setMaximum(100000);

        gridLayout->addWidget(spinMarginR, 8, 5, 1, 1);

        labelMarginV = new QLabel(SubtitleStyleEdit_UI);
        labelMarginV->setObjectName("labelMarginV");
        labelMarginV->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelMarginV, 9, 0, 1, 2);

        spinMarginV = new QSpinBox(SubtitleStyleEdit_UI);
        spinMarginV->setObjectName("spinMarginV");
        spinMarginV->setMinimum(-100000);
        spinMarginV->setMaximum(100000);

        gridLayout->addWidget(spinMarginV, 9, 2, 1, 1);

        labelScaleX = new QLabel(SubtitleStyleEdit_UI);
        labelScaleX->setObjectName("labelScaleX");
        labelScaleX->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelScaleX, 10, 1, 1, 1);

        spinScaleX = new QDoubleSpinBox(SubtitleStyleEdit_UI);
        spinScaleX->setObjectName("spinScaleX");
        spinScaleX->setMaximum(1000000.000000000000000);

        gridLayout->addWidget(spinScaleX, 10, 2, 1, 1);

        spinScaleY = new QDoubleSpinBox(SubtitleStyleEdit_UI);
        spinScaleY->setObjectName("spinScaleY");
        spinScaleY->setMaximum(1000000.000000000000000);

        gridLayout->addWidget(spinScaleY, 10, 5, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 11, 2, 1, 1);

        buttonPreview = new QPushButton(SubtitleStyleEdit_UI);
        buttonPreview->setObjectName("buttonPreview");

        gridLayout->addWidget(buttonPreview, 12, 0, 1, 6);

        editPreview = new QLineEdit(SubtitleStyleEdit_UI);
        editPreview->setObjectName("editPreview");
        editPreview->setEnabled(true);

        gridLayout->addWidget(editPreview, 12, 7, 1, 1);

        buttonBox = new QDialogButtonBox(SubtitleStyleEdit_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 13, 0, 1, 6);

        labelColor = new QLabel(SubtitleStyleEdit_UI);
        labelColor->setObjectName("labelColor");
        labelColor->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelColor, 3, 0, 1, 2);

        labelColor_2 = new QLabel(SubtitleStyleEdit_UI);
        labelColor_2->setObjectName("labelColor_2");
        labelColor_2->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelColor_2, 4, 0, 1, 2);

        labelColor_3 = new QLabel(SubtitleStyleEdit_UI);
        labelColor_3->setObjectName("labelColor_3");
        labelColor_3->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelColor_3, 5, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        checkBold = new QCheckBox(SubtitleStyleEdit_UI);
        checkBold->setObjectName("checkBold");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(checkBold->sizePolicy().hasHeightForWidth());
        checkBold->setSizePolicy(sizePolicy);
        checkBold->setAutoRepeatDelay(308);

        horizontalLayout->addWidget(checkBold);

        checkItalic = new QCheckBox(SubtitleStyleEdit_UI);
        checkItalic->setObjectName("checkItalic");
        sizePolicy.setHeightForWidth(checkItalic->sizePolicy().hasHeightForWidth());
        checkItalic->setSizePolicy(sizePolicy);
        checkItalic->setLayoutDirection(Qt::LayoutDirection::LeftToRight);

        horizontalLayout->addWidget(checkItalic);

        checkUnderline = new QCheckBox(SubtitleStyleEdit_UI);
        checkUnderline->setObjectName("checkUnderline");
        sizePolicy.setHeightForWidth(checkUnderline->sizePolicy().hasHeightForWidth());
        checkUnderline->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(checkUnderline);

        checkStrikeOut = new QCheckBox(SubtitleStyleEdit_UI);
        checkStrikeOut->setObjectName("checkStrikeOut");
        sizePolicy.setHeightForWidth(checkStrikeOut->sizePolicy().hasHeightForWidth());
        checkStrikeOut->setSizePolicy(sizePolicy);

        horizontalLayout->addWidget(checkStrikeOut);

        horizontalSpacer_2 = new QSpacerItem(28, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout->addLayout(horizontalLayout, 2, 0, 1, 6);

        labelMarginR = new QLabel(SubtitleStyleEdit_UI);
        labelMarginR->setObjectName("labelMarginR");
        labelMarginR->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelMarginR, 8, 3, 1, 2);

        labelAlignment = new QLabel(SubtitleStyleEdit_UI);
        labelAlignment->setObjectName("labelAlignment");
        labelAlignment->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelAlignment, 6, 3, 1, 2);

        labelScaleY = new QLabel(SubtitleStyleEdit_UI);
        labelScaleY->setObjectName("labelScaleY");
        labelScaleY->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout->addWidget(labelScaleY, 10, 3, 1, 2);

        QWidget::setTabOrder(editName, buttonSelectFont);
        QWidget::setTabOrder(buttonSelectFont, spinFontSize);
        QWidget::setTabOrder(spinFontSize, checkBold);
        QWidget::setTabOrder(checkBold, checkItalic);
        QWidget::setTabOrder(checkItalic, checkUnderline);
        QWidget::setTabOrder(checkUnderline, checkStrikeOut);
        QWidget::setTabOrder(checkStrikeOut, buttonPrimaryColor);
        QWidget::setTabOrder(buttonPrimaryColor, kcontextualhelpbutton);
        QWidget::setTabOrder(kcontextualhelpbutton, buttonSecondaryColor);
        QWidget::setTabOrder(buttonSecondaryColor, spinOutline);
        QWidget::setTabOrder(spinOutline, buttonOutlineColor);
        QWidget::setTabOrder(buttonOutlineColor, spinShadow);
        QWidget::setTabOrder(spinShadow, buttonBackColor);
        QWidget::setTabOrder(buttonBackColor, comboBorderStyle);
        QWidget::setTabOrder(comboBorderStyle, comboAlignment);
        QWidget::setTabOrder(comboAlignment, spinAngle);
        QWidget::setTabOrder(spinAngle, spinSpacing);
        QWidget::setTabOrder(spinSpacing, spinMarginL);
        QWidget::setTabOrder(spinMarginL, spinMarginR);
        QWidget::setTabOrder(spinMarginR, spinMarginV);
        QWidget::setTabOrder(spinMarginV, spinScaleX);
        QWidget::setTabOrder(spinScaleX, spinScaleY);
        QWidget::setTabOrder(spinScaleY, buttonPreview);
        QWidget::setTabOrder(buttonPreview, editPreview);

        retranslateUi(SubtitleStyleEdit_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SubtitleStyleEdit_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SubtitleStyleEdit_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SubtitleStyleEdit_UI);
    } // setupUi

    void retranslateUi(QDialog *SubtitleStyleEdit_UI)
    {
        SubtitleStyleEdit_UI->setWindowTitle(tr2i18n("Subtitle Style Editor", nullptr));
        labelName->setText(tr2i18n("Style name", nullptr));
        preview->setText(QString());
        labelFont->setText(tr2i18n("Font", nullptr));
        labelFontName->setText(QString());
        buttonSelectFont->setText(QString());
        buttonPrimaryColor->setText(QString());
        labelSecondaryColor->setText(tr2i18n("Secondary", nullptr));
        kcontextualhelpbutton->setContextualHelpText(tr2i18n("The secondary color might be used in case of subtitle collision to help distinguish both subtitles", nullptr));
        buttonSecondaryColor->setText(QString());
        buttonOutlineColor->setText(QString());
        buttonBackColor->setText(QString());
        labelBoarderStyle->setText(tr2i18n("Background", nullptr));
        labelAngle->setText(tr2i18n("Rotation", nullptr));
        labelSpacing->setText(tr2i18n("Character spacing", nullptr));
        labelMarginL->setText(tr2i18n("Left margin", nullptr));
        labelMarginV->setText(tr2i18n("Vertical margin", nullptr));
        labelScaleX->setText(tr2i18n("Scale X", nullptr));
        buttonPreview->setText(tr2i18n("Show Preview >>>", nullptr));
        labelColor->setText(tr2i18n("Text color", nullptr));
        labelColor_2->setText(tr2i18n("Outline", nullptr));
        labelColor_3->setText(tr2i18n("Shadow", nullptr));
        checkBold->setText(tr2i18n("Bold", nullptr));
        checkItalic->setText(tr2i18n("Italic", nullptr));
        checkUnderline->setText(tr2i18n("Underline", nullptr));
        checkStrikeOut->setText(tr2i18n("StrikeOut", nullptr));
        labelMarginR->setText(tr2i18n("Right margin", nullptr));
        labelAlignment->setText(tr2i18n("Alignment", nullptr));
        labelScaleY->setText(tr2i18n("Scale Y", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SubtitleStyleEdit_UI: public Ui_SubtitleStyleEdit_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITSUBSTYLE_UI_H

