/********************************************************************************
** Form generated from reading UI file 'configcapture_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGCAPTURE_UI_H
#define UI_CONFIGCAPTURE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigCapture_UI
{
public:
    QGridLayout *gridLayout_8;
    QLabel *label;
    QComboBox *kcfg_defaultcapture;
    QTabWidget *tabWidget;
    QWidget *screen_grab_tab;
    QFormLayout *formLayout_3;
    QLabel *label_8;
    QComboBox *kcfg_grab_capture_type;
    QFrame *region_group;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout;
    QCheckBox *kcfg_grab_follow_mouse;
    QCheckBox *kcfg_grab_hide_frame;
    QSpacerItem *horizontalSpacer_4;
    QLabel *label_19;
    QSpinBox *kcfg_grab_offsetx;
    QSpinBox *kcfg_grab_offsety;
    QLabel *label_20;
    QSpinBox *kcfg_grab_width;
    QSpinBox *kcfg_grab_height;
    QCheckBox *kcfg_grab_hide_mouse;
    QLabel *label_7;
    QLabel *label_18;
    QDoubleSpinBox *kcfg_grab_fps;
    QLabel *label_screengrab;
    QHBoxLayout *screen_grab_profile_box;
    QSpacerItem *verticalSpacer_3;
    QWidget *decklink_tab;
    QFormLayout *formLayout;
    QLabel *label_27;
    QComboBox *kcfg_decklink_capturedevice;
    QLabel *label_16;
    QHBoxLayout *decklink_profile_box;
    QLabel *label_29;
    QLineEdit *kcfg_decklink_filename;
    QSpacerItem *verticalSpacer_4;
    QWidget *audio_tab;
    QFormLayout *formLayout_2;
    QLabel *label_33;
    QComboBox *defaultaudiocapture;
    QLabel *label_2;
    QSlider *kcfg_audiocapturevolume;
    QLabel *label_3;
    QComboBox *audiocapturechannels;
    QLabel *label_5;
    QComboBox *audiocapturesamplerate;
    QSpacerItem *verticalSpacer_2;
    QLabel *labelNoAudioDevices;
    QCheckBox *kcfg_disablereccountdown;
    QComboBox *audiocapturesampleformat;
    QLabel *label_4;
    QPushButton *audiocapturedefaults;

    void setupUi(QWidget *ConfigCapture_UI)
    {
        if (ConfigCapture_UI->objectName().isEmpty())
            ConfigCapture_UI->setObjectName("ConfigCapture_UI");
        ConfigCapture_UI->resize(557, 974);
        gridLayout_8 = new QGridLayout(ConfigCapture_UI);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setContentsMargins(-1, 0, -1, -1);
        label = new QLabel(ConfigCapture_UI);
        label->setObjectName("label");

        gridLayout_8->addWidget(label, 0, 0, 1, 1);

        kcfg_defaultcapture = new QComboBox(ConfigCapture_UI);
        kcfg_defaultcapture->addItem(QString());
        kcfg_defaultcapture->addItem(QString());
        kcfg_defaultcapture->setObjectName("kcfg_defaultcapture");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_defaultcapture->sizePolicy().hasHeightForWidth());
        kcfg_defaultcapture->setSizePolicy(sizePolicy);

        gridLayout_8->addWidget(kcfg_defaultcapture, 0, 1, 1, 1);

        tabWidget = new QTabWidget(ConfigCapture_UI);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setMinimumSize(QSize(401, 0));
        screen_grab_tab = new QWidget();
        screen_grab_tab->setObjectName("screen_grab_tab");
        formLayout_3 = new QFormLayout(screen_grab_tab);
        formLayout_3->setObjectName("formLayout_3");
        label_8 = new QLabel(screen_grab_tab);
        label_8->setObjectName("label_8");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, label_8);

        kcfg_grab_capture_type = new QComboBox(screen_grab_tab);
        kcfg_grab_capture_type->addItem(QString());
        kcfg_grab_capture_type->addItem(QString());
        kcfg_grab_capture_type->setObjectName("kcfg_grab_capture_type");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_grab_capture_type);

        region_group = new QFrame(screen_grab_tab);
        region_group->setObjectName("region_group");
        region_group->setFrameShape(QFrame::Shape::StyledPanel);
        region_group->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_3 = new QGridLayout(region_group);
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_grab_follow_mouse = new QCheckBox(region_group);
        kcfg_grab_follow_mouse->setObjectName("kcfg_grab_follow_mouse");

        horizontalLayout->addWidget(kcfg_grab_follow_mouse);

        kcfg_grab_hide_frame = new QCheckBox(region_group);
        kcfg_grab_hide_frame->setObjectName("kcfg_grab_hide_frame");

        horizontalLayout->addWidget(kcfg_grab_hide_frame);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_4);


        gridLayout_3->addLayout(horizontalLayout, 0, 0, 1, 3);

        label_19 = new QLabel(region_group);
        label_19->setObjectName("label_19");

        gridLayout_3->addWidget(label_19, 1, 0, 1, 1);

        kcfg_grab_offsetx = new QSpinBox(region_group);
        kcfg_grab_offsetx->setObjectName("kcfg_grab_offsetx");
        sizePolicy.setHeightForWidth(kcfg_grab_offsetx->sizePolicy().hasHeightForWidth());
        kcfg_grab_offsetx->setSizePolicy(sizePolicy);
        kcfg_grab_offsetx->setMaximum(5000);
        kcfg_grab_offsetx->setValue(0);

        gridLayout_3->addWidget(kcfg_grab_offsetx, 1, 1, 1, 1);

        kcfg_grab_offsety = new QSpinBox(region_group);
        kcfg_grab_offsety->setObjectName("kcfg_grab_offsety");
        sizePolicy.setHeightForWidth(kcfg_grab_offsety->sizePolicy().hasHeightForWidth());
        kcfg_grab_offsety->setSizePolicy(sizePolicy);
        kcfg_grab_offsety->setMaximum(5000);
        kcfg_grab_offsety->setValue(0);

        gridLayout_3->addWidget(kcfg_grab_offsety, 1, 2, 1, 1);

        label_20 = new QLabel(region_group);
        label_20->setObjectName("label_20");

        gridLayout_3->addWidget(label_20, 2, 0, 1, 1);

        kcfg_grab_width = new QSpinBox(region_group);
        kcfg_grab_width->setObjectName("kcfg_grab_width");
        kcfg_grab_width->setMinimum(1);
        kcfg_grab_width->setMaximum(5000);
        kcfg_grab_width->setValue(1280);

        gridLayout_3->addWidget(kcfg_grab_width, 2, 1, 1, 1);

        kcfg_grab_height = new QSpinBox(region_group);
        kcfg_grab_height->setObjectName("kcfg_grab_height");
        kcfg_grab_height->setMinimum(1);
        kcfg_grab_height->setMaximum(5000);
        kcfg_grab_height->setValue(720);

        gridLayout_3->addWidget(kcfg_grab_height, 2, 2, 1, 1);


        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, region_group);

        kcfg_grab_hide_mouse = new QCheckBox(screen_grab_tab);
        kcfg_grab_hide_mouse->setObjectName("kcfg_grab_hide_mouse");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_grab_hide_mouse);

        label_7 = new QLabel(screen_grab_tab);
        label_7->setObjectName("label_7");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, label_7);

        label_18 = new QLabel(screen_grab_tab);
        label_18->setObjectName("label_18");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, label_18);

        kcfg_grab_fps = new QDoubleSpinBox(screen_grab_tab);
        kcfg_grab_fps->setObjectName("kcfg_grab_fps");
        kcfg_grab_fps->setMinimum(1.000000000000000);
        kcfg_grab_fps->setMaximum(1000.000000000000000);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_grab_fps);

        label_screengrab = new QLabel(screen_grab_tab);
        label_screengrab->setObjectName("label_screengrab");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(label_screengrab->sizePolicy().hasHeightForWidth());
        label_screengrab->setSizePolicy(sizePolicy1);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, label_screengrab);

        screen_grab_profile_box = new QHBoxLayout();
        screen_grab_profile_box->setObjectName("screen_grab_profile_box");

        formLayout_3->setLayout(4, QFormLayout::ItemRole::FieldRole, screen_grab_profile_box);

        verticalSpacer_3 = new QSpacerItem(383, 160, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_3->setItem(5, QFormLayout::ItemRole::FieldRole, verticalSpacer_3);

        tabWidget->addTab(screen_grab_tab, QString());
        decklink_tab = new QWidget();
        decklink_tab->setObjectName("decklink_tab");
        formLayout = new QFormLayout(decklink_tab);
        formLayout->setObjectName("formLayout");
        label_27 = new QLabel(decklink_tab);
        label_27->setObjectName("label_27");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_27);

        kcfg_decklink_capturedevice = new QComboBox(decklink_tab);
        kcfg_decklink_capturedevice->setObjectName("kcfg_decklink_capturedevice");
        sizePolicy.setHeightForWidth(kcfg_decklink_capturedevice->sizePolicy().hasHeightForWidth());
        kcfg_decklink_capturedevice->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_decklink_capturedevice);

        label_16 = new QLabel(decklink_tab);
        label_16->setObjectName("label_16");
        sizePolicy1.setHeightForWidth(label_16->sizePolicy().hasHeightForWidth());
        label_16->setSizePolicy(sizePolicy1);

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_16);

        decklink_profile_box = new QHBoxLayout();
        decklink_profile_box->setSpacing(0);
        decklink_profile_box->setObjectName("decklink_profile_box");

        formLayout->setLayout(1, QFormLayout::ItemRole::FieldRole, decklink_profile_box);

        label_29 = new QLabel(decklink_tab);
        label_29->setObjectName("label_29");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_29);

        kcfg_decklink_filename = new QLineEdit(decklink_tab);
        kcfg_decklink_filename->setObjectName("kcfg_decklink_filename");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_decklink_filename);

        verticalSpacer_4 = new QSpacerItem(20, 327, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(3, QFormLayout::ItemRole::FieldRole, verticalSpacer_4);

        tabWidget->addTab(decklink_tab, QString());
        audio_tab = new QWidget();
        audio_tab->setObjectName("audio_tab");
        formLayout_2 = new QFormLayout(audio_tab);
        formLayout_2->setObjectName("formLayout_2");
        label_33 = new QLabel(audio_tab);
        label_33->setObjectName("label_33");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::LabelRole, label_33);

        defaultaudiocapture = new QComboBox(audio_tab);
        defaultaudiocapture->setObjectName("defaultaudiocapture");

        formLayout_2->setWidget(0, QFormLayout::ItemRole::FieldRole, defaultaudiocapture);

        label_2 = new QLabel(audio_tab);
        label_2->setObjectName("label_2");

        formLayout_2->setWidget(2, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_audiocapturevolume = new QSlider(audio_tab);
        kcfg_audiocapturevolume->setObjectName("kcfg_audiocapturevolume");
        kcfg_audiocapturevolume->setMaximum(100);
        kcfg_audiocapturevolume->setSliderPosition(100);
        kcfg_audiocapturevolume->setTracking(true);
        kcfg_audiocapturevolume->setOrientation(Qt::Orientation::Horizontal);
        kcfg_audiocapturevolume->setInvertedAppearance(false);
        kcfg_audiocapturevolume->setInvertedControls(false);
        kcfg_audiocapturevolume->setTickPosition(QSlider::TickPosition::TicksAbove);

        formLayout_2->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_audiocapturevolume);

        label_3 = new QLabel(audio_tab);
        label_3->setObjectName("label_3");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::LabelRole, label_3);

        audiocapturechannels = new QComboBox(audio_tab);
        audiocapturechannels->setObjectName("audiocapturechannels");

        formLayout_2->setWidget(4, QFormLayout::ItemRole::FieldRole, audiocapturechannels);

        label_5 = new QLabel(audio_tab);
        label_5->setObjectName("label_5");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::LabelRole, label_5);

        audiocapturesamplerate = new QComboBox(audio_tab);
        audiocapturesamplerate->setObjectName("audiocapturesamplerate");

        formLayout_2->setWidget(5, QFormLayout::ItemRole::FieldRole, audiocapturesamplerate);

        verticalSpacer_2 = new QSpacerItem(20, 661, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout_2->setItem(8, QFormLayout::ItemRole::FieldRole, verticalSpacer_2);

        labelNoAudioDevices = new QLabel(audio_tab);
        labelNoAudioDevices->setObjectName("labelNoAudioDevices");
        QFont font;
        font.setPointSize(10);
        labelNoAudioDevices->setFont(font);

        formLayout_2->setWidget(1, QFormLayout::ItemRole::FieldRole, labelNoAudioDevices);

        kcfg_disablereccountdown = new QCheckBox(audio_tab);
        kcfg_disablereccountdown->setObjectName("kcfg_disablereccountdown");

        formLayout_2->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_disablereccountdown);

        audiocapturesampleformat = new QComboBox(audio_tab);
        audiocapturesampleformat->setObjectName("audiocapturesampleformat");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::FieldRole, audiocapturesampleformat);

        label_4 = new QLabel(audio_tab);
        label_4->setObjectName("label_4");

        formLayout_2->setWidget(6, QFormLayout::ItemRole::LabelRole, label_4);

        audiocapturedefaults = new QPushButton(audio_tab);
        audiocapturedefaults->setObjectName("audiocapturedefaults");

        formLayout_2->setWidget(3, QFormLayout::ItemRole::FieldRole, audiocapturedefaults);

        tabWidget->addTab(audio_tab, QString());

        gridLayout_8->addWidget(tabWidget, 1, 0, 1, 2);

        QWidget::setTabOrder(kcfg_defaultcapture, tabWidget);
        QWidget::setTabOrder(tabWidget, kcfg_grab_follow_mouse);
        QWidget::setTabOrder(kcfg_grab_follow_mouse, kcfg_grab_hide_frame);
        QWidget::setTabOrder(kcfg_grab_hide_frame, kcfg_grab_offsetx);
        QWidget::setTabOrder(kcfg_grab_offsetx, kcfg_grab_offsety);
        QWidget::setTabOrder(kcfg_grab_offsety, kcfg_grab_width);
        QWidget::setTabOrder(kcfg_grab_width, kcfg_grab_height);
        QWidget::setTabOrder(kcfg_grab_height, kcfg_decklink_capturedevice);
        QWidget::setTabOrder(kcfg_decklink_capturedevice, kcfg_decklink_filename);
        QWidget::setTabOrder(kcfg_decklink_filename, defaultaudiocapture);
        QWidget::setTabOrder(defaultaudiocapture, kcfg_audiocapturevolume);
        QWidget::setTabOrder(kcfg_audiocapturevolume, audiocapturechannels);
        QWidget::setTabOrder(audiocapturechannels, audiocapturesamplerate);
        QWidget::setTabOrder(audiocapturesamplerate, kcfg_disablereccountdown);

        retranslateUi(ConfigCapture_UI);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ConfigCapture_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigCapture_UI)
    {
        label->setText(tr2i18n("Default capture device", nullptr));
        kcfg_defaultcapture->setItemText(0, tr2i18n("FFmpeg", nullptr));
        kcfg_defaultcapture->setItemText(1, tr2i18n("Screen grab", nullptr));

        label_8->setText(tr2i18n("Region to capture:", nullptr));
        kcfg_grab_capture_type->setItemText(0, tr2i18n("Full Screen", nullptr));
        kcfg_grab_capture_type->setItemText(1, tr2i18n("Rectangular Region", nullptr));

        kcfg_grab_follow_mouse->setText(tr2i18n("Follow mouse", nullptr));
        kcfg_grab_hide_frame->setText(tr2i18n("Hide frame", nullptr));
        label_19->setText(tr2i18n("Offset", nullptr));
        label_20->setText(tr2i18n("Size", nullptr));
        kcfg_grab_hide_mouse->setText(tr2i18n("Hide", nullptr));
        label_7->setText(tr2i18n("Mouse cursor:", nullptr));
        label_18->setText(tr2i18n("Frame rate:", nullptr));
        label_screengrab->setText(tr2i18n("Encoding profile:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(screen_grab_tab), tr2i18n("Screen Grab", nullptr));
        label_27->setText(tr2i18n("Detected devices:", nullptr));
        label_16->setText(tr2i18n("Encoding profile:", nullptr));
        label_29->setText(tr2i18n("Capture file name:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(decklink_tab), tr2i18n("Blackmagic", nullptr));
        label_33->setText(tr2i18n("Device:", nullptr));
        label_2->setText(tr2i18n("Capture volume:", nullptr));
        label_3->setText(tr2i18n("Channels:", nullptr));
        label_5->setText(tr2i18n("Sample rate:", nullptr));
        labelNoAudioDevices->setText(tr2i18n("Make sure you have audio plugins installed on your system", nullptr));
        kcfg_disablereccountdown->setText(tr2i18n("Disable countdown before recording", nullptr));
        label_4->setText(tr2i18n("Sample format:", nullptr));
        audiocapturedefaults->setText(tr2i18n("Use Device Default Settings", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(audio_tab), tr2i18n("Audio", nullptr));
        (void)ConfigCapture_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigCapture_UI: public Ui_ConfigCapture_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGCAPTURE_UI_H

