/****************************************************************************
** Meta object code from reading C++ file 'timelinerecwaveform.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/timeline2/view/qml/timelinerecwaveform.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinerecwaveform.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN19TimelineRecWaveformE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineRecWaveform::qt_create_metaobjectdata<qt_meta_tag_ZN19TimelineRecWaveformE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineRecWaveform",
        "QML.Element",
        "auto",
        "levelsChanged",
        "",
        "propertyChanged",
        "inPointChanged",
        "audioChannelsChanged",
        "fillColor0",
        "QColor",
        "fillColor1",
        "fillColor2",
        "waveInPoint",
        "channels",
        "ix",
        "waveOutPoint",
        "waveOutPointWithUpdate",
        "scaleFactor",
        "format",
        "enforceRepaint",
        "isFirstChunk",
        "isOpaque"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'levelsChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'propertyChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inPointChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audioChannelsChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'fillColor0'
        QtMocHelpers::PropertyData<QColor>(8, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'fillColor1'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'fillColor2'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'waveInPoint'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'channels'
        QtMocHelpers::PropertyData<int>(13, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'ix'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'waveOutPoint'
        QtMocHelpers::PropertyData<int>(15, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'waveOutPointWithUpdate'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<double>(17, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'format'
        QtMocHelpers::PropertyData<bool>(18, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'enforceRepaint'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'isFirstChunk'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'isOpaque'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TimelineRecWaveform, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TimelineRecWaveform::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TimelineRecWaveformE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TimelineRecWaveformE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN19TimelineRecWaveformE_t>.metaTypes,
    nullptr
} };

void TimelineRecWaveform::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineRecWaveform *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->levelsChanged(); break;
        case 1: _t->propertyChanged(); break;
        case 2: _t->inPointChanged(); break;
        case 3: _t->audioChannelsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineRecWaveform::*)()>(_a, &TimelineRecWaveform::levelsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineRecWaveform::*)()>(_a, &TimelineRecWaveform::propertyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineRecWaveform::*)()>(_a, &TimelineRecWaveform::inPointChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineRecWaveform::*)()>(_a, &TimelineRecWaveform::audioChannelsChanged, 3))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->m_bgColor; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->m_color; break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->m_color2; break;
        case 3: *reinterpret_cast<int*>(_v) = _t->m_inPoint; break;
        case 4: *reinterpret_cast<int*>(_v) = _t->m_channels; break;
        case 5: *reinterpret_cast<int*>(_v) = _t->m_index; break;
        case 6: *reinterpret_cast<int*>(_v) = _t->m_outPoint; break;
        case 7: *reinterpret_cast<int*>(_v) = _t->m_outPoint; break;
        case 8: *reinterpret_cast<double*>(_v) = _t->m_scale; break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->m_format; break;
        case 10: *reinterpret_cast<bool*>(_v) = _t->m_repaint; break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->m_firstChunk; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->m_opaquePaint; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_bgColor, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_color, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_color2, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_inPoint, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_channels, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 5: QtMocHelpers::setProperty(_t->m_index, *reinterpret_cast<int*>(_v)); break;
        case 6: QtMocHelpers::setProperty(_t->m_outPoint, *reinterpret_cast<int*>(_v)); break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_outPoint, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 8: QtMocHelpers::setProperty(_t->m_scale, *reinterpret_cast<double*>(_v)); break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_format, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_repaint, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->propertyChanged();
            break;
        case 11: QtMocHelpers::setProperty(_t->m_firstChunk, *reinterpret_cast<bool*>(_v)); break;
        case 12: QtMocHelpers::setProperty(_t->m_opaquePaint, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TimelineRecWaveform::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineRecWaveform::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN19TimelineRecWaveformE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int TimelineRecWaveform::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 13;
    }
    return _id;
}

// SIGNAL 0
void TimelineRecWaveform::levelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineRecWaveform::propertyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineRecWaveform::inPointChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TimelineRecWaveform::audioChannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
