/********************************************************************************
** Form generated from reading UI file 'vectorscope_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VECTORSCOPE_UI_H
#define UI_VECTORSCOPE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Vectorscope_UI
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *headerLayout;
    QToolButton *gainButton;
    QSlider *gainSlider;
    QLabel *gainLabel;
    QToolButton *hamburgerButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Vectorscope_UI)
    {
        if (Vectorscope_UI->objectName().isEmpty())
            Vectorscope_UI->setObjectName("Vectorscope_UI");
        Vectorscope_UI->resize(400, 450);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(Vectorscope_UI->sizePolicy().hasHeightForWidth());
        Vectorscope_UI->setSizePolicy(sizePolicy);
        Vectorscope_UI->setBaseSize(QSize(400, 450));
        verticalLayout = new QVBoxLayout(Vectorscope_UI);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        headerLayout = new QHBoxLayout();
        headerLayout->setSpacing(4);
        headerLayout->setObjectName("headerLayout");
        headerLayout->setContentsMargins(4, 4, 4, 4);
        gainButton = new QToolButton(Vectorscope_UI);
        gainButton->setObjectName("gainButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("zoom-original")));
        gainButton->setIcon(icon);
        gainButton->setAutoRaise(true);

        headerLayout->addWidget(gainButton);

        gainSlider = new QSlider(Vectorscope_UI);
        gainSlider->setObjectName("gainSlider");
        gainSlider->setOrientation(Qt::Horizontal);
        gainSlider->setMinimum(10);
        gainSlider->setMaximum(50);
        gainSlider->setValue(10);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(gainSlider->sizePolicy().hasHeightForWidth());
        gainSlider->setSizePolicy(sizePolicy1);

        headerLayout->addWidget(gainSlider);

        gainLabel = new QLabel(Vectorscope_UI);
        gainLabel->setObjectName("gainLabel");

        headerLayout->addWidget(gainLabel);

        hamburgerButton = new QToolButton(Vectorscope_UI);
        hamburgerButton->setObjectName("hamburgerButton");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("application-menu")));
        hamburgerButton->setIcon(icon1);
        hamburgerButton->setAutoRaise(true);
        hamburgerButton->setPopupMode(QToolButton::InstantPopup);

        headerLayout->addWidget(hamburgerButton);


        verticalLayout->addLayout(headerLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Vectorscope_UI);

        QMetaObject::connectSlotsByName(Vectorscope_UI);
    } // setupUi

    void retranslateUi(QWidget *Vectorscope_UI)
    {
        gainButton->setText(QString());
#if QT_CONFIG(tooltip)
        gainButton->setToolTip(tr2i18n("Reset Zoom", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        gainSlider->setToolTip(tr2i18n("Zoom level", nullptr));
#endif // QT_CONFIG(tooltip)
        gainLabel->setText(tr2i18n("1.0\303\227", nullptr));
#if QT_CONFIG(tooltip)
        gainLabel->setToolTip(tr2i18n("Zoom level", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        hamburgerButton->setToolTip(tr2i18n("Settings", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)Vectorscope_UI;
    } // retranslateUi

};

namespace Ui {
    class Vectorscope_UI: public Ui_Vectorscope_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // VECTORSCOPE_UI_H

