/****************************************************************************
** Meta object code from reading C++ file 'timelineitemmodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/timeline2/model/timelineitemmodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelineitemmodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17TimelineItemModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineItemModel::qt_create_metaobjectdata<qt_meta_tag_ZN17TimelineItemModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineItemModel",
        "trackVisibilityChanged",
        "",
        "showTrackEffectStack",
        "tid",
        "subtitleModelInitialized",
        "subtitlesListChanged",
        "maxSubLayerChanged",
        "setTrackProperty",
        "name",
        "value",
        "setTrackStackEnabled",
        "enable",
        "getTrackProperty",
        "QVariant",
        "setTrackName",
        "trackId",
        "text",
        "copyClipEffect",
        "clipId",
        "sourceId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trackVisibilityChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTrackEffectStack'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'subtitleModelInitialized'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subtitlesListChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxSubLayerChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setTrackProperty'
        QtMocHelpers::MethodData<void(int, const QString &, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Method 'setTrackStackEnabled'
        QtMocHelpers::MethodData<void(int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Bool, 12 },
        }}),
        // Method 'getTrackProperty'
        QtMocHelpers::MethodData<QVariant(int, const QString &) const>(13, 2, QMC::AccessPublic, 0x80000000 | 14, {{
            { QMetaType::Int, 4 }, { QMetaType::QString, 9 },
        }}),
        // Method 'setTrackName'
        QtMocHelpers::MethodData<void(int, const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { QMetaType::QString, 17 },
        }}),
        // Method 'copyClipEffect'
        QtMocHelpers::MethodData<bool(int, const QString)>(18, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 19 }, { QMetaType::QString, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineItemModel, qt_meta_tag_ZN17TimelineItemModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineItemModel::staticMetaObject = { {
    QMetaObject::SuperData::link<TimelineModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TimelineItemModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TimelineItemModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17TimelineItemModelE_t>.metaTypes,
    nullptr
} };

void TimelineItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineItemModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trackVisibilityChanged(); break;
        case 1: _t->showTrackEffectStack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->subtitleModelInitialized(); break;
        case 3: _t->subtitlesListChanged(); break;
        case 4: _t->maxSubLayerChanged(); break;
        case 5: _t->setTrackProperty((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 6: _t->setTrackStackEnabled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 7: { QVariant _r = _t->getTrackProperty((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->setTrackName((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: { bool _r = _t->copyClipEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineItemModel::*)()>(_a, &TimelineItemModel::trackVisibilityChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineItemModel::*)(int )>(_a, &TimelineItemModel::showTrackEffectStack, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineItemModel::*)()>(_a, &TimelineItemModel::subtitleModelInitialized, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineItemModel::*)()>(_a, &TimelineItemModel::subtitlesListChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineItemModel::*)()>(_a, &TimelineItemModel::maxSubLayerChanged, 4))
            return;
    }
}

const QMetaObject *TimelineItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17TimelineItemModelE_t>.strings))
        return static_cast<void*>(this);
    return TimelineModel::qt_metacast(_clname);
}

int TimelineItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = TimelineModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void TimelineItemModel::trackVisibilityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineItemModel::showTrackEffectStack(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void TimelineItemModel::subtitleModelInitialized()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void TimelineItemModel::subtitlesListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void TimelineItemModel::maxSubLayerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
QT_WARNING_POP
