/****************************************************************************
** Meta object code from reading C++ file 'lumaliftgainparam.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/assets/view/widgets/lumaliftgainparam.hpp"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'lumaliftgainparam.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN17LumaLiftGainParamE_t {};
} // unnamed namespace

template <> constexpr inline auto LumaLiftGainParam::qt_create_metaobjectdata<qt_meta_tag_ZN17LumaLiftGainParamE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LumaLiftGainParam",
        "liftChanged",
        "",
        "NegQColor",
        "sourceColor",
        "color",
        "createUndo",
        "gammaChanged",
        "gainChanged",
        "valuesChanged",
        "QList<QModelIndex>",
        "updateHeight",
        "height",
        "slotRefresh",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'liftChanged'
        QtMocHelpers::SignalData<void(const NegQColor &, const NegQColor &, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'gammaChanged'
        QtMocHelpers::SignalData<void(const NegQColor &, const NegQColor &, bool)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'gainChanged'
        QtMocHelpers::SignalData<void(const NegQColor &, const NegQColor &, bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { 0x80000000 | 3, 5 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'valuesChanged'
        QtMocHelpers::SignalData<void(const QList<QModelIndex>, const QStringList &, const QStringList &, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 2 }, { QMetaType::QStringList, 2 }, { QMetaType::QStringList, 2 }, { QMetaType::Bool, 6 },
        }}),
        // Signal 'updateHeight'
        QtMocHelpers::SignalData<void(int)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'slotRefresh'
        QtMocHelpers::SlotData<void(int)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LumaLiftGainParam, qt_meta_tag_ZN17LumaLiftGainParamE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LumaLiftGainParam::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17LumaLiftGainParamE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17LumaLiftGainParamE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN17LumaLiftGainParamE_t>.metaTypes,
    nullptr
} };

void LumaLiftGainParam::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LumaLiftGainParam *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->liftChanged((*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 1: _t->gammaChanged((*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 2: _t->gainChanged((*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<NegQColor>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->valuesChanged((*reinterpret_cast<std::add_pointer_t<QList<QModelIndex>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 4: _t->updateHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->slotRefresh((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LumaLiftGainParam::*)(const NegQColor & , const NegQColor & , bool )>(_a, &LumaLiftGainParam::liftChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LumaLiftGainParam::*)(const NegQColor & , const NegQColor & , bool )>(_a, &LumaLiftGainParam::gammaChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (LumaLiftGainParam::*)(const NegQColor & , const NegQColor & , bool )>(_a, &LumaLiftGainParam::gainChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (LumaLiftGainParam::*)(const QList<QModelIndex> , const QStringList & , const QStringList & , bool )>(_a, &LumaLiftGainParam::valuesChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (LumaLiftGainParam::*)(int )>(_a, &LumaLiftGainParam::updateHeight, 4))
            return;
    }
}

const QMetaObject *LumaLiftGainParam::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LumaLiftGainParam::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN17LumaLiftGainParamE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int LumaLiftGainParam::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void LumaLiftGainParam::liftChanged(const NegQColor & _t1, const NegQColor & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void LumaLiftGainParam::gammaChanged(const NegQColor & _t1, const NegQColor & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 2
void LumaLiftGainParam::gainChanged(const NegQColor & _t1, const NegQColor & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void LumaLiftGainParam::valuesChanged(const QList<QModelIndex> _t1, const QStringList & _t2, const QStringList & _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 4
void LumaLiftGainParam::updateHeight(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
QT_WARNING_POP
