/****************************************************************************
** Meta object code from reading C++ file 'timelinemodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/timeline2/model/timelinemodel.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinemodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13TimelineModelE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineModel::qt_create_metaobjectdata<qt_meta_tag_ZN13TimelineModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineModel",
        "requestClearAssetView",
        "",
        "requestMonitorRefresh",
        "invalidateZone",
        "in",
        "out",
        "isAudio",
        "invalidateAudioZone",
        "durationUpdated",
        "QUuid",
        "uuid",
        "selectionChanged",
        "selectedMixChanged",
        "cid",
        "std::shared_ptr<AssetParameterModel>",
        "asset",
        "refreshOnly",
        "checkTrackDeletion",
        "tid",
        "checkItemDeletion",
        "flashLock",
        "highlightSub",
        "index",
        "visibleSequenceNameChanged",
        "connectPreviewManager",
        "refreshClipActions",
        "selectionModeChanged",
        "isAudioTrack",
        "trackId",
        "isSubtitleTrack",
        "getClipTrackId",
        "clipId",
        "getCompositionTrackId",
        "compoId",
        "hideComposition",
        "itemId",
        "hide",
        "getItemTrackId",
        "getCompositionPosition",
        "getItemPosition",
        "getItemFakePosition",
        "isClip",
        "id",
        "isComposition",
        "isSubTitle",
        "isItem",
        "isTrack",
        "isGroup",
        "isInGroup",
        "getClipPosition",
        "addClipEffect",
        "QVariantList",
        "effectId",
        "notify",
        "addTrackEffect",
        "copyTrackEffect",
        "sourceId",
        "suggestSnapPoint",
        "pos",
        "snapDistance",
        "getPreviousTrackId",
        "getNextTrackId",
        "hasClipEndMix",
        "setTrackLockedState",
        "lock",
        "requestClipMove",
        "position",
        "moveMirrorTracks",
        "updateView",
        "logUndo",
        "invalidateTimeline",
        "revertMove",
        "requestSubtitleMove",
        "layer",
        "finalMove",
        "fakeMove",
        "getPreviousBlank",
        "getNextBlank",
        "requestCompositionMove",
        "allowResize",
        "requestFakeClipMove",
        "suggestItemMove",
        "cursorPosition",
        "suggestClipMove",
        "suggestSubtitleMove",
        "subId",
        "newLayer",
        "suggestCompositionMove",
        "allowAdjustDuration",
        "adjustFrame",
        "frame",
        "requestItemDeletion",
        "requestGroupDeletion",
        "requestItemResize",
        "size",
        "right",
        "allowSingleResize",
        "requestClipSlip",
        "offset",
        "requestSlipSelection",
        "hasMultipleSelection",
        "requestItemSpeedChange",
        "getGroupData",
        "processGroupResize",
        "startPosList",
        "endPosList",
        "requestClipResizeAndTimeWarp",
        "speed",
        "normalEdit",
        "requestClipTimeWarp",
        "pitchCompensate",
        "changeDuration",
        "requestClearSelection",
        "onDeletion",
        "requestMixSelection",
        "requestAddToSelection",
        "clear",
        "singleSelect",
        "requestRemoveFromSelection",
        "resizeStartMix",
        "duration",
        "singleResize",
        "visibleSequenceName"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestClearAssetView'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'requestMonitorRefresh'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'invalidateZone'
        QtMocHelpers::SignalData<void(int, int, bool)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'invalidateZone'
        QtMocHelpers::SignalData<void(int, int)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'invalidateAudioZone'
        QtMocHelpers::SignalData<void(int, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 5 }, { QMetaType::Int, 6 },
        }}),
        // Signal 'durationUpdated'
        QtMocHelpers::SignalData<void(const QUuid &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'selectionChanged'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectedMixChanged'
        QtMocHelpers::SignalData<void(int, const std::shared_ptr<AssetParameterModel> &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 15, 16 }, { QMetaType::Bool, 17 },
        }}),
        // Signal 'selectedMixChanged'
        QtMocHelpers::SignalData<void(int, const std::shared_ptr<AssetParameterModel> &)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { 0x80000000 | 15, 16 },
        }}),
        // Signal 'checkTrackDeletion'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'checkItemDeletion'
        QtMocHelpers::SignalData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Signal 'flashLock'
        QtMocHelpers::SignalData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 },
        }}),
        // Signal 'highlightSub'
        QtMocHelpers::SignalData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 23 },
        }}),
        // Signal 'visibleSequenceNameChanged'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'connectPreviewManager'
        QtMocHelpers::SignalData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshClipActions'
        QtMocHelpers::SignalData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectionModeChanged'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'isAudioTrack'
        QtMocHelpers::MethodData<bool(int) const>(28, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'isSubtitleTrack'
        QtMocHelpers::MethodData<bool(int) const>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'getClipTrackId'
        QtMocHelpers::MethodData<int(int) const>(31, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 32 },
        }}),
        // Method 'getCompositionTrackId'
        QtMocHelpers::MethodData<int(int) const>(33, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 34 },
        }}),
        // Method 'hideComposition'
        QtMocHelpers::MethodData<void(int, bool)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Bool, 37 },
        }}),
        // Method 'getItemTrackId'
        QtMocHelpers::MethodData<int(int) const>(38, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'getCompositionPosition'
        QtMocHelpers::MethodData<int(int) const>(39, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 34 },
        }}),
        // Method 'getItemPosition'
        QtMocHelpers::MethodData<int(int) const>(40, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'getItemFakePosition'
        QtMocHelpers::MethodData<int(int) const>(41, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'isClip'
        QtMocHelpers::MethodData<bool(int) const>(42, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isComposition'
        QtMocHelpers::MethodData<bool(int) const>(44, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isSubTitle'
        QtMocHelpers::MethodData<bool(int) const>(45, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isItem'
        QtMocHelpers::MethodData<bool(int) const>(46, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isTrack'
        QtMocHelpers::MethodData<bool(int) const>(47, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isGroup'
        QtMocHelpers::MethodData<bool(int) const>(48, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'isInGroup'
        QtMocHelpers::MethodData<bool(int) const>(49, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 43 },
        }}),
        // Method 'getClipPosition'
        QtMocHelpers::MethodData<int(int) const>(50, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 32 },
        }}),
        // Method 'addClipEffect'
        QtMocHelpers::MethodData<QVariantList(int, const QString &, bool)>(51, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::QString, 53 }, { QMetaType::Bool, 54 },
        }}),
        // Method 'addClipEffect'
        QtMocHelpers::MethodData<QVariantList(int, const QString &)>(51, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::QString, 53 },
        }}),
        // Method 'addTrackEffect'
        QtMocHelpers::MethodData<bool(int, const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 53 },
        }}),
        // Method 'copyTrackEffect'
        QtMocHelpers::MethodData<bool(int, const QString &)>(56, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 29 }, { QMetaType::QString, 57 },
        }}),
        // Method 'suggestSnapPoint'
        QtMocHelpers::MethodData<int(int, int)>(58, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 59 }, { QMetaType::Int, 60 },
        }}),
        // Method 'getPreviousTrackId'
        QtMocHelpers::MethodData<int(int)>(61, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'getNextTrackId'
        QtMocHelpers::MethodData<int(int)>(62, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 29 },
        }}),
        // Method 'hasClipEndMix'
        QtMocHelpers::MethodData<bool(int) const>(63, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 },
        }}),
        // Method 'setTrackLockedState'
        QtMocHelpers::MethodData<void(int, bool)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 }, { QMetaType::Bool, 65 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool, bool, bool)>(66, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 68 },
            { QMetaType::Bool, 69 }, { QMetaType::Bool, 70 }, { QMetaType::Bool, 71 }, { QMetaType::Bool, 72 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool, bool)>(66, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 68 },
            { QMetaType::Bool, 69 }, { QMetaType::Bool, 70 }, { QMetaType::Bool, 71 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool)>(66, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 68 },
            { QMetaType::Bool, 69 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool)>(66, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 68 },
            { QMetaType::Bool, 69 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool)>(66, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 68 },
        }}),
        // Method 'requestClipMove'
        QtMocHelpers::MethodData<bool(int, int, int)>(66, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 },
        }}),
        // Method 'requestSubtitleMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool, bool)>(73, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 74 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 75 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'requestSubtitleMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool)>(73, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 74 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 75 },
        }}),
        // Method 'requestSubtitleMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool)>(73, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 74 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 },
        }}),
        // Method 'requestSubtitleMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool)>(73, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 74 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
        }}),
        // Method 'requestSubtitleMove'
        QtMocHelpers::MethodData<bool(int, int, int)>(73, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 74 }, { QMetaType::Int, 67 },
        }}),
        // Method 'getPreviousBlank'
        QtMocHelpers::MethodData<int(int, int)>(77, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 59 },
        }}),
        // Method 'getNextBlank'
        QtMocHelpers::MethodData<int(int, int)>(78, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 29 }, { QMetaType::Int, 59 },
        }}),
        // Method 'requestCompositionMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool, bool)>(79, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 76 }, { QMetaType::Bool, 80 },
        }}),
        // Method 'requestCompositionMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool)>(79, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'requestCompositionMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool)>(79, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 },
        }}),
        // Method 'requestCompositionMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool)>(79, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
        }}),
        // Method 'requestCompositionMove'
        QtMocHelpers::MethodData<bool(int, int, int)>(79, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 },
        }}),
        // Method 'requestFakeClipMove'
        QtMocHelpers::MethodData<bool(int, int, int, bool, bool, bool)>(81, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Bool, 69 },
            { QMetaType::Bool, 70 }, { QMetaType::Bool, 71 },
        }}),
        // Method 'suggestItemMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int, bool)>(82, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'suggestItemMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 },
        }}),
        // Method 'suggestItemMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int)>(82, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
        }}),
        // Method 'suggestClipMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int, bool, bool)>(84, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 68 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'suggestClipMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int, bool)>(84, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 68 },
        }}),
        // Method 'suggestClipMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int)>(84, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 },
        }}),
        // Method 'suggestClipMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int)>(84, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 32 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
        }}),
        // Method 'suggestSubtitleMove'
        QtMocHelpers::MethodData<int(int, int, int, int, int, bool)>(85, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 86 }, { QMetaType::Int, 87 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'suggestSubtitleMove'
        QtMocHelpers::MethodData<int(int, int, int, int, int)>(85, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 86 }, { QMetaType::Int, 87 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 },
        }}),
        // Method 'suggestCompositionMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int, bool, bool)>(88, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 76 }, { QMetaType::Bool, 89 },
        }}),
        // Method 'suggestCompositionMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int, bool)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 76 },
        }}),
        // Method 'suggestCompositionMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int, int)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
            { QMetaType::Int, 60 },
        }}),
        // Method 'suggestCompositionMove'
        QtMocHelpers::MethodData<QVariantList(int, int, int, int)>(88, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 52, {{
            { QMetaType::Int, 34 }, { QMetaType::Int, 29 }, { QMetaType::Int, 67 }, { QMetaType::Int, 83 },
        }}),
        // Method 'adjustFrame'
        QtMocHelpers::MethodData<int(int, int)>(90, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 91 }, { QMetaType::Int, 29 },
        }}),
        // Method 'requestItemDeletion'
        QtMocHelpers::MethodData<bool(int, bool)>(92, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 36 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'requestItemDeletion'
        QtMocHelpers::MethodData<bool(int)>(92, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'requestGroupDeletion'
        QtMocHelpers::MethodData<bool(int, bool)>(93, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'requestGroupDeletion'
        QtMocHelpers::MethodData<bool(int)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Int, 32 },
        }}),
        // Method 'requestItemResize'
        QtMocHelpers::MethodData<int(int, int, bool, bool, int, bool)>(94, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 }, { QMetaType::Bool, 70 },
            { QMetaType::Int, 60 }, { QMetaType::Bool, 97 },
        }}),
        // Method 'requestItemResize'
        QtMocHelpers::MethodData<int(int, int, bool, bool, int)>(94, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 }, { QMetaType::Bool, 70 },
            { QMetaType::Int, 60 },
        }}),
        // Method 'requestItemResize'
        QtMocHelpers::MethodData<int(int, int, bool, bool)>(94, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'requestItemResize'
        QtMocHelpers::MethodData<int(int, int, bool)>(94, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 },
        }}),
        // Method 'requestClipSlip'
        QtMocHelpers::MethodData<int(int, int, bool, bool)>(98, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 99 }, { QMetaType::Bool, 70 }, { QMetaType::Bool, 97 },
        }}),
        // Method 'requestClipSlip'
        QtMocHelpers::MethodData<int(int, int, bool)>(98, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 99 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'requestClipSlip'
        QtMocHelpers::MethodData<int(int, int)>(98, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 99 },
        }}),
        // Method 'requestSlipSelection'
        QtMocHelpers::MethodData<int(int, bool)>(100, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 99 }, { QMetaType::Bool, 70 },
        }}),
        // Method 'hasMultipleSelection'
        QtMocHelpers::MethodData<bool() const>(101, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'requestItemSpeedChange'
        QtMocHelpers::MethodData<int(int, int, bool, int)>(102, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 }, { QMetaType::Int, 60 },
        }}),
        // Method 'getGroupData'
        QtMocHelpers::MethodData<const QVariantList(int)>(103, 2, QMC::AccessPublic, 0x80000000 | 52, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'processGroupResize'
        QtMocHelpers::MethodData<void(QVariantList, QVariantList, bool)>(104, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 52, 105 }, { 0x80000000 | 52, 106 }, { QMetaType::Bool, 96 },
        }}),
        // Method 'requestClipResizeAndTimeWarp'
        QtMocHelpers::MethodData<int(int, int, bool, int, bool, double)>(107, 2, QMC::AccessPublic, QMetaType::Int, {{
            { QMetaType::Int, 36 }, { QMetaType::Int, 95 }, { QMetaType::Bool, 96 }, { QMetaType::Int, 60 },
            { QMetaType::Bool, 97 }, { QMetaType::Double, 108 },
        }}),
        // Method 'normalEdit'
        QtMocHelpers::MethodData<bool() const>(109, 2, QMC::AccessPublic, QMetaType::Bool),
        // Method 'requestClipTimeWarp'
        QtMocHelpers::MethodData<bool(int, double, bool, bool)>(110, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 32 }, { QMetaType::Double, 108 }, { QMetaType::Bool, 111 }, { QMetaType::Bool, 112 },
        }}),
        // Method 'requestClearSelection'
        QtMocHelpers::MethodData<bool(bool)>(113, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 114 },
        }}),
        // Method 'requestClearSelection'
        QtMocHelpers::MethodData<bool()>(113, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Method 'requestMixSelection'
        QtMocHelpers::MethodData<void(int)>(115, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'requestAddToSelection'
        QtMocHelpers::MethodData<void(int, bool, bool)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Bool, 117 }, { QMetaType::Bool, 118 },
        }}),
        // Method 'requestAddToSelection'
        QtMocHelpers::MethodData<void(int, bool)>(116, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 36 }, { QMetaType::Bool, 117 },
        }}),
        // Method 'requestAddToSelection'
        QtMocHelpers::MethodData<void(int)>(116, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'requestRemoveFromSelection'
        QtMocHelpers::MethodData<void(int)>(119, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Method 'resizeStartMix'
        QtMocHelpers::MethodData<bool(int, int, bool)>(120, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 121 }, { QMetaType::Bool, 122 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visibleSequenceName'
        QtMocHelpers::PropertyData<QString>(123, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 13),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimelineModel, qt_meta_tag_ZN13TimelineModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimelineModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractItemModel_shared_from_this<TimelineModel>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13TimelineModelE_t>.metaTypes,
    nullptr
} };

void TimelineModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestClearAssetView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->requestMonitorRefresh(); break;
        case 2: _t->invalidateZone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->invalidateZone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->invalidateAudioZone((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->durationUpdated((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 6: _t->selectionChanged(); break;
        case 7: _t->selectedMixChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 8: _t->selectedMixChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AssetParameterModel>>>(_a[2]))); break;
        case 9: _t->checkTrackDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->checkItemDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->flashLock((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->highlightSub((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->visibleSequenceNameChanged(); break;
        case 14: _t->connectPreviewManager(); break;
        case 15: _t->refreshClipActions(); break;
        case 16: _t->selectionModeChanged(); break;
        case 17: { bool _r = _t->isAudioTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->isSubtitleTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: { int _r = _t->getClipTrackId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 20: { int _r = _t->getCompositionTrackId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 21: _t->hideComposition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 22: { int _r = _t->getItemTrackId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 23: { int _r = _t->getCompositionPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 24: { int _r = _t->getItemPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 25: { int _r = _t->getItemFakePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 26: { bool _r = _t->isClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 27: { bool _r = _t->isComposition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 28: { bool _r = _t->isSubTitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 29: { bool _r = _t->isItem((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 30: { bool _r = _t->isTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 31: { bool _r = _t->isGroup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 32: { bool _r = _t->isInGroup((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 33: { int _r = _t->getClipPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 34: { QVariantList _r = _t->addClipEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 35: { QVariantList _r = _t->addClipEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 36: { bool _r = _t->addTrackEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 37: { bool _r = _t->copyTrackEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 38: { int _r = _t->suggestSnapPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 39: { int _r = _t->getPreviousTrackId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 40: { int _r = _t->getNextTrackId((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 41: { bool _r = _t->hasClipEndMix((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 42: _t->setTrackLockedState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 43: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[8])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 45: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 46: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 47: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 48: { bool _r = _t->requestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 49: { bool _r = _t->requestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 50: { bool _r = _t->requestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 51: { bool _r = _t->requestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 52: { bool _r = _t->requestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 53: { bool _r = _t->requestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 54: { int _r = _t->getPreviousBlank((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 55: { int _r = _t->getNextBlank((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 56: { bool _r = _t->requestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 57: { bool _r = _t->requestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 58: { bool _r = _t->requestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 59: { bool _r = _t->requestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 60: { bool _r = _t->requestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 61: { bool _r = _t->requestFakeClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 62: { QVariantList _r = _t->suggestItemMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 63: { QVariantList _r = _t->suggestItemMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 64: { QVariantList _r = _t->suggestItemMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 65: { QVariantList _r = _t->suggestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 66: { QVariantList _r = _t->suggestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 67: { QVariantList _r = _t->suggestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 68: { QVariantList _r = _t->suggestClipMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 69: { int _r = _t->suggestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 70: { int _r = _t->suggestSubtitleMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 71: { QVariantList _r = _t->suggestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[7])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 72: { QVariantList _r = _t->suggestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 73: { QVariantList _r = _t->suggestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 74: { QVariantList _r = _t->suggestCompositionMove((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 75: { int _r = _t->adjustFrame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 76: { bool _r = _t->requestItemDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 77: { bool _r = _t->requestItemDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 78: { bool _r = _t->requestGroupDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 79: { bool _r = _t->requestGroupDeletion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 80: { int _r = _t->requestItemResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 81: { int _r = _t->requestItemResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 82: { int _r = _t->requestItemResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 83: { int _r = _t->requestItemResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 84: { int _r = _t->requestClipSlip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 85: { int _r = _t->requestClipSlip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 86: { int _r = _t->requestClipSlip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 87: { int _r = _t->requestSlipSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 88: { bool _r = _t->hasMultipleSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 89: { int _r = _t->requestItemSpeedChange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 90: { QVariantList _r = _t->getGroupData((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariantList*>(_a[0]) = std::move(_r); }  break;
        case 91: _t->processGroupResize((*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariantList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 92: { int _r = _t->requestClipResizeAndTimeWarp((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[6])));
            if (_a[0]) *reinterpret_cast<int*>(_a[0]) = std::move(_r); }  break;
        case 93: { bool _r = _t->normalEdit();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 94: { bool _r = _t->requestClipTimeWarp((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 95: { bool _r = _t->requestClearSelection((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 96: { bool _r = _t->requestClearSelection();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 97: _t->requestMixSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 98: _t->requestAddToSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 99: _t->requestAddToSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 100: _t->requestAddToSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 101: _t->requestRemoveFromSelection((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 102: { bool _r = _t->resizeStartMix((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::requestClearAssetView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::requestMonitorRefresh, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int , int , bool )>(_a, &TimelineModel::invalidateZone, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int , int )>(_a, &TimelineModel::invalidateAudioZone, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(const QUuid & )>(_a, &TimelineModel::durationUpdated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::selectionChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int , const std::shared_ptr<AssetParameterModel> & , bool )>(_a, &TimelineModel::selectedMixChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::checkTrackDeletion, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::checkItemDeletion, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::flashLock, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)(int )>(_a, &TimelineModel::highlightSub, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::visibleSequenceNameChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::connectPreviewManager, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::refreshClipActions, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineModel::*)()>(_a, &TimelineModel::selectionModeChanged, 16))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_visibleSequenceName; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_visibleSequenceName, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->visibleSequenceNameChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *TimelineModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13TimelineModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractItemModel_shared_from_this<TimelineModel>::qt_metacast(_clname);
}

int TimelineModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractItemModel_shared_from_this<TimelineModel>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 103)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 103;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 103)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 103;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void TimelineModel::requestClearAssetView(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TimelineModel::requestMonitorRefresh()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineModel::invalidateZone(int _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void TimelineModel::invalidateAudioZone(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void TimelineModel::durationUpdated(const QUuid & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void TimelineModel::selectionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void TimelineModel::selectedMixChanged(int _t1, const std::shared_ptr<AssetParameterModel> & _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void TimelineModel::checkTrackDeletion(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void TimelineModel::checkItemDeletion(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void TimelineModel::flashLock(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void TimelineModel::highlightSub(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void TimelineModel::visibleSequenceNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void TimelineModel::connectPreviewManager()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void TimelineModel::refreshClipActions()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void TimelineModel::selectionModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}
QT_WARNING_POP
