/****************************************************************************
** Meta object code from reading C++ file 'guideslist.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/project/dialogs/guideslist.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'guideslist.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21GuideFilterEventEaterE_t {};
} // unnamed namespace

template <> constexpr inline auto GuideFilterEventEater::qt_create_metaobjectdata<qt_meta_tag_ZN21GuideFilterEventEaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GuideFilterEventEater",
        "clearSearchLine",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clearSearchLine'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuideFilterEventEater, qt_meta_tag_ZN21GuideFilterEventEaterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GuideFilterEventEater::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GuideFilterEventEaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GuideFilterEventEaterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21GuideFilterEventEaterE_t>.metaTypes,
    nullptr
} };

void GuideFilterEventEater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuideFilterEventEater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clearSearchLine(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GuideFilterEventEater::*)()>(_a, &GuideFilterEventEater::clearSearchLine, 0))
            return;
    }
}

const QMetaObject *GuideFilterEventEater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GuideFilterEventEater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21GuideFilterEventEaterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GuideFilterEventEater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void GuideFilterEventEater::clearSearchLine()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
namespace {
struct qt_meta_tag_ZN16GuidesProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto GuidesProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN16GuidesProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GuidesProxyModel",
        "refreshDar",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'refreshDar'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuidesProxyModel, qt_meta_tag_ZN16GuidesProxyModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GuidesProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QIdentityProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GuidesProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GuidesProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16GuidesProxyModelE_t>.metaTypes,
    nullptr
} };

void GuidesProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuidesProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshDar(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *GuidesProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GuidesProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16GuidesProxyModelE_t>.strings))
        return static_cast<void*>(this);
    return QIdentityProxyModel::qt_metacast(_clname);
}

int GuidesProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QIdentityProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN10GuidesListE_t {};
} // unnamed namespace

template <> constexpr inline auto GuidesList::qt_create_metaobjectdata<qt_meta_tag_ZN10GuidesListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GuidesList",
        "removeGuide",
        "",
        "selectAll",
        "updateJobProgress",
        "markerActivated",
        "frame",
        "saveGuides",
        "editGuides",
        "importGuides",
        "editGuide",
        "QModelIndex",
        "ix",
        "selectionChanged",
        "QItemSelection",
        "selected",
        "addGuide",
        "configureGuides",
        "rebuildCategories",
        "updateFilter",
        "QList<int>",
        "categories",
        "filterView",
        "text",
        "sortView",
        "QAction*",
        "ac",
        "changeSortOrder",
        "descending",
        "refreshDefaultCategory",
        "switchFilter",
        "enable",
        "showAllMarkers",
        "rebuildAllMarkers",
        "renameTimeline",
        "QUuid",
        "uuid",
        "name",
        "slotShowThumbs",
        "show",
        "buildMissingThumbs",
        "checkGuideChange",
        "start",
        "end",
        "roles",
        "fetchMovedThumbs",
        "rebuildThumbs",
        "activateMarker"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'removeGuide'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectAll'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateJobProgress'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'markerActivated'
        QtMocHelpers::SlotData<void(int)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Slot 'saveGuides'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editGuides'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importGuides'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'editGuide'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void(const QItemSelection &, const QItemSelection &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { 0x80000000 | 14, 2 },
        }}),
        // Slot 'addGuide'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureGuides'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rebuildCategories'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateFilter'
        QtMocHelpers::SlotData<void(QList<int>)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Slot 'filterView'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'sortView'
        QtMocHelpers::SlotData<void(QAction *)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 25, 26 },
        }}),
        // Slot 'changeSortOrder'
        QtMocHelpers::SlotData<void(bool)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 28 },
        }}),
        // Slot 'refreshDefaultCategory'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'switchFilter'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'showAllMarkers'
        QtMocHelpers::SlotData<void(bool)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'rebuildAllMarkers'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'renameTimeline'
        QtMocHelpers::SlotData<void(const QUuid &, const QString &)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 }, { QMetaType::QString, 37 },
        }}),
        // Slot 'slotShowThumbs'
        QtMocHelpers::SlotData<void(bool)>(38, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 39 },
        }}),
        // Slot 'buildMissingThumbs'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkGuideChange'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QList<int> &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 42 }, { 0x80000000 | 11, 43 }, { 0x80000000 | 20, 44 },
        }}),
        // Slot 'fetchMovedThumbs'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'rebuildThumbs'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateMarker'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GuidesList, qt_meta_tag_ZN10GuidesListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GuidesList::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10GuidesListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10GuidesListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10GuidesListE_t>.metaTypes,
    nullptr
} };

void GuidesList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GuidesList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->removeGuide(); break;
        case 1: _t->selectAll(); break;
        case 2: _t->updateJobProgress(); break;
        case 3: _t->markerActivated((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->saveGuides(); break;
        case 5: _t->editGuides(); break;
        case 6: _t->importGuides(); break;
        case 7: _t->editGuide((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 8: _t->selectionChanged((*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QItemSelection>>(_a[2]))); break;
        case 9: _t->addGuide(); break;
        case 10: _t->configureGuides(); break;
        case 11: _t->rebuildCategories(); break;
        case 12: _t->updateFilter((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1]))); break;
        case 13: _t->filterView((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->sortView((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 15: _t->changeSortOrder((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->refreshDefaultCategory(); break;
        case 17: _t->switchFilter((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->showAllMarkers((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->rebuildAllMarkers(); break;
        case 20: _t->renameTimeline((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 21: _t->slotShowThumbs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->buildMissingThumbs(); break;
        case 23: _t->checkGuideChange((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 24: _t->fetchMovedThumbs(); break;
        case 25: _t->rebuildThumbs(); break;
        case 26: _t->activateMarker((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QItemSelection >(); break;
            }
            break;
        case 12:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 23:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *GuidesList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GuidesList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10GuidesListE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::GuidesList_UI"))
        return static_cast< Ui::GuidesList_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int GuidesList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 27)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 27;
    }
    return _id;
}
QT_WARNING_POP
