/****************************************************************************
** Meta object code from reading C++ file 'layoutmanagement.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/layouts/layoutmanagement.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'layoutmanagement.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16LayoutManagementE_t {};
} // unnamed namespace

template <> constexpr inline auto LayoutManagement::qt_create_metaobjectdata<qt_meta_tag_ZN16LayoutManagementE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LayoutManagement",
        "slotLoadLayout",
        "",
        "LayoutInfo",
        "layout",
        "onlyIfNoPrevious",
        "slotLoadLayoutById",
        "layoutId",
        "slotLoadLayoutFromData",
        "layoutData",
        "adjustLayoutToDar",
        "slotSaveLayout",
        "slotLoadLayoutFromAction",
        "QAction*",
        "action",
        "slotManageLayouts",
        "hideAutoSave",
        "startAutoSave",
        "slotUpdatePalette"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotLoadLayout'
        QtMocHelpers::SlotData<bool(LayoutInfo, bool)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'slotLoadLayout'
        QtMocHelpers::SlotData<bool(LayoutInfo)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'slotLoadLayoutById'
        QtMocHelpers::SlotData<bool(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 7 },
        }}),
        // Slot 'slotLoadLayoutFromData'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(8, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'slotLoadLayoutFromData'
        QtMocHelpers::SlotData<bool(const QString &)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'adjustLayoutToDar'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveLayout'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadLayoutFromAction'
        QtMocHelpers::SlotData<void(QAction *)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'slotManageLayouts'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'hideAutoSave'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startAutoSave'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdatePalette'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LayoutManagement, qt_meta_tag_ZN16LayoutManagementE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LayoutManagement::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LayoutManagementE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LayoutManagementE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16LayoutManagementE_t>.metaTypes,
    nullptr
} };

void LayoutManagement::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LayoutManagement *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->slotLoadLayout((*reinterpret_cast<std::add_pointer_t<LayoutInfo>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 1: { bool _r = _t->slotLoadLayout((*reinterpret_cast<std::add_pointer_t<LayoutInfo>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 2: { bool _r = _t->slotLoadLayoutById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 3: { bool _r = _t->slotLoadLayoutFromData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { bool _r = _t->slotLoadLayoutFromData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->adjustLayoutToDar(); break;
        case 6: _t->slotSaveLayout(); break;
        case 7: _t->slotLoadLayoutFromAction((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 8: _t->slotManageLayouts(); break;
        case 9: _t->hideAutoSave(); break;
        case 10: _t->startAutoSave(); break;
        case 11: _t->slotUpdatePalette(); break;
        default: ;
        }
    }
}

const QMetaObject *LayoutManagement::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LayoutManagement::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16LayoutManagementE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LayoutManagement::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 12;
    }
    return _id;
}
QT_WARNING_POP
