/********************************************************************************
** Form generated from reading UI file 'qtextclip_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_QTEXTCLIP_UI_H
#define UI_QTEXTCLIP_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kcolorbutton.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_QTextClip_UI
{
public:
    QVBoxLayout *verticalLayout;
    QFormLayout *formLayout;
    QLabel *label_name;
    QLineEdit *name;
    QLabel *label_text;
    QTextEdit *text;
    QLabel *label_font;
    QHBoxLayout *fontGroup;
    QFontComboBox *font;
    QSpinBox *fontSize;
    QLabel *weightLabel;
    QSpinBox *weight;
    QToolButton *italic;
    KColorButton *fgColor;
    QLabel *label_outline;
    QHBoxLayout *lineGroup;
    QSpinBox *lineWidth;
    KColorButton *lineColor;
    QLabel *label_bg;
    KColorButton *bgColor;
    QLabel *label_padding;
    QSpinBox *pad;
    QLabel *label_duration;
    TimecodeDisplay *duration;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *QTextClip_UI)
    {
        if (QTextClip_UI->objectName().isEmpty())
            QTextClip_UI->setObjectName("QTextClip_UI");
        QTextClip_UI->resize(641, 429);
        verticalLayout = new QVBoxLayout(QTextClip_UI);
        verticalLayout->setObjectName("verticalLayout");
        formLayout = new QFormLayout();
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(-1, -1, -1, 20);
        label_name = new QLabel(QTextClip_UI);
        label_name->setObjectName("label_name");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_name);

        name = new QLineEdit(QTextClip_UI);
        name->setObjectName("name");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, name);

        label_text = new QLabel(QTextClip_UI);
        label_text->setObjectName("label_text");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_text);

        text = new QTextEdit(QTextClip_UI);
        text->setObjectName("text");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, text);

        label_font = new QLabel(QTextClip_UI);
        label_font->setObjectName("label_font");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_font);

        fontGroup = new QHBoxLayout();
        fontGroup->setObjectName("fontGroup");
        font = new QFontComboBox(QTextClip_UI);
        font->setObjectName("font");

        fontGroup->addWidget(font);

        fontSize = new QSpinBox(QTextClip_UI);
        fontSize->setObjectName("fontSize");
        fontSize->setMinimum(6);
        fontSize->setMaximum(1000);
        fontSize->setValue(100);

        fontGroup->addWidget(fontSize);

        weightLabel = new QLabel(QTextClip_UI);
        weightLabel->setObjectName("weightLabel");

        fontGroup->addWidget(weightLabel);

        weight = new QSpinBox(QTextClip_UI);
        weight->setObjectName("weight");
        weight->setMinimum(100);
        weight->setMaximum(1000);
        weight->setValue(400);

        fontGroup->addWidget(weight);

        italic = new QToolButton(QTextClip_UI);
        italic->setObjectName("italic");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("format-text-italic");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        italic->setIcon(icon);
        italic->setCheckable(true);

        fontGroup->addWidget(italic);

        fgColor = new KColorButton(QTextClip_UI);
        fgColor->setObjectName("fgColor");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(fgColor->sizePolicy().hasHeightForWidth());
        fgColor->setSizePolicy(sizePolicy);
        fgColor->setDefaultColor(QColor(255, 255, 255));
        fgColor->setAlphaChannelEnabled(true);

        fontGroup->addWidget(fgColor);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, fontGroup);

        label_outline = new QLabel(QTextClip_UI);
        label_outline->setObjectName("label_outline");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_outline);

        lineGroup = new QHBoxLayout();
        lineGroup->setObjectName("lineGroup");
        lineWidth = new QSpinBox(QTextClip_UI);
        lineWidth->setObjectName("lineWidth");
        lineWidth->setMaximum(5000);

        lineGroup->addWidget(lineWidth);

        lineColor = new KColorButton(QTextClip_UI);
        lineColor->setObjectName("lineColor");
        sizePolicy.setHeightForWidth(lineColor->sizePolicy().hasHeightForWidth());
        lineColor->setSizePolicy(sizePolicy);
        lineColor->setAutoDefault(false);
        lineColor->setAlphaChannelEnabled(true);

        lineGroup->addWidget(lineColor);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, lineGroup);

        label_bg = new QLabel(QTextClip_UI);
        label_bg->setObjectName("label_bg");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_bg);

        bgColor = new KColorButton(QTextClip_UI);
        bgColor->setObjectName("bgColor");
        sizePolicy.setHeightForWidth(bgColor->sizePolicy().hasHeightForWidth());
        bgColor->setSizePolicy(sizePolicy);
        bgColor->setAlphaChannelEnabled(true);

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, bgColor);

        label_padding = new QLabel(QTextClip_UI);
        label_padding->setObjectName("label_padding");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_padding);

        pad = new QSpinBox(QTextClip_UI);
        pad->setObjectName("pad");
        pad->setMaximum(4096);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, pad);

        label_duration = new QLabel(QTextClip_UI);
        label_duration->setObjectName("label_duration");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, label_duration);

        duration = new TimecodeDisplay(QTextClip_UI);
        duration->setObjectName("duration");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, duration);


        verticalLayout->addLayout(formLayout);

        buttonBox = new QDialogButtonBox(QTextClip_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(QTextClip_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, QTextClip_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, QTextClip_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(QTextClip_UI);
    } // setupUi

    void retranslateUi(QDialog *QTextClip_UI)
    {
        QTextClip_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_name->setText(tr2i18n("Name:", nullptr));
        label_text->setText(tr2i18n("Text:", nullptr));
        label_font->setText(tr2i18n("Font:", nullptr));
        weightLabel->setText(tr2i18n("Weight:", nullptr));
        italic->setText(tr2i18n("...", nullptr));
        label_outline->setText(tr2i18n("Outline:", nullptr));
        label_bg->setText(tr2i18n("Background:", nullptr));
        label_padding->setText(tr2i18n("Padding:", nullptr));
        label_duration->setText(tr2i18n("Duration:", nullptr));
    } // retranslateUi

};

namespace Ui {
    class QTextClip_UI: public Ui_QTextClip_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // QTEXTCLIP_UI_H

