// /qt/qml/org/kde/kdenlive/MonitorSafeZone.qml
#include <QtQml/qqmlprivate.h>
#include <QtCore/qdatetime.h>
#include <QtCore/qobject.h>
#include <QtCore/qstring.h>
#include <QtCore/qstringlist.h>
#include <QtCore/qtimezone.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtQml/qjsengine.h>
#include <QtQml/qjsprimitivevalue.h>
#include <QtQml/qjsvalue.h>
#include <QtQml/qqmlcomponent.h>
#include <QtQml/qqmlcontext.h>
#include <QtQml/qqmlengine.h>
#include <QtQml/qqmllist.h>
#include <type_traits>
namespace QmlCacheGeneratedCode {
namespace _qt_qml_org_kde_kdenlive_MonitorSafeZone_qml {
extern const unsigned char qmlData alignas(16) [];
extern const unsigned char qmlData alignas(16) [] = {

0x71,0x76,0x34,0x63,0x64,0x61,0x74,0x61,
0x49,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x9,0x0,0x0,0xd1,0xc2,0x7,0xd2,
0xdc,0xf0,0x80,0x15,0x3f,0x37,0x4a,0x42,
0x4,0x71,0xee,0xed,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x23,0x0,0x0,0x0,
0x1b,0x0,0x0,0x0,0x60,0x3,0x0,0x0,
0x5,0x0,0x0,0x0,0xc8,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0xdc,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0xe4,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x1,0x0,0x0,0x0,0x20,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0x0,0x0,0x0,0x0,0x28,0x1,0x0,0x0,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe8,0x6,0x0,0x0,
0x28,0x1,0x0,0x0,0x78,0x1,0x0,0x0,
0x0,0x2,0x0,0x0,0x90,0x2,0x0,0x0,
0xf0,0x2,0x0,0x0,0x40,0x3,0x0,0x0,
0x50,0x3,0x0,0x0,0x43,0x1,0x0,0x0,
0x80,0x0,0x0,0x0,0x73,0x0,0x0,0x0,
0x53,0x0,0x0,0x0,0xc4,0x0,0x0,0x0,
0x73,0x0,0x0,0x0,0x83,0x0,0x0,0x0,
0x50,0x1,0x0,0x0,0x83,0x0,0x0,0x0,
0x60,0x1,0x0,0x0,0x3,0x1,0x0,0x0,
0x94,0x1,0x0,0x0,0x53,0x0,0x0,0x0,
0xc4,0x0,0x0,0x0,0xa3,0x1,0x0,0x0,
0x66,0x66,0x66,0x66,0x66,0x26,0x13,0x40,
0x44,0x0,0x0,0x0,0x7,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0xd,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xd,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0x0,0x3c,0x1,
0x18,0x6,0x2,0x0,0x0,0x0,0x0,0x0,
0x68,0x0,0x0,0x0,0x14,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x4,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xe,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xf,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x11,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x4,0x0,0x0,0x0,
0xca,0x2e,0x2,0x50,0xb,0x2e,0x3,0x18,
0x7,0xac,0x4,0x7,0x0,0x0,0x18,0x6,
0xd4,0x16,0x6,0x2,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x5c,0x0,0x0,0x0,0x2f,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x3,0x0,
0xff,0xff,0xff,0xff,0xc,0x0,0x0,0x0,
0x15,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x8,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x16,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x24,0x0,0x0,0x0,
0x17,0x0,0x0,0x0,0x3,0x0,0x0,0x0,
0x2d,0x0,0x0,0x0,0x18,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2e,0x5,0x50,0x1c,
0x2e,0x6,0x3c,0x7,0x18,0x8,0x2e,0x8,
0x3c,0x9,0x9e,0x8,0x18,0x9,0x4,0x0,
0x68,0x9,0x50,0x4,0x12,0x17,0x4c,0x2,
0x12,0x18,0x4c,0x2,0x12,0x0,0x18,0x7,
0x2e,0xa,0x18,0x8,0xac,0xb,0x8,0x1,
0x7,0xe,0x2,0x0,0x0,0x0,0x0,0x0,
0x50,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0xe,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x2,0x0,
0xff,0xff,0xff,0xff,0xa,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x19,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x19,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0xca,0x2e,0xc,0x18,0x7,0xac,0xd,0x7,
0x0,0x0,0x18,0x6,0xd4,0x16,0x6,0x2,
0x44,0x0,0x0,0x0,0x5,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x38,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0xff,0xff,0xff,0xff,0x7,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x7,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x1d,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x2e,0xe,0x18,0x6,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd0,0x3,0x0,0x0,0xd8,0x3,0x0,0x0,
0xf0,0x3,0x0,0x0,0xf8,0x3,0x0,0x0,
0x20,0x4,0x0,0x0,0x30,0x4,0x0,0x0,
0x48,0x4,0x0,0x0,0x58,0x4,0x0,0x0,
0x78,0x4,0x0,0x0,0x90,0x4,0x0,0x0,
0xc8,0x4,0x0,0x0,0xf0,0x4,0x0,0x0,
0x38,0x5,0x0,0x0,0x50,0x5,0x0,0x0,
0x80,0x5,0x0,0x0,0xd0,0x5,0x0,0x0,
0xe8,0x5,0x0,0x0,0x0,0x6,0x0,0x0,
0x18,0x6,0x0,0x0,0x28,0x6,0x0,0x0,
0x58,0x6,0x0,0x0,0x68,0x6,0x0,0x0,
0x70,0x6,0x0,0x0,0x78,0x6,0x0,0x0,
0x98,0x6,0x0,0x0,0xb8,0x6,0x0,0x0,
0xd0,0x6,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x51,0x0,0x74,0x0,
0x51,0x0,0x75,0x0,0x69,0x0,0x63,0x0,
0x6b,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x4b,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x72,0x0,
0x67,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x2e,0x0,0x6b,0x0,0x64,0x0,
0x65,0x0,0x6e,0x0,0x6c,0x0,0x69,0x0,
0x76,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x49,0x0,0x74,0x0,
0x65,0x0,0x6d,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x61,0x0,
0x66,0x0,0x65,0x0,0x46,0x0,0x72,0x0,
0x61,0x0,0x6d,0x0,0x65,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x63,0x0,0x6f,0x0,
0x6c,0x0,0x6f,0x0,0x72,0x0,0x0,0x0,
0xc,0x0,0x0,0x0,0x73,0x0,0x68,0x0,
0x6f,0x0,0x77,0x0,0x53,0x0,0x61,0x0,
0x66,0x0,0x65,0x0,0x5a,0x0,0x6f,0x0,
0x6e,0x0,0x65,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x70,0x0,0x72,0x0,
0x6f,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x65,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x16,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x70,0x0,0x72,0x0,0x6f,0x0,
0x66,0x0,0x69,0x0,0x6c,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x50,0x0,0x72,0x0,0x6f,0x0,0x66,0x0,
0x69,0x0,0x6c,0x0,0x65,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x1f,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x50,0x0,
0x72,0x0,0x6f,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x65,0x0,0x43,0x0,0x68,0x0,
0x61,0x0,0x6e,0x0,0x67,0x0,0x65,0x0,
0x64,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x75,0x0,0x70,0x0,
0x64,0x0,0x61,0x0,0x74,0x0,0x65,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x15,0x0,0x0,0x0,0x6f,0x0,0x6e,0x0,
0x53,0x0,0x68,0x0,0x6f,0x0,0x77,0x0,
0x53,0x0,0x61,0x0,0x66,0x0,0x65,0x0,
0x5a,0x0,0x6f,0x0,0x6e,0x0,0x65,0x0,
0x43,0x0,0x68,0x0,0x61,0x0,0x6e,0x0,
0x67,0x0,0x65,0x0,0x64,0x0,0x0,0x0,
0x24,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x6f,0x0,0x6e,0x0,0x53,0x0,
0x68,0x0,0x6f,0x0,0x77,0x0,0x53,0x0,
0x61,0x0,0x66,0x0,0x65,0x0,0x5a,0x0,
0x6f,0x0,0x6e,0x0,0x65,0x0,0x43,0x0,
0x68,0x0,0x61,0x0,0x6e,0x0,0x67,0x0,
0x65,0x0,0x64,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x4c,0x0,0x6f,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x6c,0x0,0x6f,0x0,
0x61,0x0,0x64,0x0,0x65,0x0,0x72,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7,0x0,0x0,0x0,0x61,0x0,0x6e,0x0,
0x63,0x0,0x68,0x0,0x6f,0x0,0x72,0x0,
0x73,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x66,0x0,0x69,0x0,
0x6c,0x0,0x6c,0x0,0x0,0x0,0x0,0x0,
0x13,0x0,0x0,0x0,0x65,0x0,0x78,0x0,
0x70,0x0,0x72,0x0,0x65,0x0,0x73,0x0,
0x73,0x0,0x69,0x0,0x6f,0x0,0x6e,0x0,
0x20,0x0,0x66,0x0,0x6f,0x0,0x72,0x0,
0x20,0x0,0x66,0x0,0x69,0x0,0x6c,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x4,0x0,0x0,0x0,0x72,0x0,0x6f,0x0,
0x6f,0x0,0x74,0x0,0x0,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x78,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x79,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x53,0x0,0x61,0x0,
0x66,0x0,0x65,0x0,0x39,0x0,0x31,0x0,
0x36,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xb,0x0,0x0,0x0,0x53,0x0,0x61,0x0,
0x66,0x0,0x65,0x0,0x31,0x0,0x36,0x0,
0x39,0x0,0x2e,0x0,0x71,0x0,0x6d,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x9,0x0,0x0,0x0,0x73,0x0,0x65,0x0,
0x74,0x0,0x53,0x0,0x6f,0x0,0x75,0x0,
0x72,0x0,0x63,0x0,0x65,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0x70,0x0,0x61,0x0,
0x72,0x0,0x65,0x0,0x6e,0x0,0x74,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x10,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x38,0x0,0x0,0x0,
0x1,0x0,0x0,0x0,0x1,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6,0x0,0x10,0x0,
0xff,0xff,0x0,0x0,0x1,0x0,0x0,0x0,
0x3,0x0,0x0,0x0,0x2,0x0,0x0,0x0,
0x7,0x0,0x10,0x0,0xff,0xff,0x0,0x0,
0x44,0x0,0x0,0x0,0x3c,0x1,0x0,0x0,
0xac,0x1,0x0,0x0,0x4,0x0,0x0,0x0,
0x5,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x1,0x0,0x3,0x0,
0x54,0x0,0x0,0x0,0x58,0x0,0x0,0x0,
0x7c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x7c,0x0,0x0,0x0,0x7c,0x0,0x0,0x0,
0x0,0x0,0x5,0x0,0x7c,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0xf4,0x0,0x0,0x0,
0x9,0x0,0x10,0x0,0xa,0x0,0x50,0x0,
0xf4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xf4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x2,0x0,0x0,0x0,0x6,0x0,0x0,0x0,
0x6,0x0,0x0,0x0,0xb,0x0,0x50,0x0,
0x7,0x0,0x0,0x0,0x3,0x0,0x0,0x20,
0xc,0x0,0x50,0x0,0x8,0x0,0x0,0x0,
0xc,0x0,0x0,0x20,0xd,0x0,0x50,0x0,
0xd,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x3,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x19,0x0,0x50,0x0,0x19,0x0,0xc0,0x1,
0xa,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xe,0x0,0x50,0x0,0xe,0x0,0x70,0x1,
0x8,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xd,0x0,0x40,0x1,0xd,0x0,0xd0,0x1,
0x7,0x0,0x0,0x0,0x0,0x0,0x1,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0xc,0x0,0x30,0x1,0xc,0x0,0x10,0x2,
0x0,0x0,0x0,0x0,0x0,0x0,0x8,0x0,
0x1,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x1b,0x0,0x50,0x0,
0x0,0x0,0x0,0x0,0xf,0x0,0x0,0x0,
0x10,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x1b,0x0,0x50,0x0,0x1c,0x0,0x90,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x11,0x0,0x0,0x0,0x0,0x0,0xa,0x0,
0x2,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x1d,0x0,0x10,0x1,
0x0,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x0,0x0,0xff,0xff,
0xff,0xff,0xff,0xff,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x54,0x0,0x0,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x1,0x0,0x54,0x0,0x0,0x0,
0x0,0x0,0x0,0x0,0x6c,0x0,0x0,0x0,
0x1d,0x0,0x90,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x6c,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x12,0x0,0x0,0x0,0x0,0x0,0x7,0x0,
0x4,0x0,0x0,0x0,0x0,0x0,0x0,0x0,
0x1d,0x0,0x10,0x1,0x1d,0x0,0x70,0x1,
0x0,0x0,0x0,0x0
};
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[];
extern const QQmlPrivate::AOTCompiledFunction aotBuiltFunctions[] = {
{ 1, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onProfileChanged at line 14, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_5, markStack);
    aotContext->mark(v2_9, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_5 = nullptr;
QVariant v2_9;
bool v2_1;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(2, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadScopeObjectPropertyLookup(2);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_1) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
while (!aotContext->loadContextIdLookup(3, &s.v2_5)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(7);
#endif
aotContext->initLoadContextIdLookup(3);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(4, s.v2_5, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(4, s.v2_5, 2);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_9 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_9);
}
{
}
{
}
label_0:;
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 2, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// update at line 21, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_10, markStack);
    aotContext->mark(v2_36, markStack);
    aotContext->mark(v2_4, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_36 = nullptr;
QUrl c2_30;
QUrl v2_24;
QUrl v2_28;
QUrl v2_32;
QUrl v7_34;
QVariant v2_10;
QVariant v2_4;
bool v2_0;
bool v2_20;
double v2_12;
double v2_14;
double v2_18;
double v2_6;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(5, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(5);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_JumpFalse
if (!s.v2_0) {
    goto label_0;
}
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
s.v2_4 = QVariant(aotContext->lookupResultMetaType(6));
while (!aotContext->loadScopeObjectPropertyLookup(6, s.v2_4.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(6);
#endif
aotContext->initLoadScopeObjectPropertyLookup(6);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
s.v2_4 = QVariant(aotContext->lookupResultMetaType(6));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
while (!aotContext->getValueLookup(7, s.v2_4.data(), &s.v2_6)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(8);
#endif
aotContext->initGetValueLookup(7, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
s.v2_10 = QVariant(aotContext->lookupResultMetaType(8));
while (!aotContext->loadScopeObjectPropertyLookup(8, s.v2_10.data())) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(12);
#endif
aotContext->initLoadScopeObjectPropertyLookup(8);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
s.v2_10 = QVariant(aotContext->lookupResultMetaType(8));
}
{
}
// generate_GetLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
while (!aotContext->getValueLookup(9, s.v2_10.data(), &s.v2_12)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(14);
#endif
aotContext->initGetValueLookup(9, []() { static const auto t = QMetaType::fromName("QQmlPointFValueType"); return t; }().metaObject());
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_Div
QT_WARNING_PUSH
QT_WARNING_DISABLE_MSVC(4723) // potential divide by 0
s.v2_14 = (s.v2_6 / s.v2_12);
QT_WARNING_POP
{
}
// generate_StoreReg
{
}
// generate_LoadConst
s.v2_18 = 0.69999999999999996;
{
}
// generate_CmpLt
s.v2_20 = s.v2_14 < s.v2_18;
{
}
// generate_JumpFalse
if (!s.v2_20) {
    goto label_1;
}
{
}
// generate_LoadRuntimeString
s.v2_24 = QUrl(QStringLiteral("Safe916.qml"));
{
}
// generate_Jump
{
s.c2_30 = s.v2_24;
    goto label_2;
}
label_1:;
// generate_LoadRuntimeString
s.v2_28 = QUrl(QStringLiteral("Safe169.qml"));
{
s.c2_30 = s.v2_28;
}
label_2:;
// generate_Jump
{
s.v7_34 = s.c2_30;
    goto label_3;
}
label_0:;
// generate_LoadRuntimeString
s.v2_32 = QUrl(QStringLiteral(""));
{
s.v7_34 = s.v2_32;
}
label_3:;
// generate_StoreReg
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
while (!aotContext->loadContextIdLookup(10, &s.v2_36)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(38);
#endif
aotContext->initLoadContextIdLookup(10);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
const auto doCall = [&]() {
    void *args[] = {nullptr, &s.v7_34};
    return aotContext->callObjectPropertyLookup(11, s.v2_36, args, 1);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(11, s.v2_36, 11);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(45);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(45);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 3, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = QMetaType();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for onShowSafeZoneChanged at line 25, column 5
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_1, markStack);
    aotContext->mark(v2_5, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_1 = nullptr;
QVariant v2_5;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_CreateCallContext
{
{
}
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
while (!aotContext->loadContextIdLookup(12, &s.v2_1)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(3);
#endif
aotContext->initLoadContextIdLookup(12);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
{
}
// generate_StoreReg
{
}
// generate_CallPropertyLookup
{
QVariant callResult;
const auto doCall = [&]() {
    void *args[] = {&callResult};
    return aotContext->callObjectPropertyLookup(13, s.v2_1, args, 0);
};
const auto doInit = [&]() {
    aotContext->initCallObjectPropertyLookup(13, s.v2_1, 2);
};
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
while (!doCall()) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(10);
#endif
doInit();
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
return;
}
}
s.v2_5 = std::move(callResult);
aotContext->setImplicitDestructible(s.v2_5);
}
{
}
{
}
// generate_PopContext
{}
}
{
}
{
}
// generate_Ret
return;
}
 },{ 4, 0, [](QV4::ExecutableCompilationUnit *contextUnit, QMetaType *argTypes) {
    struct { QV4::ExecutableCompilationUnit *compilationUnit; } c { contextUnit };
    const auto *aotContext = &c;
    Q_UNUSED(aotContext);
    argTypes[0] = []() { static const auto t = QMetaType::fromName("QQuickItem*"); return t; }();
}, 
    [](const QQmlPrivate::AOTCompiledContext *aotContext, void **argv) {
Q_UNUSED(aotContext)
Q_UNUSED(argv)
// expression for fill at line 29, column 9
struct Storage : QQmlPrivate::AOTTrackedLocalsStorage {
Storage(const QQmlPrivate::AOTCompiledContext *ctxt, void **a)   : aotContext(ctxt), argv(a) {}
void markObjects(QV4::MarkStack *markStack) const final {    Q_UNUSED(markStack);
    aotContext->mark(v2_0, markStack);
}
const QQmlPrivate::AOTCompiledContext *aotContext;
void **argv;
QObject *v2_0 = nullptr;
};
Storage s(aotContext, argv);
aotContext->setLocals(&s);
// generate_LoadQmlContextPropertyLookup
#ifndef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
while (!aotContext->loadScopeObjectPropertyLookup(14, &s.v2_0)) {
#ifdef QT_NO_DEBUG
aotContext->setInstructionPointer(2);
#endif
aotContext->initLoadScopeObjectPropertyLookup(14);
if (aotContext->engine->hasError()) {
aotContext->setReturnValueUndefined();
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = nullptr;
}
return;
}
}
{
}
{
}
// generate_Ret
if (argv[0]) {
    *static_cast<QObject * *>(argv[0]) = s.v2_0;
}
return;
}
 },{ 0, 0, nullptr, nullptr }};
}
}
