/****************************************************************************
** Meta object code from reading C++ file 'providermodel.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/onlineresources/providermodel.hpp"
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'providermodel.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN13ProviderModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ProviderModel::qt_create_metaobjectdata<qt_meta_tag_ZN13ProviderModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProviderModel",
        "searchDone",
        "",
        "QList<ResourceItemInfo>&",
        "list",
        "pageCount",
        "searchError",
        "msg",
        "fetchedFiles",
        "token",
        "authenticated",
        "usePreview",
        "authorizeWithBrowser",
        "QUrl",
        "url",
        "slotStartSearch",
        "searchText",
        "page",
        "slotFetchFiles",
        "id"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'searchDone'
        QtMocHelpers::SignalData<void(QList<ResourceItemInfo> &, const int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'searchError'
        QtMocHelpers::SignalData<void(const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 },
        }}),
        // Signal 'searchError'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'fetchedFiles'
        QtMocHelpers::SignalData<void(QStringList, QStringList, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QStringList, 2 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'fetchedFiles'
        QtMocHelpers::SignalData<void(QStringList, QStringList)>(8, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { QMetaType::QStringList, 2 },
        }}),
        // Signal 'authenticated'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Signal 'usePreview'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'authorizeWithBrowser'
        QtMocHelpers::SignalData<void(const QUrl &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 14 },
        }}),
        // Slot 'slotStartSearch'
        QtMocHelpers::SlotData<void(const QString &, int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'slotFetchFiles'
        QtMocHelpers::SlotData<void(const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProviderModel, qt_meta_tag_ZN13ProviderModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProviderModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProviderModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProviderModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13ProviderModelE_t>.metaTypes,
    nullptr
} };

void ProviderModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProviderModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->searchDone((*reinterpret_cast<std::add_pointer_t<QList<ResourceItemInfo>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->searchError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->searchError(); break;
        case 3: _t->fetchedFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 4: _t->fetchedFiles((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 5: _t->authenticated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->usePreview(); break;
        case 7: _t->authorizeWithBrowser((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: _t->slotStartSearch((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->slotFetchFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)(QList<ResourceItemInfo> & , const int )>(_a, &ProviderModel::searchDone, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)(const QString & )>(_a, &ProviderModel::searchError, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)(QStringList , QStringList , const QString & )>(_a, &ProviderModel::fetchedFiles, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)(const QString & )>(_a, &ProviderModel::authenticated, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)()>(_a, &ProviderModel::usePreview, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProviderModel::*)(const QUrl & )>(_a, &ProviderModel::authorizeWithBrowser, 7))
            return;
    }
}

const QMetaObject *ProviderModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProviderModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13ProviderModelE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProviderModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void ProviderModel::searchDone(QList<ResourceItemInfo> & _t1, const int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ProviderModel::searchError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 3
void ProviderModel::fetchedFiles(QStringList _t1, QStringList _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 5
void ProviderModel::authenticated(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ProviderModel::usePreview()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ProviderModel::authorizeWithBrowser(const QUrl & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
