/********************************************************************************
** Form generated from reading UI file 'urllistparamwidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_URLLISTPARAMWIDGET_UI_H
#define UI_URLLISTPARAMWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "KNSWidgets/Button"

QT_BEGIN_NAMESPACE

class Ui_UrlListParamWidget_UI
{
public:
    QGridLayout *gridLayout;
    QWidget *m_widgetComment;
    QGridLayout *_2;
    QLabel *m_labelComment;
    QWidget *m_value_box;
    QHBoxLayout *horizontalLayout;
    QComboBox *m_list;
    KNSWidgets::Button *m_knsbutton;
    QToolButton *m_maskButton;

    void setupUi(QWidget *UrlListParamWidget_UI)
    {
        if (UrlListParamWidget_UI->objectName().isEmpty())
            UrlListParamWidget_UI->setObjectName("UrlListParamWidget_UI");
        UrlListParamWidget_UI->resize(170, 58);
        gridLayout = new QGridLayout(UrlListParamWidget_UI);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        m_widgetComment = new QWidget(UrlListParamWidget_UI);
        m_widgetComment->setObjectName("m_widgetComment");
        _2 = new QGridLayout(m_widgetComment);
        _2->setSpacing(0);
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);
        m_labelComment = new QLabel(m_widgetComment);
        m_labelComment->setObjectName("m_labelComment");
        m_labelComment->setFrameShape(QFrame::Shape::StyledPanel);
        m_labelComment->setFrameShadow(QFrame::Shadow::Raised);
        m_labelComment->setTextFormat(Qt::TextFormat::RichText);
        m_labelComment->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        m_labelComment->setWordWrap(true);

        _2->addWidget(m_labelComment, 0, 0, 1, 1);


        gridLayout->addWidget(m_widgetComment, 1, 0, 1, 3);

        m_value_box = new QWidget(UrlListParamWidget_UI);
        m_value_box->setObjectName("m_value_box");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(1);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(m_value_box->sizePolicy().hasHeightForWidth());
        m_value_box->setSizePolicy(sizePolicy);
        horizontalLayout = new QHBoxLayout(m_value_box);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        m_list = new QComboBox(m_value_box);
        m_list->setObjectName("m_list");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(1);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(m_list->sizePolicy().hasHeightForWidth());
        m_list->setSizePolicy(sizePolicy1);
        m_list->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout->addWidget(m_list);

        m_knsbutton = new KNSWidgets::Button(m_value_box);
        m_knsbutton->setObjectName("m_knsbutton");

        horizontalLayout->addWidget(m_knsbutton);

        m_maskButton = new QToolButton(m_value_box);
        m_maskButton->setObjectName("m_maskButton");

        horizontalLayout->addWidget(m_maskButton);


        gridLayout->addWidget(m_value_box, 0, 1, 1, 1);


        retranslateUi(UrlListParamWidget_UI);

        QMetaObject::connectSlotsByName(UrlListParamWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *UrlListParamWidget_UI)
    {
        m_knsbutton->setText(QString());
        m_maskButton->setText(tr2i18n("...", nullptr));
        (void)UrlListParamWidget_UI;
    } // retranslateUi

};

namespace Ui {
    class UrlListParamWidget_UI: public Ui_UrlListParamWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // URLLISTPARAMWIDGET_UI_H

