/********************************************************************************
** Form generated from reading UI file 'keywordval_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYWORDVAL_UI_H
#define UI_KEYWORDVAL_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Keywordval_UI
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *label;
    QPlainTextEdit *lineeditwidget;
    QComboBox *comboboxwidget;

    void setupUi(QWidget *Keywordval_UI)
    {
        if (Keywordval_UI->objectName().isEmpty())
            Keywordval_UI->setObjectName("Keywordval_UI");
        Keywordval_UI->resize(175, 131);
        verticalLayout = new QVBoxLayout(Keywordval_UI);
        verticalLayout->setSpacing(4);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(4, 4, 4, 4);
        label = new QLabel(Keywordval_UI);
        label->setObjectName("label");

        verticalLayout->addWidget(label);

        lineeditwidget = new QPlainTextEdit(Keywordval_UI);
        lineeditwidget->setObjectName("lineeditwidget");

        verticalLayout->addWidget(lineeditwidget);

        comboboxwidget = new QComboBox(Keywordval_UI);
        comboboxwidget->setObjectName("comboboxwidget");

        verticalLayout->addWidget(comboboxwidget);


        retranslateUi(Keywordval_UI);

        QMetaObject::connectSlotsByName(Keywordval_UI);
    } // setupUi

    void retranslateUi(QWidget *Keywordval_UI)
    {
        label->setText(QString());
        (void)Keywordval_UI;
    } // retranslateUi

};

namespace Ui {
    class Keywordval_UI: public Ui_Keywordval_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // KEYWORDVAL_UI_H

