/********************************************************************************
** Form generated from reading UI file 'editsub_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EDITSUB_UI_H
#define UI_EDITSUB_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "ktextedit.h"
#include "widgets/subtitletextedit.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_SubEdit_UI
{
public:
    QGridLayout *gridLayout;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QGridLayout *gridLayout_10;
    QFrame *frame_position;
    QGridLayout *gridLayout_6;
    QStackedWidget *stackedWidget;
    QWidget *page;
    QGridLayout *gridLayout_7;
    QLabel *label_duration;
    SubtitleTextEdit *subText;
    TimecodeDisplay *tc_duration;
    QLabel *label_position;
    KTextEdit *simpleSubText;
    QToolButton *buttonLock;
    QToolButton *buttonEditStyle;
    TimecodeDisplay *tc_end;
    QLabel *label_end;
    QToolButton *buttonIn;
    QLabel *label_style;
    TimecodeDisplay *tc_position;
    QToolButton *buttonOut;
    QSpacerItem *verticalSpacer_3;
    QHBoxLayout *horizontalLayout_4;
    QToolButton *buttonBold;
    QToolButton *buttonItalic;
    QToolButton *buttonUnderline;
    QToolButton *buttonStrikeout;
    QToolButton *buttonFont;
    QToolButton *buttonResetStyle;
    QToolButton *buttonMoreTags;
    QSpacerItem *horizontalSpacer_4;
    QSpinBox *subLayer;
    QHBoxLayout *horizontalLayout_5;
    QLabel *char_count;
    QToolButton *subMenu;
    QComboBox *comboStyle;
    QSpacerItem *horizontalSpacer_5;
    QWidget *page_2;
    QGridLayout *gridLayout_8;
    QScrollArea *scrollArea_3;
    QWidget *scrollAreaWidgetContents_3;
    QGridLayout *gridLayout_9;
    QComboBox *scrollDirection;
    QLabel *labelMarginL;
    QSpinBox *marginL;
    QLineEdit *editName;
    QSpinBox *scrollSpeed;
    QSpinBox *marginV;
    QSpinBox *scrollUpper;
    QLabel *labelMarginR;
    QSpinBox *scrollLower;
    QLabel *labelScrollUpper;
    QSpinBox *marginR;
    QLabel *labelMarginV;
    QLabel *labelEffects;
    QLabel *labelScrollSpeed;
    KTextEdit *editEffects;
    QSpacerItem *verticalSpacer_4;
    QLabel *lavelScrollLower;
    QCheckBox *checkComment;
    QCheckBox *checkScroll;
    QLabel *labelName;
    QHBoxLayout *horizontalLayout_6;
    QToolButton *buttonPrev;
    QToolButton *buttonNext;
    QToolButton *buttonAdd;
    QToolButton *buttonCut;
    QToolButton *buttonApply;
    QToolButton *buttonMoreOption;
    QSpacerItem *horizontalSpacer_6;
    QToolButton *buttonDelete;

    void setupUi(QWidget *SubEdit_UI)
    {
        if (SubEdit_UI->objectName().isEmpty())
            SubEdit_UI->setObjectName("SubEdit_UI");
        SubEdit_UI->resize(397, 500);
        gridLayout = new QGridLayout(SubEdit_UI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        scrollArea = new QScrollArea(SubEdit_UI);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, 0, 397, 500));
        gridLayout_10 = new QGridLayout(scrollAreaWidgetContents);
        gridLayout_10->setObjectName("gridLayout_10");
        gridLayout_10->setContentsMargins(0, 0, 0, 0);
        frame_position = new QFrame(scrollAreaWidgetContents);
        frame_position->setObjectName("frame_position");
        frame_position->setFrameShape(QFrame::Shape::NoFrame);
        frame_position->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_6 = new QGridLayout(frame_position);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        stackedWidget = new QStackedWidget(frame_position);
        stackedWidget->setObjectName("stackedWidget");
        page = new QWidget();
        page->setObjectName("page");
        gridLayout_7 = new QGridLayout(page);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(6, 6, 6, 6);
        label_duration = new QLabel(page);
        label_duration->setObjectName("label_duration");
        label_duration->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_7->addWidget(label_duration, 7, 0, 1, 1);

        subText = new SubtitleTextEdit(page);
        subText->setObjectName("subText");
        subText->setInputMethodHints(Qt::InputMethodHint::ImhNone);
        subText->setTabChangesFocus(true);
        subText->setAcceptRichText(false);

        gridLayout_7->addWidget(subText, 1, 0, 1, 6);

        tc_duration = new TimecodeDisplay(page);
        tc_duration->setObjectName("tc_duration");

        gridLayout_7->addWidget(tc_duration, 7, 2, 1, 2);

        label_position = new QLabel(page);
        label_position->setObjectName("label_position");
        label_position->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_7->addWidget(label_position, 5, 0, 1, 1);

        simpleSubText = new KTextEdit(page);
        simpleSubText->setObjectName("simpleSubText");

        gridLayout_7->addWidget(simpleSubText, 2, 0, 1, 6);

        buttonLock = new QToolButton(page);
        buttonLock->setObjectName("buttonLock");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("lock")));
        buttonLock->setIcon(icon);
        buttonLock->setCheckable(true);

        gridLayout_7->addWidget(buttonLock, 7, 1, 1, 1);

        buttonEditStyle = new QToolButton(page);
        buttonEditStyle->setObjectName("buttonEditStyle");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-entry")));
        buttonEditStyle->setIcon(icon1);

        gridLayout_7->addWidget(buttonEditStyle, 4, 1, 1, 1);

        tc_end = new TimecodeDisplay(page);
        tc_end->setObjectName("tc_end");

        gridLayout_7->addWidget(tc_end, 6, 2, 1, 2);

        label_end = new QLabel(page);
        label_end->setObjectName("label_end");
        label_end->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_7->addWidget(label_end, 6, 0, 1, 1);

        buttonIn = new QToolButton(page);
        buttonIn->setObjectName("buttonIn");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("zone-in")));
        buttonIn->setIcon(icon2);

        gridLayout_7->addWidget(buttonIn, 5, 1, 1, 1);

        label_style = new QLabel(page);
        label_style->setObjectName("label_style");
        label_style->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_7->addWidget(label_style, 4, 0, 1, 1);

        tc_position = new TimecodeDisplay(page);
        tc_position->setObjectName("tc_position");

        gridLayout_7->addWidget(tc_position, 5, 2, 1, 2);

        buttonOut = new QToolButton(page);
        buttonOut->setObjectName("buttonOut");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("zone-out")));
        buttonOut->setIcon(icon3);

        gridLayout_7->addWidget(buttonOut, 6, 1, 1, 1);

        verticalSpacer_3 = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_7->addItem(verticalSpacer_3, 8, 1, 1, 1);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        horizontalLayout_4->setContentsMargins(-1, -1, 0, -1);
        buttonBold = new QToolButton(page);
        buttonBold->setObjectName("buttonBold");
        QIcon icon4(QIcon::fromTheme(QString::fromUtf8("format-text-bold")));
        buttonBold->setIcon(icon4);

        horizontalLayout_4->addWidget(buttonBold);

        buttonItalic = new QToolButton(page);
        buttonItalic->setObjectName("buttonItalic");
        QIcon icon5(QIcon::fromTheme(QString::fromUtf8("format-text-italic")));
        buttonItalic->setIcon(icon5);

        horizontalLayout_4->addWidget(buttonItalic);

        buttonUnderline = new QToolButton(page);
        buttonUnderline->setObjectName("buttonUnderline");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("format-text-underline")));
        buttonUnderline->setIcon(icon6);

        horizontalLayout_4->addWidget(buttonUnderline);

        buttonStrikeout = new QToolButton(page);
        buttonStrikeout->setObjectName("buttonStrikeout");
        QIcon icon7(QIcon::fromTheme(QString::fromUtf8("format-text-strikethrough")));
        buttonStrikeout->setIcon(icon7);

        horizontalLayout_4->addWidget(buttonStrikeout);

        buttonFont = new QToolButton(page);
        buttonFont->setObjectName("buttonFont");
        QIcon icon8(QIcon::fromTheme(QString::fromUtf8("font-enable")));
        buttonFont->setIcon(icon8);

        horizontalLayout_4->addWidget(buttonFont);

        buttonResetStyle = new QToolButton(page);
        buttonResetStyle->setObjectName("buttonResetStyle");
        QIcon icon9(QIcon::fromTheme(QString::fromUtf8("edit-paste-style")));
        buttonResetStyle->setIcon(icon9);

        horizontalLayout_4->addWidget(buttonResetStyle);

        buttonMoreTags = new QToolButton(page);
        buttonMoreTags->setObjectName("buttonMoreTags");
        QIcon icon10(QIcon::fromTheme(QString::fromUtf8("view-more-symbolic")));
        buttonMoreTags->setIcon(icon10);
        buttonMoreTags->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);

        horizontalLayout_4->addWidget(buttonMoreTags);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_4);

        subLayer = new QSpinBox(page);
        subLayer->setObjectName("subLayer");
        subLayer->setFocusPolicy(Qt::FocusPolicy::ClickFocus);
        subLayer->setInputMethodHints(Qt::InputMethodHint::ImhDigitsOnly);
        subLayer->setFrame(false);
        subLayer->setAlignment(Qt::AlignmentFlag::AlignCenter);
        subLayer->setMaximum(20);

        horizontalLayout_4->addWidget(subLayer);


        gridLayout_7->addLayout(horizontalLayout_4, 0, 0, 1, 6);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        char_count = new QLabel(page);
        char_count->setObjectName("char_count");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(char_count->sizePolicy().hasHeightForWidth());
        char_count->setSizePolicy(sizePolicy);
        char_count->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignVCenter);

        horizontalLayout_5->addWidget(char_count);

        subMenu = new QToolButton(page);
        subMenu->setObjectName("subMenu");
        QIcon icon11(QIcon::fromTheme(QString::fromUtf8("application-menu")));
        subMenu->setIcon(icon11);
        subMenu->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);

        horizontalLayout_5->addWidget(subMenu);


        gridLayout_7->addLayout(horizontalLayout_5, 3, 0, 1, 6);

        comboStyle = new QComboBox(page);
        comboStyle->setObjectName("comboStyle");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(comboStyle->sizePolicy().hasHeightForWidth());
        comboStyle->setSizePolicy(sizePolicy1);

        gridLayout_7->addWidget(comboStyle, 4, 2, 1, 3);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_7->addItem(horizontalSpacer_5, 5, 5, 1, 1);

        stackedWidget->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_8 = new QGridLayout(page_2);
        gridLayout_8->setObjectName("gridLayout_8");
        gridLayout_8->setVerticalSpacing(0);
        scrollArea_3 = new QScrollArea(page_2);
        scrollArea_3->setObjectName("scrollArea_3");
        scrollArea_3->setFrameShape(QFrame::Shape::NoFrame);
        scrollArea_3->setWidgetResizable(true);
        scrollAreaWidgetContents_3 = new QWidget();
        scrollAreaWidgetContents_3->setObjectName("scrollAreaWidgetContents_3");
        scrollAreaWidgetContents_3->setGeometry(QRect(0, 0, 364, 489));
        gridLayout_9 = new QGridLayout(scrollAreaWidgetContents_3);
        gridLayout_9->setObjectName("gridLayout_9");
        gridLayout_9->setContentsMargins(0, 0, 0, 0);
        scrollDirection = new QComboBox(scrollAreaWidgetContents_3);
        scrollDirection->setObjectName("scrollDirection");

        gridLayout_9->addWidget(scrollDirection, 0, 3, 1, 1);

        labelMarginL = new QLabel(scrollAreaWidgetContents_3);
        labelMarginL->setObjectName("labelMarginL");
        labelMarginL->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelMarginL, 2, 0, 1, 3);

        marginL = new QSpinBox(scrollAreaWidgetContents_3);
        marginL->setObjectName("marginL");
        marginL->setMinimum(-999999999);
        marginL->setMaximum(999999999);

        gridLayout_9->addWidget(marginL, 2, 3, 1, 1);

        editName = new QLineEdit(scrollAreaWidgetContents_3);
        editName->setObjectName("editName");

        gridLayout_9->addWidget(editName, 9, 3, 1, 1);

        scrollSpeed = new QSpinBox(scrollAreaWidgetContents_3);
        scrollSpeed->setObjectName("scrollSpeed");
        scrollSpeed->setMinimum(1);
        scrollSpeed->setMaximum(100);
        scrollSpeed->setValue(10);

        gridLayout_9->addWidget(scrollSpeed, 6, 3, 1, 1);

        marginV = new QSpinBox(scrollAreaWidgetContents_3);
        marginV->setObjectName("marginV");
        marginV->setMinimum(-999999999);
        marginV->setMaximum(999999999);

        gridLayout_9->addWidget(marginV, 4, 3, 1, 1);

        scrollUpper = new QSpinBox(scrollAreaWidgetContents_3);
        scrollUpper->setObjectName("scrollUpper");
        scrollUpper->setMinimum(-99999);
        scrollUpper->setMaximum(99999);
        scrollUpper->setValue(0);

        gridLayout_9->addWidget(scrollUpper, 7, 3, 1, 1);

        labelMarginR = new QLabel(scrollAreaWidgetContents_3);
        labelMarginR->setObjectName("labelMarginR");
        labelMarginR->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelMarginR, 3, 0, 1, 3);

        scrollLower = new QSpinBox(scrollAreaWidgetContents_3);
        scrollLower->setObjectName("scrollLower");
        scrollLower->setMinimum(-99999);
        scrollLower->setMaximum(99999);
        scrollLower->setValue(1080);

        gridLayout_9->addWidget(scrollLower, 8, 3, 1, 1);

        labelScrollUpper = new QLabel(scrollAreaWidgetContents_3);
        labelScrollUpper->setObjectName("labelScrollUpper");
        labelScrollUpper->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelScrollUpper, 7, 0, 1, 3);

        marginR = new QSpinBox(scrollAreaWidgetContents_3);
        marginR->setObjectName("marginR");
        marginR->setMinimum(-999999999);
        marginR->setValue(0);

        gridLayout_9->addWidget(marginR, 3, 3, 1, 1);

        labelMarginV = new QLabel(scrollAreaWidgetContents_3);
        labelMarginV->setObjectName("labelMarginV");
        labelMarginV->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelMarginV, 4, 0, 1, 3);

        labelEffects = new QLabel(scrollAreaWidgetContents_3);
        labelEffects->setObjectName("labelEffects");

        gridLayout_9->addWidget(labelEffects, 11, 0, 1, 4);

        labelScrollSpeed = new QLabel(scrollAreaWidgetContents_3);
        labelScrollSpeed->setObjectName("labelScrollSpeed");
        labelScrollSpeed->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelScrollSpeed, 6, 0, 1, 3);

        editEffects = new KTextEdit(scrollAreaWidgetContents_3);
        editEffects->setObjectName("editEffects");
        editEffects->setInputMethodHints(Qt::InputMethodHint::ImhNone);

        gridLayout_9->addWidget(editEffects, 12, 0, 1, 4);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_9->addItem(verticalSpacer_4, 13, 0, 1, 1);

        lavelScrollLower = new QLabel(scrollAreaWidgetContents_3);
        lavelScrollLower->setObjectName("lavelScrollLower");
        lavelScrollLower->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(lavelScrollLower, 8, 0, 1, 3);

        checkComment = new QCheckBox(scrollAreaWidgetContents_3);
        checkComment->setObjectName("checkComment");

        gridLayout_9->addWidget(checkComment, 10, 0, 1, 3);

        checkScroll = new QCheckBox(scrollAreaWidgetContents_3);
        checkScroll->setObjectName("checkScroll");
        checkScroll->setLayoutDirection(Qt::LayoutDirection::LeftToRight);

        gridLayout_9->addWidget(checkScroll, 0, 0, 1, 3);

        labelName = new QLabel(scrollAreaWidgetContents_3);
        labelName->setObjectName("labelName");
        labelName->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_9->addWidget(labelName, 9, 0, 1, 3);

        scrollArea_3->setWidget(scrollAreaWidgetContents_3);

        gridLayout_8->addWidget(scrollArea_3, 0, 1, 1, 1);

        stackedWidget->addWidget(page_2);

        gridLayout_6->addWidget(stackedWidget, 0, 0, 1, 2);


        gridLayout_10->addWidget(frame_position, 0, 0, 1, 1);

        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        buttonPrev = new QToolButton(scrollAreaWidgetContents);
        buttonPrev->setObjectName("buttonPrev");
        buttonPrev->setArrowType(Qt::ArrowType::LeftArrow);

        horizontalLayout_6->addWidget(buttonPrev);

        buttonNext = new QToolButton(scrollAreaWidgetContents);
        buttonNext->setObjectName("buttonNext");
        buttonNext->setArrowType(Qt::ArrowType::RightArrow);

        horizontalLayout_6->addWidget(buttonNext);

        buttonAdd = new QToolButton(scrollAreaWidgetContents);
        buttonAdd->setObjectName("buttonAdd");
        QIcon icon12(QIcon::fromTheme(QString::fromUtf8("list-add")));
        buttonAdd->setIcon(icon12);

        horizontalLayout_6->addWidget(buttonAdd);

        buttonCut = new QToolButton(scrollAreaWidgetContents);
        buttonCut->setObjectName("buttonCut");
        QIcon icon13(QIcon::fromTheme(QString::fromUtf8("edit-cut")));
        buttonCut->setIcon(icon13);

        horizontalLayout_6->addWidget(buttonCut);

        buttonApply = new QToolButton(scrollAreaWidgetContents);
        buttonApply->setObjectName("buttonApply");
        QIcon icon14(QIcon::fromTheme(QString::fromUtf8("dialog-ok-apply")));
        buttonApply->setIcon(icon14);

        horizontalLayout_6->addWidget(buttonApply);

        buttonMoreOption = new QToolButton(scrollAreaWidgetContents);
        buttonMoreOption->setObjectName("buttonMoreOption");
        QIcon icon15(QIcon::fromTheme(QString::fromUtf8("settings-configure")));
        buttonMoreOption->setIcon(icon15);
        buttonMoreOption->setCheckable(true);

        horizontalLayout_6->addWidget(buttonMoreOption);

        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);

        buttonDelete = new QToolButton(scrollAreaWidgetContents);
        buttonDelete->setObjectName("buttonDelete");
        QIcon icon16(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        buttonDelete->setIcon(icon16);

        horizontalLayout_6->addWidget(buttonDelete);


        gridLayout_10->addLayout(horizontalLayout_6, 1, 0, 1, 1);

        scrollArea->setWidget(scrollAreaWidgetContents);

        gridLayout->addWidget(scrollArea, 0, 0, 1, 1);


        retranslateUi(SubEdit_UI);

        stackedWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(SubEdit_UI);
    } // setupUi

    void retranslateUi(QWidget *SubEdit_UI)
    {
        SubEdit_UI->setWindowTitle(tr2i18n("Form", nullptr));
        label_duration->setText(tr2i18n("Duration:", nullptr));
        label_position->setText(tr2i18n("Position:", nullptr));
        buttonLock->setText(tr2i18n("...", nullptr));
        buttonEditStyle->setText(tr2i18n("...", nullptr));
        label_end->setText(tr2i18n("End:", nullptr));
        buttonIn->setText(tr2i18n("...", nullptr));
        label_style->setText(tr2i18n("Style:", nullptr));
        buttonOut->setText(tr2i18n("...", nullptr));
        buttonBold->setText(tr2i18n("...", nullptr));
        buttonItalic->setText(tr2i18n("...", nullptr));
        buttonUnderline->setText(tr2i18n("...", nullptr));
        buttonStrikeout->setText(tr2i18n("...", nullptr));
        buttonFont->setText(tr2i18n("...", nullptr));
        buttonResetStyle->setText(tr2i18n("...", nullptr));
        buttonMoreTags->setText(QString());
        subLayer->setPrefix(tr2i18n("S", nullptr));
        char_count->setText(QString());
        subMenu->setText(tr2i18n("...", nullptr));
        labelMarginL->setText(tr2i18n("Left margin", nullptr));
        labelMarginR->setText(tr2i18n("Right margin", nullptr));
        labelScrollUpper->setText(tr2i18n("Upper Bound", nullptr));
        labelMarginV->setText(tr2i18n("Vertical margin", nullptr));
        labelEffects->setText(tr2i18n("Effects", nullptr));
        labelScrollSpeed->setText(tr2i18n("Speed", nullptr));
        lavelScrollLower->setText(tr2i18n("Lower Bound", nullptr));
        checkComment->setText(tr2i18n("Comment", nullptr));
        checkScroll->setText(tr2i18n("Scroll", nullptr));
        labelName->setText(tr2i18n("<html><head/><body><p>Name</p></body></html>", nullptr));
        buttonPrev->setText(tr2i18n("...", nullptr));
        buttonNext->setText(tr2i18n("...", nullptr));
        buttonAdd->setText(tr2i18n("...", nullptr));
        buttonCut->setText(tr2i18n("...", nullptr));
        buttonApply->setText(tr2i18n("...", nullptr));
        buttonMoreOption->setText(tr2i18n("...", nullptr));
        buttonDelete->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SubEdit_UI: public Ui_SubEdit_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EDITSUB_UI_H

