/****************************************************************************
** Meta object code from reading C++ file 'bin.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/bin/bin.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'bin.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MyListViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MyListView::qt_create_metaobjectdata<qt_meta_tag_ZN10MyListViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MyListView",
        "focusView",
        "",
        "updateDragMode",
        "PlaylistState::ClipState",
        "type",
        "displayBinFrame",
        "QModelIndex",
        "ix",
        "frame",
        "storeFrame",
        "performDrag",
        "QModelIndexList",
        "indexes"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focusView'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateDragMode'
        QtMocHelpers::SignalData<void(PlaylistState::ClipState)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'displayBinFrame'
        QtMocHelpers::SignalData<void(QModelIndex, int, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'displayBinFrame'
        QtMocHelpers::SignalData<void(QModelIndex, int)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'performDrag'
        QtMocHelpers::SignalData<void(const QModelIndexList)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MyListView, qt_meta_tag_ZN10MyListViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MyListView::staticMetaObject = { {
    QMetaObject::SuperData::link<QListView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyListViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyListViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MyListViewE_t>.metaTypes,
    nullptr
} };

void MyListView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MyListView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusView(); break;
        case 1: _t->updateDragMode((*reinterpret_cast<std::add_pointer_t<PlaylistState::ClipState>>(_a[1]))); break;
        case 2: _t->displayBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->displayBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->performDrag((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MyListView::*)()>(_a, &MyListView::focusView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyListView::*)(PlaylistState::ClipState )>(_a, &MyListView::updateDragMode, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyListView::*)(QModelIndex , int , bool )>(_a, &MyListView::displayBinFrame, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyListView::*)(const QModelIndexList )>(_a, &MyListView::performDrag, 4))
            return;
    }
}

const QMetaObject *MyListView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MyListView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyListViewE_t>.strings))
        return static_cast<void*>(this);
    return QListView::qt_metacast(_clname);
}

int MyListView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void MyListView::focusView()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MyListView::updateDragMode(PlaylistState::ClipState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MyListView::displayBinFrame(QModelIndex _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void MyListView::performDrag(const QModelIndexList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN10MyTreeViewE_t {};
} // unnamed namespace

template <> constexpr inline auto MyTreeView::qt_create_metaobjectdata<qt_meta_tag_ZN10MyTreeViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MyTreeView",
        "focusView",
        "",
        "updateDragMode",
        "PlaylistState::ClipState",
        "type",
        "displayBinFrame",
        "QModelIndex",
        "ix",
        "frame",
        "storeFrame",
        "processDragEnd",
        "selectCurrent",
        "editingChanged",
        "performDrag",
        "QModelIndexList",
        "indexes",
        "closeEditor",
        "QWidget*",
        "editor",
        "QAbstractItemDelegate::EndEditHint",
        "hint",
        "editorDestroyed",
        "editing"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'focusView'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateDragMode'
        QtMocHelpers::SignalData<void(PlaylistState::ClipState)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'displayBinFrame'
        QtMocHelpers::SignalData<void(QModelIndex, int, bool)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 }, { QMetaType::Bool, 10 },
        }}),
        // Signal 'displayBinFrame'
        QtMocHelpers::SignalData<void(QModelIndex, int)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::Int, 9 },
        }}),
        // Signal 'processDragEnd'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selectCurrent'
        QtMocHelpers::SignalData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'editingChanged'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'performDrag'
        QtMocHelpers::SignalData<void(const QModelIndexList)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 },
        }}),
        // Slot 'closeEditor'
        QtMocHelpers::SlotData<void(QWidget *, QAbstractItemDelegate::EndEditHint)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { 0x80000000 | 18, 19 }, { 0x80000000 | 20, 21 },
        }}),
        // Slot 'editorDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(22, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::QObjectStar, 19 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'editing'
        QtMocHelpers::PropertyData<bool>(23, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MyTreeView, qt_meta_tag_ZN10MyTreeViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MyTreeView::staticMetaObject = { {
    QMetaObject::SuperData::link<QTreeView::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTreeViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTreeViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MyTreeViewE_t>.metaTypes,
    nullptr
} };

void MyTreeView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MyTreeView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->focusView(); break;
        case 1: _t->updateDragMode((*reinterpret_cast<std::add_pointer_t<PlaylistState::ClipState>>(_a[1]))); break;
        case 2: _t->displayBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 3: _t->displayBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 4: _t->processDragEnd(); break;
        case 5: _t->selectCurrent(); break;
        case 6: _t->editingChanged(); break;
        case 7: _t->performDrag((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1]))); break;
        case 8: _t->closeEditor((*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAbstractItemDelegate::EndEditHint>>(_a[2]))); break;
        case 9: _t->editorDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)()>(_a, &MyTreeView::focusView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)(PlaylistState::ClipState )>(_a, &MyTreeView::updateDragMode, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)(QModelIndex , int , bool )>(_a, &MyTreeView::displayBinFrame, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)()>(_a, &MyTreeView::processDragEnd, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)()>(_a, &MyTreeView::selectCurrent, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)()>(_a, &MyTreeView::editingChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MyTreeView::*)(const QModelIndexList )>(_a, &MyTreeView::performDrag, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->isEditing(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setEditing(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *MyTreeView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MyTreeView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MyTreeViewE_t>.strings))
        return static_cast<void*>(this);
    return QTreeView::qt_metacast(_clname);
}

int MyTreeView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTreeView::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void MyTreeView::focusView()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MyTreeView::updateDragMode(PlaylistState::ClipState _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void MyTreeView::displayBinFrame(QModelIndex _t1, int _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void MyTreeView::processDragEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void MyTreeView::selectCurrent()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void MyTreeView::editingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void MyTreeView::performDrag(const QModelIndexList _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN13SmallJobLabelE_t {};
} // unnamed namespace

template <> constexpr inline auto SmallJobLabel::qt_create_metaobjectdata<qt_meta_tag_ZN13SmallJobLabelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SmallJobLabel",
        "slotSetJobCount",
        "",
        "jobCount",
        "slotTimeLineChanged",
        "value",
        "slotTimeLineFinished"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotSetJobCount'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'slotTimeLineChanged'
        QtMocHelpers::SlotData<void(qreal)>(4, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QReal, 5 },
        }}),
        // Slot 'slotTimeLineFinished'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SmallJobLabel, qt_meta_tag_ZN13SmallJobLabelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SmallJobLabel::staticMetaObject = { {
    QMetaObject::SuperData::link<QPushButton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SmallJobLabelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SmallJobLabelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13SmallJobLabelE_t>.metaTypes,
    nullptr
} };

void SmallJobLabel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SmallJobLabel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotSetJobCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->slotTimeLineChanged((*reinterpret_cast<std::add_pointer_t<qreal>>(_a[1]))); break;
        case 2: _t->slotTimeLineFinished(); break;
        default: ;
        }
    }
}

const QMetaObject *SmallJobLabel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SmallJobLabel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13SmallJobLabelE_t>.strings))
        return static_cast<void*>(this);
    return QPushButton::qt_metacast(_clname);
}

int SmallJobLabel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QPushButton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN14LineEventEaterE_t {};
} // unnamed namespace

template <> constexpr inline auto LineEventEater::qt_create_metaobjectdata<qt_meta_tag_ZN14LineEventEaterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "LineEventEater",
        "clearSearchLine",
        "",
        "showClearButton"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'clearSearchLine'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showClearButton'
        QtMocHelpers::SignalData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<LineEventEater, qt_meta_tag_ZN14LineEventEaterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject LineEventEater::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineEventEaterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineEventEaterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14LineEventEaterE_t>.metaTypes,
    nullptr
} };

void LineEventEater::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<LineEventEater *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->clearSearchLine(); break;
        case 1: _t->showClearButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (LineEventEater::*)()>(_a, &LineEventEater::clearSearchLine, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (LineEventEater::*)(bool )>(_a, &LineEventEater::showClearButton, 1))
            return;
    }
}

const QMetaObject *LineEventEater::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *LineEventEater::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14LineEventEaterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int LineEventEater::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void LineEventEater::clearSearchLine()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void LineEventEater::showClearButton(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN3BinE_t {};
} // unnamed namespace

template <> constexpr inline auto Bin::qt_create_metaobjectdata<qt_meta_tag_ZN3BinE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Bin",
        "itemUpdated",
        "",
        "std::shared_ptr<AbstractProjectItem>",
        "producerReady",
        "id",
        "storeFolder",
        "folderId",
        "parentId",
        "oldParentId",
        "folderName",
        "gotFilterJobResults",
        "stringMap",
        "requestShowClipProperties",
        "std::shared_ptr<ProjectClip>",
        "clip",
        "forceRefresh",
        "requestClipShow",
        "displayBinMessage",
        "KMessageWidget::MessageType",
        "requesteInvalidRemoval",
        "updateAnalysisData",
        "openClip",
        "c",
        "in",
        "out",
        "QUuid",
        "sequenceUuid",
        "seekFrame",
        "findInTimeline",
        "QList<int>",
        "ids",
        "clipNameChanged",
        "refreshPanel",
        "setupTargets",
        "hasVideo",
        "QMap<int,QString>",
        "audioStreams",
        "requestBinClose",
        "updateTabName",
        "requestAddClipReset",
        "requestUpdateSequences",
        "QMap<QUuid,std::pair<int,int>>",
        "seqs",
        "slotUrlsDropped",
        "QList<QUrl>",
        "urls",
        "QModelIndex",
        "parent",
        "slotAddClip",
        "slotReloadClip",
        "slotReplaceClip",
        "slotReplaceClipInTimeline",
        "slotSetSorting",
        "slotShowColumn",
        "show",
        "ensureCurrent",
        "slotBack",
        "slotInitView",
        "QAction*",
        "action",
        "slotSetIconSize",
        "size",
        "selectProxyModel",
        "slotSaveHeaders",
        "slotResetInfoMessage",
        "slotQueryRemoval",
        "url",
        "errorMessage",
        "slotOpenCurrent",
        "slotZoomView",
        "zoomIn",
        "slotGotFocus",
        "slotRenameItem",
        "doRefreshPanel",
        "slotMessageActionTriggered",
        "slotEditClip",
        "showClearButton",
        "showBinFrame",
        "ix",
        "frame",
        "storeFrame",
        "switchTag",
        "tag",
        "add",
        "updateTags",
        "QMap<int,QStringList>",
        "previousTags",
        "tags",
        "rebuildFilters",
        "tagsCount",
        "editTags",
        "allClips",
        "updateClipsCount",
        "updateTimelineOccurrences",
        "setDefaultSequenceFolder",
        "enable",
        "setDefaultAudioCaptureFolder",
        "slotApplyFilters",
        "fromFilterButton",
        "slotOpenNewBin",
        "openClipInMonitor",
        "uuid",
        "performDrag",
        "QModelIndexList",
        "indexes",
        "slotRemoveInvalidClip",
        "replace",
        "slotDeleteClip",
        "slotItemDoubleClicked",
        "QPoint",
        "pos",
        "modifiers",
        "slotSwitchClipProperties",
        "slotAddFolder",
        "slotCreateProjectClip",
        "slotEditClipCommand",
        "QMap<QString,QString>",
        "oldProps",
        "newProps",
        "slotStartFilterJob",
        "QMap<QString,QString>&",
        "filterParams",
        "consumerParams",
        "extraParams",
        "slotItemDropped",
        "dropFromSameSource",
        "slotEffectDropped",
        "effectData",
        "slotTagDropped",
        "slotItemEdited",
        "slotOpenClipExtern",
        "slotDuplicateClip",
        "slotLocateClip",
        "showClipProperties",
        "slotAddClipExtraData",
        "key",
        "data",
        "slotUpdateClipProperties",
        "properties",
        "refreshPropertiesPanel",
        "slotAddEffect",
        "std::vector<QString>",
        "slotExpandUrl",
        "QUndoCommand*",
        "command",
        "abortOperations",
        "doDisplaySimpleMessage",
        "text",
        "type",
        "doDisplayMessage",
        "QList<QAction*>",
        "actions",
        "showCloseButton",
        "BinMessage::BinCategory",
        "messageCategory",
        "logInfo",
        "selectClipById",
        "zone",
        "activateMonitor",
        "droppedUrls",
        "folderInfo",
        "adjustProjectProfileToItem",
        "checkProjectAudioTracks",
        "clipId",
        "minimumTracksCount",
        "showTitleWidget",
        "addProjectClipInFolder",
        "path",
        "sourceClipId",
        "sourceFolder",
        "jobId",
        "addFilterToClip",
        "filterId",
        "params",
        "slotCheckProfile",
        "binId",
        "requestTranscoding",
        "TranscodeSeek::TranscodeInfo",
        "info",
        "checkProfile",
        "suffix",
        "message",
        "requestSelectionTranscoding",
        "forceReplace",
        "slotUpdatePalette",
        "processMultiStream",
        "videoStreams",
        "transcodeUsedClips"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemUpdated'
        QtMocHelpers::SignalData<void(std::shared_ptr<AbstractProjectItem>)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 },
        }}),
        // Signal 'producerReady'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'storeFolder'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::QString, 8 }, { QMetaType::QString, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'gotFilterJobResults'
        QtMocHelpers::SignalData<void(const QString &, int, int, stringMap, stringMap)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 }, { 0x80000000 | 12, 2 },
            { 0x80000000 | 12, 2 },
        }}),
        // Signal 'requestShowClipProperties'
        QtMocHelpers::SignalData<void(const std::shared_ptr<ProjectClip> &, bool)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Bool, 16 },
        }}),
        // Signal 'requestShowClipProperties'
        QtMocHelpers::SignalData<void(const std::shared_ptr<ProjectClip> &)>(13, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'requestClipShow'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 2 },
        }}),
        // Signal 'displayBinMessage'
        QtMocHelpers::SignalData<void(const QString &, KMessageWidget::MessageType)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 19, 2 },
        }}),
        // Signal 'requesteInvalidRemoval'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::QString, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'updateAnalysisData'
        QtMocHelpers::SignalData<void(const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'openClip'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>, int, int, const QUuid, int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { 0x80000000 | 26, 27 },
            { QMetaType::Int, 28 },
        }}),
        // Signal 'openClip'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>, int, int, const QUuid)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { 0x80000000 | 26, 27 },
        }}),
        // Signal 'openClip'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>, int, int)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Signal 'openClip'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>, int)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 23 }, { QMetaType::Int, 24 },
        }}),
        // Signal 'openClip'
        QtMocHelpers::SignalData<void(std::shared_ptr<ProjectClip>)>(22, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 23 },
        }}),
        // Signal 'findInTimeline'
        QtMocHelpers::SignalData<void(const QString &, QList<int>)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 30, 31 },
        }}),
        // Signal 'findInTimeline'
        QtMocHelpers::SignalData<void(const QString &)>(29, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'clipNameChanged'
        QtMocHelpers::SignalData<void(int, const QString)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'refreshPanel'
        QtMocHelpers::SignalData<void(const QString &)>(33, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Signal 'setupTargets'
        QtMocHelpers::SignalData<void(bool, QMap<int,QString>)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 35 }, { 0x80000000 | 36, 37 },
        }}),
        // Signal 'requestBinClose'
        QtMocHelpers::SignalData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateTabName'
        QtMocHelpers::SignalData<void(const QUuid &, const QString &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'requestAddClipReset'
        QtMocHelpers::SignalData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestUpdateSequences'
        QtMocHelpers::SignalData<void(QMap<QUuid,std::pair<int,int>>)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 42, 43 },
        }}),
        // Slot 'slotUrlsDropped'
        QtMocHelpers::SlotData<const QString(const QList<QUrl>, const QModelIndex)>(44, 2, QMC::AccessPublic, QMetaType::QString, {{
            { 0x80000000 | 45, 46 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotAddClip'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReloadClip'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplaceClip'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotReplaceClipInTimeline'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetSorting'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowColumn'
        QtMocHelpers::SlotData<void(bool)>(54, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 55 },
        }}),
        // Slot 'ensureCurrent'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBack'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInitView'
        QtMocHelpers::SlotData<void(QAction *)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 59, 60 },
        }}),
        // Slot 'slotSetIconSize'
        QtMocHelpers::SlotData<void(int)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 62 },
        }}),
        // Slot 'selectProxyModel'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 5 },
        }}),
        // Slot 'slotSaveHeaders'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResetInfoMessage'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotQueryRemoval'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 67 }, { QMetaType::QString, 68 },
        }}),
        // Slot 'slotOpenCurrent'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomView'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 71 },
        }}),
        // Slot 'slotGotFocus'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenameItem'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doRefreshPanel'
        QtMocHelpers::SlotData<void(const QString &)>(74, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'slotMessageActionTriggered'
        QtMocHelpers::SlotData<void()>(75, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditClip'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showClearButton'
        QtMocHelpers::SlotData<void(bool)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 55 },
        }}),
        // Slot 'showBinFrame'
        QtMocHelpers::SlotData<void(const QModelIndex &, int, bool)>(78, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 47, 79 }, { QMetaType::Int, 80 }, { QMetaType::Bool, 81 },
        }}),
        // Slot 'showBinFrame'
        QtMocHelpers::SlotData<void(const QModelIndex &, int)>(78, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 47, 79 }, { QMetaType::Int, 80 },
        }}),
        // Slot 'switchTag'
        QtMocHelpers::SlotData<void(const QString &, bool)>(82, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 83 }, { QMetaType::Bool, 84 },
        }}),
        // Slot 'updateTags'
        QtMocHelpers::SlotData<void(const QMap<int,QStringList> &, const QMap<int,QStringList> &)>(85, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 86, 87 }, { 0x80000000 | 86, 88 },
        }}),
        // Slot 'rebuildFilters'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'editTags'
        QtMocHelpers::SlotData<void(const QList<QString> &, const QString &, bool)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 92 }, { QMetaType::QString, 83 }, { QMetaType::Bool, 84 },
        }}),
        // Slot 'updateClipsCount'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTimelineOccurrences'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setDefaultSequenceFolder'
        QtMocHelpers::SlotData<void(bool)>(95, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 96 },
        }}),
        // Slot 'setDefaultAudioCaptureFolder'
        QtMocHelpers::SlotData<void(bool)>(97, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 96 },
        }}),
        // Slot 'slotApplyFilters'
        QtMocHelpers::SlotData<void(bool)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 99 },
        }}),
        // Slot 'slotApplyFilters'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotOpenNewBin'
        QtMocHelpers::SlotData<void()>(100, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'openClipInMonitor'
        QtMocHelpers::SlotData<void(std::shared_ptr<ProjectClip>, int, int, const QUuid &, int)>(101, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { 0x80000000 | 26, 102 },
            { QMetaType::Int, 28 },
        }}),
        // Slot 'openClipInMonitor'
        QtMocHelpers::SlotData<void(std::shared_ptr<ProjectClip>, int, int, const QUuid &)>(101, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 }, { 0x80000000 | 26, 102 },
        }}),
        // Slot 'openClipInMonitor'
        QtMocHelpers::SlotData<void(std::shared_ptr<ProjectClip>, int, int)>(101, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 24 }, { QMetaType::Int, 25 },
        }}),
        // Slot 'openClipInMonitor'
        QtMocHelpers::SlotData<void(std::shared_ptr<ProjectClip>, int)>(101, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Int, 24 },
        }}),
        // Slot 'openClipInMonitor'
        QtMocHelpers::SlotData<void(std::shared_ptr<ProjectClip>)>(101, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'performDrag'
        QtMocHelpers::SlotData<bool(const QModelIndexList)>(103, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 104, 105 },
        }}),
        // Slot 'slotRemoveInvalidClip'
        QtMocHelpers::SlotData<void(const QString &, bool, const QString &)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Bool, 107 }, { QMetaType::QString, 68 },
        }}),
        // Slot 'slotDeleteClip'
        QtMocHelpers::SlotData<void()>(108, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotItemDoubleClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QPoint &, uint)>(109, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 79 }, { 0x80000000 | 110, 111 }, { QMetaType::UInt, 112 },
        }}),
        // Slot 'slotSwitchClipProperties'
        QtMocHelpers::SlotData<void(const std::shared_ptr<ProjectClip> &)>(113, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotSwitchClipProperties'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddFolder'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCreateProjectClip'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditClipCommand'
        QtMocHelpers::SlotData<void(const QString &, const QMap<QString,QString> &, const QMap<QString,QString> &)>(116, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 117, 118 }, { 0x80000000 | 117, 119 },
        }}),
        // Slot 'slotStartFilterJob'
        QtMocHelpers::SlotData<void(const QString &, QMap<QString,QString> &, QMap<QString,QString> &, QMap<QString,QString> &)>(120, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 121, 122 }, { 0x80000000 | 121, 123 }, { 0x80000000 | 121, 124 },
        }}),
        // Slot 'slotItemDropped'
        QtMocHelpers::SlotData<void(const QStringList, const QModelIndex, bool)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 31 }, { 0x80000000 | 47, 48 }, { QMetaType::Bool, 126 },
        }}),
        // Slot 'slotEffectDropped'
        QtMocHelpers::SlotData<void(const QStringList &, const QModelIndex &)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 128 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotTagDropped'
        QtMocHelpers::SlotData<void(const QString &, const QModelIndex &)>(129, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 83 }, { 0x80000000 | 47, 48 },
        }}),
        // Slot 'slotItemEdited'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(130, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 47, 2 }, { 0x80000000 | 47, 2 }, { 0x80000000 | 30, 2 },
        }}),
        // Slot 'slotOpenClipExtern'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotDuplicateClip'
        QtMocHelpers::SlotData<void()>(132, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLocateClip'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showClipProperties'
        QtMocHelpers::SlotData<void(const std::shared_ptr<ProjectClip> &, bool)>(134, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 }, { QMetaType::Bool, 16 },
        }}),
        // Slot 'showClipProperties'
        QtMocHelpers::SlotData<void(const std::shared_ptr<ProjectClip> &)>(134, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'slotAddClipExtraData'
        QtMocHelpers::SlotData<void(const QString &, const QString &, const QString &)>(135, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 136 }, { QMetaType::QString, 137 },
        }}),
        // Slot 'slotAddClipExtraData'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(135, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::QString, 136 },
        }}),
        // Slot 'slotUpdateClipProperties'
        QtMocHelpers::SlotData<void(const QString &, const QMap<QString,QString> &, bool)>(138, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 117, 139 }, { QMetaType::Bool, 140 },
        }}),
        // Slot 'slotAddEffect'
        QtMocHelpers::SlotData<void(std::vector<QString>, const QStringList &)>(141, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 142, 31 }, { QMetaType::QStringList, 128 },
        }}),
        // Slot 'slotExpandUrl'
        QtMocHelpers::SlotData<void(const QString &, QUndoCommand *)>(143, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 67 }, { 0x80000000 | 144, 145 },
        }}),
        // Slot 'abortOperations'
        QtMocHelpers::SlotData<void()>(146, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doDisplaySimpleMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType)>(147, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 },
        }}),
        // Slot 'doDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType, const QList<QAction*> &, bool, BinMessage::BinCategory)>(150, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 }, { 0x80000000 | 151, 152 }, { QMetaType::Bool, 153 },
            { 0x80000000 | 154, 155 },
        }}),
        // Slot 'doDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType, const QList<QAction*> &, bool)>(150, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 }, { 0x80000000 | 151, 152 }, { QMetaType::Bool, 153 },
        }}),
        // Slot 'doDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType, const QList<QAction*> &)>(150, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 }, { 0x80000000 | 151, 152 },
        }}),
        // Slot 'doDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType)>(150, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 },
        }}),
        // Slot 'doDisplayMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType, const QString)>(150, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 148 }, { 0x80000000 | 19, 149 }, { QMetaType::QString, 156 },
        }}),
        // Slot 'selectClipById'
        QtMocHelpers::SlotData<void(const QString &, int, const QPoint &, bool)>(157, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 80 }, { 0x80000000 | 110, 158 }, { QMetaType::Bool, 159 },
        }}),
        // Slot 'selectClipById'
        QtMocHelpers::SlotData<void(const QString &, int, const QPoint &)>(157, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 80 }, { 0x80000000 | 110, 158 },
        }}),
        // Slot 'selectClipById'
        QtMocHelpers::SlotData<void(const QString &, int)>(157, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Int, 80 },
        }}),
        // Slot 'selectClipById'
        QtMocHelpers::SlotData<void(const QString &)>(157, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 },
        }}),
        // Slot 'droppedUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &, const QString &)>(160, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 45, 46 }, { QMetaType::QString, 161 },
        }}),
        // Slot 'droppedUrls'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(160, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 45, 46 },
        }}),
        // Slot 'adjustProjectProfileToItem'
        QtMocHelpers::SlotData<void()>(162, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkProjectAudioTracks'
        QtMocHelpers::SlotData<void(QString, int)>(163, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 164 }, { QMetaType::Int, 165 },
        }}),
        // Slot 'showTitleWidget'
        QtMocHelpers::SlotData<void(const std::shared_ptr<ProjectClip> &)>(166, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Slot 'addProjectClipInFolder'
        QtMocHelpers::SlotData<bool(const QString &, const QString &, const QString &, const QString &)>(167, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 168 }, { QMetaType::QString, 169 }, { QMetaType::QString, 170 }, { QMetaType::QString, 171 },
        }}),
        // Slot 'addFilterToClip'
        QtMocHelpers::SlotData<void(const QString &, const QString &, stringMap)>(172, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 169 }, { QMetaType::QString, 173 }, { 0x80000000 | 12, 174 },
        }}),
        // Slot 'slotCheckProfile'
        QtMocHelpers::SlotData<void(const QString &)>(175, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 176 },
        }}),
        // Slot 'requestTranscoding'
        QtMocHelpers::SlotData<void(const QString &, TranscodeSeek::TranscodeInfo, bool, const QString &, const QString &)>(177, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 178, 179 }, { QMetaType::Bool, 180 }, { QMetaType::QString, 181 },
            { QMetaType::QString, 182 },
        }}),
        // Slot 'requestTranscoding'
        QtMocHelpers::SlotData<void(const QString &, TranscodeSeek::TranscodeInfo, bool, const QString &)>(177, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 178, 179 }, { QMetaType::Bool, 180 }, { QMetaType::QString, 181 },
        }}),
        // Slot 'requestTranscoding'
        QtMocHelpers::SlotData<void(const QString &, TranscodeSeek::TranscodeInfo, bool)>(177, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { 0x80000000 | 178, 179 }, { QMetaType::Bool, 180 },
        }}),
        // Slot 'requestSelectionTranscoding'
        QtMocHelpers::SlotData<void(bool)>(183, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 184 },
        }}),
        // Slot 'requestSelectionTranscoding'
        QtMocHelpers::SlotData<void()>(183, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotUpdatePalette'
        QtMocHelpers::SlotData<void()>(185, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'processMultiStream'
        QtMocHelpers::SlotData<void(const QString &, QList<int>, QList<int>)>(186, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 164 }, { 0x80000000 | 30, 187 }, { 0x80000000 | 30, 37 },
        }}),
        // Slot 'transcodeUsedClips'
        QtMocHelpers::SlotData<void()>(188, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Bin, qt_meta_tag_ZN3BinE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Bin::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3BinE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3BinE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3BinE_t>.metaTypes,
    nullptr
} };

void Bin::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Bin *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemUpdated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AbstractProjectItem>>>(_a[1]))); break;
        case 1: _t->producerReady((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->storeFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->gotFilterJobResults((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<stringMap>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<stringMap>>(_a[5]))); break;
        case 4: _t->requestShowClipProperties((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->requestShowClipProperties((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 6: _t->requestClipShow((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 7: _t->displayBinMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 8: _t->requesteInvalidRemoval((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 9: _t->updateAnalysisData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->openClip((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 11: _t->openClip((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[4]))); break;
        case 12: _t->openClip((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 13: _t->openClip((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 14: _t->openClip((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 15: _t->findInTimeline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 16: _t->findInTimeline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->clipNameChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 18: _t->refreshPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->setupTargets((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<int,QString>>>(_a[2]))); break;
        case 20: _t->requestBinClose(); break;
        case 21: _t->updateTabName((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->requestAddClipReset(); break;
        case 23: _t->requestUpdateSequences((*reinterpret_cast<std::add_pointer_t<QMap<QUuid,std::pair<int,int>>>>(_a[1]))); break;
        case 24: { QString _r = _t->slotUrlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->slotAddClip(); break;
        case 26: _t->slotReloadClip(); break;
        case 27: _t->slotReplaceClip(); break;
        case 28: _t->slotReplaceClipInTimeline(); break;
        case 29: _t->slotSetSorting(); break;
        case 30: _t->slotShowColumn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 31: _t->ensureCurrent(); break;
        case 32: _t->slotBack(); break;
        case 33: _t->slotInitView((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 34: _t->slotSetIconSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 35: _t->selectProxyModel((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 36: _t->slotSaveHeaders(); break;
        case 37: _t->slotResetInfoMessage(); break;
        case 38: _t->slotQueryRemoval((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 39: _t->slotOpenCurrent(); break;
        case 40: _t->slotZoomView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->slotGotFocus(); break;
        case 42: _t->slotRenameItem(); break;
        case 43: _t->doRefreshPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 44: _t->slotMessageActionTriggered(); break;
        case 45: _t->slotEditClip(); break;
        case 46: _t->showClearButton((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->showBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 48: _t->showBinFrame((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 49: _t->switchTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 50: _t->updateTags((*reinterpret_cast<std::add_pointer_t<QMap<int,QStringList>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<int,QStringList>>>(_a[2]))); break;
        case 51: _t->rebuildFilters((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->editTags((*reinterpret_cast<std::add_pointer_t<QList<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 53: _t->updateClipsCount(); break;
        case 54: _t->updateTimelineOccurrences(); break;
        case 55: _t->setDefaultSequenceFolder((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 56: _t->setDefaultAudioCaptureFolder((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 57: _t->slotApplyFilters((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 58: _t->slotApplyFilters(); break;
        case 59: _t->slotOpenNewBin(); break;
        case 60: _t->openClipInMonitor((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 61: _t->openClipInMonitor((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[4]))); break;
        case 62: _t->openClipInMonitor((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 63: _t->openClipInMonitor((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 64: _t->openClipInMonitor((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 65: { bool _r = _t->performDrag((*reinterpret_cast<std::add_pointer_t<QModelIndexList>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 66: _t->slotRemoveInvalidClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 67: _t->slotDeleteClip(); break;
        case 68: _t->slotItemDoubleClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 69: _t->slotSwitchClipProperties((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 70: _t->slotSwitchClipProperties(); break;
        case 71: _t->slotAddFolder(); break;
        case 72: _t->slotCreateProjectClip(); break;
        case 73: _t->slotEditClipCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3]))); break;
        case 74: _t->slotStartFilterJob((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[4]))); break;
        case 75: _t->slotItemDropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 76: _t->slotEffectDropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 77: _t->slotTagDropped((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 78: _t->slotItemEdited((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 79: _t->slotOpenClipExtern(); break;
        case 80: _t->slotDuplicateClip(); break;
        case 81: _t->slotLocateClip(); break;
        case 82: _t->showClipProperties((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 83: _t->showClipProperties((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 84: _t->slotAddClipExtraData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 85: _t->slotAddClipExtraData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 86: _t->slotUpdateClipProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 87: _t->slotAddEffect((*reinterpret_cast<std::add_pointer_t<std::vector<QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 88: _t->slotExpandUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUndoCommand*>>(_a[2]))); break;
        case 89: _t->abortOperations(); break;
        case 90: _t->doDisplaySimpleMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 91: _t->doDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BinMessage::BinCategory>>(_a[5]))); break;
        case 92: _t->doDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 93: _t->doDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3]))); break;
        case 94: _t->doDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 95: _t->doDisplayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 96: _t->selectClipById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 97: _t->selectClipById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[3]))); break;
        case 98: _t->selectClipById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 99: _t->selectClipById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 100: _t->droppedUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 101: _t->droppedUrls((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 102: _t->adjustProjectProfileToItem(); break;
        case 103: _t->checkProjectAudioTracks((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 104: _t->showTitleWidget((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<ProjectClip>>>(_a[1]))); break;
        case 105: { bool _r = _t->addProjectClipInFolder((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 106: _t->addFilterToClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<stringMap>>(_a[3]))); break;
        case 107: _t->slotCheckProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 108: _t->requestTranscoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TranscodeSeek::TranscodeInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5]))); break;
        case 109: _t->requestTranscoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TranscodeSeek::TranscodeInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 110: _t->requestTranscoding((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<TranscodeSeek::TranscodeInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 111: _t->requestSelectionTranscoding((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 112: _t->requestSelectionTranscoding(); break;
        case 113: _t->slotUpdatePalette(); break;
        case 114: _t->processMultiStream((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 115: _t->transcodeUsedClips(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 15:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 33:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 65:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QModelIndexList >(); break;
            }
            break;
        case 78:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 91:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 92:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 93:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 114:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(std::shared_ptr<AbstractProjectItem> )>(_a, &Bin::itemUpdated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & )>(_a, &Bin::producerReady, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & , const QString & , const QString & , const QString & )>(_a, &Bin::storeFolder, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & , int , int , stringMap , stringMap )>(_a, &Bin::gotFilterJobResults, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const std::shared_ptr<ProjectClip> & , bool )>(_a, &Bin::requestShowClipProperties, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(std::shared_ptr<ProjectClip> )>(_a, &Bin::requestClipShow, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & , KMessageWidget::MessageType )>(_a, &Bin::displayBinMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & , const QString & , const QString & )>(_a, &Bin::requesteInvalidRemoval, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & )>(_a, &Bin::updateAnalysisData, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(std::shared_ptr<ProjectClip> , int , int , const QUuid , int )>(_a, &Bin::openClip, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & , QList<int> )>(_a, &Bin::findInTimeline, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(int , const QString )>(_a, &Bin::clipNameChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QString & )>(_a, &Bin::refreshPanel, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(bool , QMap<int,QString> )>(_a, &Bin::setupTargets, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)()>(_a, &Bin::requestBinClose, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(const QUuid & , const QString & )>(_a, &Bin::updateTabName, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)()>(_a, &Bin::requestAddClipReset, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Bin::*)(QMap<QUuid,std::pair<int,int>> )>(_a, &Bin::requestUpdateSequences, 23))
            return;
    }
}

const QMetaObject *Bin::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Bin::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3BinE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Bin::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 116)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 116;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 116)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 116;
    }
    return _id;
}

// SIGNAL 0
void Bin::itemUpdated(std::shared_ptr<AbstractProjectItem> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void Bin::producerReady(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void Bin::storeFolder(const QString & _t1, const QString & _t2, const QString & _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void Bin::gotFilterJobResults(const QString & _t1, int _t2, int _t3, stringMap _t4, stringMap _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 4
void Bin::requestShowClipProperties(const std::shared_ptr<ProjectClip> & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 6
void Bin::requestClipShow(std::shared_ptr<ProjectClip> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Bin::displayBinMessage(const QString & _t1, KMessageWidget::MessageType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void Bin::requesteInvalidRemoval(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2, _t3);
}

// SIGNAL 9
void Bin::updateAnalysisData(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void Bin::openClip(std::shared_ptr<ProjectClip> _t1, int _t2, int _t3, const QUuid _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 15
void Bin::findInTimeline(const QString & _t1, QList<int> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 17
void Bin::clipNameChanged(int _t1, const QString _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2);
}

// SIGNAL 18
void Bin::refreshPanel(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Bin::setupTargets(bool _t1, QMap<int,QString> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1, _t2);
}

// SIGNAL 20
void Bin::requestBinClose()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Bin::updateTabName(const QUuid & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1, _t2);
}

// SIGNAL 22
void Bin::requestAddClipReset()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void Bin::requestUpdateSequences(QMap<QUuid,std::pair<int,int>> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1);
}
QT_WARNING_POP
