/****************************************************************************
** Meta object code from reading C++ file 'resourcewidget.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/onlineresources/resourcewidget.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'resourcewidget.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ResourceWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto ResourceWidget::qt_create_metaobjectdata<qt_meta_tag_ZN14ResourceWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ResourceWidget",
        "addClip",
        "",
        "QUrl",
        "addLicenseInfo",
        "previewClip",
        "path",
        "title",
        "gotPixmap",
        "url",
        "QPixmap",
        "pix",
        "slotChangeProvider",
        "slotOpenUrl",
        "slotStartSearch",
        "slotLoadImages",
        "slotShowPixmap",
        "pixmap",
        "slotSearchFinished",
        "QList<ResourceItemInfo>",
        "list",
        "pageCount",
        "slotDisplayError",
        "message",
        "slotUpdateCurrentItem",
        "slotSetIconSize",
        "size",
        "slotPreviewItem",
        "slotChooseVersion",
        "urls",
        "labels",
        "accessToken",
        "slotSaveItem",
        "originalUrl",
        "slotGotFile",
        "KJob*",
        "job",
        "slotAccessTokenReceived",
        "abortDownload"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addClip'
        QtMocHelpers::SignalData<void(const QUrl &, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { QMetaType::QString, 2 },
        }}),
        // Signal 'addLicenseInfo'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'previewClip'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 }, { QMetaType::QString, 7 },
        }}),
        // Signal 'gotPixmap'
        QtMocHelpers::SignalData<void(const QString &, const QPixmap &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'slotChangeProvider'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOpenUrl'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 },
        }}),
        // Slot 'slotStartSearch'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadImages'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowPixmap'
        QtMocHelpers::SlotData<void(const QString &, const QPixmap &)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 9 }, { 0x80000000 | 10, 17 },
        }}),
        // Slot 'slotSearchFinished'
        QtMocHelpers::SlotData<void(const QList<ResourceItemInfo> &, const int)>(18, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 19, 20 }, { QMetaType::Int, 21 },
        }}),
        // Slot 'slotDisplayError'
        QtMocHelpers::SlotData<void(const QString &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 23 },
        }}),
        // Slot 'slotUpdateCurrentItem'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetIconSize'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'slotPreviewItem'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotChooseVersion'
        QtMocHelpers::SlotData<void(const QStringList &, const QStringList &, const QString &)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 29 }, { QMetaType::QStringList, 30 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'slotChooseVersion'
        QtMocHelpers::SlotData<void(const QStringList &, const QStringList &)>(28, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 29 }, { QMetaType::QStringList, 30 },
        }}),
        // Slot 'slotSaveItem'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::QString, 31 },
        }}),
        // Slot 'slotSaveItem'
        QtMocHelpers::SlotData<void(const QString &)>(32, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Slot 'slotSaveItem'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotGotFile'
        QtMocHelpers::SlotData<void(KJob *)>(34, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Slot 'slotAccessTokenReceived'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 31 },
        }}),
        // Slot 'abortDownload'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ResourceWidget, qt_meta_tag_ZN14ResourceWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ResourceWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourceWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourceWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ResourceWidgetE_t>.metaTypes,
    nullptr
} };

void ResourceWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ResourceWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addClip((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->addLicenseInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->previewClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->gotPixmap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 4: _t->slotChangeProvider(); break;
        case 5: _t->slotOpenUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->slotStartSearch(); break;
        case 7: _t->slotLoadImages(); break;
        case 8: _t->slotShowPixmap((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QPixmap>>(_a[2]))); break;
        case 9: _t->slotSearchFinished((*reinterpret_cast<std::add_pointer_t<QList<ResourceItemInfo>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 10: _t->slotDisplayError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->slotUpdateCurrentItem(); break;
        case 12: _t->slotSetIconSize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->slotPreviewItem(); break;
        case 14: _t->slotChooseVersion((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 15: _t->slotChooseVersion((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 16: _t->slotSaveItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 17: _t->slotSaveItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->slotSaveItem(); break;
        case 19: _t->slotGotFile((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 20: _t->slotAccessTokenReceived((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 21: _t->abortDownload(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< KJob* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ResourceWidget::*)(const QUrl & , const QString & )>(_a, &ResourceWidget::addClip, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceWidget::*)(const QString & )>(_a, &ResourceWidget::addLicenseInfo, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceWidget::*)(const QString & , const QString & )>(_a, &ResourceWidget::previewClip, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ResourceWidget::*)(const QString & , const QPixmap & )>(_a, &ResourceWidget::gotPixmap, 3))
            return;
    }
}

const QMetaObject *ResourceWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ResourceWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ResourceWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ResourceWidget_UI"))
        return static_cast< Ui::ResourceWidget_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int ResourceWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 22)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 22;
    }
    return _id;
}

// SIGNAL 0
void ResourceWidget::addClip(const QUrl & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void ResourceWidget::addLicenseInfo(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ResourceWidget::previewClip(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void ResourceWidget::gotPixmap(const QString & _t1, const QPixmap & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}
QT_WARNING_POP
