/********************************************************************************
** Form generated from reading UI file 'cliptranscode_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPTRANSCODE_UI_H
#define UI_CLIPTRANSCODE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ClipTranscode_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QProgressBar *job_progress;
    KComboBox *profile_list;
    QDialogButtonBox *buttonBox;
    QLabel *ffmpeg_label;
    QListWidget *urls_list;
    QLabel *label_4;
    KUrlRequester *source_url;
    QLabel *label_dest;
    QTextEdit *log_text;
    QLabel *label_source;
    QPlainTextEdit *ffmpeg_params;
    QCheckBox *auto_close;
    QLabel *transcode_info;
    QPushButton *button_start;
    QLabel *label_profile;
    QCheckBox *auto_add;
    KUrlRequester *dest_url;

    void setupUi(QDialog *ClipTranscode_UI)
    {
        if (ClipTranscode_UI->objectName().isEmpty())
            ClipTranscode_UI->setObjectName("ClipTranscode_UI");
        ClipTranscode_UI->resize(574, 802);
        gridLayout = new QGridLayout(ClipTranscode_UI);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 11, 2, 1, 1);

        job_progress = new QProgressBar(ClipTranscode_UI);
        job_progress->setObjectName("job_progress");
        job_progress->setValue(0);

        gridLayout->addWidget(job_progress, 7, 2, 1, 2);

        profile_list = new KComboBox(ClipTranscode_UI);
        profile_list->setObjectName("profile_list");

        gridLayout->addWidget(profile_list, 3, 2, 1, 2);

        buttonBox = new QDialogButtonBox(ClipTranscode_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Abort);

        gridLayout->addWidget(buttonBox, 11, 3, 1, 1);

        ffmpeg_label = new QLabel(ClipTranscode_UI);
        ffmpeg_label->setObjectName("ffmpeg_label");

        gridLayout->addWidget(ffmpeg_label, 5, 0, 1, 4);

        urls_list = new QListWidget(ClipTranscode_UI);
        urls_list->setObjectName("urls_list");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(urls_list->sizePolicy().hasHeightForWidth());
        urls_list->setSizePolicy(sizePolicy);
        urls_list->setAlternatingRowColors(true);

        gridLayout->addWidget(urls_list, 2, 0, 1, 4);

        label_4 = new QLabel(ClipTranscode_UI);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 7, 0, 1, 1);

        source_url = new KUrlRequester(ClipTranscode_UI);
        source_url->setObjectName("source_url");

        gridLayout->addWidget(source_url, 0, 1, 1, 3);

        label_dest = new QLabel(ClipTranscode_UI);
        label_dest->setObjectName("label_dest");

        gridLayout->addWidget(label_dest, 1, 0, 1, 1);

        log_text = new QTextEdit(ClipTranscode_UI);
        log_text->setObjectName("log_text");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(log_text->sizePolicy().hasHeightForWidth());
        log_text->setSizePolicy(sizePolicy1);
        log_text->setReadOnly(true);

        gridLayout->addWidget(log_text, 8, 0, 1, 4);

        label_source = new QLabel(ClipTranscode_UI);
        label_source->setObjectName("label_source");

        gridLayout->addWidget(label_source, 0, 0, 1, 1);

        ffmpeg_params = new QPlainTextEdit(ClipTranscode_UI);
        ffmpeg_params->setObjectName("ffmpeg_params");
        sizePolicy1.setHeightForWidth(ffmpeg_params->sizePolicy().hasHeightForWidth());
        ffmpeg_params->setSizePolicy(sizePolicy1);
        ffmpeg_params->setReadOnly(true);

        gridLayout->addWidget(ffmpeg_params, 6, 0, 1, 4);

        auto_close = new QCheckBox(ClipTranscode_UI);
        auto_close->setObjectName("auto_close");
        auto_close->setChecked(true);

        gridLayout->addWidget(auto_close, 9, 3, 1, 1);

        transcode_info = new QLabel(ClipTranscode_UI);
        transcode_info->setObjectName("transcode_info");
        transcode_info->setFrameShape(QFrame::StyledPanel);
        transcode_info->setFrameShadow(QFrame::Raised);

        gridLayout->addWidget(transcode_info, 4, 0, 1, 4);

        button_start = new QPushButton(ClipTranscode_UI);
        button_start->setObjectName("button_start");

        gridLayout->addWidget(button_start, 11, 0, 1, 1);

        label_profile = new QLabel(ClipTranscode_UI);
        label_profile->setObjectName("label_profile");

        gridLayout->addWidget(label_profile, 3, 0, 1, 1);

        auto_add = new QCheckBox(ClipTranscode_UI);
        auto_add->setObjectName("auto_add");

        gridLayout->addWidget(auto_add, 9, 0, 1, 3);

        dest_url = new KUrlRequester(ClipTranscode_UI);
        dest_url->setObjectName("dest_url");

        gridLayout->addWidget(dest_url, 1, 1, 1, 3);


        retranslateUi(ClipTranscode_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ClipTranscode_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipTranscode_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClipTranscode_UI);
    } // setupUi

    void retranslateUi(QDialog *ClipTranscode_UI)
    {
        ClipTranscode_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        job_progress->setFormat(tr2i18n("%p%", nullptr));
        ffmpeg_label->setText(tr2i18n("FFmpeg parameters", nullptr));
        label_4->setText(tr2i18n("Job status", nullptr));
        label_dest->setText(tr2i18n("Destination", nullptr));
        label_source->setText(tr2i18n("Source", nullptr));
        auto_close->setText(tr2i18n("Close after transcode", nullptr));
        button_start->setText(tr2i18n("Start", "@action:button start transcode"));
        label_profile->setText(tr2i18n("Profile", nullptr));
        auto_add->setText(tr2i18n("Add clip to project", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClipTranscode_UI: public Ui_ClipTranscode_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLIPTRANSCODE_UI_H

