/********************************************************************************
** Form generated from reading UI file 'manageencodingprofile_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGEENCODINGPROFILE_UI_H
#define UI_MANAGEENCODINGPROFILE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_ManageEncodingProfile_UI
{
public:
    QGridLayout *gridLayout;
    QLabel *label;
    KComboBox *profile_type;
    QListWidget *profile_list;
    QPlainTextEdit *profile_parameters;
    QToolButton *button_add;
    QToolButton *button_edit;
    QToolButton *button_delete;
    QToolButton *button_download;
    QSpacerItem *horizontalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ManageEncodingProfile_UI)
    {
        if (ManageEncodingProfile_UI->objectName().isEmpty())
            ManageEncodingProfile_UI->setObjectName("ManageEncodingProfile_UI");
        ManageEncodingProfile_UI->resize(444, 337);
        gridLayout = new QGridLayout(ManageEncodingProfile_UI);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(ManageEncodingProfile_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 4);

        profile_type = new KComboBox(ManageEncodingProfile_UI);
        profile_type->setObjectName("profile_type");

        gridLayout->addWidget(profile_type, 0, 4, 1, 2);

        profile_list = new QListWidget(ManageEncodingProfile_UI);
        profile_list->setObjectName("profile_list");
        profile_list->setAlternatingRowColors(true);

        gridLayout->addWidget(profile_list, 1, 0, 1, 6);

        profile_parameters = new QPlainTextEdit(ManageEncodingProfile_UI);
        profile_parameters->setObjectName("profile_parameters");
        profile_parameters->setReadOnly(true);

        gridLayout->addWidget(profile_parameters, 2, 0, 1, 6);

        button_add = new QToolButton(ManageEncodingProfile_UI);
        button_add->setObjectName("button_add");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-add");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_add->setIcon(icon);

        gridLayout->addWidget(button_add, 3, 0, 1, 1);

        button_edit = new QToolButton(ManageEncodingProfile_UI);
        button_edit->setObjectName("button_edit");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("document-edit");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_edit->setIcon(icon1);

        gridLayout->addWidget(button_edit, 3, 1, 1, 1);

        button_delete = new QToolButton(ManageEncodingProfile_UI);
        button_delete->setObjectName("button_delete");
        QIcon icon2;
        iconThemeName = QString::fromUtf8("edit-delete");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_delete->setIcon(icon2);

        gridLayout->addWidget(button_delete, 3, 2, 1, 1);

        button_download = new QToolButton(ManageEncodingProfile_UI);
        button_download->setObjectName("button_download");
        button_download->setEnabled(false);
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("download")));
        button_download->setIcon(icon3);

        gridLayout->addWidget(button_download, 3, 3, 1, 1);

        horizontalSpacer = new QSpacerItem(155, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 3, 4, 1, 1);

        buttonBox = new QDialogButtonBox(ManageEncodingProfile_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 3, 5, 1, 1);


        retranslateUi(ManageEncodingProfile_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ManageEncodingProfile_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ManageEncodingProfile_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ManageEncodingProfile_UI);
    } // setupUi

    void retranslateUi(QDialog *ManageEncodingProfile_UI)
    {
        ManageEncodingProfile_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label->setText(tr2i18n("Editing profiles for:", nullptr));
        button_add->setText(tr2i18n("...", nullptr));
        button_edit->setText(tr2i18n("...", nullptr));
        button_delete->setText(tr2i18n("...", nullptr));
        button_download->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ManageEncodingProfile_UI: public Ui_ManageEncodingProfile_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // MANAGEENCODINGPROFILE_UI_H

