/********************************************************************************
** Form generated from reading UI file 'configtimeline_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTIMELINE_UI_H
#define UI_CONFIGTIMELINE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigTimeline_UI
{
public:
    QFormLayout *formLayout;
    QLabel *label_3;
    QCheckBox *kcfg_videothumbnails;
    QCheckBox *kcfg_audiothumbnails;
    QCheckBox *kcfg_displayallchannels;
    QFrame *line_2;
    QLabel *label_5;
    QCheckBox *kcfg_pauseonseek;
    QCheckBox *kcfg_jumptostart;
    QCheckBox *kcfg_seekonaddeffect;
    QFrame *line_3;
    QLabel *label_7;
    QFrame *line_4;
    QLabel *label_4;
    QCheckBox *kcfg_autoscroll;
    QCheckBox *kcfg_centeredplayhead;
    QCheckBox *kcfg_scrollvertically;
    QFrame *line;
    QCheckBox *kcfg_showmarkers;
    QLabel *label;
    QSpinBox *kcfg_trackheight;
    QGroupBox *groupBox_3;
    QGridLayout *gridLayout_4;
    QComboBox *kcfg_multistream;
    QLabel *label_2;
    QCheckBox *kcfg_multistream_checktrack;
    QLabel *label_6;
    QCheckBox *kcfg_uiDebugMode;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_2;
    QCheckBox *kcfg_raisepropscompositions;
    QCheckBox *kcfg_raisepropstracks;
    QCheckBox *kcfg_raisepropsclips;
    QCheckBox *kcfg_raisepropsmixes;

    void setupUi(QWidget *ConfigTimeline_UI)
    {
        if (ConfigTimeline_UI->objectName().isEmpty())
            ConfigTimeline_UI->setObjectName("ConfigTimeline_UI");
        ConfigTimeline_UI->resize(907, 646);
        formLayout = new QFormLayout(ConfigTimeline_UI);
        formLayout->setObjectName("formLayout");
        label_3 = new QLabel(ConfigTimeline_UI);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_videothumbnails = new QCheckBox(ConfigTimeline_UI);
        kcfg_videothumbnails->setObjectName("kcfg_videothumbnails");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_videothumbnails);

        kcfg_audiothumbnails = new QCheckBox(ConfigTimeline_UI);
        kcfg_audiothumbnails->setObjectName("kcfg_audiothumbnails");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_audiothumbnails);

        kcfg_displayallchannels = new QCheckBox(ConfigTimeline_UI);
        kcfg_displayallchannels->setObjectName("kcfg_displayallchannels");
        kcfg_displayallchannels->setEnabled(false);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_displayallchannels);

        line_2 = new QFrame(ConfigTimeline_UI);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, line_2);

        label_5 = new QLabel(ConfigTimeline_UI);
        label_5->setObjectName("label_5");

        formLayout->setWidget(4, QFormLayout::ItemRole::LabelRole, label_5);

        kcfg_pauseonseek = new QCheckBox(ConfigTimeline_UI);
        kcfg_pauseonseek->setObjectName("kcfg_pauseonseek");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_pauseonseek);

        kcfg_jumptostart = new QCheckBox(ConfigTimeline_UI);
        kcfg_jumptostart->setObjectName("kcfg_jumptostart");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_jumptostart);

        kcfg_seekonaddeffect = new QCheckBox(ConfigTimeline_UI);
        kcfg_seekonaddeffect->setObjectName("kcfg_seekonaddeffect");

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_seekonaddeffect);

        line_3 = new QFrame(ConfigTimeline_UI);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(7, QFormLayout::ItemRole::SpanningRole, line_3);

        label_7 = new QLabel(ConfigTimeline_UI);
        label_7->setObjectName("label_7");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_7);

        line_4 = new QFrame(ConfigTimeline_UI);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(9, QFormLayout::ItemRole::SpanningRole, line_4);

        label_4 = new QLabel(ConfigTimeline_UI);
        label_4->setObjectName("label_4");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_4);

        kcfg_autoscroll = new QCheckBox(ConfigTimeline_UI);
        kcfg_autoscroll->setObjectName("kcfg_autoscroll");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, kcfg_autoscroll);

        kcfg_centeredplayhead = new QCheckBox(ConfigTimeline_UI);
        kcfg_centeredplayhead->setObjectName("kcfg_centeredplayhead");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_centeredplayhead);

        kcfg_scrollvertically = new QCheckBox(ConfigTimeline_UI);
        kcfg_scrollvertically->setObjectName("kcfg_scrollvertically");

        formLayout->setWidget(12, QFormLayout::ItemRole::FieldRole, kcfg_scrollvertically);

        line = new QFrame(ConfigTimeline_UI);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(13, QFormLayout::ItemRole::SpanningRole, line);

        kcfg_showmarkers = new QCheckBox(ConfigTimeline_UI);
        kcfg_showmarkers->setObjectName("kcfg_showmarkers");

        formLayout->setWidget(16, QFormLayout::ItemRole::FieldRole, kcfg_showmarkers);

        label = new QLabel(ConfigTimeline_UI);
        label->setObjectName("label");

        formLayout->setWidget(17, QFormLayout::ItemRole::LabelRole, label);

        kcfg_trackheight = new QSpinBox(ConfigTimeline_UI);
        kcfg_trackheight->setObjectName("kcfg_trackheight");
        kcfg_trackheight->setMinimum(0);
        kcfg_trackheight->setMaximum(999);
        kcfg_trackheight->setValue(10);

        formLayout->setWidget(17, QFormLayout::ItemRole::FieldRole, kcfg_trackheight);

        groupBox_3 = new QGroupBox(ConfigTimeline_UI);
        groupBox_3->setObjectName("groupBox_3");
        gridLayout_4 = new QGridLayout(groupBox_3);
        gridLayout_4->setObjectName("gridLayout_4");
        kcfg_multistream = new QComboBox(groupBox_3);
        kcfg_multistream->addItem(QString());
        kcfg_multistream->addItem(QString());
        kcfg_multistream->addItem(QString());
        kcfg_multistream->setObjectName("kcfg_multistream");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_multistream->sizePolicy().hasHeightForWidth());
        kcfg_multistream->setSizePolicy(sizePolicy);

        gridLayout_4->addWidget(kcfg_multistream, 0, 1, 1, 1);

        label_2 = new QLabel(groupBox_3);
        label_2->setObjectName("label_2");

        gridLayout_4->addWidget(label_2, 0, 0, 1, 1);

        kcfg_multistream_checktrack = new QCheckBox(groupBox_3);
        kcfg_multistream_checktrack->setObjectName("kcfg_multistream_checktrack");

        gridLayout_4->addWidget(kcfg_multistream_checktrack, 1, 0, 1, 2);


        formLayout->setWidget(19, QFormLayout::ItemRole::SpanningRole, groupBox_3);

        label_6 = new QLabel(ConfigTimeline_UI);
        label_6->setObjectName("label_6");

        formLayout->setWidget(20, QFormLayout::ItemRole::LabelRole, label_6);

        kcfg_uiDebugMode = new QCheckBox(ConfigTimeline_UI);
        kcfg_uiDebugMode->setObjectName("kcfg_uiDebugMode");

        formLayout->setWidget(20, QFormLayout::ItemRole::FieldRole, kcfg_uiDebugMode);

        verticalSpacer = new QSpacerItem(20, 23, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(21, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        groupBox_2 = new QGroupBox(ConfigTimeline_UI);
        groupBox_2->setObjectName("groupBox_2");
        gridLayout_2 = new QGridLayout(groupBox_2);
        gridLayout_2->setObjectName("gridLayout_2");
        kcfg_raisepropscompositions = new QCheckBox(groupBox_2);
        kcfg_raisepropscompositions->setObjectName("kcfg_raisepropscompositions");

        gridLayout_2->addWidget(kcfg_raisepropscompositions, 0, 1, 1, 1);

        kcfg_raisepropstracks = new QCheckBox(groupBox_2);
        kcfg_raisepropstracks->setObjectName("kcfg_raisepropstracks");

        gridLayout_2->addWidget(kcfg_raisepropstracks, 0, 3, 1, 1);

        kcfg_raisepropsclips = new QCheckBox(groupBox_2);
        kcfg_raisepropsclips->setObjectName("kcfg_raisepropsclips");

        gridLayout_2->addWidget(kcfg_raisepropsclips, 0, 0, 1, 1);

        kcfg_raisepropsmixes = new QCheckBox(groupBox_2);
        kcfg_raisepropsmixes->setObjectName("kcfg_raisepropsmixes");

        gridLayout_2->addWidget(kcfg_raisepropsmixes, 0, 2, 1, 1);


        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, groupBox_2);

        QWidget::setTabOrder(kcfg_videothumbnails, kcfg_audiothumbnails);
        QWidget::setTabOrder(kcfg_audiothumbnails, kcfg_displayallchannels);
        QWidget::setTabOrder(kcfg_displayallchannels, kcfg_pauseonseek);
        QWidget::setTabOrder(kcfg_pauseonseek, kcfg_jumptostart);
        QWidget::setTabOrder(kcfg_jumptostart, kcfg_seekonaddeffect);
        QWidget::setTabOrder(kcfg_seekonaddeffect, kcfg_raisepropsclips);
        QWidget::setTabOrder(kcfg_raisepropsclips, kcfg_raisepropscompositions);
        QWidget::setTabOrder(kcfg_raisepropscompositions, kcfg_raisepropsmixes);
        QWidget::setTabOrder(kcfg_raisepropsmixes, kcfg_raisepropstracks);
        QWidget::setTabOrder(kcfg_raisepropstracks, kcfg_autoscroll);
        QWidget::setTabOrder(kcfg_autoscroll, kcfg_centeredplayhead);
        QWidget::setTabOrder(kcfg_centeredplayhead, kcfg_scrollvertically);
        QWidget::setTabOrder(kcfg_scrollvertically, kcfg_showmarkers);
        QWidget::setTabOrder(kcfg_showmarkers, kcfg_trackheight);
        QWidget::setTabOrder(kcfg_trackheight, kcfg_multistream);
        QWidget::setTabOrder(kcfg_multistream, kcfg_multistream_checktrack);
        QWidget::setTabOrder(kcfg_multistream_checktrack, kcfg_uiDebugMode);

        retranslateUi(ConfigTimeline_UI);
        QObject::connect(kcfg_audiothumbnails, &QCheckBox::toggled, kcfg_displayallchannels, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(ConfigTimeline_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigTimeline_UI)
    {
        label_3->setText(tr2i18n("Thumbnails:", nullptr));
        kcfg_videothumbnails->setText(tr2i18n("Enable for Video", nullptr));
        kcfg_audiothumbnails->setText(tr2i18n("Enable for Audio", nullptr));
        kcfg_displayallchannels->setText(tr2i18n("Separate audio channels", nullptr));
        label_5->setText(tr2i18n("Playback and Seeking:", nullptr));
        kcfg_pauseonseek->setText(tr2i18n("Pause playback when seeking", nullptr));
        kcfg_jumptostart->setText(tr2i18n("Jump to timeline start if playback is started on last frame in timeline", nullptr));
        kcfg_seekonaddeffect->setText(tr2i18n("Seek to clip when adding effect", nullptr));
        label_7->setText(tr2i18n("On Selection:", nullptr));
        label_4->setText(tr2i18n("Scrolling:", nullptr));
        kcfg_autoscroll->setText(tr2i18n("Autoscroll while playing", nullptr));
        kcfg_centeredplayhead->setText(tr2i18n("Fixed centered playhead", nullptr));
        kcfg_scrollvertically->setText(tr2i18n("Scroll vertically with scroll wheel, horizontally with Shift + scroll wheel", nullptr));
        kcfg_showmarkers->setText(tr2i18n("Display clip markers comments", nullptr));
        label->setText(tr2i18n("Default track height:", nullptr));
        groupBox_3->setTitle(tr2i18n("Multi Stream Audio Clips", nullptr));
        kcfg_multistream->setItemText(0, tr2i18n("All Audio Streams", nullptr));
        kcfg_multistream->setItemText(1, tr2i18n("First Audio Stream", nullptr));
        kcfg_multistream->setItemText(2, tr2i18n("First 2 Audio Streams", nullptr));

        label_2->setText(tr2i18n("On import, enable:", nullptr));
        kcfg_multistream_checktrack->setText(tr2i18n("Check if project contains enough tracks", nullptr));
        label_6->setText(tr2i18n("Developer:", nullptr));
        kcfg_uiDebugMode->setText(tr2i18n("Enable debug mode", nullptr));
        groupBox_2->setTitle(tr2i18n("Raise Effects/Composition Stack for", nullptr));
        kcfg_raisepropscompositions->setText(tr2i18n("Compositions", nullptr));
        kcfg_raisepropstracks->setText(tr2i18n("Tracks", nullptr));
        kcfg_raisepropsclips->setText(tr2i18n("Clips", nullptr));
        kcfg_raisepropsmixes->setText(tr2i18n("Mixes", nullptr));
        (void)ConfigTimeline_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigTimeline_UI: public Ui_ConfigTimeline_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGTIMELINE_UI_H

