/********************************************************************************
** Form generated from reading UI file 'configtranscode_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTRANSCODE_UI_H
#define UI_CONFIGTRANSCODE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_ConfigTranscode_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *horizontalSpacer;
    QListWidget *profiles_list;
    QGroupBox *profile_box;
    QGridLayout *gridLayout_2;
    QLineEdit *profile_extension;
    QLabel *label_2;
    QPlainTextEdit *profile_parameters;
    QLineEdit *profile_description;
    QLabel *label_3;
    QCheckBox *profile_audioonly;
    QLabel *label_4;
    QPushButton *button_add;
    QPushButton *button_update;
    QPushButton *button_delete;

    void setupUi(QWidget *ConfigTranscode_UI)
    {
        if (ConfigTranscode_UI->objectName().isEmpty())
            ConfigTranscode_UI->setObjectName("ConfigTranscode_UI");
        ConfigTranscode_UI->resize(364, 348);
        gridLayout = new QGridLayout(ConfigTranscode_UI);
        gridLayout->setObjectName("gridLayout");
        horizontalSpacer = new QSpacerItem(213, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 2, 3, 1, 1);

        profiles_list = new QListWidget(ConfigTranscode_UI);
        profiles_list->setObjectName("profiles_list");
        profiles_list->setAlternatingRowColors(true);

        gridLayout->addWidget(profiles_list, 0, 0, 1, 4);

        profile_box = new QGroupBox(ConfigTranscode_UI);
        profile_box->setObjectName("profile_box");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Maximum);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(profile_box->sizePolicy().hasHeightForWidth());
        profile_box->setSizePolicy(sizePolicy);
        gridLayout_2 = new QGridLayout(profile_box);
        gridLayout_2->setObjectName("gridLayout_2");
        profile_extension = new QLineEdit(profile_box);
        profile_extension->setObjectName("profile_extension");

        gridLayout_2->addWidget(profile_extension, 1, 1, 1, 1);

        label_2 = new QLabel(profile_box);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 0, 0, 1, 1);

        profile_parameters = new QPlainTextEdit(profile_box);
        profile_parameters->setObjectName("profile_parameters");

        gridLayout_2->addWidget(profile_parameters, 3, 0, 1, 3);

        profile_description = new QLineEdit(profile_box);
        profile_description->setObjectName("profile_description");

        gridLayout_2->addWidget(profile_description, 0, 1, 1, 2);

        label_3 = new QLabel(profile_box);
        label_3->setObjectName("label_3");

        gridLayout_2->addWidget(label_3, 1, 0, 1, 1);

        profile_audioonly = new QCheckBox(profile_box);
        profile_audioonly->setObjectName("profile_audioonly");

        gridLayout_2->addWidget(profile_audioonly, 1, 2, 1, 1);

        label_4 = new QLabel(profile_box);
        label_4->setObjectName("label_4");

        gridLayout_2->addWidget(label_4, 2, 0, 1, 3);


        gridLayout->addWidget(profile_box, 1, 0, 1, 4);

        button_add = new QPushButton(ConfigTranscode_UI);
        button_add->setObjectName("button_add");

        gridLayout->addWidget(button_add, 2, 0, 1, 1);

        button_update = new QPushButton(ConfigTranscode_UI);
        button_update->setObjectName("button_update");

        gridLayout->addWidget(button_update, 2, 1, 1, 1);

        button_delete = new QPushButton(ConfigTranscode_UI);
        button_delete->setObjectName("button_delete");

        gridLayout->addWidget(button_delete, 2, 2, 1, 1);

        QWidget::setTabOrder(profiles_list, profile_description);
        QWidget::setTabOrder(profile_description, profile_extension);
        QWidget::setTabOrder(profile_extension, profile_audioonly);
        QWidget::setTabOrder(profile_audioonly, profile_parameters);
        QWidget::setTabOrder(profile_parameters, button_add);
        QWidget::setTabOrder(button_add, button_update);
        QWidget::setTabOrder(button_update, button_delete);

        retranslateUi(ConfigTranscode_UI);

        QMetaObject::connectSlotsByName(ConfigTranscode_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigTranscode_UI)
    {
        profile_box->setTitle(QString());
        label_2->setText(tr2i18n("Description:", nullptr));
        label_3->setText(tr2i18n("Extension:", nullptr));
        profile_audioonly->setText(tr2i18n("Audio only", nullptr));
        label_4->setText(tr2i18n("Parameters", nullptr));
        button_add->setText(tr2i18n("Add Profile\342\200\246", nullptr));
        button_update->setText(tr2i18n("Update Profile", nullptr));
        button_delete->setText(tr2i18n("Delete Profile", nullptr));
        (void)ConfigTranscode_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigTranscode_UI: public Ui_ConfigTranscode_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGTRANSCODE_UI_H

