/********************************************************************************
** Form generated from reading UI file 'textbasededit_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TEXTBASEDEDIT_UI_H
#define UI_TEXTBASEDEDIT_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kseparator.h"
#include "ksqueezedtextlabel.h"

QT_BEGIN_NAMESPACE

class Ui_TextBasedEdit_UI
{
public:
    QGridLayout *gridLayout_2;
    QFrame *frame_progress;
    QHBoxLayout *horizontalLayout;
    QToolButton *button_abort;
    QProgressBar *speech_progress;
    QHBoxLayout *horizontalLayout_2;
    QToolButton *button_config;
    QComboBox *language_box;
    QCheckBox *speech_zone;
    QSpacerItem *horizontalSpacer;
    QPushButton *button_start;
    KSqueezedTextLabel *clipNameLabel;
    QFrame *edit_frame;
    QGridLayout *gridLayout;
    QToolButton *button_remove_silence;
    QSpacerItem *horizontalSpacer_3;
    QToolButton *button_insert;
    QToolButton *button_bookmark;
    QToolButton *button_font_more;
    QToolButton *button_font_less;
    KSeparator *kseparator;
    QToolButton *button_delete;
    QToolButton *button_search;
    QFrame *search_frame;
    QGridLayout *gridLayout_3;
    QToolButton *search_prev;
    QLineEdit *search_line;
    QToolButton *search_next;
    KMessageWidget *info_message;
    QFrame *text_frame;

    void setupUi(QWidget *TextBasedEdit_UI)
    {
        if (TextBasedEdit_UI->objectName().isEmpty())
            TextBasedEdit_UI->setObjectName("TextBasedEdit_UI");
        TextBasedEdit_UI->resize(463, 285);
        gridLayout_2 = new QGridLayout(TextBasedEdit_UI);
        gridLayout_2->setObjectName("gridLayout_2");
        frame_progress = new QFrame(TextBasedEdit_UI);
        frame_progress->setObjectName("frame_progress");
        frame_progress->setFrameShape(QFrame::Shape::NoFrame);
        frame_progress->setFrameShadow(QFrame::Shadow::Plain);
        horizontalLayout = new QHBoxLayout(frame_progress);
        horizontalLayout->setObjectName("horizontalLayout");
        horizontalLayout->setContentsMargins(0, 0, 0, 0);
        button_abort = new QToolButton(frame_progress);
        button_abort->setObjectName("button_abort");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("process-stop")));
        button_abort->setIcon(icon);
        button_abort->setAutoRaise(true);

        horizontalLayout->addWidget(button_abort);

        speech_progress = new QProgressBar(frame_progress);
        speech_progress->setObjectName("speech_progress");
        speech_progress->setValue(24);

        horizontalLayout->addWidget(speech_progress);


        gridLayout_2->addWidget(frame_progress, 3, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        button_config = new QToolButton(TextBasedEdit_UI);
        button_config->setObjectName("button_config");
        button_config->setPopupMode(QToolButton::ToolButtonPopupMode::InstantPopup);
        button_config->setAutoRaise(true);

        horizontalLayout_2->addWidget(button_config);

        language_box = new QComboBox(TextBasedEdit_UI);
        language_box->setObjectName("language_box");

        horizontalLayout_2->addWidget(language_box);

        speech_zone = new QCheckBox(TextBasedEdit_UI);
        speech_zone->setObjectName("speech_zone");

        horizontalLayout_2->addWidget(speech_zone);

        horizontalSpacer = new QSpacerItem(0, 0, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer);

        button_start = new QPushButton(TextBasedEdit_UI);
        button_start->setObjectName("button_start");

        horizontalLayout_2->addWidget(button_start);


        gridLayout_2->addLayout(horizontalLayout_2, 6, 0, 1, 1);

        clipNameLabel = new KSqueezedTextLabel(TextBasedEdit_UI);
        clipNameLabel->setObjectName("clipNameLabel");

        gridLayout_2->addWidget(clipNameLabel, 0, 0, 1, 1);

        edit_frame = new QFrame(TextBasedEdit_UI);
        edit_frame->setObjectName("edit_frame");
        edit_frame->setFrameShape(QFrame::Shape::NoFrame);
        edit_frame->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout = new QGridLayout(edit_frame);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        button_remove_silence = new QToolButton(edit_frame);
        button_remove_silence->setObjectName("button_remove_silence");
        button_remove_silence->setAutoRaise(true);

        gridLayout->addWidget(button_remove_silence, 0, 4, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 10, 1, 1);

        button_insert = new QToolButton(edit_frame);
        button_insert->setObjectName("button_insert");
        button_insert->setPopupMode(QToolButton::ToolButtonPopupMode::MenuButtonPopup);
        button_insert->setAutoRaise(true);
        button_insert->setArrowType(Qt::ArrowType::NoArrow);

        gridLayout->addWidget(button_insert, 0, 1, 1, 1);

        button_bookmark = new QToolButton(edit_frame);
        button_bookmark->setObjectName("button_bookmark");
        button_bookmark->setAutoRaise(true);

        gridLayout->addWidget(button_bookmark, 0, 2, 1, 1);

        button_font_more = new QToolButton(edit_frame);
        button_font_more->setObjectName("button_font_more");
        button_font_more->setAutoRaise(true);

        gridLayout->addWidget(button_font_more, 0, 7, 1, 1);

        button_font_less = new QToolButton(edit_frame);
        button_font_less->setObjectName("button_font_less");
        button_font_less->setAutoRaise(true);

        gridLayout->addWidget(button_font_less, 0, 8, 1, 1);

        kseparator = new KSeparator(edit_frame);
        kseparator->setObjectName("kseparator");
        kseparator->setFrameShape(QFrame::Shape::VLine);

        gridLayout->addWidget(kseparator, 0, 6, 1, 1);

        button_delete = new QToolButton(edit_frame);
        button_delete->setObjectName("button_delete");
        button_delete->setAutoRaise(true);

        gridLayout->addWidget(button_delete, 0, 3, 1, 1);

        button_search = new QToolButton(edit_frame);
        button_search->setObjectName("button_search");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-find")));
        button_search->setIcon(icon1);
        button_search->setCheckable(true);
        button_search->setAutoRaise(true);

        gridLayout->addWidget(button_search, 0, 5, 1, 1);


        gridLayout_2->addWidget(edit_frame, 4, 0, 1, 1);

        search_frame = new QFrame(TextBasedEdit_UI);
        search_frame->setObjectName("search_frame");
        search_frame->setFrameShape(QFrame::Shape::StyledPanel);
        search_frame->setFrameShadow(QFrame::Shadow::Raised);
        gridLayout_3 = new QGridLayout(search_frame);
        gridLayout_3->setObjectName("gridLayout_3");
        search_prev = new QToolButton(search_frame);
        search_prev->setObjectName("search_prev");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("go-up")));
        search_prev->setIcon(icon2);

        gridLayout_3->addWidget(search_prev, 0, 1, 1, 1);

        search_line = new QLineEdit(search_frame);
        search_line->setObjectName("search_line");
        search_line->setClearButtonEnabled(true);

        gridLayout_3->addWidget(search_line, 0, 0, 1, 1);

        search_next = new QToolButton(search_frame);
        search_next->setObjectName("search_next");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("go-down")));
        search_next->setIcon(icon3);

        gridLayout_3->addWidget(search_next, 0, 2, 1, 1);


        gridLayout_2->addWidget(search_frame, 5, 0, 1, 1);

        info_message = new KMessageWidget(TextBasedEdit_UI);
        info_message->setObjectName("info_message");
        info_message->setWordWrap(true);

        gridLayout_2->addWidget(info_message, 2, 0, 1, 1);

        text_frame = new QFrame(TextBasedEdit_UI);
        text_frame->setObjectName("text_frame");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(text_frame->sizePolicy().hasHeightForWidth());
        text_frame->setSizePolicy(sizePolicy);
        text_frame->setFrameShape(QFrame::Shape::NoFrame);
        text_frame->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout_2->addWidget(text_frame, 1, 0, 1, 2);


        retranslateUi(TextBasedEdit_UI);

        QMetaObject::connectSlotsByName(TextBasedEdit_UI);
    } // setupUi

    void retranslateUi(QWidget *TextBasedEdit_UI)
    {
        button_abort->setText(tr2i18n("...", nullptr));
        speech_progress->setFormat(tr2i18n("%p%", nullptr));
        button_config->setText(tr2i18n("...", nullptr));
        speech_zone->setText(tr2i18n("Selected zone only", nullptr));
        button_start->setText(tr2i18n("Transcribe", nullptr));
        button_remove_silence->setText(tr2i18n("...", nullptr));
        button_insert->setText(tr2i18n("...", nullptr));
        button_bookmark->setText(tr2i18n("...", nullptr));
        button_font_more->setText(tr2i18n("...", nullptr));
        button_font_less->setText(tr2i18n("...", nullptr));
        button_delete->setText(tr2i18n("...", nullptr));
        button_search->setText(tr2i18n("...", nullptr));
        search_prev->setText(tr2i18n("...", nullptr));
        search_line->setPlaceholderText(tr2i18n("Search", nullptr));
        search_next->setText(tr2i18n("...", nullptr));
        (void)TextBasedEdit_UI;
    } // retranslateUi

};

namespace Ui {
    class TextBasedEdit_UI: public Ui_TextBasedEdit_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TEXTBASEDEDIT_UI_H

