/********************************************************************************
** Form generated from reading UI file 'configspeech_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGSPEECH_UI_H
#define UI_CONFIGSPEECH_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QStackedWidget>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"
#include "kmessagewidget.h"
#include "kurlrequester.h"
#include "widgets/elidedfilelinklabel.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigSpeech_UI
{
public:
    QVBoxLayout *verticalLayout_4;
    QTabWidget *tabWidget;
    QWidget *tab;
    QGridLayout *gridLayout_2;
    QPushButton *check_config;
    QSpacerItem *verticalSpacer;
    QHBoxLayout *horizontalLayout;
    QLabel *label_2;
    QRadioButton *engine_vosk;
    QRadioButton *engine_whisper;
    QSpacerItem *horizontalSpacer_2;
    QStackedWidget *speech_stack;
    QWidget *page;
    QGridLayout *gridLayout;
    KUrlRequester *vosk_folder;
    QHBoxLayout *horizontalLayout_3;
    ElidedFileLinkLabel *modelV_folder_label;
    QSpacerItem *horizontalSpacer_4;
    QLabel *modelV_size;
    KMessageWidget *speech_info;
    QPushButton *button_delete;
    QPushButton *button_add;
    QFrame *list_frame;
    QCheckBox *custom_vosk_folder;
    QLabel *models_url;
    QVBoxLayout *message_layout;
    QSpacerItem *verticalSpacer_3;
    QWidget *page_2;
    QGridLayout *gridLayout_5;
    QHBoxLayout *horizontalLayout_6;
    QSpacerItem *horizontalSpacer_6;
    ElidedFileLinkLabel *seamless_folder_label;
    QLabel *seamless_folder_size;
    QGroupBox *whisper_venv_params;
    QVBoxLayout *verticalLayout_2;
    QHBoxLayout *horizontalLayout_9;
    ElidedFileLinkLabel *wr_venv_label;
    QLabel *wr_venv_size;
    QPushButton *deleteWrVenv;
    QSpacerItem *horizontalSpacer_12;
    QHBoxLayout *seamless_layout;
    QPushButton *install_seamless;
    KContextualHelpButton *seamless_device_info;
    QHBoxLayout *horizontalLayout_2;
    QSpacerItem *horizontalSpacer_3;
    ElidedFileLinkLabel *whisper_folder_label;
    QLabel *whisper_model_size;
    QGroupBox *whispersettings;
    QFormLayout *formLayout;
    QLabel *label_3;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *combo_wr_model;
    QPushButton *downloadButton;
    QSpacerItem *horizontalSpacer_5;
    KMessageWidget *noModelMessage;
    QLabel *label_4;
    QComboBox *combo_wr_lang;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout_5;
    QComboBox *combo_wr_device;
    KContextualHelpButton *whisper_device_info;
    QSpacerItem *horizontalSpacer_8;
    QPushButton *install_nvidia_wr;
    QCheckBox *kcfg_whisperDisableFP16;
    QCheckBox *kcfg_whisperTranslate;
    QVBoxLayout *message_layout_wr;
    QGroupBox *speech_system_params;
    QVBoxLayout *verticalLayout_3;
    KMessageWidget *speech_system_python_message;
    KUrlRequester *speech_system_python_path;
    QPlainTextEdit *script_log;
    QSpacerItem *horizontalSpacer;
    QHBoxLayout *horizontalLayout_12;
    QCheckBox *kcfg_speech_system_python;
    KContextualHelpButton *kcontextualhelpbutton_4;
    QSpacerItem *horizontalSpacer_11;
    QSpacerItem *verticalSpacer_4;
    QWidget *tab_2;
    QGridLayout *gridLayout_7;
    QGroupBox *modelBox;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout_10;
    QComboBox *combo_sam_device;
    KContextualHelpButton *sam_device_info;
    QSpacerItem *horizontalSpacer_7;
    QPushButton *install_nvidia_sam;
    QLabel *label;
    QHBoxLayout *horizontalLayout_7;
    QCheckBox *kcfg_sam_offload_video;
    KContextualHelpButton *kcontextualhelpbutton_3;
    QSpacerItem *horizontalSpacer_14;
    QLabel *label_6;
    QHBoxLayout *horizontalLayout_8;
    QComboBox *combo_sam_model;
    QPushButton *downloadSamButton;
    KContextualHelpButton *kcontextualhelpbutton;
    QGroupBox *sam_venv_params;
    QGridLayout *gridLayout_6;
    QSpacerItem *horizontalSpacer_10;
    QLabel *sam_venv_size;
    ElidedFileLinkLabel *sam_folder_label;
    QPushButton *deleteSamModels;
    QPushButton *deleteSamVenv;
    QSpacerItem *verticalSpacer_2;
    ElidedFileLinkLabel *sam_venv_label;
    QLabel *sam_model_size;
    QPlainTextEdit *script_sam_log;
    QToolButton *sam_rebuild;
    QSpacerItem *horizontalSpacer_9;
    QVBoxLayout *message_layout_sam;
    QGroupBox *sam_system_params;
    QVBoxLayout *verticalLayout;
    KMessageWidget *system_python_message;
    KUrlRequester *sam_system_python_path;
    QHBoxLayout *horizontalLayout_11;
    QCheckBox *kcfg_sam_system_python;
    KContextualHelpButton *kcontextualhelpbutton_2;
    QSpacerItem *horizontalSpacer_13;

    void setupUi(QWidget *ConfigSpeech_UI)
    {
        if (ConfigSpeech_UI->objectName().isEmpty())
            ConfigSpeech_UI->setObjectName("ConfigSpeech_UI");
        ConfigSpeech_UI->resize(436, 769);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(ConfigSpeech_UI->sizePolicy().hasHeightForWidth());
        ConfigSpeech_UI->setSizePolicy(sizePolicy);
        verticalLayout_4 = new QVBoxLayout(ConfigSpeech_UI);
        verticalLayout_4->setObjectName("verticalLayout_4");
        tabWidget = new QTabWidget(ConfigSpeech_UI);
        tabWidget->setObjectName("tabWidget");
        tab = new QWidget();
        tab->setObjectName("tab");
        gridLayout_2 = new QGridLayout(tab);
        gridLayout_2->setObjectName("gridLayout_2");
        check_config = new QPushButton(tab);
        check_config->setObjectName("check_config");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        check_config->setIcon(icon);

        gridLayout_2->addWidget(check_config, 6, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 7, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label_2 = new QLabel(tab);
        label_2->setObjectName("label_2");

        horizontalLayout->addWidget(label_2);

        engine_vosk = new QRadioButton(tab);
        engine_vosk->setObjectName("engine_vosk");

        horizontalLayout->addWidget(engine_vosk);

        engine_whisper = new QRadioButton(tab);
        engine_whisper->setObjectName("engine_whisper");

        horizontalLayout->addWidget(engine_whisper);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout->addItem(horizontalSpacer_2);


        gridLayout_2->addLayout(horizontalLayout, 0, 0, 1, 2);

        speech_stack = new QStackedWidget(tab);
        speech_stack->setObjectName("speech_stack");
        page = new QWidget();
        page->setObjectName("page");
        gridLayout = new QGridLayout(page);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        vosk_folder = new KUrlRequester(page);
        vosk_folder->setObjectName("vosk_folder");
        vosk_folder->setEnabled(false);

        gridLayout->addWidget(vosk_folder, 2, 0, 1, 3);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        modelV_folder_label = new ElidedFileLinkLabel(page);
        modelV_folder_label->setObjectName("modelV_folder_label");
        modelV_folder_label->setProperty("link", QVariant(QString::fromUtf8("")));

        horizontalLayout_3->addWidget(modelV_folder_label);

        horizontalSpacer_4 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_4);

        modelV_size = new QLabel(page);
        modelV_size->setObjectName("modelV_size");

        horizontalLayout_3->addWidget(modelV_size);


        gridLayout->addLayout(horizontalLayout_3, 6, 0, 1, 3);

        speech_info = new KMessageWidget(page);
        speech_info->setObjectName("speech_info");

        gridLayout->addWidget(speech_info, 8, 0, 1, 3);

        button_delete = new QPushButton(page);
        button_delete->setObjectName("button_delete");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("edit-delete")));
        button_delete->setIcon(icon1);

        gridLayout->addWidget(button_delete, 4, 1, 1, 2);

        button_add = new QPushButton(page);
        button_add->setObjectName("button_add");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("list-add")));
        button_add->setIcon(icon2);

        gridLayout->addWidget(button_add, 3, 1, 1, 2);

        list_frame = new QFrame(page);
        list_frame->setObjectName("list_frame");
        sizePolicy.setHeightForWidth(list_frame->sizePolicy().hasHeightForWidth());
        list_frame->setSizePolicy(sizePolicy);
        list_frame->setFrameShape(QFrame::Shape::NoFrame);
        list_frame->setFrameShadow(QFrame::Shadow::Raised);

        gridLayout->addWidget(list_frame, 3, 0, 2, 1);

        custom_vosk_folder = new QCheckBox(page);
        custom_vosk_folder->setObjectName("custom_vosk_folder");

        gridLayout->addWidget(custom_vosk_folder, 1, 0, 1, 1);

        models_url = new QLabel(page);
        models_url->setObjectName("models_url");
        models_url->setWordWrap(true);

        gridLayout->addWidget(models_url, 0, 0, 1, 3);

        message_layout = new QVBoxLayout();
        message_layout->setSpacing(0);
        message_layout->setObjectName("message_layout");

        gridLayout->addLayout(message_layout, 7, 0, 1, 3);

        verticalSpacer_3 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer_3, 9, 0, 1, 1);

        speech_stack->addWidget(page);
        page_2 = new QWidget();
        page_2->setObjectName("page_2");
        gridLayout_5 = new QGridLayout(page_2);
        gridLayout_5->setObjectName("gridLayout_5");
        gridLayout_5->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_6 = new QHBoxLayout();
        horizontalLayout_6->setObjectName("horizontalLayout_6");
        horizontalSpacer_6 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_6->addItem(horizontalSpacer_6);

        seamless_folder_label = new ElidedFileLinkLabel(page_2);
        seamless_folder_label->setObjectName("seamless_folder_label");
        seamless_folder_label->setMinimumSize(QSize(40, 0));
        seamless_folder_label->setProperty("link", QVariant(QString::fromUtf8("")));

        horizontalLayout_6->addWidget(seamless_folder_label);

        seamless_folder_size = new QLabel(page_2);
        seamless_folder_size->setObjectName("seamless_folder_size");

        horizontalLayout_6->addWidget(seamless_folder_size);


        gridLayout_5->addLayout(horizontalLayout_6, 3, 0, 1, 1);

        whisper_venv_params = new QGroupBox(page_2);
        whisper_venv_params->setObjectName("whisper_venv_params");
        whisper_venv_params->setFlat(true);
        verticalLayout_2 = new QVBoxLayout(whisper_venv_params);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_9 = new QHBoxLayout();
        horizontalLayout_9->setObjectName("horizontalLayout_9");
        wr_venv_label = new ElidedFileLinkLabel(whisper_venv_params);
        wr_venv_label->setObjectName("wr_venv_label");
        wr_venv_label->setMinimumSize(QSize(40, 0));

        horizontalLayout_9->addWidget(wr_venv_label);

        wr_venv_size = new QLabel(whisper_venv_params);
        wr_venv_size->setObjectName("wr_venv_size");

        horizontalLayout_9->addWidget(wr_venv_size);

        deleteWrVenv = new QPushButton(whisper_venv_params);
        deleteWrVenv->setObjectName("deleteWrVenv");
        deleteWrVenv->setIcon(icon1);

        horizontalLayout_9->addWidget(deleteWrVenv);

        horizontalSpacer_12 = new QSpacerItem(118, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_9->addItem(horizontalSpacer_12);


        verticalLayout_2->addLayout(horizontalLayout_9);

        seamless_layout = new QHBoxLayout();
        seamless_layout->setObjectName("seamless_layout");
        install_seamless = new QPushButton(whisper_venv_params);
        install_seamless->setObjectName("install_seamless");

        seamless_layout->addWidget(install_seamless);

        seamless_device_info = new KContextualHelpButton(whisper_venv_params);
        seamless_device_info->setObjectName("seamless_device_info");

        seamless_layout->addWidget(seamless_device_info);


        verticalLayout_2->addLayout(seamless_layout);


        gridLayout_5->addWidget(whisper_venv_params, 4, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_2->addItem(horizontalSpacer_3);

        whisper_folder_label = new ElidedFileLinkLabel(page_2);
        whisper_folder_label->setObjectName("whisper_folder_label");
        sizePolicy.setHeightForWidth(whisper_folder_label->sizePolicy().hasHeightForWidth());
        whisper_folder_label->setSizePolicy(sizePolicy);
        whisper_folder_label->setMinimumSize(QSize(40, 0));
        whisper_folder_label->setProperty("link", QVariant(QString::fromUtf8("")));

        horizontalLayout_2->addWidget(whisper_folder_label);

        whisper_model_size = new QLabel(page_2);
        whisper_model_size->setObjectName("whisper_model_size");

        horizontalLayout_2->addWidget(whisper_model_size);


        gridLayout_5->addLayout(horizontalLayout_2, 2, 0, 1, 1);

        whispersettings = new QGroupBox(page_2);
        whispersettings->setObjectName("whispersettings");
        whispersettings->setFlat(true);
        formLayout = new QFormLayout(whispersettings);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, 0, 0, 0);
        label_3 = new QLabel(whispersettings);
        label_3->setObjectName("label_3");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_3);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        combo_wr_model = new QComboBox(whispersettings);
        combo_wr_model->setObjectName("combo_wr_model");

        horizontalLayout_4->addWidget(combo_wr_model);

        downloadButton = new QPushButton(whispersettings);
        downloadButton->setObjectName("downloadButton");

        horizontalLayout_4->addWidget(downloadButton);

        horizontalSpacer_5 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_4->addItem(horizontalSpacer_5);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout_4);

        noModelMessage = new KMessageWidget(whispersettings);
        noModelMessage->setObjectName("noModelMessage");
        noModelMessage->setCloseButtonVisible(false);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, noModelMessage);

        label_4 = new QLabel(whispersettings);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        combo_wr_lang = new QComboBox(whispersettings);
        combo_wr_lang->setObjectName("combo_wr_lang");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, combo_wr_lang);

        label_5 = new QLabel(whispersettings);
        label_5->setObjectName("label_5");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout_5 = new QHBoxLayout();
        horizontalLayout_5->setObjectName("horizontalLayout_5");
        combo_wr_device = new QComboBox(whispersettings);
        combo_wr_device->setObjectName("combo_wr_device");
        combo_wr_device->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_5->addWidget(combo_wr_device);

        whisper_device_info = new KContextualHelpButton(whispersettings);
        whisper_device_info->setObjectName("whisper_device_info");

        horizontalLayout_5->addWidget(whisper_device_info);

        horizontalSpacer_8 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_5->addItem(horizontalSpacer_8);

        install_nvidia_wr = new QPushButton(whispersettings);
        install_nvidia_wr->setObjectName("install_nvidia_wr");

        horizontalLayout_5->addWidget(install_nvidia_wr);


        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, horizontalLayout_5);

        kcfg_whisperDisableFP16 = new QCheckBox(whispersettings);
        kcfg_whisperDisableFP16->setObjectName("kcfg_whisperDisableFP16");

        formLayout->setWidget(4, QFormLayout::ItemRole::FieldRole, kcfg_whisperDisableFP16);

        kcfg_whisperTranslate = new QCheckBox(whispersettings);
        kcfg_whisperTranslate->setObjectName("kcfg_whisperTranslate");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_whisperTranslate);


        gridLayout_5->addWidget(whispersettings, 0, 0, 1, 1);

        message_layout_wr = new QVBoxLayout();
        message_layout_wr->setSpacing(0);
        message_layout_wr->setObjectName("message_layout_wr");
        message_layout_wr->setContentsMargins(-1, 0, -1, -1);

        gridLayout_5->addLayout(message_layout_wr, 1, 0, 1, 1);

        speech_stack->addWidget(page_2);

        gridLayout_2->addWidget(speech_stack, 1, 0, 1, 2);

        speech_system_params = new QGroupBox(tab);
        speech_system_params->setObjectName("speech_system_params");
        speech_system_params->setMinimumSize(QSize(0, 0));
        speech_system_params->setFlat(true);
        verticalLayout_3 = new QVBoxLayout(speech_system_params);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        speech_system_python_message = new KMessageWidget(speech_system_params);
        speech_system_python_message->setObjectName("speech_system_python_message");
        speech_system_python_message->setWordWrap(true);
        speech_system_python_message->setCloseButtonVisible(false);
        speech_system_python_message->setMessageType(KMessageWidget::MessageType::Warning);

        verticalLayout_3->addWidget(speech_system_python_message);

        speech_system_python_path = new KUrlRequester(speech_system_params);
        speech_system_python_path->setObjectName("speech_system_python_path");

        verticalLayout_3->addWidget(speech_system_python_path);


        gridLayout_2->addWidget(speech_system_params, 3, 0, 1, 2);

        script_log = new QPlainTextEdit(tab);
        script_log->setObjectName("script_log");
        script_log->setFrameShape(QFrame::Shape::NoFrame);
        script_log->setUndoRedoEnabled(false);
        script_log->setReadOnly(true);

        gridLayout_2->addWidget(script_log, 4, 0, 1, 2);

        horizontalSpacer = new QSpacerItem(280, 31, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 6, 1, 1, 1);

        horizontalLayout_12 = new QHBoxLayout();
        horizontalLayout_12->setObjectName("horizontalLayout_12");
        kcfg_speech_system_python = new QCheckBox(tab);
        kcfg_speech_system_python->setObjectName("kcfg_speech_system_python");

        horizontalLayout_12->addWidget(kcfg_speech_system_python);

        kcontextualhelpbutton_4 = new KContextualHelpButton(tab);
        kcontextualhelpbutton_4->setObjectName("kcontextualhelpbutton_4");

        horizontalLayout_12->addWidget(kcontextualhelpbutton_4);

        horizontalSpacer_11 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_12->addItem(horizontalSpacer_11);


        gridLayout_2->addLayout(horizontalLayout_12, 2, 0, 1, 2);

        verticalSpacer_4 = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer_4, 5, 0, 1, 1);

        tabWidget->addTab(tab, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_7 = new QGridLayout(tab_2);
        gridLayout_7->setObjectName("gridLayout_7");
        gridLayout_7->setContentsMargins(0, 0, 0, 0);
        modelBox = new QGroupBox(tab_2);
        modelBox->setObjectName("modelBox");
        modelBox->setFlat(true);
        gridLayout_3 = new QGridLayout(modelBox);
        gridLayout_3->setObjectName("gridLayout_3");
        gridLayout_3->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_10 = new QHBoxLayout();
        horizontalLayout_10->setObjectName("horizontalLayout_10");
        combo_sam_device = new QComboBox(modelBox);
        combo_sam_device->setObjectName("combo_sam_device");
        combo_sam_device->setSizeAdjustPolicy(QComboBox::SizeAdjustPolicy::AdjustToContents);

        horizontalLayout_10->addWidget(combo_sam_device);

        sam_device_info = new KContextualHelpButton(modelBox);
        sam_device_info->setObjectName("sam_device_info");

        horizontalLayout_10->addWidget(sam_device_info);

        horizontalSpacer_7 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_10->addItem(horizontalSpacer_7);

        install_nvidia_sam = new QPushButton(modelBox);
        install_nvidia_sam->setObjectName("install_nvidia_sam");
        install_nvidia_sam->setEnabled(true);

        horizontalLayout_10->addWidget(install_nvidia_sam);


        gridLayout_3->addLayout(horizontalLayout_10, 1, 1, 1, 1);

        label = new QLabel(modelBox);
        label->setObjectName("label");

        gridLayout_3->addWidget(label, 0, 0, 1, 1);

        horizontalLayout_7 = new QHBoxLayout();
        horizontalLayout_7->setObjectName("horizontalLayout_7");
        kcfg_sam_offload_video = new QCheckBox(modelBox);
        kcfg_sam_offload_video->setObjectName("kcfg_sam_offload_video");

        horizontalLayout_7->addWidget(kcfg_sam_offload_video);

        kcontextualhelpbutton_3 = new KContextualHelpButton(modelBox);
        kcontextualhelpbutton_3->setObjectName("kcontextualhelpbutton_3");

        horizontalLayout_7->addWidget(kcontextualhelpbutton_3);

        horizontalSpacer_14 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_7->addItem(horizontalSpacer_14);


        gridLayout_3->addLayout(horizontalLayout_7, 2, 0, 1, 2);

        label_6 = new QLabel(modelBox);
        label_6->setObjectName("label_6");

        gridLayout_3->addWidget(label_6, 1, 0, 1, 1);

        horizontalLayout_8 = new QHBoxLayout();
        horizontalLayout_8->setObjectName("horizontalLayout_8");
        combo_sam_model = new QComboBox(modelBox);
        combo_sam_model->setObjectName("combo_sam_model");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(combo_sam_model->sizePolicy().hasHeightForWidth());
        combo_sam_model->setSizePolicy(sizePolicy1);

        horizontalLayout_8->addWidget(combo_sam_model);

        downloadSamButton = new QPushButton(modelBox);
        downloadSamButton->setObjectName("downloadSamButton");

        horizontalLayout_8->addWidget(downloadSamButton);

        kcontextualhelpbutton = new KContextualHelpButton(modelBox);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        horizontalLayout_8->addWidget(kcontextualhelpbutton);


        gridLayout_3->addLayout(horizontalLayout_8, 0, 1, 1, 1);


        gridLayout_7->addWidget(modelBox, 0, 0, 1, 2);

        sam_venv_params = new QGroupBox(tab_2);
        sam_venv_params->setObjectName("sam_venv_params");
        sam_venv_params->setFlat(true);
        gridLayout_6 = new QGridLayout(sam_venv_params);
        gridLayout_6->setObjectName("gridLayout_6");
        gridLayout_6->setContentsMargins(0, 0, 0, 0);
        horizontalSpacer_10 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_10, 2, 6, 1, 1);

        sam_venv_size = new QLabel(sam_venv_params);
        sam_venv_size->setObjectName("sam_venv_size");
        sam_venv_size->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_6->addWidget(sam_venv_size, 2, 2, 1, 1);

        sam_folder_label = new ElidedFileLinkLabel(sam_venv_params);
        sam_folder_label->setObjectName("sam_folder_label");
        sam_folder_label->setMinimumSize(QSize(40, 0));

        gridLayout_6->addWidget(sam_folder_label, 1, 0, 1, 1);

        deleteSamModels = new QPushButton(sam_venv_params);
        deleteSamModels->setObjectName("deleteSamModels");
        deleteSamModels->setIcon(icon1);

        gridLayout_6->addWidget(deleteSamModels, 1, 4, 1, 1);

        deleteSamVenv = new QPushButton(sam_venv_params);
        deleteSamVenv->setObjectName("deleteSamVenv");
        deleteSamVenv->setIcon(icon1);

        gridLayout_6->addWidget(deleteSamVenv, 2, 4, 1, 1);

        verticalSpacer_2 = new QSpacerItem(20, 121, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_6->addItem(verticalSpacer_2, 4, 0, 1, 7);

        sam_venv_label = new ElidedFileLinkLabel(sam_venv_params);
        sam_venv_label->setObjectName("sam_venv_label");
        sam_venv_label->setMinimumSize(QSize(40, 0));

        gridLayout_6->addWidget(sam_venv_label, 2, 0, 1, 1);

        sam_model_size = new QLabel(sam_venv_params);
        sam_model_size->setObjectName("sam_model_size");
        sam_model_size->setAlignment(Qt::AlignmentFlag::AlignRight|Qt::AlignmentFlag::AlignTrailing|Qt::AlignmentFlag::AlignVCenter);

        gridLayout_6->addWidget(sam_model_size, 1, 2, 1, 1);

        script_sam_log = new QPlainTextEdit(sam_venv_params);
        script_sam_log->setObjectName("script_sam_log");
        script_sam_log->setFrameShape(QFrame::Shape::NoFrame);
        script_sam_log->setUndoRedoEnabled(false);
        script_sam_log->setReadOnly(true);

        gridLayout_6->addWidget(script_sam_log, 3, 0, 1, 7);

        sam_rebuild = new QToolButton(sam_venv_params);
        sam_rebuild->setObjectName("sam_rebuild");
        QIcon icon3(QIcon::fromTheme(QIcon::ThemeIcon::ViewRefresh));
        sam_rebuild->setIcon(icon3);

        gridLayout_6->addWidget(sam_rebuild, 2, 5, 1, 1);

        horizontalSpacer_9 = new QSpacerItem(20, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_6->addItem(horizontalSpacer_9, 1, 5, 1, 2);


        gridLayout_7->addWidget(sam_venv_params, 4, 0, 3, 2);

        message_layout_sam = new QVBoxLayout();
        message_layout_sam->setSpacing(0);
        message_layout_sam->setObjectName("message_layout_sam");
        message_layout_sam->setContentsMargins(-1, 0, -1, -1);

        gridLayout_7->addLayout(message_layout_sam, 3, 0, 1, 2);

        sam_system_params = new QGroupBox(tab_2);
        sam_system_params->setObjectName("sam_system_params");
        sam_system_params->setMinimumSize(QSize(0, 100));
        sam_system_params->setFlat(true);
        verticalLayout = new QVBoxLayout(sam_system_params);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        system_python_message = new KMessageWidget(sam_system_params);
        system_python_message->setObjectName("system_python_message");
        system_python_message->setWordWrap(true);
        system_python_message->setCloseButtonVisible(false);
        system_python_message->setMessageType(KMessageWidget::MessageType::Warning);

        verticalLayout->addWidget(system_python_message);

        sam_system_python_path = new KUrlRequester(sam_system_params);
        sam_system_python_path->setObjectName("sam_system_python_path");

        verticalLayout->addWidget(sam_system_python_path);


        gridLayout_7->addWidget(sam_system_params, 2, 0, 1, 1);

        horizontalLayout_11 = new QHBoxLayout();
        horizontalLayout_11->setObjectName("horizontalLayout_11");
        kcfg_sam_system_python = new QCheckBox(tab_2);
        kcfg_sam_system_python->setObjectName("kcfg_sam_system_python");

        horizontalLayout_11->addWidget(kcfg_sam_system_python);

        kcontextualhelpbutton_2 = new KContextualHelpButton(tab_2);
        kcontextualhelpbutton_2->setObjectName("kcontextualhelpbutton_2");

        horizontalLayout_11->addWidget(kcontextualhelpbutton_2);

        horizontalSpacer_13 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_11->addItem(horizontalSpacer_13);


        gridLayout_7->addLayout(horizontalLayout_11, 1, 0, 1, 1);

        tabWidget->addTab(tab_2, QString());

        verticalLayout_4->addWidget(tabWidget);

        QWidget::setTabOrder(custom_vosk_folder, vosk_folder);

        retranslateUi(ConfigSpeech_UI);

        tabWidget->setCurrentIndex(0);
        speech_stack->setCurrentIndex(1);


        QMetaObject::connectSlotsByName(ConfigSpeech_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigSpeech_UI)
    {
#if QT_CONFIG(tooltip)
        check_config->setToolTip(tr2i18n("Check speech engine installation", nullptr));
#endif // QT_CONFIG(tooltip)
        check_config->setText(tr2i18n("Check configuration", nullptr));
        label_2->setText(tr2i18n("Speech engine", nullptr));
        engine_vosk->setText(tr2i18n("VOS&K", nullptr));
        engine_whisper->setText(tr2i18n("Wh&isper", nullptr));
        modelV_folder_label->setProperty("text", QVariant(tr2i18n("Models folder", nullptr)));
        modelV_size->setText(QString());
        button_delete->setText(tr2i18n("Remove Model", nullptr));
        button_add->setText(tr2i18n("Add Model", nullptr));
        custom_vosk_folder->setText(tr2i18n("Custom models folder", nullptr));
        models_url->setText(QString());
        seamless_folder_label->setProperty("text", QVariant(tr2i18n("Seamless", nullptr)));
        seamless_folder_size->setText(QString());
        whisper_venv_params->setTitle(QString());
        wr_venv_label->setProperty("text", QVariant(tr2i18n("Plugin size", nullptr)));
        wr_venv_size->setText(QString());
        deleteWrVenv->setText(tr2i18n("Uninstall plugin", nullptr));
        install_seamless->setText(tr2i18n("Install multilingual translation", nullptr));
        whisper_folder_label->setProperty("text", QVariant(tr2i18n("Whisper", nullptr)));
        whisper_model_size->setText(QString());
        whispersettings->setTitle(QString());
        label_3->setText(tr2i18n("Model:", nullptr));
        downloadButton->setText(tr2i18n("Manage models", nullptr));
        label_4->setText(tr2i18n("Language:", nullptr));
        label_5->setText(tr2i18n("Device:", nullptr));
        whisper_device_info->setContextualHelpText(tr2i18n("If your Nvidia GPU is not listed, try installing an alternative with the Nvidia GPU Support button", nullptr));
        install_nvidia_wr->setText(tr2i18n("GPU Support", nullptr));
        kcfg_whisperDisableFP16->setText(tr2i18n("Disable half precision (FP16 )", nullptr));
        kcfg_whisperTranslate->setText(tr2i18n("Translate text to English", nullptr));
        speech_system_params->setTitle(QString());
        kcfg_speech_system_python->setText(tr2i18n("Use system packages only", nullptr));
        kcontextualhelpbutton_4->setContextualHelpText(tr2i18n("When enabled, Kdenlive will use the speech to text packages installed on your system. For advanced users only, as you will have to properly setup everything by yourself.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Speech To Text", nullptr));
        modelBox->setTitle(QString());
        sam_device_info->setContextualHelpText(tr2i18n("If your Nvidia GPU is not listed, try installing an alternative with the Nvidia GPU Support button", nullptr));
        install_nvidia_sam->setText(tr2i18n("GPU Support", nullptr));
        label->setText(tr2i18n("Model", nullptr));
        kcfg_sam_offload_video->setText(tr2i18n("Offload video to CPU to save GPU Memory", nullptr));
        kcontextualhelpbutton_3->setContextualHelpText(tr2i18n("This offloads some of the memory used to the RAM instead of the GPU memory, allowing to process longer sequences.", nullptr));
        label_6->setText(tr2i18n("Device:", nullptr));
        downloadSamButton->setText(tr2i18n("Download models", nullptr));
        kcontextualhelpbutton->setContextualHelpText(tr2i18n("Object Detection relies on SAM2 - <a href=\"https://github.com/facebookresearch/sam2\">https://github.com/facebookresearch/sam2</a>", nullptr));
        sam_venv_params->setTitle(QString());
        sam_venv_size->setText(QString());
        sam_folder_label->setProperty("text", QVariant(tr2i18n("Models folder", nullptr)));
        deleteSamModels->setText(tr2i18n("Delete all models", nullptr));
        deleteSamVenv->setText(tr2i18n("Uninstall plugin", nullptr));
        sam_venv_label->setProperty("text", QVariant(tr2i18n("Plugin size", nullptr)));
        sam_model_size->setText(QString());
#if QT_CONFIG(tooltip)
        sam_rebuild->setToolTip(tr2i18n("Rebuild Virtual Environment", nullptr));
#endif // QT_CONFIG(tooltip)
        sam_rebuild->setText(tr2i18n("...", nullptr));
        sam_system_params->setTitle(QString());
        system_python_message->setText(QString());
        kcfg_sam_system_python->setText(tr2i18n("Use system packages only", nullptr));
        kcontextualhelpbutton_2->setContextualHelpText(tr2i18n("When enabled, Kdenlive will use the SAM2 version installed on your system. For advanced users only, as you will have to properly setup everything by yourself.", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Object Detection", nullptr));
        (void)ConfigSpeech_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigSpeech_UI: public Ui_ConfigSpeech_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGSPEECH_UI_H

