/********************************************************************************
** Form generated from reading UI file 'scenecutdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SCENECUTDIALOG_UI_H
#define UI_SCENECUTDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <klocalizedstring.h>
#include "widgets/markercategorychooser.h"

QT_BEGIN_NAMESPACE

class Ui_SceneCutDialog_UI
{
public:
    QGridLayout *gridLayout;
    QSlider *horizontalSlider;
    QLabel *label;
    QCheckBox *cut_scenes;
    QCheckBox *add_markers;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;
    QSpinBox *minDuration;
    QSpinBox *threshold;
    MarkerCategoryChooser *marker_category;
    QLabel *label_2;
    QCheckBox *range_markers;

    void setupUi(QDialog *SceneCutDialog_UI)
    {
        if (SceneCutDialog_UI->objectName().isEmpty())
            SceneCutDialog_UI->setObjectName("SceneCutDialog_UI");
        SceneCutDialog_UI->resize(452, 222);
        gridLayout = new QGridLayout(SceneCutDialog_UI);
        gridLayout->setObjectName("gridLayout");
        horizontalSlider = new QSlider(SceneCutDialog_UI);
        horizontalSlider->setObjectName("horizontalSlider");
        horizontalSlider->setMinimum(1);
        horizontalSlider->setValue(10);
        horizontalSlider->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(horizontalSlider, 0, 1, 1, 2);

        label = new QLabel(SceneCutDialog_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 5, 0, 1, 2);

        cut_scenes = new QCheckBox(SceneCutDialog_UI);
        cut_scenes->setObjectName("cut_scenes");

        gridLayout->addWidget(cut_scenes, 3, 0, 1, 5);

        add_markers = new QCheckBox(SceneCutDialog_UI);
        add_markers->setObjectName("add_markers");
        add_markers->setChecked(true);

        gridLayout->addWidget(add_markers, 1, 0, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);

        buttonBox = new QDialogButtonBox(SceneCutDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 7, 0, 1, 5);

        minDuration = new QSpinBox(SceneCutDialog_UI);
        minDuration->setObjectName("minDuration");
        minDuration->setMaximum(99999999);

        gridLayout->addWidget(minDuration, 5, 2, 1, 1);

        threshold = new QSpinBox(SceneCutDialog_UI);
        threshold->setObjectName("threshold");

        gridLayout->addWidget(threshold, 0, 3, 1, 1);

        marker_category = new MarkerCategoryChooser(SceneCutDialog_UI);
        marker_category->setObjectName("marker_category");
        marker_category->setProperty("allowAll", QVariant(false));

        gridLayout->addWidget(marker_category, 1, 2, 1, 2);

        label_2 = new QLabel(SceneCutDialog_UI);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 0, 0, 1, 1);

        range_markers = new QCheckBox(SceneCutDialog_UI);
        range_markers->setObjectName("range_markers");
        range_markers->setEnabled(false);

        gridLayout->addWidget(range_markers, 2, 0, 1, 4);


        retranslateUi(SceneCutDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SceneCutDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SceneCutDialog_UI, qOverload<>(&QDialog::reject));
        QObject::connect(horizontalSlider, &QSlider::valueChanged, threshold, &QSpinBox::setValue);
        QObject::connect(threshold, &QSpinBox::valueChanged, horizontalSlider, &QSlider::setValue);
        QObject::connect(add_markers, SIGNAL(toggled(bool)), marker_category, SLOT(setEnabled(bool)));
        QObject::connect(add_markers, &QCheckBox::toggled, range_markers, &QCheckBox::setEnabled);

        QMetaObject::connectSlotsByName(SceneCutDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *SceneCutDialog_UI)
    {
        SceneCutDialog_UI->setWindowTitle(tr2i18n("Scene Cut", nullptr));
        label->setText(tr2i18n("Minimum scene length:", nullptr));
        cut_scenes->setText(tr2i18n("Cut scenes", nullptr));
        add_markers->setText(tr2i18n("Add clip markers:", nullptr));
        minDuration->setSuffix(tr2i18n(" frames", nullptr));
        label_2->setText(tr2i18n("Change threshold", nullptr));
        range_markers->setText(tr2i18n("Create range markers", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SceneCutDialog_UI: public Ui_SceneCutDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SCENECUTDIALOG_UI_H

