/****************************************************************************
** Meta object code from reading C++ file 'timelinewaveform.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/timeline2/view/qml/timelinewaveform.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timelinewaveform.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16TimelineWaveformE_t {};
} // unnamed namespace

template <> constexpr inline auto TimelineWaveform::qt_create_metaobjectdata<qt_meta_tag_ZN16TimelineWaveformE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimelineWaveform",
        "QML.Element",
        "auto",
        "needRecompute",
        "",
        "needRedraw",
        "normalizeChanged",
        "bgColorEven",
        "QColor",
        "bgColorOdd",
        "fgColorEven",
        "fgColorOdd",
        "channels",
        "binId",
        "waveInPoint",
        "waveOutPoint",
        "audioStream",
        "scaleFactor",
        "speed",
        "format",
        "normalize",
        "drawChannelNames",
        "isOpaque"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'needRecompute'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'needRedraw'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalizeChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'bgColorEven'
        QtMocHelpers::PropertyData<QColor>(7, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'bgColorOdd'
        QtMocHelpers::PropertyData<QColor>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'fgColorEven'
        QtMocHelpers::PropertyData<QColor>(10, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'fgColorOdd'
        QtMocHelpers::PropertyData<QColor>(11, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'channels'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'binId'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'waveInPoint'
        QtMocHelpers::PropertyData<double>(14, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'waveOutPoint'
        QtMocHelpers::PropertyData<double>(15, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'audioStream'
        QtMocHelpers::PropertyData<int>(16, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'scaleFactor'
        QtMocHelpers::PropertyData<double>(17, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'speed'
        QtMocHelpers::PropertyData<double>(18, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'format'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'normalize'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'drawChannelNames'
        QtMocHelpers::PropertyData<bool>(21, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'isOpaque'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TimelineWaveform, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject TimelineWaveform::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickPaintedItem::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TimelineWaveformE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TimelineWaveformE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16TimelineWaveformE_t>.metaTypes,
    nullptr
} };

void TimelineWaveform::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimelineWaveform *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->needRecompute(); break;
        case 1: _t->needRedraw(); break;
        case 2: _t->normalizeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TimelineWaveform::*)()>(_a, &TimelineWaveform::needRecompute, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineWaveform::*)()>(_a, &TimelineWaveform::needRedraw, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TimelineWaveform::*)()>(_a, &TimelineWaveform::normalizeChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QColor*>(_v) = _t->m_bgColorEven; break;
        case 1: *reinterpret_cast<QColor*>(_v) = _t->m_bgColorOdd; break;
        case 2: *reinterpret_cast<QColor*>(_v) = _t->m_fgColorEven; break;
        case 3: *reinterpret_cast<QColor*>(_v) = _t->m_fgColorOdd; break;
        case 4: *reinterpret_cast<int*>(_v) = _t->m_channels; break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->m_binId; break;
        case 6: *reinterpret_cast<double*>(_v) = _t->m_inPoint; break;
        case 7: *reinterpret_cast<double*>(_v) = _t->m_outPoint; break;
        case 8: *reinterpret_cast<int*>(_v) = _t->m_stream; break;
        case 9: *reinterpret_cast<double*>(_v) = _t->m_scale; break;
        case 10: *reinterpret_cast<double*>(_v) = _t->m_speed; break;
        case 11: *reinterpret_cast<bool*>(_v) = _t->m_separateChannels; break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->m_normalize; break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->m_drawChannelNames; break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->m_opaquePaint; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_bgColorEven, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->needRedraw();
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_bgColorOdd, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->needRedraw();
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_fgColorEven, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->needRedraw();
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_fgColorOdd, *reinterpret_cast<QColor*>(_v)))
                Q_EMIT _t->needRedraw();
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_channels, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_binId, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_inPoint, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_outPoint, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 8:
            if (QtMocHelpers::setProperty(_t->m_stream, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 9:
            if (QtMocHelpers::setProperty(_t->m_scale, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 10:
            if (QtMocHelpers::setProperty(_t->m_speed, *reinterpret_cast<double*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 11:
            if (QtMocHelpers::setProperty(_t->m_separateChannels, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->needRecompute();
            break;
        case 12:
            if (QtMocHelpers::setProperty(_t->m_normalize, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->normalizeChanged();
            break;
        case 13:
            if (QtMocHelpers::setProperty(_t->m_drawChannelNames, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->needRedraw();
            break;
        case 14: QtMocHelpers::setProperty(_t->m_opaquePaint, *reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *TimelineWaveform::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimelineWaveform::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16TimelineWaveformE_t>.strings))
        return static_cast<void*>(this);
    return QQuickPaintedItem::qt_metacast(_clname);
}

int TimelineWaveform::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickPaintedItem::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 15;
    }
    return _id;
}

// SIGNAL 0
void TimelineWaveform::needRecompute()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TimelineWaveform::needRedraw()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void TimelineWaveform::normalizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
