/****************************************************************************
** Meta object code from reading C++ file 'clippropertiescontroller.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/mltcontroller/clippropertiescontroller.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'clippropertiescontroller.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN24ClipPropertiesControllerE_t {};
} // unnamed namespace

template <> constexpr inline auto ClipPropertiesController::qt_create_metaobjectdata<qt_meta_tag_ZN24ClipPropertiesControllerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ClipPropertiesController",
        "updateClipProperties",
        "",
        "QMap<QString,QString>",
        "colorModified",
        "QColor",
        "durationModified",
        "timecodeModified",
        "updateTimeCodeFormat",
        "seekToFrame",
        "editAnalysis",
        "id",
        "name",
        "value",
        "editClip",
        "requestProxy",
        "doProxy",
        "proxyModified",
        "deleteProxy",
        "enableProxy",
        "slotReloadProperties",
        "slotFillMeta",
        "QTreeWidget*",
        "tree",
        "slotFillAnalysisData",
        "updateStreamInfo",
        "streamIndex",
        "slotColorModified",
        "newcolor",
        "slotTimecodeChanged",
        "slotDurationChanged",
        "duration",
        "slotEnableForce",
        "state",
        "slotDeleteAnalysis",
        "slotSaveAnalysis",
        "slotLoadAnalysis",
        "slotAspectValueChanged",
        "slotTextChanged",
        "updateTab",
        "ix",
        "extractInfo",
        "url",
        "addMetadata",
        "meta"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'updateClipProperties'
        QtMocHelpers::SignalData<void(const QString &, const QMap<QString,QString> &, const QMap<QString,QString> &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'colorModified'
        QtMocHelpers::SignalData<void(const QColor &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'durationModified'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'timecodeModified'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'updateTimeCodeFormat'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekToFrame'
        QtMocHelpers::SignalData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'editAnalysis'
        QtMocHelpers::SignalData<void(const QString &, const QString &, const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 11 }, { QMetaType::QString, 12 }, { QMetaType::QString, 13 },
        }}),
        // Signal 'editClip'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestProxy'
        QtMocHelpers::SignalData<void(bool)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 16 },
        }}),
        // Signal 'proxyModified'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'deleteProxy'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableProxy'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotReloadProperties'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotFillMeta'
        QtMocHelpers::SlotData<void(QTreeWidget *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'slotFillAnalysisData'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateStreamInfo'
        QtMocHelpers::SlotData<void(int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 26 },
        }}),
        // Slot 'slotColorModified'
        QtMocHelpers::SlotData<void(const QColor &)>(27, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 28 },
        }}),
        // Slot 'slotTimecodeChanged'
        QtMocHelpers::SlotData<void(int)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 13 },
        }}),
        // Slot 'slotDurationChanged'
        QtMocHelpers::SlotData<void(int)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Slot 'slotEnableForce'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Slot 'slotDeleteAnalysis'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveAnalysis'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLoadAnalysis'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAspectValueChanged'
        QtMocHelpers::SlotData<void(int)>(37, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotTextChanged'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTab'
        QtMocHelpers::SlotData<void(int)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 40 },
        }}),
        // Slot 'extractInfo'
        QtMocHelpers::SlotData<void(const QString &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 42 },
        }}),
        // Slot 'addMetadata'
        QtMocHelpers::SlotData<void(const QMap<QString,QString>)>(43, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 44 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ClipPropertiesController, qt_meta_tag_ZN24ClipPropertiesControllerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ClipPropertiesController::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ClipPropertiesControllerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ClipPropertiesControllerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN24ClipPropertiesControllerE_t>.metaTypes,
    nullptr
} };

void ClipPropertiesController::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ClipPropertiesController *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateClipProperties((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[3]))); break;
        case 1: _t->colorModified((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 2: _t->durationModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->timecodeModified((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->updateTimeCodeFormat(); break;
        case 5: _t->seekToFrame((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->editAnalysis((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 7: _t->editClip(); break;
        case 8: _t->requestProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->proxyModified((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->deleteProxy(); break;
        case 11: _t->enableProxy((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 12: _t->slotReloadProperties(); break;
        case 13: _t->slotFillMeta((*reinterpret_cast<std::add_pointer_t<QTreeWidget*>>(_a[1]))); break;
        case 14: _t->slotFillAnalysisData(); break;
        case 15: _t->updateStreamInfo((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->slotColorModified((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 17: _t->slotTimecodeChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->slotDurationChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 19: _t->slotEnableForce((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->slotDeleteAnalysis(); break;
        case 21: _t->slotSaveAnalysis(); break;
        case 22: _t->slotLoadAnalysis(); break;
        case 23: _t->slotAspectValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->slotTextChanged(); break;
        case 25: _t->updateTab((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->extractInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->addMetadata((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 13:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QTreeWidget* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(const QString & , const QMap<QString,QString> & , const QMap<QString,QString> & )>(_a, &ClipPropertiesController::updateClipProperties, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(const QColor & )>(_a, &ClipPropertiesController::colorModified, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(int )>(_a, &ClipPropertiesController::durationModified, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(int )>(_a, &ClipPropertiesController::timecodeModified, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)()>(_a, &ClipPropertiesController::updateTimeCodeFormat, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(int )>(_a, &ClipPropertiesController::seekToFrame, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(const QString & , const QString & , const QString & )>(_a, &ClipPropertiesController::editAnalysis, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)()>(_a, &ClipPropertiesController::editClip, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(bool )>(_a, &ClipPropertiesController::requestProxy, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(const QString & )>(_a, &ClipPropertiesController::proxyModified, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)()>(_a, &ClipPropertiesController::deleteProxy, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ClipPropertiesController::*)(bool )>(_a, &ClipPropertiesController::enableProxy, 11))
            return;
    }
}

const QMetaObject *ClipPropertiesController::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ClipPropertiesController::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN24ClipPropertiesControllerE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int ClipPropertiesController::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void ClipPropertiesController::updateClipProperties(const QString & _t1, const QMap<QString,QString> & _t2, const QMap<QString,QString> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void ClipPropertiesController::colorModified(const QColor & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ClipPropertiesController::durationModified(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void ClipPropertiesController::timecodeModified(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ClipPropertiesController::updateTimeCodeFormat()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ClipPropertiesController::seekToFrame(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void ClipPropertiesController::editAnalysis(const QString & _t1, const QString & _t2, const QString & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void ClipPropertiesController::editClip()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void ClipPropertiesController::requestProxy(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void ClipPropertiesController::proxyModified(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void ClipPropertiesController::deleteProxy()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void ClipPropertiesController::enableProxy(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}
QT_WARNING_POP
