/********************************************************************************
** Form generated from reading UI file 'unicodewidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_UNICODEWIDGET_UI_H
#define UI_UNICODEWIDGET_UI_H

#include <QtCore/QLocale>
#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_UnicodeWidget_UI
{
public:
    QGridLayout *gridLayout;
    QFrame *frame;
    QGridLayout *gridLayout_2;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QLabel *unicodeChar;
    QSpacerItem *horizontalSpacer_2;
    QSpacerItem *horizontalSpacer_3;
    QLineEdit *unicodeNumber;
    QFrame *lineRight;
    QFrame *lineLeft;
    QLabel *leftChars;
    QLabel *rightChars;
    QVBoxLayout *verticalLayout_5;
    QToolButton *arrowUp;
    QToolButton *arrowDown;
    QFrame *frame_2;
    QGridLayout *gridLayout_3;
    QLabel *label_2;
    QFrame *line;
    QTextBrowser *labelInfoText;
    QFrame *line_4;
    QLabel *unicode_link;
    QSpacerItem *horizontalSpacer_4;

    void setupUi(QWidget *UnicodeWidget_UI)
    {
        if (UnicodeWidget_UI->objectName().isEmpty())
            UnicodeWidget_UI->setObjectName("UnicodeWidget_UI");
        UnicodeWidget_UI->resize(484, 286);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Expanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(UnicodeWidget_UI->sizePolicy().hasHeightForWidth());
        UnicodeWidget_UI->setSizePolicy(sizePolicy);
        gridLayout = new QGridLayout(UnicodeWidget_UI);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        frame = new QFrame(UnicodeWidget_UI);
        frame->setObjectName("frame");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(frame->sizePolicy().hasHeightForWidth());
        frame->setSizePolicy(sizePolicy1);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        gridLayout_2 = new QGridLayout(frame);
        gridLayout_2->setObjectName("gridLayout_2");
        label = new QLabel(frame);
        label->setObjectName("label");
        sizePolicy1.setHeightForWidth(label->sizePolicy().hasHeightForWidth());
        label->setSizePolicy(sizePolicy1);
        QFont font;
        font.setPointSize(15);
        label->setFont(font);
        label->setText(QString::fromUtf8("U+"));

        gridLayout_2->addWidget(label, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 0, 4, 1, 1);

        unicodeChar = new QLabel(frame);
        unicodeChar->setObjectName("unicodeChar");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(unicodeChar->sizePolicy().hasHeightForWidth());
        unicodeChar->setSizePolicy(sizePolicy2);
        unicodeChar->setFont(font);
        unicodeChar->setText(QString::fromUtf8(""));

        gridLayout_2->addWidget(unicodeChar, 0, 7, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 0, 10, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_3, 0, 11, 1, 1);

        unicodeNumber = new QLineEdit(frame);
        unicodeNumber->setObjectName("unicodeNumber");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(unicodeNumber->sizePolicy().hasHeightForWidth());
        unicodeNumber->setSizePolicy(sizePolicy3);
        unicodeNumber->setFont(font);
        unicodeNumber->setInputMask(QString::fromUtf8(""));
        unicodeNumber->setText(QString::fromUtf8(""));
        unicodeNumber->setMaxLength(7);

        gridLayout_2->addWidget(unicodeNumber, 0, 1, 1, 1);

        lineRight = new QFrame(frame);
        lineRight->setObjectName("lineRight");
        lineRight->setFrameShape(QFrame::Shape::VLine);
        lineRight->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(lineRight, 0, 8, 1, 1);

        lineLeft = new QFrame(frame);
        lineLeft->setObjectName("lineLeft");
        lineLeft->setFrameShape(QFrame::Shape::VLine);
        lineLeft->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_2->addWidget(lineLeft, 0, 6, 1, 1);

        leftChars = new QLabel(frame);
        leftChars->setObjectName("leftChars");
        leftChars->setText(QString::fromUtf8(""));

        gridLayout_2->addWidget(leftChars, 0, 5, 1, 1);

        rightChars = new QLabel(frame);
        rightChars->setObjectName("rightChars");
        rightChars->setText(QString::fromUtf8(""));

        gridLayout_2->addWidget(rightChars, 0, 9, 1, 1);

        verticalLayout_5 = new QVBoxLayout();
        verticalLayout_5->setSpacing(0);
        verticalLayout_5->setObjectName("verticalLayout_5");
        arrowUp = new QToolButton(frame);
        arrowUp->setObjectName("arrowUp");
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Maximum);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(arrowUp->sizePolicy().hasHeightForWidth());
        arrowUp->setSizePolicy(sizePolicy4);
        arrowUp->setMaximumSize(QSize(16777215, 18));
        arrowUp->setAutoRaise(true);
        arrowUp->setArrowType(Qt::UpArrow);

        verticalLayout_5->addWidget(arrowUp);

        arrowDown = new QToolButton(frame);
        arrowDown->setObjectName("arrowDown");
        sizePolicy4.setHeightForWidth(arrowDown->sizePolicy().hasHeightForWidth());
        arrowDown->setSizePolicy(sizePolicy4);
        arrowDown->setMaximumSize(QSize(16777215, 18));
        arrowDown->setAutoRaise(true);
        arrowDown->setArrowType(Qt::DownArrow);

        verticalLayout_5->addWidget(arrowDown);


        gridLayout_2->addLayout(verticalLayout_5, 0, 2, 1, 1);


        gridLayout->addWidget(frame, 0, 0, 1, 1);

        frame_2 = new QFrame(UnicodeWidget_UI);
        frame_2->setObjectName("frame_2");
        sizePolicy.setHeightForWidth(frame_2->sizePolicy().hasHeightForWidth());
        frame_2->setSizePolicy(sizePolicy);
        frame_2->setFrameShape(QFrame::StyledPanel);
        frame_2->setFrameShadow(QFrame::Raised);
        gridLayout_3 = new QGridLayout(frame_2);
        gridLayout_3->setObjectName("gridLayout_3");
        label_2 = new QLabel(frame_2);
        label_2->setObjectName("label_2");
        QFont font1;
        font1.setItalic(true);
        label_2->setFont(font1);
        label_2->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));

        gridLayout_3->addWidget(label_2, 0, 0, 1, 1);

        line = new QFrame(frame_2);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_3->addWidget(line, 1, 0, 1, 2);

        labelInfoText = new QTextBrowser(frame_2);
        labelInfoText->setObjectName("labelInfoText");
        labelInfoText->setFrameShadow(QFrame::Plain);
        labelInfoText->setDocumentTitle(QString::fromUtf8(""));
        labelInfoText->setReadOnly(true);
        labelInfoText->setOpenExternalLinks(true);
        labelInfoText->setOpenLinks(true);

        gridLayout_3->addWidget(labelInfoText, 2, 0, 1, 2);

        line_4 = new QFrame(frame_2);
        line_4->setObjectName("line_4");
        line_4->setFrameShape(QFrame::Shape::HLine);
        line_4->setFrameShadow(QFrame::Shadow::Sunken);

        gridLayout_3->addWidget(line_4, 3, 0, 1, 2);

        unicode_link = new QLabel(frame_2);
        unicode_link->setObjectName("unicode_link");
        unicode_link->setLocale(QLocale(QLocale::English, QLocale::UnitedStates));
        unicode_link->setWordWrap(false);
        unicode_link->setOpenExternalLinks(true);

        gridLayout_3->addWidget(unicode_link, 4, 0, 1, 1);

        horizontalSpacer_4 = new QSpacerItem(43, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_3->addItem(horizontalSpacer_4, 4, 1, 1, 1);


        gridLayout->addWidget(frame_2, 1, 0, 1, 1);


        retranslateUi(UnicodeWidget_UI);

        QMetaObject::connectSlotsByName(UnicodeWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *UnicodeWidget_UI)
    {
        UnicodeWidget_UI->setWindowTitle(tr2i18n("Enter Unicode value", nullptr));
        arrowUp->setText(tr2i18n("...", nullptr));
        arrowDown->setText(tr2i18n("...", nullptr));
        label_2->setText(tr2i18n("Additional Information", nullptr));
        unicode_link->setText(QString());
    } // retranslateUi

};

namespace Ui {
    class UnicodeWidget_UI: public Ui_UnicodeWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UNICODEWIDGET_UI_H

