/****************************************************************************
** Meta object code from reading C++ file 'collapsibleeffectview.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/effects/effectstack/view/collapsibleeffectview.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'collapsibleeffectview.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21CollapsibleEffectViewE_t {};
} // unnamed namespace

template <> constexpr inline auto CollapsibleEffectView::qt_create_metaobjectdata<qt_meta_tag_ZN21CollapsibleEffectViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "CollapsibleEffectView",
        "parameterChanged",
        "",
        "QDomElement",
        "syncEffectsPos",
        "effectStateChanged",
        "ix",
        "MonitorSceneType",
        "effectNeedsMonitorScene",
        "deleteEffect",
        "std::shared_ptr<EffectItemModel>",
        "effect",
        "moveEffect",
        "destRow",
        "checkMonitorPosition",
        "seekTimeline",
        "startFilterJob",
        "QMap<QString,QString>&",
        "resetEffect",
        "createGroup",
        "effectModel",
        "unGroup",
        "CollapsibleEffectView*",
        "createRegion",
        "QUrl",
        "deleteGroup",
        "QDomDocument",
        "importClipKeyframes",
        "GraphicsRectItem",
        "ItemInfo",
        "QMap<QString,QString>",
        "keyframes",
        "switchHeight",
        "model",
        "height",
        "activateEffect",
        "row",
        "showEffectZone",
        "ObjectId",
        "id",
        "std::pair<int,int>",
        "inOut",
        "checked",
        "effectNamesUpdated",
        "collapseAllEffects",
        "collapse",
        "refresh",
        "slotSyncEffectsPos",
        "pos",
        "slotDisable",
        "disable",
        "switchInOut",
        "slotResetEffect",
        "slotActivateEffect",
        "active",
        "slotSetTargetEffect",
        "updateHeight",
        "blockWheelEvent",
        "block",
        "switchCollapsed",
        "slotSaveEffect",
        "title",
        "description",
        "updateGroupedInstances",
        "enableView",
        "enabled",
        "enableHideKeyframes",
        "slotSwitch",
        "expand",
        "slotDeleteEffect",
        "slotEffectUp",
        "slotEffectDown",
        "slotCreateGroup",
        "slotCreateRegion",
        "slotUnGroup",
        "slotUpdateRegionEffectParams",
        "updateEffectZone",
        "slotHideKeyframes",
        "hide",
        "enableAndExpand"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'parameterChanged'
        QtMocHelpers::SignalData<void(const QDomElement &, const QDomElement &, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'syncEffectsPos'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'effectStateChanged'
        QtMocHelpers::SignalData<void(bool, int, MonitorSceneType)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 }, { QMetaType::Int, 6 }, { 0x80000000 | 7, 8 },
        }}),
        // Signal 'deleteEffect'
        QtMocHelpers::SignalData<void(std::shared_ptr<EffectItemModel>)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 11 },
        }}),
        // Signal 'moveEffect'
        QtMocHelpers::SignalData<void(int, std::shared_ptr<EffectItemModel>)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 13 }, { 0x80000000 | 10, 11 },
        }}),
        // Signal 'checkMonitorPosition'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'seekTimeline'
        QtMocHelpers::SignalData<void(int)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'startFilterJob'
        QtMocHelpers::SignalData<void(QMap<QString,QString> &, QMap<QString,QString> &, QMap<QString,QString> &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 }, { 0x80000000 | 17, 2 },
        }}),
        // Signal 'resetEffect'
        QtMocHelpers::SignalData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'createGroup'
        QtMocHelpers::SignalData<void(std::shared_ptr<EffectItemModel>)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 20 },
        }}),
        // Signal 'unGroup'
        QtMocHelpers::SignalData<void(CollapsibleEffectView *)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 2 },
        }}),
        // Signal 'createRegion'
        QtMocHelpers::SignalData<void(int, const QUrl &)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { 0x80000000 | 24, 2 },
        }}),
        // Signal 'deleteGroup'
        QtMocHelpers::SignalData<void(const QDomDocument &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 2 },
        }}),
        // Signal 'importClipKeyframes'
        QtMocHelpers::SignalData<void(GraphicsRectItem, ItemInfo, QDomElement, const QMap<QString,QString> &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 }, { 0x80000000 | 29, 2 }, { 0x80000000 | 3, 2 }, { 0x80000000 | 30, 31 },
        }}),
        // Signal 'importClipKeyframes'
        QtMocHelpers::SignalData<void(GraphicsRectItem, ItemInfo, QDomElement)>(27, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 28, 2 }, { 0x80000000 | 29, 2 }, { 0x80000000 | 3, 2 },
        }}),
        // Signal 'switchHeight'
        QtMocHelpers::SignalData<void(std::shared_ptr<EffectItemModel>, int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 33 }, { QMetaType::Int, 34 },
        }}),
        // Signal 'activateEffect'
        QtMocHelpers::SignalData<void(int)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Signal 'showEffectZone'
        QtMocHelpers::SignalData<void(ObjectId, QPair<int,int>, bool)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { 0x80000000 | 40, 41 }, { QMetaType::Bool, 42 },
        }}),
        // Signal 'effectNamesUpdated'
        QtMocHelpers::SignalData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'collapseAllEffects'
        QtMocHelpers::SignalData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Signal 'refresh'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSyncEffectsPos'
        QtMocHelpers::SlotData<void(int)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 48 },
        }}),
        // Slot 'slotDisable'
        QtMocHelpers::SlotData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 50 },
        }}),
        // Slot 'switchInOut'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 42 },
        }}),
        // Slot 'slotResetEffect'
        QtMocHelpers::SlotData<void()>(52, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotActivateEffect'
        QtMocHelpers::SlotData<void(bool)>(53, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 54 },
        }}),
        // Slot 'slotSetTargetEffect'
        QtMocHelpers::SlotData<void(bool)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 54 },
        }}),
        // Slot 'updateHeight'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'blockWheelEvent'
        QtMocHelpers::SlotData<void(bool)>(57, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 58 },
        }}),
        // Slot 'switchCollapsed'
        QtMocHelpers::SlotData<void(int)>(59, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'slotSaveEffect'
        QtMocHelpers::SlotData<void(const QString, const QString)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 61 }, { QMetaType::QString, 62 },
        }}),
        // Slot 'slotSaveEffect'
        QtMocHelpers::SlotData<void(const QString)>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 61 },
        }}),
        // Slot 'slotSaveEffect'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'updateGroupedInstances'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'enableView'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'enableHideKeyframes'
        QtMocHelpers::SlotData<void(bool)>(66, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 65 },
        }}),
        // Slot 'slotSwitch'
        QtMocHelpers::SlotData<void(bool)>(67, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Slot 'slotDeleteEffect'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEffectUp'
        QtMocHelpers::SlotData<void()>(70, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEffectDown'
        QtMocHelpers::SlotData<void()>(71, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateGroup'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateRegion'
        QtMocHelpers::SlotData<void()>(73, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUnGroup'
        QtMocHelpers::SlotData<void()>(74, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateRegionEffectParams'
        QtMocHelpers::SlotData<void(const QDomElement &, const QDomElement &, int)>(75, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 2 }, { 0x80000000 | 3, 2 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'updateEffectZone'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHideKeyframes'
        QtMocHelpers::SlotData<void(bool)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 78 },
        }}),
        // Slot 'enableAndExpand'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<CollapsibleEffectView, qt_meta_tag_ZN21CollapsibleEffectViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject CollapsibleEffectView::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractCollapsibleWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CollapsibleEffectViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CollapsibleEffectViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21CollapsibleEffectViewE_t>.metaTypes,
    nullptr
} };

void CollapsibleEffectView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<CollapsibleEffectView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->parameterChanged((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->syncEffectsPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->effectStateChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<MonitorSceneType>>(_a[3]))); break;
        case 3: _t->deleteEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1]))); break;
        case 4: _t->moveEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[2]))); break;
        case 5: _t->checkMonitorPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->seekTimeline((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->startFilterJob((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>&>>(_a[3]))); break;
        case 8: _t->resetEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->createGroup((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1]))); break;
        case 10: _t->unGroup((*reinterpret_cast<std::add_pointer_t<CollapsibleEffectView*>>(_a[1]))); break;
        case 11: _t->createRegion((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[2]))); break;
        case 12: _t->deleteGroup((*reinterpret_cast<std::add_pointer_t<QDomDocument>>(_a[1]))); break;
        case 13: _t->importClipKeyframes((*reinterpret_cast<std::add_pointer_t<GraphicsRectItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ItemInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[4]))); break;
        case 14: _t->importClipKeyframes((*reinterpret_cast<std::add_pointer_t<GraphicsRectItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ItemInfo>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[3]))); break;
        case 15: _t->switchHeight((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->activateEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 17: _t->showEffectZone((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 18: _t->effectNamesUpdated(); break;
        case 19: _t->collapseAllEffects((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->refresh(); break;
        case 21: _t->slotSyncEffectsPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->slotDisable((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->switchInOut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 24: _t->slotResetEffect(); break;
        case 25: _t->slotActivateEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 26: _t->slotSetTargetEffect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 27: _t->updateHeight(); break;
        case 28: _t->blockWheelEvent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->switchCollapsed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 30: _t->slotSaveEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 31: _t->slotSaveEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->slotSaveEffect(); break;
        case 33: _t->updateGroupedInstances(); break;
        case 34: _t->enableView((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 35: _t->enableHideKeyframes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 36: _t->slotSwitch((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 37: _t->slotDeleteEffect(); break;
        case 38: _t->slotEffectUp(); break;
        case 39: _t->slotEffectDown(); break;
        case 40: _t->slotCreateGroup(); break;
        case 41: _t->slotCreateRegion(); break;
        case 42: _t->slotUnGroup(); break;
        case 43: _t->slotUpdateRegionEffectParams((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 44: _t->updateEffectZone(); break;
        case 45: _t->slotHideKeyframes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 46: _t->enableAndExpand(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 10:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< CollapsibleEffectView* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(const QDomElement & , const QDomElement & , int )>(_a, &CollapsibleEffectView::parameterChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int )>(_a, &CollapsibleEffectView::syncEffectsPos, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(bool , int , MonitorSceneType )>(_a, &CollapsibleEffectView::effectStateChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(std::shared_ptr<EffectItemModel> )>(_a, &CollapsibleEffectView::deleteEffect, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int , std::shared_ptr<EffectItemModel> )>(_a, &CollapsibleEffectView::moveEffect, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int )>(_a, &CollapsibleEffectView::checkMonitorPosition, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int )>(_a, &CollapsibleEffectView::seekTimeline, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(QMap<QString,QString> & , QMap<QString,QString> & , QMap<QString,QString> & )>(_a, &CollapsibleEffectView::startFilterJob, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int )>(_a, &CollapsibleEffectView::resetEffect, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(std::shared_ptr<EffectItemModel> )>(_a, &CollapsibleEffectView::createGroup, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(CollapsibleEffectView * )>(_a, &CollapsibleEffectView::unGroup, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int , const QUrl & )>(_a, &CollapsibleEffectView::createRegion, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(const QDomDocument & )>(_a, &CollapsibleEffectView::deleteGroup, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(GraphicsRectItem , ItemInfo , QDomElement , const QMap<QString,QString> & )>(_a, &CollapsibleEffectView::importClipKeyframes, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(std::shared_ptr<EffectItemModel> , int )>(_a, &CollapsibleEffectView::switchHeight, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(int )>(_a, &CollapsibleEffectView::activateEffect, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(ObjectId , QPair<int,int> , bool )>(_a, &CollapsibleEffectView::showEffectZone, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)()>(_a, &CollapsibleEffectView::effectNamesUpdated, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)(bool )>(_a, &CollapsibleEffectView::collapseAllEffects, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (CollapsibleEffectView::*)()>(_a, &CollapsibleEffectView::refresh, 20))
            return;
    }
}

const QMetaObject *CollapsibleEffectView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *CollapsibleEffectView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21CollapsibleEffectViewE_t>.strings))
        return static_cast<void*>(this);
    return AbstractCollapsibleWidget::qt_metacast(_clname);
}

int CollapsibleEffectView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractCollapsibleWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    return _id;
}

// SIGNAL 0
void CollapsibleEffectView::parameterChanged(const QDomElement & _t1, const QDomElement & _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void CollapsibleEffectView::syncEffectsPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void CollapsibleEffectView::effectStateChanged(bool _t1, int _t2, MonitorSceneType _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void CollapsibleEffectView::deleteEffect(std::shared_ptr<EffectItemModel> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void CollapsibleEffectView::moveEffect(int _t1, std::shared_ptr<EffectItemModel> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void CollapsibleEffectView::checkMonitorPosition(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void CollapsibleEffectView::seekTimeline(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void CollapsibleEffectView::startFilterJob(QMap<QString,QString> & _t1, QMap<QString,QString> & _t2, QMap<QString,QString> & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void CollapsibleEffectView::resetEffect(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void CollapsibleEffectView::createGroup(std::shared_ptr<EffectItemModel> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void CollapsibleEffectView::unGroup(CollapsibleEffectView * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 11
void CollapsibleEffectView::createRegion(int _t1, const QUrl & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1, _t2);
}

// SIGNAL 12
void CollapsibleEffectView::deleteGroup(const QDomDocument & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void CollapsibleEffectView::importClipKeyframes(GraphicsRectItem _t1, ItemInfo _t2, QDomElement _t3, const QMap<QString,QString> & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 15
void CollapsibleEffectView::switchHeight(std::shared_ptr<EffectItemModel> _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1, _t2);
}

// SIGNAL 16
void CollapsibleEffectView::activateEffect(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void CollapsibleEffectView::showEffectZone(ObjectId _t1, QPair<int,int> _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1, _t2, _t3);
}

// SIGNAL 18
void CollapsibleEffectView::effectNamesUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void CollapsibleEffectView::collapseAllEffects(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void CollapsibleEffectView::refresh()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}
QT_WARNING_POP
