/********************************************************************************
** Form generated from reading UI file 'configtools_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTOOLS_UI_H
#define UI_CONFIGTOOLS_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcontextualhelpbutton.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigTools_UI
{
public:
    QFormLayout *formLayout;
    QGroupBox *groupBox_1;
    QGridLayout *gridLayout_1;
    QLabel *label_2;
    QComboBox *kcfg_subtitle_razor_mode;
    QSpacerItem *verticalSpacer;
    QGroupBox *groupBox;
    QGridLayout *gridLayout;
    QLabel *label;
    QSpacerItem *horizontalSpacer;
    QSpinBox *kcfg_limitAutoKeyframesInterval;
    KContextualHelpButton *kcontextualhelpbutton;

    void setupUi(QWidget *ConfigTools_UI)
    {
        if (ConfigTools_UI->objectName().isEmpty())
            ConfigTools_UI->setObjectName("ConfigTools_UI");
        ConfigTools_UI->resize(505, 306);
        formLayout = new QFormLayout(ConfigTools_UI);
        formLayout->setObjectName("formLayout");
        groupBox_1 = new QGroupBox(ConfigTools_UI);
        groupBox_1->setObjectName("groupBox_1");
        gridLayout_1 = new QGridLayout(groupBox_1);
        gridLayout_1->setObjectName("gridLayout_1");
        label_2 = new QLabel(groupBox_1);
        label_2->setObjectName("label_2");

        gridLayout_1->addWidget(label_2, 0, 0, 1, 1);

        kcfg_subtitle_razor_mode = new QComboBox(groupBox_1);
        kcfg_subtitle_razor_mode->addItem(QString());
        kcfg_subtitle_razor_mode->addItem(QString());
        kcfg_subtitle_razor_mode->setObjectName("kcfg_subtitle_razor_mode");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(kcfg_subtitle_razor_mode->sizePolicy().hasHeightForWidth());
        kcfg_subtitle_razor_mode->setSizePolicy(sizePolicy);

        gridLayout_1->addWidget(kcfg_subtitle_razor_mode, 0, 1, 1, 1);


        formLayout->setWidget(0, QFormLayout::ItemRole::SpanningRole, groupBox_1);

        verticalSpacer = new QSpacerItem(20, 23, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(2, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        groupBox = new QGroupBox(ConfigTools_UI);
        groupBox->setObjectName("groupBox");
        gridLayout = new QGridLayout(groupBox);
        gridLayout->setObjectName("gridLayout");
        label = new QLabel(groupBox);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 0, 3, 1, 1);

        kcfg_limitAutoKeyframesInterval = new QSpinBox(groupBox);
        kcfg_limitAutoKeyframesInterval->setObjectName("kcfg_limitAutoKeyframesInterval");
        kcfg_limitAutoKeyframesInterval->setMinimum(2);

        gridLayout->addWidget(kcfg_limitAutoKeyframesInterval, 0, 1, 1, 1);

        kcontextualhelpbutton = new KContextualHelpButton(groupBox);
        kcontextualhelpbutton->setObjectName("kcontextualhelpbutton");

        gridLayout->addWidget(kcontextualhelpbutton, 0, 2, 1, 1);


        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, groupBox);


        retranslateUi(ConfigTools_UI);

        QMetaObject::connectSlotsByName(ConfigTools_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigTools_UI)
    {
        groupBox_1->setTitle(tr2i18n("Razor", nullptr));
        label_2->setText(tr2i18n("When cutting subtitles:", nullptr));
        kcfg_subtitle_razor_mode->setItemText(0, tr2i18n("Duplicate text", nullptr));
        kcfg_subtitle_razor_mode->setItemText(1, tr2i18n("Split after first line", nullptr));

        groupBox->setTitle(tr2i18n("Keyframes", nullptr));
        label->setText(tr2i18n("Minimum frame interval for automatic keyframes:", nullptr));
        kcontextualhelpbutton->setText(tr2i18n("When adding automatic keyframes (for example in the Transform effect) while the monitor is playing, this is the minimum frame interval between 2 keyframes.", nullptr));
        (void)ConfigTools_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigTools_UI: public Ui_ConfigTools_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGTOOLS_UI_H

