/****************************************************************************
** Meta object code from reading C++ file 'projectitemmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/bin/projectitemmodel.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectitemmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16ProjectItemModelE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectItemModel::qt_create_metaobjectdata<qt_meta_tag_ZN16ProjectItemModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectItemModel",
        "refreshAudioThumbs",
        "",
        "id",
        "refreshClip",
        "emitMessage",
        "MessageType",
        "refreshPanel",
        "requestAudioThumbs",
        "duration",
        "markersNeedUpdate",
        "QList<int>",
        "itemDropped",
        "QModelIndex",
        "dropFromSameSource",
        "urlsDropped",
        "QList<QUrl>",
        "effectDropped",
        "addTag",
        "addClipCut",
        "resetPlayOrLoopZone",
        "clipRenamed",
        "controlUuid",
        "clipName",
        "projectClipsModified",
        "onItemUpdated",
        "std::shared_ptr<AbstractProjectItem>",
        "item",
        "roles",
        "binId",
        "role",
        "setDragType",
        "PlaylistState::ClipState",
        "type",
        "loadSubClips",
        "clipData",
        "logUndo",
        "loadSubSequences",
        "sequenceMap",
        "dataMap",
        "requestBinClipDeletionById",
        "slotUpdateInvalidCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'refreshAudioThumbs'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'refreshClip'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'emitMessage'
        QtMocHelpers::SignalData<void(const QString &, int, MessageType)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { 0x80000000 | 6, 2 },
        }}),
        // Signal 'refreshPanel'
        QtMocHelpers::SignalData<void(const QString &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'requestAudioThumbs'
        QtMocHelpers::SignalData<void(const QString &, long)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Long, 9 },
        }}),
        // Signal 'markersNeedUpdate'
        QtMocHelpers::SignalData<void(const QString &, const QList<int> &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 11, 2 },
        }}),
        // Signal 'itemDropped'
        QtMocHelpers::SignalData<void(const QStringList, const QModelIndex, bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { 0x80000000 | 13, 2 }, { QMetaType::Bool, 14 },
        }}),
        // Signal 'urlsDropped'
        QtMocHelpers::SignalData<void(const QList<QUrl>, const QModelIndex)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Signal 'effectDropped'
        QtMocHelpers::SignalData<void(const QStringList &, const QModelIndex &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Signal 'addTag'
        QtMocHelpers::SignalData<void(const QString &, const QModelIndex &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 13, 2 },
        }}),
        // Signal 'addClipCut'
        QtMocHelpers::SignalData<void(const QString &, int, int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'resetPlayOrLoopZone'
        QtMocHelpers::SignalData<void(const QString &)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'clipRenamed'
        QtMocHelpers::SignalData<void(const QString &, const QString &)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 },
        }}),
        // Signal 'projectClipsModified'
        QtMocHelpers::SignalData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onItemUpdated'
        QtMocHelpers::SlotData<void(const std::shared_ptr<AbstractProjectItem> &, const QVector<int> &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 11, 28 },
        }}),
        // Slot 'onItemUpdated'
        QtMocHelpers::SlotData<void(const QString &, int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'setDragType'
        QtMocHelpers::SlotData<void(PlaylistState::ClipState)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 32, 33 },
        }}),
        // Slot 'loadSubClips'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 35 }, { QMetaType::Bool, 36 },
        }}),
        // Slot 'loadSubSequences'
        QtMocHelpers::SlotData<void(const QString &, const sequenceMap &)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 38, 39 },
        }}),
        // Slot 'requestBinClipDeletionById'
        QtMocHelpers::SlotData<bool(const QString &)>(40, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'slotUpdateInvalidCount'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectItemModel, qt_meta_tag_ZN16ProjectItemModelE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectItemModel::staticMetaObject = { {
    QMetaObject::SuperData::link<AbstractTreeModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ProjectItemModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ProjectItemModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16ProjectItemModelE_t>.metaTypes,
    nullptr
} };

void ProjectItemModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectItemModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->refreshAudioThumbs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->refreshClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->emitMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[3]))); break;
        case 3: _t->refreshPanel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->requestAudioThumbs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<long>>(_a[2]))); break;
        case 5: _t->markersNeedUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 6: _t->itemDropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 7: _t->urlsDropped((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 8: _t->effectDropped((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 9: _t->addTag((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 10: _t->addClipCut((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 11: _t->resetPlayOrLoopZone((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->clipRenamed((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 13: _t->projectClipsModified(); break;
        case 14: _t->onItemUpdated((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<AbstractProjectItem>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 15: _t->onItemUpdated((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->setDragType((*reinterpret_cast<std::add_pointer_t<PlaylistState::ClipState>>(_a[1]))); break;
        case 17: _t->loadSubClips((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 18: _t->loadSubSequences((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<sequenceMap>>(_a[2]))); break;
        case 19: { bool _r = _t->requestBinClipDeletionById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->slotUpdateInvalidCount(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 14:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & )>(_a, &ProjectItemModel::refreshAudioThumbs, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & )>(_a, &ProjectItemModel::refreshClip, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , int , MessageType )>(_a, &ProjectItemModel::emitMessage, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & )>(_a, &ProjectItemModel::refreshPanel, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , long )>(_a, &ProjectItemModel::requestAudioThumbs, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , const QList<int> & )>(_a, &ProjectItemModel::markersNeedUpdate, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QStringList , const QModelIndex , bool )>(_a, &ProjectItemModel::itemDropped, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QList<QUrl> , const QModelIndex )>(_a, &ProjectItemModel::urlsDropped, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QStringList & , const QModelIndex & )>(_a, &ProjectItemModel::effectDropped, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , const QModelIndex & )>(_a, &ProjectItemModel::addTag, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , int , int )>(_a, &ProjectItemModel::addClipCut, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & )>(_a, &ProjectItemModel::resetPlayOrLoopZone, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)(const QString & , const QString & )>(_a, &ProjectItemModel::clipRenamed, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (ProjectItemModel::*)()>(_a, &ProjectItemModel::projectClipsModified, 13))
            return;
    }
}

const QMetaObject *ProjectItemModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectItemModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16ProjectItemModelE_t>.strings))
        return static_cast<void*>(this);
    return AbstractTreeModel::qt_metacast(_clname);
}

int ProjectItemModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = AbstractTreeModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void ProjectItemModel::refreshAudioThumbs(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void ProjectItemModel::refreshClip(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void ProjectItemModel::emitMessage(const QString & _t1, int _t2, MessageType _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void ProjectItemModel::refreshPanel(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void ProjectItemModel::requestAudioThumbs(const QString & _t1, long _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void ProjectItemModel::markersNeedUpdate(const QString & _t1, const QList<int> & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2);
}

// SIGNAL 6
void ProjectItemModel::itemDropped(const QStringList _t1, const QModelIndex _t2, bool _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2, _t3);
}

// SIGNAL 7
void ProjectItemModel::urlsDropped(const QList<QUrl> _t1, const QModelIndex _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void ProjectItemModel::effectDropped(const QStringList & _t1, const QModelIndex & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}

// SIGNAL 9
void ProjectItemModel::addTag(const QString & _t1, const QModelIndex & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1, _t2);
}

// SIGNAL 10
void ProjectItemModel::addClipCut(const QString & _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2, _t3);
}

// SIGNAL 11
void ProjectItemModel::resetPlayOrLoopZone(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void ProjectItemModel::clipRenamed(const QString & _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void ProjectItemModel::projectClipsModified()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}
QT_WARNING_POP
