/********************************************************************************
** Form generated from reading UI file 'gradientedit_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GRADIENTEDIT_UI_H
#define UI_GRADIENTEDIT_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kcolorbutton.h"

QT_BEGIN_NAMESPACE

class Ui_GradientEdit_UI
{
public:
    QGridLayout *gridLayout;
    QLabel *label_3;
    QSlider *color2_pos;
    KColorButton *color1;
    QSlider *color1_pos;
    QLabel *preview;
    QLabel *label_4;
    QSlider *angle;
    QLabel *label_2;
    QToolButton *remove_gradient;
    QDialogButtonBox *buttonBox;
    QToolButton *add_gradient;
    KColorButton *color2;
    QSpinBox *angle_spin;
    QListWidget *gradient_list;
    QSpinBox *color2_spin;
    QSpinBox *color1_spin;

    void setupUi(QDialog *GradientEdit_UI)
    {
        if (GradientEdit_UI->objectName().isEmpty())
            GradientEdit_UI->setObjectName("GradientEdit_UI");
        GradientEdit_UI->resize(440, 537);
        gridLayout = new QGridLayout(GradientEdit_UI);
        gridLayout->setObjectName("gridLayout");
        label_3 = new QLabel(GradientEdit_UI);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 3, 1, 1);

        color2_pos = new QSlider(GradientEdit_UI);
        color2_pos->setObjectName("color2_pos");
        color2_pos->setMaximum(100);
        color2_pos->setValue(100);
        color2_pos->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(color2_pos, 2, 4, 1, 1);

        color1 = new KColorButton(GradientEdit_UI);
        color1->setObjectName("color1");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(color1->sizePolicy().hasHeightForWidth());
        color1->setSizePolicy(sizePolicy);
        color1->setFlat(false);
        color1->setColor(QColor(255, 255, 255));
        color1->setDefaultColor(QColor(0, 0, 0));
        color1->setAlphaChannelEnabled(true);

        gridLayout->addWidget(color1, 1, 0, 1, 2);

        color1_pos = new QSlider(GradientEdit_UI);
        color1_pos->setObjectName("color1_pos");
        color1_pos->setMaximum(100);
        color1_pos->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(color1_pos, 1, 4, 1, 1);

        preview = new QLabel(GradientEdit_UI);
        preview->setObjectName("preview");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(preview->sizePolicy().hasHeightForWidth());
        preview->setSizePolicy(sizePolicy1);

        gridLayout->addWidget(preview, 0, 0, 1, 6);

        label_4 = new QLabel(GradientEdit_UI);
        label_4->setObjectName("label_4");

        gridLayout->addWidget(label_4, 3, 3, 1, 1);

        angle = new QSlider(GradientEdit_UI);
        angle->setObjectName("angle");
        angle->setMinimum(0);
        angle->setMaximum(180);
        angle->setValue(90);
        angle->setOrientation(Qt::Orientation::Horizontal);

        gridLayout->addWidget(angle, 3, 4, 1, 1);

        label_2 = new QLabel(GradientEdit_UI);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 1, 3, 1, 1);

        remove_gradient = new QToolButton(GradientEdit_UI);
        remove_gradient->setObjectName("remove_gradient");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("list-remove")));
        remove_gradient->setIcon(icon);

        gridLayout->addWidget(remove_gradient, 5, 1, 1, 1);

        buttonBox = new QDialogButtonBox(GradientEdit_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 6, 3, 1, 3);

        add_gradient = new QToolButton(GradientEdit_UI);
        add_gradient->setObjectName("add_gradient");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("list-add")));
        add_gradient->setIcon(icon1);

        gridLayout->addWidget(add_gradient, 5, 0, 1, 1);

        color2 = new KColorButton(GradientEdit_UI);
        color2->setObjectName("color2");
        sizePolicy.setHeightForWidth(color2->sizePolicy().hasHeightForWidth());
        color2->setSizePolicy(sizePolicy);
        color2->setFlat(false);
        color2->setColor(QColor(0, 0, 0));
        color2->setDefaultColor(QColor(0, 0, 0));
        color2->setAlphaChannelEnabled(true);

        gridLayout->addWidget(color2, 2, 0, 1, 2);

        angle_spin = new QSpinBox(GradientEdit_UI);
        angle_spin->setObjectName("angle_spin");
        angle_spin->setMaximum(180);

        gridLayout->addWidget(angle_spin, 3, 5, 1, 1);

        gradient_list = new QListWidget(GradientEdit_UI);
        gradient_list->setObjectName("gradient_list");

        gridLayout->addWidget(gradient_list, 4, 0, 1, 6);

        color2_spin = new QSpinBox(GradientEdit_UI);
        color2_spin->setObjectName("color2_spin");
        color2_spin->setMaximum(100);

        gridLayout->addWidget(color2_spin, 2, 5, 1, 1);

        color1_spin = new QSpinBox(GradientEdit_UI);
        color1_spin->setObjectName("color1_spin");
        color1_spin->setMaximum(100);

        gridLayout->addWidget(color1_spin, 1, 5, 1, 1);


        retranslateUi(GradientEdit_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, GradientEdit_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, GradientEdit_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(GradientEdit_UI);
    } // setupUi

    void retranslateUi(QDialog *GradientEdit_UI)
    {
        GradientEdit_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        label_3->setText(tr2i18n("Color 2", nullptr));
        preview->setText(QString());
        label_4->setText(tr2i18n("Angle", nullptr));
        label_2->setText(tr2i18n("Color 1", nullptr));
        remove_gradient->setText(tr2i18n("...", nullptr));
        add_gradient->setText(tr2i18n("...", nullptr));
    } // retranslateUi

};

namespace Ui {
    class GradientEdit_UI: public Ui_GradientEdit_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GRADIENTEDIT_UI_H

