/****************************************************************************
** Meta object code from reading C++ file 'splash.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/splash.hpp"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'splash.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6SplashE_t {};
} // unnamed namespace

template <> constexpr inline auto Splash::qt_create_metaobjectdata<qt_meta_tag_ZN6SplashE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Splash",
        "openBlank",
        "",
        "openOtherFile",
        "closeApp",
        "openFile",
        "openLink",
        "openTemplate",
        "switchPalette",
        "firstStart",
        "resolution",
        "fps",
        "interlaced",
        "vTracks",
        "aTracks",
        "resetConfig",
        "releaseLock",
        "clearHistory",
        "clearProfiles",
        "forgetFile",
        "url",
        "forgetProfile",
        "id",
        "fadeOut",
        "fadeOutAndDelete",
        "showProgressMessage",
        "message",
        "max",
        "updateWelcomeDisplay",
        "show"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openBlank'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openOtherFile'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeApp'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openFile'
        QtMocHelpers::SignalData<void(QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'openLink'
        QtMocHelpers::SignalData<void(QString)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'openTemplate'
        QtMocHelpers::SignalData<void(QString)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'switchPalette'
        QtMocHelpers::SignalData<void(bool)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'firstStart'
        QtMocHelpers::SignalData<void(QString, QString, bool, int, int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 10 }, { QMetaType::QString, 11 }, { QMetaType::Bool, 12 }, { QMetaType::Int, 13 },
            { QMetaType::Int, 14 },
        }}),
        // Signal 'resetConfig'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'releaseLock'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearHistory'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearProfiles'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'forgetFile'
        QtMocHelpers::SignalData<void(QString)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Signal 'forgetProfile'
        QtMocHelpers::SignalData<void(QString)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 },
        }}),
        // Slot 'fadeOut'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'fadeOutAndDelete'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showProgressMessage'
        QtMocHelpers::SlotData<void(const QString &, int)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 }, { QMetaType::Int, 27 },
        }}),
        // Slot 'showProgressMessage'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'updateWelcomeDisplay'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Splash, qt_meta_tag_ZN6SplashE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Splash::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SplashE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SplashE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6SplashE_t>.metaTypes,
    nullptr
} };

void Splash::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Splash *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openBlank(); break;
        case 1: _t->openOtherFile(); break;
        case 2: _t->closeApp(); break;
        case 3: _t->openFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 4: _t->openLink((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->openTemplate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->switchPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->firstStart((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 8: _t->resetConfig(); break;
        case 9: _t->releaseLock(); break;
        case 10: _t->clearHistory(); break;
        case 11: _t->clearProfiles(); break;
        case 12: _t->forgetFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 13: _t->forgetProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->fadeOut(); break;
        case 15: _t->fadeOutAndDelete(); break;
        case 16: _t->showProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 17: _t->showProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 18: _t->updateWelcomeDisplay((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::openBlank, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::openOtherFile, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::closeApp, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString )>(_a, &Splash::openFile, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString )>(_a, &Splash::openLink, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString )>(_a, &Splash::openTemplate, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(bool )>(_a, &Splash::switchPalette, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString , QString , bool , int , int )>(_a, &Splash::firstStart, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::resetConfig, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::releaseLock, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::clearHistory, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)()>(_a, &Splash::clearProfiles, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString )>(_a, &Splash::forgetFile, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Splash::*)(QString )>(_a, &Splash::forgetProfile, 13))
            return;
    }
}

const QMetaObject *Splash::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Splash::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6SplashE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Splash::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void Splash::openBlank()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Splash::openOtherFile()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Splash::closeApp()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void Splash::openFile(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void Splash::openLink(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void Splash::openTemplate(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void Splash::switchPalette(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void Splash::firstStart(QString _t1, QString _t2, bool _t3, int _t4, int _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 8
void Splash::resetConfig()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Splash::releaseLock()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Splash::clearHistory()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Splash::clearProfiles()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Splash::forgetFile(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1);
}

// SIGNAL 13
void Splash::forgetProfile(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1);
}
QT_WARNING_POP
