/********************************************************************************
** Form generated from reading UI file 'fontval_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FONTVAL_UI_H
#define UI_FONTVAL_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFontComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Fontval_UI
{
public:
    QGridLayout *gridLayout;
    QFontComboBox *fontfamilywidget;

    void setupUi(QWidget *Fontval_UI)
    {
        if (Fontval_UI->objectName().isEmpty())
            Fontval_UI->setObjectName("Fontval_UI");
        Fontval_UI->resize(257, 32);
        gridLayout = new QGridLayout(Fontval_UI);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        fontfamilywidget = new QFontComboBox(Fontval_UI);
        fontfamilywidget->setObjectName("fontfamilywidget");

        gridLayout->addWidget(fontfamilywidget, 0, 0, 1, 1);


        retranslateUi(Fontval_UI);

        QMetaObject::connectSlotsByName(Fontval_UI);
    } // setupUi

    void retranslateUi(QWidget *Fontval_UI)
    {
        (void)Fontval_UI;
    } // retranslateUi

};

namespace Ui {
    class Fontval_UI: public Ui_Fontval_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // FONTVAL_UI_H

