/********************************************************************************
** Form generated from reading UI file 'resourcewidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_RESOURCEWIDGET_UI_H
#define UI_RESOURCEWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QTextBrowser>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "klineedit.h"
#include "kmessagewidget.h"
#include "kurllabel.h"

QT_BEGIN_NAMESPACE

class Ui_ResourceWidget_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *spacer_horiz;
    QSplitter *splitter;
    QWidget *left_box_widget;
    QVBoxLayout *left_box;
    KLineEdit *search_text;
    QFrame *buildin_box;
    QVBoxLayout *verticalLayout_4;
    QListWidget *search_results;
    QSpinBox *page_number;
    QWidget *right_box_widget;
    QVBoxLayout *right_box;
    QFrame *details_box;
    QVBoxLayout *verticalLayout_3;
    QTextBrowser *info_browser;
    KUrlLabel *label_license;
    KUrlLabel *provider_info;
    QToolButton *button_zoomin;
    QPushButton *button_import;
    QPushButton *button_preview;
    QSlider *slider_zoom;
    QToolButton *button_zoomout;
    QWidget *service_box_2;
    QHBoxLayout *service_box;
    QLabel *label_3;
    KComboBox *service_list;
    KMessageWidget *message_line;

    void setupUi(QWidget *ResourceWidget_UI)
    {
        if (ResourceWidget_UI->objectName().isEmpty())
            ResourceWidget_UI->setObjectName("ResourceWidget_UI");
        ResourceWidget_UI->resize(313, 335);
        gridLayout = new QGridLayout(ResourceWidget_UI);
        gridLayout->setObjectName("gridLayout");
        spacer_horiz = new QSpacerItem(81, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(spacer_horiz, 4, 4, 1, 1);

        splitter = new QSplitter(ResourceWidget_UI);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        splitter->setHandleWidth(7);
        left_box_widget = new QWidget(splitter);
        left_box_widget->setObjectName("left_box_widget");
        left_box = new QVBoxLayout(left_box_widget);
        left_box->setSpacing(0);
        left_box->setObjectName("left_box");
        left_box->setContentsMargins(0, 0, 0, 0);
        search_text = new KLineEdit(left_box_widget);
        search_text->setObjectName("search_text");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(search_text->sizePolicy().hasHeightForWidth());
        search_text->setSizePolicy(sizePolicy);
        search_text->setProperty("showClearButton", QVariant(true));

        left_box->addWidget(search_text);

        buildin_box = new QFrame(left_box_widget);
        buildin_box->setObjectName("buildin_box");
        buildin_box->setMinimumSize(QSize(0, 50));
        buildin_box->setFrameShape(QFrame::NoFrame);
        buildin_box->setFrameShadow(QFrame::Raised);
        verticalLayout_4 = new QVBoxLayout(buildin_box);
        verticalLayout_4->setSpacing(0);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        search_results = new QListWidget(buildin_box);
        search_results->setObjectName("search_results");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(search_results->sizePolicy().hasHeightForWidth());
        search_results->setSizePolicy(sizePolicy1);
        search_results->setAlternatingRowColors(true);
        search_results->setResizeMode(QListView::Adjust);
        search_results->setSpacing(2);
        search_results->setUniformItemSizes(true);
        search_results->setWordWrap(true);

        verticalLayout_4->addWidget(search_results);

        page_number = new QSpinBox(buildin_box);
        page_number->setObjectName("page_number");
        page_number->setButtonSymbols(QAbstractSpinBox::UpDownArrows);
        page_number->setMinimum(1);

        verticalLayout_4->addWidget(page_number);


        left_box->addWidget(buildin_box);

        splitter->addWidget(left_box_widget);
        right_box_widget = new QWidget(splitter);
        right_box_widget->setObjectName("right_box_widget");
        right_box = new QVBoxLayout(right_box_widget);
        right_box->setObjectName("right_box");
        right_box->setContentsMargins(0, 0, 0, 0);
        details_box = new QFrame(right_box_widget);
        details_box->setObjectName("details_box");
        details_box->setFrameShape(QFrame::NoFrame);
        details_box->setFrameShadow(QFrame::Raised);
        verticalLayout_3 = new QVBoxLayout(details_box);
        verticalLayout_3->setSpacing(0);
        verticalLayout_3->setObjectName("verticalLayout_3");
        verticalLayout_3->setContentsMargins(0, 0, 0, 0);
        info_browser = new QTextBrowser(details_box);
        info_browser->setObjectName("info_browser");
        info_browser->setAutoFillBackground(true);
        info_browser->setFrameShape(QFrame::NoFrame);
        info_browser->setOpenExternalLinks(true);
        info_browser->setOpenLinks(true);

        verticalLayout_3->addWidget(info_browser);

        label_license = new KUrlLabel(details_box);
        label_license->setObjectName("label_license");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_license->sizePolicy().hasHeightForWidth());
        label_license->setSizePolicy(sizePolicy2);
        label_license->setWordWrap(true);

        verticalLayout_3->addWidget(label_license);

        provider_info = new KUrlLabel(details_box);
        provider_info->setObjectName("provider_info");
        provider_info->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        provider_info->setWordWrap(true);
        provider_info->setUseCursor(true);

        verticalLayout_3->addWidget(provider_info);


        right_box->addWidget(details_box);

        splitter->addWidget(right_box_widget);

        gridLayout->addWidget(splitter, 2, 0, 1, 7);

        button_zoomin = new QToolButton(ResourceWidget_UI);
        button_zoomin->setObjectName("button_zoomin");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("zoom-in");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_zoomin->setIcon(icon);
        button_zoomin->setAutoRaise(true);

        gridLayout->addWidget(button_zoomin, 4, 3, 1, 1);

        button_import = new QPushButton(ResourceWidget_UI);
        button_import->setObjectName("button_import");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Fixed);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(button_import->sizePolicy().hasHeightForWidth());
        button_import->setSizePolicy(sizePolicy3);
        QIcon icon1;
        iconThemeName = QString::fromUtf8("document-import");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_import->setIcon(icon1);

        gridLayout->addWidget(button_import, 4, 6, 1, 1);

        button_preview = new QPushButton(ResourceWidget_UI);
        button_preview->setObjectName("button_preview");
        sizePolicy3.setHeightForWidth(button_preview->sizePolicy().hasHeightForWidth());
        button_preview->setSizePolicy(sizePolicy3);
        QIcon icon2;
        iconThemeName = QString::fromUtf8("media-playback-start");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon2 = QIcon::fromTheme(iconThemeName);
        } else {
            icon2.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_preview->setIcon(icon2);

        gridLayout->addWidget(button_preview, 4, 5, 1, 1);

        slider_zoom = new QSlider(ResourceWidget_UI);
        slider_zoom->setObjectName("slider_zoom");
        slider_zoom->setMinimumSize(QSize(40, 0));
        slider_zoom->setMaximumSize(QSize(100, 16777215));
        slider_zoom->setOrientation(Qt::Horizontal);

        gridLayout->addWidget(slider_zoom, 4, 2, 1, 1);

        button_zoomout = new QToolButton(ResourceWidget_UI);
        button_zoomout->setObjectName("button_zoomout");
        QIcon icon3;
        iconThemeName = QString::fromUtf8("zoom-out");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon3 = QIcon::fromTheme(iconThemeName);
        } else {
            icon3.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_zoomout->setIcon(icon3);
        button_zoomout->setAutoRaise(true);

        gridLayout->addWidget(button_zoomout, 4, 1, 1, 1);

        service_box_2 = new QWidget(ResourceWidget_UI);
        service_box_2->setObjectName("service_box_2");
        service_box_2->setEnabled(true);
        QSizePolicy sizePolicy4(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy4.setHorizontalStretch(0);
        sizePolicy4.setVerticalStretch(0);
        sizePolicy4.setHeightForWidth(service_box_2->sizePolicy().hasHeightForWidth());
        service_box_2->setSizePolicy(sizePolicy4);
        service_box = new QHBoxLayout(service_box_2);
        service_box->setObjectName("service_box");
        service_box->setContentsMargins(0, 0, 0, 0);
        label_3 = new QLabel(service_box_2);
        label_3->setObjectName("label_3");

        service_box->addWidget(label_3);

        service_list = new KComboBox(service_box_2);
        service_list->setObjectName("service_list");
        sizePolicy.setHeightForWidth(service_list->sizePolicy().hasHeightForWidth());
        service_list->setSizePolicy(sizePolicy);

        service_box->addWidget(service_list);


        gridLayout->addWidget(service_box_2, 0, 0, 1, 7);

        message_line = new KMessageWidget(ResourceWidget_UI);
        message_line->setObjectName("message_line");
        sizePolicy2.setHeightForWidth(message_line->sizePolicy().hasHeightForWidth());
        message_line->setSizePolicy(sizePolicy2);
        message_line->setWordWrap(false);
        message_line->setCloseButtonVisible(false);

        gridLayout->addWidget(message_line, 3, 1, 1, 6);

        splitter->raise();
        service_box_2->raise();
        button_preview->raise();
        button_import->raise();
        button_zoomin->raise();
        button_zoomout->raise();
        slider_zoom->raise();
        message_line->raise();
        QWidget::setTabOrder(service_list, button_preview);
        QWidget::setTabOrder(button_preview, button_import);

        retranslateUi(ResourceWidget_UI);

        QMetaObject::connectSlotsByName(ResourceWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *ResourceWidget_UI)
    {
        search_text->setPlaceholderText(tr2i18n("Search...", nullptr));
        page_number->setPrefix(tr2i18n("Page ", nullptr));
        provider_info->setText(tr2i18n("Photos provided by Example Provider", nullptr));
        button_zoomin->setText(tr2i18n("...", nullptr));
        button_import->setText(tr2i18n("Import", nullptr));
        button_preview->setText(tr2i18n("Preview", nullptr));
        button_zoomout->setText(tr2i18n("...", nullptr));
        label_3->setText(tr2i18n("Service:", nullptr));
        (void)ResourceWidget_UI;
    } // retranslateUi

};

namespace Ui {
    class ResourceWidget_UI: public Ui_ResourceWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // RESOURCEWIDGET_UI_H

