/********************************************************************************
** Form generated from reading UI file 'import_subtitle_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_IMPORT_SUBTITLE_UI_H
#define UI_IMPORT_SUBTITLE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QDoubleSpinBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSplitter>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ImportSub_UI
{
public:
    QGridLayout *gridLayout;
    QSplitter *splitter;
    QWidget *layoutWidget;
    QVBoxLayout *verticalLayout;
    QGroupBox *groupBox_2;
    QGridLayout *gridLayout_3;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    KUrlRequester *subtitle_url;
    QHBoxLayout *horizontalLayout_2;
    QLabel *label_2;
    QComboBox *codecs_list;
    QCheckBox *cursor_pos;
    QGroupBox *groupBox;
    QGridLayout *gridLayout_2;
    QCheckBox *transform_framerate_check_box;
    QLabel *caption_convert_framerate_label1;
    QSpacerItem *horizontalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QDoubleSpinBox *caption_original_framerate;
    QLabel *caption_convert_framerate_label2;
    QDoubleSpinBox *caption_target_framerate;
    QSpacerItem *verticalSpacer;
    QWidget *layoutWidget1;
    QVBoxLayout *verticalLayout_2;
    QLabel *label_3;
    QPlainTextEdit *text_preview;
    QCheckBox *create_track;
    QLineEdit *track_name;
    KMessageWidget *info_message;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *ImportSub_UI)
    {
        if (ImportSub_UI->objectName().isEmpty())
            ImportSub_UI->setObjectName("ImportSub_UI");
        ImportSub_UI->resize(539, 351);
        gridLayout = new QGridLayout(ImportSub_UI);
        gridLayout->setObjectName("gridLayout");
        splitter = new QSplitter(ImportSub_UI);
        splitter->setObjectName("splitter");
        splitter->setOrientation(Qt::Horizontal);
        layoutWidget = new QWidget(splitter);
        layoutWidget->setObjectName("layoutWidget");
        verticalLayout = new QVBoxLayout(layoutWidget);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        groupBox_2 = new QGroupBox(layoutWidget);
        groupBox_2->setObjectName("groupBox_2");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(groupBox_2->sizePolicy().hasHeightForWidth());
        groupBox_2->setSizePolicy(sizePolicy);
        gridLayout_3 = new QGridLayout(groupBox_2);
        gridLayout_3->setObjectName("gridLayout_3");
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(groupBox_2);
        label->setObjectName("label");
        label->setMaximumSize(QSize(100, 16777215));

        horizontalLayout->addWidget(label);

        subtitle_url = new KUrlRequester(groupBox_2);
        subtitle_url->setObjectName("subtitle_url");

        horizontalLayout->addWidget(subtitle_url);


        gridLayout_3->addLayout(horizontalLayout, 0, 0, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setSpacing(6);
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        label_2 = new QLabel(groupBox_2);
        label_2->setObjectName("label_2");

        horizontalLayout_2->addWidget(label_2);

        codecs_list = new QComboBox(groupBox_2);
        codecs_list->setObjectName("codecs_list");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(codecs_list->sizePolicy().hasHeightForWidth());
        codecs_list->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(codecs_list);


        gridLayout_3->addLayout(horizontalLayout_2, 1, 0, 1, 1);


        verticalLayout->addWidget(groupBox_2);

        cursor_pos = new QCheckBox(layoutWidget);
        cursor_pos->setObjectName("cursor_pos");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Fixed);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(cursor_pos->sizePolicy().hasHeightForWidth());
        cursor_pos->setSizePolicy(sizePolicy2);

        verticalLayout->addWidget(cursor_pos);

        groupBox = new QGroupBox(layoutWidget);
        groupBox->setObjectName("groupBox");
        groupBox->setMinimumSize(QSize(0, 85));
        gridLayout_2 = new QGridLayout(groupBox);
        gridLayout_2->setObjectName("gridLayout_2");
        gridLayout_2->setSizeConstraint(QLayout::SetDefaultConstraint);
        transform_framerate_check_box = new QCheckBox(groupBox);
        transform_framerate_check_box->setObjectName("transform_framerate_check_box");

        gridLayout_2->addWidget(transform_framerate_check_box, 0, 0, 1, 9, Qt::AlignHCenter);

        caption_convert_framerate_label1 = new QLabel(groupBox);
        caption_convert_framerate_label1->setObjectName("caption_convert_framerate_label1");
        caption_convert_framerate_label1->setMaximumSize(QSize(20, 16777215));

        gridLayout_2->addWidget(caption_convert_framerate_label1, 3, 4, 1, 1);

        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer, 3, 0, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout_2->addItem(horizontalSpacer_2, 3, 7, 1, 1);

        caption_original_framerate = new QDoubleSpinBox(groupBox);
        caption_original_framerate->setObjectName("caption_original_framerate");
        caption_original_framerate->setEnabled(true);
        caption_original_framerate->setMinimumSize(QSize(75, 0));
        caption_original_framerate->setMaximumSize(QSize(100, 16777215));
        caption_original_framerate->setValue(30.000000000000000);

        gridLayout_2->addWidget(caption_original_framerate, 3, 2, 1, 1);

        caption_convert_framerate_label2 = new QLabel(groupBox);
        caption_convert_framerate_label2->setObjectName("caption_convert_framerate_label2");
        caption_convert_framerate_label2->setMaximumSize(QSize(51, 16777215));

        gridLayout_2->addWidget(caption_convert_framerate_label2, 3, 1, 1, 1);

        caption_target_framerate = new QDoubleSpinBox(groupBox);
        caption_target_framerate->setObjectName("caption_target_framerate");
        caption_target_framerate->setMinimumSize(QSize(75, 0));
        caption_target_framerate->setMaximumSize(QSize(100, 16777215));
        caption_target_framerate->setValue(30.000000000000000);

        gridLayout_2->addWidget(caption_target_framerate, 3, 5, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout_2->addItem(verticalSpacer, 4, 4, 1, 1);


        verticalLayout->addWidget(groupBox);

        splitter->addWidget(layoutWidget);
        layoutWidget1 = new QWidget(splitter);
        layoutWidget1->setObjectName("layoutWidget1");
        verticalLayout_2 = new QVBoxLayout(layoutWidget1);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout_2->setContentsMargins(0, 0, 0, 0);
        label_3 = new QLabel(layoutWidget1);
        label_3->setObjectName("label_3");
        label_3->setAlignment(Qt::AlignCenter);

        verticalLayout_2->addWidget(label_3);

        text_preview = new QPlainTextEdit(layoutWidget1);
        text_preview->setObjectName("text_preview");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Expanding);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(text_preview->sizePolicy().hasHeightForWidth());
        text_preview->setSizePolicy(sizePolicy3);
        text_preview->setAutoFillBackground(false);
        text_preview->setFrameShape(QFrame::NoFrame);
        text_preview->setReadOnly(true);

        verticalLayout_2->addWidget(text_preview);

        splitter->addWidget(layoutWidget1);

        gridLayout->addWidget(splitter, 0, 0, 1, 2);

        create_track = new QCheckBox(ImportSub_UI);
        create_track->setObjectName("create_track");

        gridLayout->addWidget(create_track, 1, 0, 1, 1);

        track_name = new QLineEdit(ImportSub_UI);
        track_name->setObjectName("track_name");
        track_name->setEnabled(false);

        gridLayout->addWidget(track_name, 1, 1, 1, 1);

        info_message = new KMessageWidget(ImportSub_UI);
        info_message->setObjectName("info_message");

        gridLayout->addWidget(info_message, 2, 0, 1, 2);

        buttonBox = new QDialogButtonBox(ImportSub_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 2);


        retranslateUi(ImportSub_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ImportSub_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ImportSub_UI, qOverload<>(&QDialog::reject));
        QObject::connect(create_track, &QCheckBox::toggled, track_name, &QLineEdit::setEnabled);

        QMetaObject::connectSlotsByName(ImportSub_UI);
    } // setupUi

    void retranslateUi(QDialog *ImportSub_UI)
    {
        ImportSub_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        groupBox_2->setTitle(QString());
        label->setText(tr2i18n("Subtitle file:", nullptr));
        label_2->setText(tr2i18n("Encoding", nullptr));
        cursor_pos->setText(tr2i18n("Import at timeline cursor position", nullptr));
        groupBox->setTitle(QString());
        transform_framerate_check_box->setText(tr2i18n("Transform framerate", nullptr));
        caption_convert_framerate_label1->setText(tr2i18n(" to ", nullptr));
        caption_convert_framerate_label2->setText(tr2i18n("From", nullptr));
        label_3->setText(tr2i18n("Subtitle Preview", nullptr));
        create_track->setText(tr2i18n("Create New Subtitle Track", nullptr));
        track_name->setPlaceholderText(tr2i18n("Subtitle Track Name", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ImportSub_UI: public Ui_ImportSub_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // IMPORT_SUBTITLE_UI_H

