/****************************************************************************
** Meta object code from reading C++ file 'subtitleedit.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/subtitleedit.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'subtitleedit.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23SimpleEditorEventFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto SimpleEditorEventFilter::qt_create_metaobjectdata<qt_meta_tag_ZN23SimpleEditorEventFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SimpleEditorEventFilter",
        "singleKeyPress",
        "",
        "QKeyEvent*",
        "event",
        "inputMethod",
        "QInputMethodEvent*",
        "shortCut",
        "triggerUpdate"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'singleKeyPress'
        QtMocHelpers::SignalData<void(QKeyEvent *)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'inputMethod'
        QtMocHelpers::SignalData<void(QInputMethodEvent *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 4 },
        }}),
        // Signal 'shortCut'
        QtMocHelpers::SignalData<void(QKeyEvent *)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'triggerUpdate'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SimpleEditorEventFilter, qt_meta_tag_ZN23SimpleEditorEventFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SimpleEditorEventFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23SimpleEditorEventFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23SimpleEditorEventFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23SimpleEditorEventFilterE_t>.metaTypes,
    nullptr
} };

void SimpleEditorEventFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SimpleEditorEventFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->singleKeyPress((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 1: _t->inputMethod((*reinterpret_cast<std::add_pointer_t<QInputMethodEvent*>>(_a[1]))); break;
        case 2: _t->shortCut((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 3: _t->triggerUpdate(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SimpleEditorEventFilter::*)(QKeyEvent * )>(_a, &SimpleEditorEventFilter::singleKeyPress, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleEditorEventFilter::*)(QInputMethodEvent * )>(_a, &SimpleEditorEventFilter::inputMethod, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleEditorEventFilter::*)(QKeyEvent * )>(_a, &SimpleEditorEventFilter::shortCut, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (SimpleEditorEventFilter::*)()>(_a, &SimpleEditorEventFilter::triggerUpdate, 3))
            return;
    }
}

const QMetaObject *SimpleEditorEventFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SimpleEditorEventFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23SimpleEditorEventFilterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int SimpleEditorEventFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void SimpleEditorEventFilter::singleKeyPress(QKeyEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SimpleEditorEventFilter::inputMethod(QInputMethodEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void SimpleEditorEventFilter::shortCut(QKeyEvent * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void SimpleEditorEventFilter::triggerUpdate()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN12SubtitleEditE_t {};
} // unnamed namespace

template <> constexpr inline auto SubtitleEdit::qt_create_metaobjectdata<qt_meta_tag_ZN12SubtitleEditE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SubtitleEdit",
        "addSubtitle",
        "",
        "cutSubtitle",
        "id",
        "cursorPos",
        "showSubtitleManager",
        "page",
        "setActiveSubtitle",
        "updateSubtitle",
        "goToPrevious",
        "goToNext",
        "slotZoomIn",
        "slotZoomOut",
        "syncSimpleText",
        "slotToggleBold",
        "slotToggleItalic",
        "slotToggleUnderline",
        "slotToggleStrikeOut",
        "slotSelectFont",
        "slotResetStyle",
        "slotSetPosition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addSubtitle'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'cutSubtitle'
        QtMocHelpers::SignalData<void(int, int)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'showSubtitleManager'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'setActiveSubtitle'
        QtMocHelpers::SlotData<void(int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'updateSubtitle'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToPrevious'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'goToNext'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'syncSimpleText'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleBold'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleItalic'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleUnderline'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleStrikeOut'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectFont'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResetStyle'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SubtitleEdit, qt_meta_tag_ZN12SubtitleEditE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SubtitleEdit::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubtitleEditE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubtitleEditE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12SubtitleEditE_t>.metaTypes,
    nullptr
} };

void SubtitleEdit::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SubtitleEdit *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addSubtitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->cutSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 2: _t->showSubtitleManager((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->setActiveSubtitle((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->updateSubtitle(); break;
        case 5: _t->goToPrevious(); break;
        case 6: _t->goToNext(); break;
        case 7: _t->slotZoomIn(); break;
        case 8: _t->slotZoomOut(); break;
        case 9: _t->syncSimpleText(); break;
        case 10: _t->slotToggleBold(); break;
        case 11: _t->slotToggleItalic(); break;
        case 12: _t->slotToggleUnderline(); break;
        case 13: _t->slotToggleStrikeOut(); break;
        case 14: _t->slotSelectFont(); break;
        case 15: _t->slotResetStyle(); break;
        case 16: _t->slotSetPosition(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SubtitleEdit::*)(const QString & )>(_a, &SubtitleEdit::addSubtitle, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubtitleEdit::*)(int , int )>(_a, &SubtitleEdit::cutSubtitle, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (SubtitleEdit::*)(int )>(_a, &SubtitleEdit::showSubtitleManager, 2))
            return;
    }
}

const QMetaObject *SubtitleEdit::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SubtitleEdit::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12SubtitleEditE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::SubEdit_UI"))
        return static_cast< Ui::SubEdit_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int SubtitleEdit::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void SubtitleEdit::addSubtitle(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void SubtitleEdit::cutSubtitle(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void SubtitleEdit::showSubtitleManager(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}
QT_WARNING_POP
