/********************************************************************************
** Form generated from reading UI file 'customjobinterface_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUSTOMJOBINTERFACE_UI_H
#define UI_CUSTOMJOBINTERFACE_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QVBoxLayout>
#include <klocalizedstring.h>
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CustomJobInterface_UI
{
public:
    QVBoxLayout *verticalLayout;
    QLabel *param1Label;
    KUrlRequester *param1Url;
    QComboBox *param1List;
    QLabel *param2Label;
    KUrlRequester *param2Url;
    QComboBox *param2List;
    QTextEdit *taskDescription;
    QSpacerItem *verticalSpacer;
    QDialogButtonBox *buttonBox;

    void setupUi(QDialog *CustomJobInterface_UI)
    {
        if (CustomJobInterface_UI->objectName().isEmpty())
            CustomJobInterface_UI->setObjectName("CustomJobInterface_UI");
        CustomJobInterface_UI->resize(281, 341);
        verticalLayout = new QVBoxLayout(CustomJobInterface_UI);
        verticalLayout->setObjectName("verticalLayout");
        param1Label = new QLabel(CustomJobInterface_UI);
        param1Label->setObjectName("param1Label");

        verticalLayout->addWidget(param1Label);

        param1Url = new KUrlRequester(CustomJobInterface_UI);
        param1Url->setObjectName("param1Url");

        verticalLayout->addWidget(param1Url);

        param1List = new QComboBox(CustomJobInterface_UI);
        param1List->setObjectName("param1List");

        verticalLayout->addWidget(param1List);

        param2Label = new QLabel(CustomJobInterface_UI);
        param2Label->setObjectName("param2Label");

        verticalLayout->addWidget(param2Label);

        param2Url = new KUrlRequester(CustomJobInterface_UI);
        param2Url->setObjectName("param2Url");

        verticalLayout->addWidget(param2Url);

        param2List = new QComboBox(CustomJobInterface_UI);
        param2List->setObjectName("param2List");

        verticalLayout->addWidget(param2List);

        taskDescription = new QTextEdit(CustomJobInterface_UI);
        taskDescription->setObjectName("taskDescription");
        taskDescription->setFrameShape(QFrame::NoFrame);
        taskDescription->setReadOnly(true);

        verticalLayout->addWidget(taskDescription);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        buttonBox = new QDialogButtonBox(CustomJobInterface_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        verticalLayout->addWidget(buttonBox);


        retranslateUi(CustomJobInterface_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CustomJobInterface_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CustomJobInterface_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(CustomJobInterface_UI);
    } // setupUi

    void retranslateUi(QDialog *CustomJobInterface_UI)
    {
        CustomJobInterface_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        param1Label->setText(tr2i18n("TextLabel", nullptr));
        param2Label->setText(tr2i18n("TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CustomJobInterface_UI: public Ui_CustomJobInterface_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUSTOMJOBINTERFACE_UI_H

