/********************************************************************************
** Form generated from reading UI file 'exportguidesdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_EXPORTGUIDESDIALOG_UI_H
#define UI_EXPORTGUIDESDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "widgets/markercategorychooser.h"
#include "widgets/timecodedisplay.h"

QT_BEGIN_NAMESPACE

class Ui_ExportGuidesDialog_UI
{
public:
    QGridLayout *gridLayout;
    QPlainTextEdit *generatedContent;
    QDialogButtonBox *buttonBox;
    QGroupBox *textOptions;
    QFormLayout *formLayout;
    QLabel *label_4;
    QLabel *label;
    QHBoxLayout *horizontalLayout_2;
    QLineEdit *formatEdit;
    QToolButton *infoButton;
    QToolButton *buttonReset;
    QHBoxLayout *horizontalLayout;
    QComboBox *offsetTimeComboBox;
    TimecodeDisplay *offsetTimeSpinbox;
    KMessageWidget *messageWidget;
    QLabel *label_3;
    QSpacerItem *horizontalSpacer;
    QRadioButton *format_text;
    QRadioButton *format_json;
    MarkerCategoryChooser *categoryChooser;
    QLabel *label_5;
    QLabel *label_2;
    QRadioButton *format_ffmpeg;

    void setupUi(QDialog *ExportGuidesDialog_UI)
    {
        if (ExportGuidesDialog_UI->objectName().isEmpty())
            ExportGuidesDialog_UI->setObjectName("ExportGuidesDialog_UI");
        ExportGuidesDialog_UI->resize(489, 450);
        gridLayout = new QGridLayout(ExportGuidesDialog_UI);
        gridLayout->setObjectName("gridLayout");
        generatedContent = new QPlainTextEdit(ExportGuidesDialog_UI);
        generatedContent->setObjectName("generatedContent");
        generatedContent->setReadOnly(true);

        gridLayout->addWidget(generatedContent, 4, 0, 1, 5);

        buttonBox = new QDialogButtonBox(ExportGuidesDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 6, 0, 1, 5);

        textOptions = new QGroupBox(ExportGuidesDialog_UI);
        textOptions->setObjectName("textOptions");
        textOptions->setFlat(false);
        formLayout = new QFormLayout(textOptions);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(textOptions);
        label_4->setObjectName("label_4");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_4->sizePolicy().hasHeightForWidth());
        label_4->setSizePolicy(sizePolicy);

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label_4);

        label = new QLabel(textOptions);
        label->setObjectName("label");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        formatEdit = new QLineEdit(textOptions);
        formatEdit->setObjectName("formatEdit");

        horizontalLayout_2->addWidget(formatEdit);

        infoButton = new QToolButton(textOptions);
        infoButton->setObjectName("infoButton");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("help-about");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        infoButton->setIcon(icon);
        infoButton->setPopupMode(QToolButton::InstantPopup);
        infoButton->setArrowType(Qt::NoArrow);

        horizontalLayout_2->addWidget(infoButton);

        buttonReset = new QToolButton(textOptions);
        buttonReset->setObjectName("buttonReset");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-reset");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("../../../../.designer/backup"), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        buttonReset->setIcon(icon1);

        horizontalLayout_2->addWidget(buttonReset);


        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        offsetTimeComboBox = new QComboBox(textOptions);
        offsetTimeComboBox->addItem(QString());
        offsetTimeComboBox->addItem(QString());
        offsetTimeComboBox->addItem(QString());
        offsetTimeComboBox->setObjectName("offsetTimeComboBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(offsetTimeComboBox->sizePolicy().hasHeightForWidth());
        offsetTimeComboBox->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(offsetTimeComboBox);

        offsetTimeSpinbox = new TimecodeDisplay(textOptions);
        offsetTimeSpinbox->setObjectName("offsetTimeSpinbox");

        horizontalLayout->addWidget(offsetTimeSpinbox);


        formLayout->setLayout(0, QFormLayout::ItemRole::FieldRole, horizontalLayout);


        gridLayout->addWidget(textOptions, 2, 0, 1, 5);

        messageWidget = new KMessageWidget(ExportGuidesDialog_UI);
        messageWidget->setObjectName("messageWidget");
        messageWidget->setCloseButtonVisible(true);

        gridLayout->addWidget(messageWidget, 5, 0, 1, 5);

        label_3 = new QLabel(ExportGuidesDialog_UI);
        label_3->setObjectName("label_3");
        sizePolicy.setHeightForWidth(label_3->sizePolicy().hasHeightForWidth());
        label_3->setSizePolicy(sizePolicy);

        gridLayout->addWidget(label_3, 0, 0, 1, 1);

        horizontalSpacer = new QSpacerItem(55, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer, 1, 4, 1, 1);

        format_text = new QRadioButton(ExportGuidesDialog_UI);
        format_text->setObjectName("format_text");
        format_text->setChecked(true);

        gridLayout->addWidget(format_text, 1, 1, 1, 1);

        format_json = new QRadioButton(ExportGuidesDialog_UI);
        format_json->setObjectName("format_json");

        gridLayout->addWidget(format_json, 1, 3, 1, 1);

        categoryChooser = new MarkerCategoryChooser(ExportGuidesDialog_UI);
        categoryChooser->setObjectName("categoryChooser");
        sizePolicy1.setHeightForWidth(categoryChooser->sizePolicy().hasHeightForWidth());
        categoryChooser->setSizePolicy(sizePolicy1);
        categoryChooser->setProperty("onlyUsed", QVariant(true));

        gridLayout->addWidget(categoryChooser, 0, 1, 1, 4);

        label_5 = new QLabel(ExportGuidesDialog_UI);
        label_5->setObjectName("label_5");

        gridLayout->addWidget(label_5, 1, 0, 1, 1);

        label_2 = new QLabel(ExportGuidesDialog_UI);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 5);

        format_ffmpeg = new QRadioButton(ExportGuidesDialog_UI);
        format_ffmpeg->setObjectName("format_ffmpeg");

        gridLayout->addWidget(format_ffmpeg, 1, 2, 1, 1);

        QWidget::setTabOrder(categoryChooser, format_text);
        QWidget::setTabOrder(format_text, format_ffmpeg);
        QWidget::setTabOrder(format_ffmpeg, format_json);
        QWidget::setTabOrder(format_json, offsetTimeComboBox);
        QWidget::setTabOrder(offsetTimeComboBox, formatEdit);
        QWidget::setTabOrder(formatEdit, infoButton);
        QWidget::setTabOrder(infoButton, buttonReset);
        QWidget::setTabOrder(buttonReset, generatedContent);

        retranslateUi(ExportGuidesDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ExportGuidesDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ExportGuidesDialog_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ExportGuidesDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *ExportGuidesDialog_UI)
    {
        ExportGuidesDialog_UI->setWindowTitle(tr2i18n("Marker", nullptr));
        generatedContent->setPlaceholderText(tr2i18n("Formatted chapter marker text will be generated here.", nullptr));
        textOptions->setTitle(tr2i18n("Text Options", nullptr));
        label_4->setText(tr2i18n("Offset:", nullptr));
        label->setText(tr2i18n("Format:", nullptr));
        infoButton->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonReset->setToolTip(tr2i18n("Reset", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonReset->setText(tr2i18n("...", nullptr));
        offsetTimeComboBox->setItemText(0, tr2i18n("Disabled", nullptr));
        offsetTimeComboBox->setItemText(1, tr2i18n("Add", nullptr));
        offsetTimeComboBox->setItemText(2, tr2i18n("Subtract", nullptr));

        label_3->setText(tr2i18n("Marker Type:", nullptr));
        format_text->setText(tr2i18n("Text File", nullptr));
        format_json->setText(tr2i18n("Kdenlive JSON", nullptr));
        label_5->setText(tr2i18n("Save As:", nullptr));
        label_2->setText(tr2i18n("Exported:", nullptr));
        format_ffmpeg->setText(tr2i18n("FFmpeg Chapters", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ExportGuidesDialog_UI: public Ui_ExportGuidesDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // EXPORTGUIDESDIALOG_UI_H

