/****************************************************************************
** Meta object code from reading C++ file 'encodingprofilesdialog.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/encodingprofilesdialog.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'encodingprofilesdialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN22EncodingProfilesDialogE_t {};
} // unnamed namespace

template <> constexpr inline auto EncodingProfilesDialog::qt_create_metaobjectdata<qt_meta_tag_ZN22EncodingProfilesDialogE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EncodingProfilesDialog",
        "slotLoadProfiles",
        "",
        "slotShowParams",
        "slotDeleteProfile",
        "slotAddProfile",
        "slotEditProfile"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotLoadProfiles'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowParams'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteProfile'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddProfile'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditProfile'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncodingProfilesDialog, qt_meta_tag_ZN22EncodingProfilesDialogE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EncodingProfilesDialog::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EncodingProfilesDialogE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EncodingProfilesDialogE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN22EncodingProfilesDialogE_t>.metaTypes,
    nullptr
} };

void EncodingProfilesDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncodingProfilesDialog *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotLoadProfiles(); break;
        case 1: _t->slotShowParams(); break;
        case 2: _t->slotDeleteProfile(); break;
        case 3: _t->slotAddProfile(); break;
        case 4: _t->slotEditProfile(); break;
        default: ;
        }
    }
    (void)_a;
}

const QMetaObject *EncodingProfilesDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EncodingProfilesDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN22EncodingProfilesDialogE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ManageEncodingProfile_UI"))
        return static_cast< Ui::ManageEncodingProfile_UI*>(this);
    return QDialog::qt_metacast(_clname);
}

int EncodingProfilesDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN23EncodingProfilesChooserE_t {};
} // unnamed namespace

template <> constexpr inline auto EncodingProfilesChooser::qt_create_metaobjectdata<qt_meta_tag_ZN23EncodingProfilesChooserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EncodingProfilesChooser",
        "slotUpdateProfile",
        "",
        "ix",
        "slotManageEncodingProfile",
        "loadEncodingProfiles"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'slotUpdateProfile'
        QtMocHelpers::SlotData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Slot 'slotManageEncodingProfile'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadEncodingProfiles'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncodingProfilesChooser, qt_meta_tag_ZN23EncodingProfilesChooserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EncodingProfilesChooser::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23EncodingProfilesChooserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23EncodingProfilesChooserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23EncodingProfilesChooserE_t>.metaTypes,
    nullptr
} };

void EncodingProfilesChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncodingProfilesChooser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->slotUpdateProfile((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->slotManageEncodingProfile(); break;
        case 2: _t->loadEncodingProfiles(); break;
        default: ;
        }
    }
}

const QMetaObject *EncodingProfilesChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EncodingProfilesChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23EncodingProfilesChooserE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EncodingProfilesChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t {};
} // unnamed namespace

template <> constexpr inline auto EncodingTimelinePreviewProfilesChooser::qt_create_metaobjectdata<qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EncodingTimelinePreviewProfilesChooser",
        "currentIndexChanged",
        "",
        "loadEncodingProfiles"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentIndexChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadEncodingProfiles'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EncodingTimelinePreviewProfilesChooser, qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EncodingTimelinePreviewProfilesChooser::staticMetaObject = { {
    QMetaObject::SuperData::link<EncodingProfilesChooser::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>.metaTypes,
    nullptr
} };

void EncodingTimelinePreviewProfilesChooser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EncodingTimelinePreviewProfilesChooser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentIndexChanged(); break;
        case 1: _t->loadEncodingProfiles(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EncodingTimelinePreviewProfilesChooser::*)()>(_a, &EncodingTimelinePreviewProfilesChooser::currentIndexChanged, 0))
            return;
    }
}

const QMetaObject *EncodingTimelinePreviewProfilesChooser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EncodingTimelinePreviewProfilesChooser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN38EncodingTimelinePreviewProfilesChooserE_t>.strings))
        return static_cast<void*>(this);
    return EncodingProfilesChooser::qt_metacast(_clname);
}

int EncodingTimelinePreviewProfilesChooser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = EncodingProfilesChooser::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void EncodingTimelinePreviewProfilesChooser::currentIndexChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
