/********************************************************************************
** Form generated from reading UI file 'speechdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPEECHDIALOG_UI_H
#define UI_SPEECHDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_SpeechDialog_UI
{
public:
    QGridLayout *gridLayout;
    QRadioButton *timeline_zone;
    KMessageWidget *speech_info;
    QPlainTextEdit *logOutput;
    QComboBox *speech_model;
    QSpacerItem *verticalSpacer;
    QRadioButton *timeline_clips;
    QDialogButtonBox *buttonBox;
    QLabel *label;
    QRadioButton *timeline_track;
    QRadioButton *timeline_full;
    QGroupBox *whisper_settings;
    QGridLayout *gridLayout_2;
    QLabel *label_2;
    QComboBox *speech_language;
    QHBoxLayout *horizontalLayout_2;
    QCheckBox *check_maxchars;
    QSpinBox *maxChars;
    QCheckBox *translate_seamless;
    QCheckBox *translate_box;
    QHBoxLayout *horizontalLayout_3;
    QLabel *seamless_out_label;
    QComboBox *seamless_out;
    QHBoxLayout *horizontalLayout;
    QLabel *seamless_in_label;
    QComboBox *seamless_in;
    QFrame *frame_progress;
    QGridLayout *gridLayout_3;
    QToolButton *button_abort;
    QProgressBar *speech_progress;

    void setupUi(QDialog *SpeechDialog_UI)
    {
        if (SpeechDialog_UI->objectName().isEmpty())
            SpeechDialog_UI->setObjectName("SpeechDialog_UI");
        SpeechDialog_UI->resize(374, 611);
        gridLayout = new QGridLayout(SpeechDialog_UI);
        gridLayout->setObjectName("gridLayout");
        timeline_zone = new QRadioButton(SpeechDialog_UI);
        timeline_zone->setObjectName("timeline_zone");
        timeline_zone->setChecked(true);

        gridLayout->addWidget(timeline_zone, 3, 0, 1, 3);

        speech_info = new KMessageWidget(SpeechDialog_UI);
        speech_info->setObjectName("speech_info");
        speech_info->setCloseButtonVisible(false);

        gridLayout->addWidget(speech_info, 9, 0, 1, 3);

        logOutput = new QPlainTextEdit(SpeechDialog_UI);
        logOutput->setObjectName("logOutput");
        logOutput->setAutoFillBackground(false);
        logOutput->setReadOnly(true);
        logOutput->setBackgroundVisible(false);

        gridLayout->addWidget(logOutput, 10, 0, 1, 3);

        speech_model = new QComboBox(SpeechDialog_UI);
        speech_model->setObjectName("speech_model");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(speech_model->sizePolicy().hasHeightForWidth());
        speech_model->setSizePolicy(sizePolicy);

        gridLayout->addWidget(speech_model, 0, 1, 1, 2);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 6, 0, 1, 1);

        timeline_clips = new QRadioButton(SpeechDialog_UI);
        timeline_clips->setObjectName("timeline_clips");

        gridLayout->addWidget(timeline_clips, 5, 0, 1, 3);

        buttonBox = new QDialogButtonBox(SpeechDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 11, 2, 1, 1);

        label = new QLabel(SpeechDialog_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 0, 0, 1, 1);

        timeline_track = new QRadioButton(SpeechDialog_UI);
        timeline_track->setObjectName("timeline_track");

        gridLayout->addWidget(timeline_track, 4, 0, 1, 3);

        timeline_full = new QRadioButton(SpeechDialog_UI);
        timeline_full->setObjectName("timeline_full");

        gridLayout->addWidget(timeline_full, 2, 0, 1, 3);

        whisper_settings = new QGroupBox(SpeechDialog_UI);
        whisper_settings->setObjectName("whisper_settings");
        whisper_settings->setFlat(true);
        gridLayout_2 = new QGridLayout(whisper_settings);
        gridLayout_2->setObjectName("gridLayout_2");
        label_2 = new QLabel(whisper_settings);
        label_2->setObjectName("label_2");

        gridLayout_2->addWidget(label_2, 0, 0, 1, 1);

        speech_language = new QComboBox(whisper_settings);
        speech_language->setObjectName("speech_language");
        sizePolicy.setHeightForWidth(speech_language->sizePolicy().hasHeightForWidth());
        speech_language->setSizePolicy(sizePolicy);

        gridLayout_2->addWidget(speech_language, 0, 1, 1, 1);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        check_maxchars = new QCheckBox(whisper_settings);
        check_maxchars->setObjectName("check_maxchars");

        horizontalLayout_2->addWidget(check_maxchars);

        maxChars = new QSpinBox(whisper_settings);
        maxChars->setObjectName("maxChars");
        maxChars->setEnabled(false);
        maxChars->setValue(42);

        horizontalLayout_2->addWidget(maxChars);


        gridLayout_2->addLayout(horizontalLayout_2, 1, 0, 1, 2);

        translate_seamless = new QCheckBox(whisper_settings);
        translate_seamless->setObjectName("translate_seamless");

        gridLayout_2->addWidget(translate_seamless, 2, 0, 1, 1);

        translate_box = new QCheckBox(whisper_settings);
        translate_box->setObjectName("translate_box");

        gridLayout_2->addWidget(translate_box, 3, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        seamless_out_label = new QLabel(whisper_settings);
        seamless_out_label->setObjectName("seamless_out_label");

        horizontalLayout_3->addWidget(seamless_out_label);

        seamless_out = new QComboBox(whisper_settings);
        seamless_out->setObjectName("seamless_out");

        horizontalLayout_3->addWidget(seamless_out);


        gridLayout_2->addLayout(horizontalLayout_3, 5, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        seamless_in_label = new QLabel(whisper_settings);
        seamless_in_label->setObjectName("seamless_in_label");

        horizontalLayout->addWidget(seamless_in_label);

        seamless_in = new QComboBox(whisper_settings);
        seamless_in->setObjectName("seamless_in");

        horizontalLayout->addWidget(seamless_in);


        gridLayout_2->addLayout(horizontalLayout, 4, 0, 1, 2);


        gridLayout->addWidget(whisper_settings, 1, 0, 1, 3);

        frame_progress = new QFrame(SpeechDialog_UI);
        frame_progress->setObjectName("frame_progress");
        frame_progress->setFrameShape(QFrame::NoFrame);
        frame_progress->setFrameShadow(QFrame::Plain);
        gridLayout_3 = new QGridLayout(frame_progress);
        gridLayout_3->setObjectName("gridLayout_3");
        button_abort = new QToolButton(frame_progress);
        button_abort->setObjectName("button_abort");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("process-stop");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        button_abort->setIcon(icon);
        button_abort->setAutoRaise(true);

        gridLayout_3->addWidget(button_abort, 0, 0, 1, 1);

        speech_progress = new QProgressBar(frame_progress);
        speech_progress->setObjectName("speech_progress");
        sizePolicy.setHeightForWidth(speech_progress->sizePolicy().hasHeightForWidth());
        speech_progress->setSizePolicy(sizePolicy);
        speech_progress->setValue(24);

        gridLayout_3->addWidget(speech_progress, 0, 1, 1, 1);


        gridLayout->addWidget(frame_progress, 8, 0, 1, 3);

        QWidget::setTabOrder(speech_model, speech_language);
        QWidget::setTabOrder(speech_language, translate_box);
        QWidget::setTabOrder(translate_box, timeline_full);
        QWidget::setTabOrder(timeline_full, timeline_zone);
        QWidget::setTabOrder(timeline_zone, timeline_track);
        QWidget::setTabOrder(timeline_track, timeline_clips);
        QWidget::setTabOrder(timeline_clips, button_abort);

        retranslateUi(SpeechDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SpeechDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SpeechDialog_UI, qOverload<>(&QDialog::reject));
        QObject::connect(check_maxchars, &QCheckBox::toggled, maxChars, &QSpinBox::setEnabled);

        QMetaObject::connectSlotsByName(SpeechDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *SpeechDialog_UI)
    {
        SpeechDialog_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        timeline_zone->setText(tr2i18n("Timeline zone (all tracks)", nullptr));
        timeline_clips->setText(tr2i18n("Selected clip", nullptr));
        label->setText(tr2i18n("Model", nullptr));
        timeline_track->setText(tr2i18n("Timeline zone (selected track)", nullptr));
        timeline_full->setText(tr2i18n("Full project", nullptr));
        whisper_settings->setTitle(QString());
        label_2->setText(tr2i18n("Language", nullptr));
        check_maxchars->setText(tr2i18n("Maximum characters per line", nullptr));
        translate_seamless->setText(tr2i18n("Translate with SeamlessM4T", nullptr));
        translate_box->setText(tr2i18n("Translate to English", nullptr));
        seamless_out_label->setText(tr2i18n("Output language", nullptr));
        seamless_in_label->setText(tr2i18n("Input language", nullptr));
        button_abort->setText(tr2i18n("...", nullptr));
        speech_progress->setFormat(tr2i18n("%p%", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpeechDialog_UI: public Ui_SpeechDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPEECHDIALOG_UI_H

