/****************************************************************************
** Meta object code from reading C++ file 'titlewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/titler/titlewidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'titlewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11TitleWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto TitleWidget::qt_create_metaobjectdata<qt_meta_tag_ZN11TitleWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TitleWidget",
        "requestBackgroundFrame",
        "",
        "request",
        "updatePatternsBackgroundFrame",
        "slotNewText",
        "MyTextItem*",
        "tt",
        "slotNewRect",
        "QGraphicsRectItem*",
        "rect",
        "slotNewEllipse",
        "QGraphicsEllipseItem*",
        "slotChangeBackground",
        "selectionChanged",
        "rectChanged",
        "zIndexChanged",
        "itemScaled",
        "itemRotateX",
        "itemRotateY",
        "itemRotateZ",
        "saveTitle",
        "QUrl",
        "url",
        "loadTitle",
        "slotGotBackground",
        "QImage",
        "img",
        "slotOriginXClicked",
        "slotOriginYClicked",
        "slotChanged",
        "slotValueChanged",
        "valueType",
        "slotZoom",
        "up",
        "slotUpdateZoom",
        "pos",
        "slotAdjustZoom",
        "slotZoomOneToOne",
        "slotSelectAll",
        "slotSelectText",
        "slotSelectRects",
        "slotSelectEllipses",
        "slotSelectImages",
        "slotSelectNone",
        "slotUpdateText",
        "slotInsertUnicode",
        "slotInsertUnicodeString",
        "string",
        "displayBackgroundFrame",
        "setCurrentItem",
        "QGraphicsItem*",
        "item",
        "slotTextTool",
        "slotRectTool",
        "slotEllipseTool",
        "slotSelectTool",
        "slotImageTool",
        "slotAnimStart",
        "slotAnimEnd",
        "slotKeepAspect",
        "keep",
        "itemHCenter",
        "itemVCenter",
        "itemTop",
        "itemBottom",
        "itemLeft",
        "itemRight",
        "slotResize",
        "percentSize",
        "showGuides",
        "state",
        "updateGuides",
        "guideColorChanged",
        "QColor",
        "col",
        "slotAccepted",
        "slotAddEffect",
        "ix",
        "slotZIndexUp",
        "slotZIndexDown",
        "slotZIndexTop",
        "slotZIndexBottom",
        "templateIndexChanged",
        "slotEditGradient",
        "slotUpdateShadow",
        "slotUpdateTW",
        "deleteMissingItems",
        "showMissingItems",
        "slotPatternsTileWidth",
        "width",
        "slotPatternDblClicked",
        "QModelIndex",
        "idx",
        "slotPatternBtnAddClicked",
        "slotPatternBtnRemoveClicked",
        "updateItemRatio",
        "Qt::CheckState",
        "scalePixmap",
        "scalex",
        "scaley",
        "GraphicsSceneRectMove::resizeModes",
        "resize",
        "center",
        "seekTimeline"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'requestBackgroundFrame'
        QtMocHelpers::SignalData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 3 },
        }}),
        // Signal 'updatePatternsBackgroundFrame'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotNewText'
        QtMocHelpers::SlotData<void(MyTextItem *)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 7 },
        }}),
        // Slot 'slotNewRect'
        QtMocHelpers::SlotData<void(QGraphicsRectItem *)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotNewEllipse'
        QtMocHelpers::SlotData<void(QGraphicsEllipseItem *)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 10 },
        }}),
        // Slot 'slotChangeBackground'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'selectionChanged'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'rectChanged'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'zIndexChanged'
        QtMocHelpers::SlotData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'itemScaled'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'itemRotateX'
        QtMocHelpers::SlotData<void(int)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'itemRotateY'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'itemRotateZ'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'saveTitle'
        QtMocHelpers::SlotData<QUrl(QUrl)>(21, 2, QMC::AccessPublic, 0x80000000 | 22, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'saveTitle'
        QtMocHelpers::SlotData<QUrl()>(21, 2, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 22),
        // Slot 'loadTitle'
        QtMocHelpers::SlotData<void(QUrl)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 22, 23 },
        }}),
        // Slot 'loadTitle'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotGotBackground'
        QtMocHelpers::SlotData<void(const QImage &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 26, 27 },
        }}),
        // Slot 'slotOriginXClicked'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotOriginYClicked'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotChanged'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotValueChanged'
        QtMocHelpers::SlotData<void(int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 32 },
        }}),
        // Slot 'slotZoom'
        QtMocHelpers::SlotData<void(bool)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 34 },
        }}),
        // Slot 'slotUpdateZoom'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 36 },
        }}),
        // Slot 'slotAdjustZoom'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZoomOneToOne'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectAll'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectText'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectRects'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectEllipses'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectImages'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectNone'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateText'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInsertUnicode'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInsertUnicodeString'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'displayBackgroundFrame'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setCurrentItem'
        QtMocHelpers::SlotData<void(QGraphicsItem *)>(50, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 },
        }}),
        // Slot 'slotTextTool'
        QtMocHelpers::SlotData<void()>(53, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRectTool'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEllipseTool'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectTool'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImageTool'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAnimStart'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotAnimEnd'
        QtMocHelpers::SlotData<void(bool)>(59, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'slotKeepAspect'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 61 },
        }}),
        // Slot 'itemHCenter'
        QtMocHelpers::SlotData<void()>(62, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemVCenter'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemTop'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemBottom'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemLeft'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'itemRight'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResize'
        QtMocHelpers::SlotData<void(int)>(68, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 69 },
        }}),
        // Slot 'showGuides'
        QtMocHelpers::SlotData<void(int)>(70, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 71 },
        }}),
        // Slot 'updateGuides'
        QtMocHelpers::SlotData<void(int)>(72, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'guideColorChanged'
        QtMocHelpers::SlotData<void(const QColor &)>(73, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 74, 75 },
        }}),
        // Slot 'slotAccepted'
        QtMocHelpers::SlotData<void()>(76, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddEffect'
        QtMocHelpers::SlotData<void(int)>(77, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 78 },
        }}),
        // Slot 'slotZIndexUp'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZIndexDown'
        QtMocHelpers::SlotData<void()>(80, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZIndexTop'
        QtMocHelpers::SlotData<void()>(81, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotZIndexBottom'
        QtMocHelpers::SlotData<void()>(82, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'templateIndexChanged'
        QtMocHelpers::SlotData<void(int)>(83, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotEditGradient'
        QtMocHelpers::SlotData<void()>(84, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateShadow'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateTW'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteMissingItems'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMissingItems'
        QtMocHelpers::SlotData<void()>(88, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPatternsTileWidth'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotPatternDblClicked'
        QtMocHelpers::SlotData<void(const QModelIndex &)>(91, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 92, 93 },
        }}),
        // Slot 'slotPatternBtnAddClicked'
        QtMocHelpers::SlotData<void()>(94, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPatternBtnRemoveClicked'
        QtMocHelpers::SlotData<void()>(95, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateItemRatio'
        QtMocHelpers::SlotData<void(Qt::CheckState)>(96, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 97, 71 },
        }}),
        // Slot 'scalePixmap'
        QtMocHelpers::SlotData<void(QGraphicsItem *, double, double, GraphicsSceneRectMove::resizeModes, bool)>(98, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 51, 52 }, { QMetaType::Double, 99 }, { QMetaType::Double, 100 }, { 0x80000000 | 101, 102 },
            { QMetaType::Bool, 103 },
        }}),
        // Slot 'scalePixmap'
        QtMocHelpers::SlotData<void(QGraphicsItem *, double, double, GraphicsSceneRectMove::resizeModes)>(98, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 51, 52 }, { QMetaType::Double, 99 }, { QMetaType::Double, 100 }, { 0x80000000 | 101, 102 },
        }}),
        // Slot 'seekTimeline'
        QtMocHelpers::SlotData<void()>(104, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TitleWidget, qt_meta_tag_ZN11TitleWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TitleWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TitleWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TitleWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11TitleWidgetE_t>.metaTypes,
    nullptr
} };

void TitleWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TitleWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->requestBackgroundFrame((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->updatePatternsBackgroundFrame(); break;
        case 2: _t->slotNewText((*reinterpret_cast<std::add_pointer_t<MyTextItem*>>(_a[1]))); break;
        case 3: _t->slotNewRect((*reinterpret_cast<std::add_pointer_t<QGraphicsRectItem*>>(_a[1]))); break;
        case 4: _t->slotNewEllipse((*reinterpret_cast<std::add_pointer_t<QGraphicsEllipseItem*>>(_a[1]))); break;
        case 5: _t->slotChangeBackground(); break;
        case 6: _t->selectionChanged(); break;
        case 7: _t->rectChanged(); break;
        case 8: _t->zIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->itemScaled((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->itemRotateX((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->itemRotateY((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->itemRotateZ((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: { QUrl _r = _t->saveTitle((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 14: { QUrl _r = _t->saveTitle();
            if (_a[0]) *reinterpret_cast<QUrl*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->loadTitle((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 16: _t->loadTitle(); break;
        case 17: _t->slotGotBackground((*reinterpret_cast<std::add_pointer_t<QImage>>(_a[1]))); break;
        case 18: _t->slotOriginXClicked(); break;
        case 19: _t->slotOriginYClicked(); break;
        case 20: _t->slotChanged(); break;
        case 21: _t->slotValueChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->slotZoom((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->slotUpdateZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 24: _t->slotAdjustZoom(); break;
        case 25: _t->slotZoomOneToOne(); break;
        case 26: _t->slotSelectAll(); break;
        case 27: _t->slotSelectText(); break;
        case 28: _t->slotSelectRects(); break;
        case 29: _t->slotSelectEllipses(); break;
        case 30: _t->slotSelectImages(); break;
        case 31: _t->slotSelectNone(); break;
        case 32: _t->slotUpdateText(); break;
        case 33: _t->slotInsertUnicode(); break;
        case 34: _t->slotInsertUnicodeString((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 35: _t->displayBackgroundFrame(); break;
        case 36: _t->setCurrentItem((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1]))); break;
        case 37: _t->slotTextTool(); break;
        case 38: _t->slotRectTool(); break;
        case 39: _t->slotEllipseTool(); break;
        case 40: _t->slotSelectTool(); break;
        case 41: _t->slotImageTool(); break;
        case 42: _t->slotAnimStart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 43: _t->slotAnimEnd((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->slotKeepAspect((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 45: _t->itemHCenter(); break;
        case 46: _t->itemVCenter(); break;
        case 47: _t->itemTop(); break;
        case 48: _t->itemBottom(); break;
        case 49: _t->itemLeft(); break;
        case 50: _t->itemRight(); break;
        case 51: _t->slotResize((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 52: _t->showGuides((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 53: _t->updateGuides((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 54: _t->guideColorChanged((*reinterpret_cast<std::add_pointer_t<QColor>>(_a[1]))); break;
        case 55: _t->slotAccepted(); break;
        case 56: _t->slotAddEffect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 57: _t->slotZIndexUp(); break;
        case 58: _t->slotZIndexDown(); break;
        case 59: _t->slotZIndexTop(); break;
        case 60: _t->slotZIndexBottom(); break;
        case 61: _t->templateIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: _t->slotEditGradient(); break;
        case 63: _t->slotUpdateShadow(); break;
        case 64: _t->slotUpdateTW(); break;
        case 65: _t->deleteMissingItems(); break;
        case 66: _t->showMissingItems(); break;
        case 67: _t->slotPatternsTileWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 68: _t->slotPatternDblClicked((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1]))); break;
        case 69: _t->slotPatternBtnAddClicked(); break;
        case 70: _t->slotPatternBtnRemoveClicked(); break;
        case 71: _t->updateItemRatio((*reinterpret_cast<std::add_pointer_t<Qt::CheckState>>(_a[1]))); break;
        case 72: _t->scalePixmap((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<GraphicsSceneRectMove::resizeModes>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5]))); break;
        case 73: _t->scalePixmap((*reinterpret_cast<std::add_pointer_t<QGraphicsItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<GraphicsSceneRectMove::resizeModes>>(_a[4]))); break;
        case 74: _t->seekTimeline(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< MyTextItem* >(); break;
            }
            break;
        case 36:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 72:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        case 73:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QGraphicsItem* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TitleWidget::*)(bool )>(_a, &TitleWidget::requestBackgroundFrame, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TitleWidget::*)()>(_a, &TitleWidget::updatePatternsBackgroundFrame, 1))
            return;
    }
}

const QMetaObject *TitleWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TitleWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11TitleWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TitleWidget_UI"))
        return static_cast< Ui::TitleWidget_UI*>(this);
    return QDialog::qt_metacast(_clname);
}

int TitleWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 75)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 75;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 75)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 75;
    }
    return _id;
}

// SIGNAL 0
void TitleWidget::requestBackgroundFrame(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void TitleWidget::updatePatternsBackgroundFrame()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
