/****************************************************************************
** Meta object code from reading C++ file 'geometrywidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/widgets/geometrywidget.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'geometrywidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14GeometryWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto GeometryWidget::qt_create_metaobjectdata<qt_meta_tag_ZN14GeometryWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "GeometryWidget",
        "valueChanged",
        "",
        "val",
        "ix",
        "frame",
        "updateMonitorGeometry",
        "QRect",
        "r",
        "slotUpdateGeometryRect",
        "QRectF",
        "slotSetRange",
        "std::pair<int,int>",
        "slotUpdateRotation",
        "rotation",
        "slotAdjustRectKeyframeValue",
        "slotAdjustRectXKeyframeValue",
        "slotAdjustRectYKeyframeValue",
        "slotAdjustToSource",
        "slotAdjustToFrameSize",
        "slotFitToWidth",
        "slotFitToHeight",
        "slotResize",
        "value",
        "slotMoveLeft",
        "slotCenterH",
        "slotMoveRight",
        "slotMoveTop",
        "slotCenterV",
        "slotMoveBottom",
        "slotLockRatio",
        "slotAdjustRectHeight",
        "slotAdjustRectWidth"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'valueChanged'
        QtMocHelpers::SignalData<void(const QString, int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 4 }, { QMetaType::Int, 5 },
        }}),
        // Signal 'updateMonitorGeometry'
        QtMocHelpers::SignalData<void(const QRect)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'slotUpdateGeometryRect'
        QtMocHelpers::SlotData<void(const QRectF &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 10, 8 },
        }}),
        // Slot 'slotSetRange'
        QtMocHelpers::SlotData<void(QPair<int,int>)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 2 },
        }}),
        // Slot 'slotUpdateRotation'
        QtMocHelpers::SlotData<void(double)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 14 },
        }}),
        // Slot 'slotAdjustRectKeyframeValue'
        QtMocHelpers::SlotData<void(int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'slotAdjustRectKeyframeValue'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotAdjustRectXKeyframeValue'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdjustRectYKeyframeValue'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdjustToSource'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdjustToFrameSize'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFitToWidth'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFitToHeight'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResize'
        QtMocHelpers::SlotData<void(double)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Double, 23 },
        }}),
        // Slot 'slotMoveLeft'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCenterH'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveRight'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveTop'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCenterV'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveBottom'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLockRatio'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdjustRectHeight'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAdjustRectWidth'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<GeometryWidget, qt_meta_tag_ZN14GeometryWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject GeometryWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GeometryWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GeometryWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14GeometryWidgetE_t>.metaTypes,
    nullptr
} };

void GeometryWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<GeometryWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->valueChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 1: _t->updateMonitorGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 2: _t->slotUpdateGeometryRect((*reinterpret_cast<std::add_pointer_t<QRectF>>(_a[1]))); break;
        case 3: _t->slotSetRange((*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[1]))); break;
        case 4: _t->slotUpdateRotation((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 5: _t->slotAdjustRectKeyframeValue((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slotAdjustRectKeyframeValue(); break;
        case 7: _t->slotAdjustRectXKeyframeValue(); break;
        case 8: _t->slotAdjustRectYKeyframeValue(); break;
        case 9: _t->slotAdjustToSource(); break;
        case 10: _t->slotAdjustToFrameSize(); break;
        case 11: _t->slotFitToWidth(); break;
        case 12: _t->slotFitToHeight(); break;
        case 13: _t->slotResize((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 14: _t->slotMoveLeft(); break;
        case 15: _t->slotCenterH(); break;
        case 16: _t->slotMoveRight(); break;
        case 17: _t->slotMoveTop(); break;
        case 18: _t->slotCenterV(); break;
        case 19: _t->slotMoveBottom(); break;
        case 20: _t->slotLockRatio(); break;
        case 21: _t->slotAdjustRectHeight(); break;
        case 22: _t->slotAdjustRectWidth(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (GeometryWidget::*)(const QString , int , int )>(_a, &GeometryWidget::valueChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (GeometryWidget::*)(const QRect )>(_a, &GeometryWidget::updateMonitorGeometry, 1))
            return;
    }
}

const QMetaObject *GeometryWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *GeometryWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14GeometryWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int GeometryWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 23)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 23;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 23)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 23;
    }
    return _id;
}

// SIGNAL 0
void GeometryWidget::valueChanged(const QString _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2, _t3);
}

// SIGNAL 1
void GeometryWidget::updateMonitorGeometry(const QRect _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}
QT_WARNING_POP
