/****************************************************************************
** Meta object code from reading C++ file 'renderwidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/renderwidget.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'renderwidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18RenderViewDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto RenderViewDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN18RenderViewDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RenderViewDelegate",
        "hoverLink",
        "",
        "hover"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'hoverLink'
        QtMocHelpers::SignalData<bool(bool)>(1, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenderViewDelegate, qt_meta_tag_ZN18RenderViewDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RenderViewDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QStyledItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RenderViewDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RenderViewDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18RenderViewDelegateE_t>.metaTypes,
    nullptr
} };

void RenderViewDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenderViewDelegate *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { bool _r = _t->hoverLink((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<bool (RenderViewDelegate::*)(bool )>(_a, &RenderViewDelegate::hoverLink, 0))
            return;
    }
}

const QMetaObject *RenderViewDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RenderViewDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18RenderViewDelegateE_t>.strings))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int RenderViewDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
bool RenderViewDelegate::hoverLink(bool _t1)
{
    bool _t0{};
    QMetaObject::activate<bool>(this, &staticMetaObject, 0, std::addressof(_t0), _t1);
    return _t0;
}
namespace {
struct qt_meta_tag_ZN12RenderWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto RenderWidget::qt_create_metaobjectdata<qt_meta_tag_ZN12RenderWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RenderWidget",
        "abortProcess",
        "",
        "url",
        "selectedRenderProfile",
        "QMap<QString,QString>",
        "renderProps",
        "renderStatusChanged",
        "shutdown",
        "slotAbortCurrentJob",
        "slotPrepareExport",
        "scriptExport",
        "adjustViewToProfile",
        "reloadGuides",
        "resetRenderPath",
        "path",
        "updateMetadataToolTip",
        "updateMissingClipsCount",
        "total",
        "used",
        "updateRenderInfoMessage",
        "updateRenderOffset",
        "slotUpdateButtons",
        "QUrl",
        "refreshView",
        "slotChangeSelection",
        "QModelIndex",
        "current",
        "previous",
        "loadProfile",
        "refreshParams",
        "slotSavePresetAs",
        "slotNewPreset",
        "slotEditPreset",
        "slotRenderModeChanged",
        "slotUpdateRescaleHeight",
        "slotUpdateRescaleWidth",
        "slotCheckStartGuidePosition",
        "slotCheckEndGuidePosition",
        "updateGuideEndOptionsForStartSelection",
        "setRescaleEnabled",
        "enable",
        "adjustSpeed",
        "videoQuality",
        "slotStartScript",
        "slotDeleteScript",
        "parseScriptFiles",
        "lastScript",
        "slotCheckScript",
        "slotCheckJob",
        "slotCleanUpJobs",
        "slotHideLog",
        "slotPlayRendering",
        "QTreeWidgetItem*",
        "item",
        "slotStartCurrentJob",
        "slotShareActionFinished",
        "QJsonObject",
        "output",
        "error",
        "message",
        "prepareJobContextMenu",
        "QPoint",
        "pos",
        "slotPrepareExport2",
        "slotCheckFreeMemory",
        "updatePowerManagement",
        "checkDriveSpace"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'abortProcess'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'selectedRenderProfile'
        QtMocHelpers::SignalData<void(const QMap<QString,QString> &)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'renderStatusChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shutdown'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAbortCurrentJob'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotPrepareExport'
        QtMocHelpers::SlotData<void(bool)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'slotPrepareExport'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'adjustViewToProfile'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'reloadGuides'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'resetRenderPath'
        QtMocHelpers::SlotData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Slot 'updateMetadataToolTip'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMissingClipsCount'
        QtMocHelpers::SlotData<void(int, int)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 18 }, { QMetaType::Int, 19 },
        }}),
        // Slot 'updateRenderInfoMessage'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateRenderOffset'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateButtons'
        QtMocHelpers::SlotData<void(const QUrl &)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 23, 3 },
        }}),
        // Slot 'slotUpdateButtons'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshView'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotChangeSelection'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 26, 27 }, { 0x80000000 | 26, 28 },
        }}),
        // Slot 'loadProfile'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'refreshParams'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSavePresetAs'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotNewPreset'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditPreset'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenderModeChanged'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateRescaleHeight'
        QtMocHelpers::SlotData<void(int)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotUpdateRescaleWidth'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotCheckStartGuidePosition'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckEndGuidePosition'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateGuideEndOptionsForStartSelection'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'setRescaleEnabled'
        QtMocHelpers::SlotData<void(bool)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Slot 'adjustSpeed'
        QtMocHelpers::SlotData<void(int)>(42, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 43 },
        }}),
        // Slot 'slotStartScript'
        QtMocHelpers::SlotData<void()>(44, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteScript'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'parseScriptFiles'
        QtMocHelpers::SlotData<void(const QString)>(46, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 47 },
        }}),
        // Slot 'parseScriptFiles'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotCheckScript'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCheckJob'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCleanUpJobs'
        QtMocHelpers::SlotData<void()>(50, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotHideLog'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPlayRendering'
        QtMocHelpers::SlotData<void(QTreeWidgetItem *, int)>(52, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 53, 54 }, { QMetaType::Int, 2 },
        }}),
        // Slot 'slotStartCurrentJob'
        QtMocHelpers::SlotData<void()>(55, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShareActionFinished'
        QtMocHelpers::SlotData<void(const QJsonObject &, int, const QString &)>(56, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 57, 58 }, { QMetaType::Int, 59 }, { QMetaType::QString, 60 },
        }}),
        // Slot 'prepareJobContextMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(61, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 62, 63 },
        }}),
        // Slot 'slotPrepareExport2'
        QtMocHelpers::SlotData<void(bool)>(64, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 11 },
        }}),
        // Slot 'slotPrepareExport2'
        QtMocHelpers::SlotData<void()>(64, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotCheckFreeMemory'
        QtMocHelpers::SlotData<void()>(65, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updatePowerManagement'
        QtMocHelpers::SlotData<void()>(66, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkDriveSpace'
        QtMocHelpers::SlotData<void()>(67, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RenderWidget, qt_meta_tag_ZN12RenderWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RenderWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12RenderWidgetE_t>.metaTypes,
    nullptr
} };

void RenderWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RenderWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->abortProcess((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->selectedRenderProfile((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 2: _t->renderStatusChanged(); break;
        case 3: _t->shutdown(); break;
        case 4: _t->slotAbortCurrentJob(); break;
        case 5: _t->slotPrepareExport((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->slotPrepareExport(); break;
        case 7: _t->adjustViewToProfile(); break;
        case 8: _t->reloadGuides(); break;
        case 9: _t->resetRenderPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->updateMetadataToolTip(); break;
        case 11: _t->updateMissingClipsCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 12: _t->updateRenderInfoMessage(); break;
        case 13: _t->updateRenderOffset(); break;
        case 14: _t->slotUpdateButtons((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 15: _t->slotUpdateButtons(); break;
        case 16: _t->refreshView(); break;
        case 17: _t->slotChangeSelection((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2]))); break;
        case 18: _t->loadProfile(); break;
        case 19: _t->refreshParams(); break;
        case 20: _t->slotSavePresetAs(); break;
        case 21: _t->slotNewPreset(); break;
        case 22: _t->slotEditPreset(); break;
        case 23: _t->slotRenderModeChanged(); break;
        case 24: _t->slotUpdateRescaleHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 25: _t->slotUpdateRescaleWidth((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 26: _t->slotCheckStartGuidePosition(); break;
        case 27: _t->slotCheckEndGuidePosition(); break;
        case 28: _t->updateGuideEndOptionsForStartSelection(); break;
        case 29: _t->setRescaleEnabled((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 30: _t->adjustSpeed((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 31: _t->slotStartScript(); break;
        case 32: _t->slotDeleteScript(); break;
        case 33: _t->parseScriptFiles((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 34: _t->parseScriptFiles(); break;
        case 35: _t->slotCheckScript(); break;
        case 36: _t->slotCheckJob(); break;
        case 37: _t->slotCleanUpJobs(); break;
        case 38: _t->slotHideLog(); break;
        case 39: _t->slotPlayRendering((*reinterpret_cast<std::add_pointer_t<QTreeWidgetItem*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: _t->slotStartCurrentJob(); break;
        case 41: _t->slotShareActionFinished((*reinterpret_cast<std::add_pointer_t<QJsonObject>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 42: _t->prepareJobContextMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 43: _t->slotPrepareExport2((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 44: _t->slotPrepareExport2(); break;
        case 45: _t->slotCheckFreeMemory(); break;
        case 46: _t->updatePowerManagement(); break;
        case 47: _t->checkDriveSpace(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RenderWidget::*)(const QString & )>(_a, &RenderWidget::abortProcess, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenderWidget::*)(const QMap<QString,QString> & )>(_a, &RenderWidget::selectedRenderProfile, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenderWidget::*)()>(_a, &RenderWidget::renderStatusChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (RenderWidget::*)()>(_a, &RenderWidget::shutdown, 3))
            return;
    }
}

const QMetaObject *RenderWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RenderWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12RenderWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int RenderWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 48;
    }
    return _id;
}

// SIGNAL 0
void RenderWidget::abortProcess(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void RenderWidget::selectedRenderProfile(const QMap<QString,QString> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void RenderWidget::renderStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void RenderWidget::shutdown()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
QT_WARNING_POP
