/********************************************************************************
** Form generated from reading UI file 'spacerdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPACERDIALOG_UI_H
#define UI_SPACERDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_SpacerDialog_UI
{
public:
    QGridLayout *gridLayout;
    QSpacerItem *verticalSpacer;
    QLabel *clip_filesize_2;
    QCheckBox *insert_all_tracks;
    QDialogButtonBox *buttonBox;
    QHBoxLayout *inputLayout;

    void setupUi(QDialog *SpacerDialog_UI)
    {
        if (SpacerDialog_UI->objectName().isEmpty())
            SpacerDialog_UI->setObjectName("SpacerDialog_UI");
        SpacerDialog_UI->resize(210, 110);
        gridLayout = new QGridLayout(SpacerDialog_UI);
        gridLayout->setObjectName("gridLayout");
        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 2, 0, 1, 2);

        clip_filesize_2 = new QLabel(SpacerDialog_UI);
        clip_filesize_2->setObjectName("clip_filesize_2");

        gridLayout->addWidget(clip_filesize_2, 0, 0, 1, 1);

        insert_all_tracks = new QCheckBox(SpacerDialog_UI);
        insert_all_tracks->setObjectName("insert_all_tracks");

        gridLayout->addWidget(insert_all_tracks, 1, 0, 1, 2);

        buttonBox = new QDialogButtonBox(SpacerDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 2);

        inputLayout = new QHBoxLayout();
        inputLayout->setObjectName("inputLayout");

        gridLayout->addLayout(inputLayout, 0, 1, 1, 1);


        retranslateUi(SpacerDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, SpacerDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, SpacerDialog_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(SpacerDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *SpacerDialog_UI)
    {
        SpacerDialog_UI->setWindowTitle(tr2i18n("Add Space", nullptr));
        clip_filesize_2->setText(tr2i18n("Duration:", nullptr));
        insert_all_tracks->setText(tr2i18n("Insert space in all tracks", nullptr));
    } // retranslateUi

};

namespace Ui {
    class SpacerDialog_UI: public Ui_SpacerDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPACERDIALOG_UI_H

