/****************************************************************************
** Meta object code from reading C++ file 'maskmanager.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/effects/effectstack/view/maskmanager.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'maskmanager.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11MaskManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto MaskManager::qt_create_metaobjectdata<qt_meta_tag_ZN11MaskManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MaskManager",
        "maskReady",
        "",
        "progressUpdate",
        "progress",
        "exportStep",
        "launchSimpleSam",
        "abortPreviewByMonitor",
        "prepareMenu",
        "QPoint",
        "pos",
        "slotOpenFolder",
        "initMaskMode",
        "autoAdd",
        "editMode",
        "addControlPoint",
        "position",
        "QSize",
        "frameSize",
        "xPos",
        "yPos",
        "extend",
        "exclude",
        "moveControlPoint",
        "ix",
        "addControlRect",
        "QRect",
        "rect",
        "previewMask",
        "show",
        "editMask",
        "generateMask",
        "loadMasks",
        "checkModelAvailability",
        "applyMask",
        "deleteMask",
        "importMask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'maskReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'progressUpdate'
        QtMocHelpers::SignalData<void(int, bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Signal 'progressUpdate'
        QtMocHelpers::SignalData<void(int)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'launchSimpleSam'
        QtMocHelpers::SlotData<bool()>(6, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'abortPreviewByMonitor'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'prepareMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'slotOpenFolder'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'initMaskMode'
        QtMocHelpers::SlotData<bool(bool, bool)>(12, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { QMetaType::Bool, 13 }, { QMetaType::Bool, 14 },
        }}),
        // Slot 'initMaskMode'
        QtMocHelpers::SlotData<bool(bool)>(12, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'initMaskMode'
        QtMocHelpers::SlotData<bool()>(12, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'addControlPoint'
        QtMocHelpers::SlotData<void(int, QSize, int, int, bool, bool)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 }, { QMetaType::Int, 20 },
            { QMetaType::Bool, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Slot 'moveControlPoint'
        QtMocHelpers::SlotData<void(int, int, QSize, int, int)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 24 }, { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 }, { QMetaType::Int, 19 },
            { QMetaType::Int, 20 },
        }}),
        // Slot 'addControlRect'
        QtMocHelpers::SlotData<void(int, QSize, const QRect, bool)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 16 }, { 0x80000000 | 17, 18 }, { 0x80000000 | 26, 27 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'previewMask'
        QtMocHelpers::SlotData<void(bool)>(28, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'editMask'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 29 },
        }}),
        // Slot 'generateMask'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadMasks'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkModelAvailability'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyMask'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'deleteMask'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'importMask'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MaskManager, qt_meta_tag_ZN11MaskManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MaskManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MaskManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MaskManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11MaskManagerE_t>.metaTypes,
    nullptr
} };

void MaskManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MaskManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->maskReady(); break;
        case 1: _t->progressUpdate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->progressUpdate((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: { bool _r = _t->launchSimpleSam();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: _t->abortPreviewByMonitor(); break;
        case 5: _t->prepareMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 6: _t->slotOpenFolder(); break;
        case 7: { bool _r = _t->initMaskMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 8: { bool _r = _t->initMaskMode((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->initMaskMode();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->addControlPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[6]))); break;
        case 11: _t->moveControlPoint((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        case 12: _t->addControlRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QRect>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 13: _t->previewMask((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 14: _t->editMask((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 15: _t->generateMask(); break;
        case 16: _t->loadMasks(); break;
        case 17: _t->checkModelAvailability(); break;
        case 18: _t->applyMask(); break;
        case 19: _t->deleteMask(); break;
        case 20: _t->importMask(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MaskManager::*)()>(_a, &MaskManager::maskReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MaskManager::*)(int , bool )>(_a, &MaskManager::progressUpdate, 1))
            return;
    }
}

const QMetaObject *MaskManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MaskManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11MaskManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MaskManage_UI"))
        return static_cast< Ui::MaskManage_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int MaskManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void MaskManager::maskReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void MaskManager::progressUpdate(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}
QT_WARNING_POP
