/********************************************************************************
** Form generated from reading UI file 'configproxy_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGPROXY_UI_H
#define UI_CONFIGPROXY_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigProxy_UI
{
public:
    QVBoxLayout *verticalLayout;
    KMessageWidget *kmessagewidget;
    QCheckBox *kcfg_enableproxy;
    QGroupBox *proxy_box;
    QFormLayout *formLayout;
    QCheckBox *kcfg_generateproxy;
    QSpinBox *kcfg_proxyminsize;
    QLabel *label;
    QSpinBox *kcfg_proxyscale;
    QLabel *label_24;
    QHBoxLayout *proxy_profile_box;
    QFrame *line_2;
    QCheckBox *kcfg_generateimageproxy;
    QSpinBox *kcfg_proxyimageminsize;
    QLabel *image_label;
    QSpinBox *kcfg_proxyimagesize;
    QFrame *line;
    QHBoxLayout *horizontalLayout;
    QComboBox *kcfg_external_proxy_profile;
    QToolButton *button_external;
    QLabel *label_3;
    QHBoxLayout *alpha_profile_box;
    QCheckBox *kcfg_externalproxy;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *ConfigProxy_UI)
    {
        if (ConfigProxy_UI->objectName().isEmpty())
            ConfigProxy_UI->setObjectName("ConfigProxy_UI");
        ConfigProxy_UI->resize(445, 440);
        verticalLayout = new QVBoxLayout(ConfigProxy_UI);
        verticalLayout->setObjectName("verticalLayout");
        kmessagewidget = new KMessageWidget(ConfigProxy_UI);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setWordWrap(true);
        kmessagewidget->setCloseButtonVisible(false);
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("help-hint")));
        kmessagewidget->setIcon(icon);

        verticalLayout->addWidget(kmessagewidget);

        kcfg_enableproxy = new QCheckBox(ConfigProxy_UI);
        kcfg_enableproxy->setObjectName("kcfg_enableproxy");

        verticalLayout->addWidget(kcfg_enableproxy);

        proxy_box = new QGroupBox(ConfigProxy_UI);
        proxy_box->setObjectName("proxy_box");
        proxy_box->setEnabled(false);
        proxy_box->setFlat(true);
        proxy_box->setCheckable(false);
        proxy_box->setChecked(false);
        formLayout = new QFormLayout(proxy_box);
        formLayout->setObjectName("formLayout");
        kcfg_generateproxy = new QCheckBox(proxy_box);
        kcfg_generateproxy->setObjectName("kcfg_generateproxy");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, kcfg_generateproxy);

        kcfg_proxyminsize = new QSpinBox(proxy_box);
        kcfg_proxyminsize->setObjectName("kcfg_proxyminsize");
        kcfg_proxyminsize->setMaximum(10000);
        kcfg_proxyminsize->setValue(1000);

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_proxyminsize);

        label = new QLabel(proxy_box);
        label->setObjectName("label");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label);

        kcfg_proxyscale = new QSpinBox(proxy_box);
        kcfg_proxyscale->setObjectName("kcfg_proxyscale");
        kcfg_proxyscale->setMinimum(200);
        kcfg_proxyscale->setMaximum(100000);

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, kcfg_proxyscale);

        label_24 = new QLabel(proxy_box);
        label_24->setObjectName("label_24");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_24->sizePolicy().hasHeightForWidth());
        label_24->setSizePolicy(sizePolicy);

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_24);

        proxy_profile_box = new QHBoxLayout();
        proxy_profile_box->setSpacing(0);
        proxy_profile_box->setObjectName("proxy_profile_box");

        formLayout->setLayout(2, QFormLayout::ItemRole::FieldRole, proxy_profile_box);

        line_2 = new QFrame(proxy_box);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, line_2);

        kcfg_generateimageproxy = new QCheckBox(proxy_box);
        kcfg_generateimageproxy->setObjectName("kcfg_generateimageproxy");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, kcfg_generateimageproxy);

        kcfg_proxyimageminsize = new QSpinBox(proxy_box);
        kcfg_proxyimageminsize->setObjectName("kcfg_proxyimageminsize");
        kcfg_proxyimageminsize->setMinimum(500);
        kcfg_proxyimageminsize->setMaximum(100000);
        kcfg_proxyimageminsize->setValue(2000);

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_proxyimageminsize);

        image_label = new QLabel(proxy_box);
        image_label->setObjectName("image_label");

        formLayout->setWidget(6, QFormLayout::ItemRole::LabelRole, image_label);

        kcfg_proxyimagesize = new QSpinBox(proxy_box);
        kcfg_proxyimagesize->setObjectName("kcfg_proxyimagesize");
        kcfg_proxyimagesize->setMinimum(200);
        kcfg_proxyimagesize->setMaximum(100000);
        kcfg_proxyimagesize->setValue(800);

        formLayout->setWidget(6, QFormLayout::ItemRole::FieldRole, kcfg_proxyimagesize);

        line = new QFrame(proxy_box);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(7, QFormLayout::ItemRole::SpanningRole, line);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_external_proxy_profile = new QComboBox(proxy_box);
        kcfg_external_proxy_profile->setObjectName("kcfg_external_proxy_profile");

        horizontalLayout->addWidget(kcfg_external_proxy_profile);

        button_external = new QToolButton(proxy_box);
        button_external->setObjectName("button_external");
        QIcon icon1(QIcon::fromTheme(QString::fromUtf8("configure")));
        button_external->setIcon(icon1);

        horizontalLayout->addWidget(button_external);


        formLayout->setLayout(9, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        label_3 = new QLabel(proxy_box);
        label_3->setObjectName("label_3");

        formLayout->setWidget(3, QFormLayout::ItemRole::LabelRole, label_3);

        alpha_profile_box = new QHBoxLayout();
        alpha_profile_box->setObjectName("alpha_profile_box");

        formLayout->setLayout(3, QFormLayout::ItemRole::FieldRole, alpha_profile_box);

        kcfg_externalproxy = new QCheckBox(proxy_box);
        kcfg_externalproxy->setObjectName("kcfg_externalproxy");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, kcfg_externalproxy);


        verticalLayout->addWidget(proxy_box);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        QWidget::setTabOrder(kcfg_enableproxy, kcfg_proxyminsize);
        QWidget::setTabOrder(kcfg_proxyminsize, kcfg_proxyimageminsize);
        QWidget::setTabOrder(kcfg_proxyimageminsize, kcfg_proxyimagesize);
        QWidget::setTabOrder(kcfg_proxyimagesize, kcfg_external_proxy_profile);

        retranslateUi(ConfigProxy_UI);
        QObject::connect(kcfg_enableproxy, &QCheckBox::toggled, proxy_box, &QGroupBox::setEnabled);

        QMetaObject::connectSlotsByName(ConfigProxy_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigProxy_UI)
    {
        kmessagewidget->setText(tr2i18n("These are the default settings for new projects. To edit the parameters of the current project, use the project settings.", nullptr));
        kcfg_enableproxy->setText(tr2i18n("Enable proxy clips", nullptr));
        kcfg_generateproxy->setText(tr2i18n("Generate for videos larger than:", nullptr));
        kcfg_proxyminsize->setSuffix(tr2i18n(" pixels", nullptr));
        label->setText(tr2i18n("Proxy video resize (width):", nullptr));
        kcfg_proxyscale->setSuffix(tr2i18n(" pixels", nullptr));
        label_24->setText(tr2i18n("Encoding profile:", nullptr));
        kcfg_generateimageproxy->setText(tr2i18n("Generate for images larger than:", nullptr));
        kcfg_proxyimageminsize->setSuffix(tr2i18n(" pixels", nullptr));
        image_label->setText(tr2i18n("Proxy image size:", nullptr));
        kcfg_proxyimagesize->setSuffix(tr2i18n(" pixels", nullptr));
        button_external->setText(tr2i18n("...", nullptr));
        label_3->setText(tr2i18n("Profile for clips with alpha channel:", nullptr));
        kcfg_externalproxy->setText(tr2i18n("Camcorder proxy clips:", nullptr));
        (void)ConfigProxy_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigProxy_UI: public Ui_ConfigProxy_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGPROXY_UI_H

