/********************************************************************************
** Form generated from reading UI file 'configproject_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGPROJECT_UI_H
#define UI_CONFIGPROJECT_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigProject_UI
{
public:
    QFormLayout *formLayout;
    KMessageWidget *kmessagewidget;
    QLabel *label_project_folder;
    QRadioButton *default_folder;
    QRadioButton *kcfg_sameprojectfolder;
    QHBoxLayout *horizontalLayout_2;
    QRadioButton *kcfg_customprojectfolder;
    KUrlRequester *projecturl;
    QFrame *line;
    QGroupBox *profile_box;
    QLabel *label_video_tracks;
    QSpinBox *kcfg_videotracks;
    QLabel *label_audio_tracks;
    QSpinBox *kcfg_audiotracks;
    QLabel *label_audio_channels;
    QComboBox *kcfg_audio_channels;
    QLabel *label_preview_profile;
    QHBoxLayout *preview_profile_box;
    QSpacerItem *verticalSpacer;
    QFrame *line_2;

    void setupUi(QWidget *ConfigProject_UI)
    {
        if (ConfigProject_UI->objectName().isEmpty())
            ConfigProject_UI->setObjectName("ConfigProject_UI");
        ConfigProject_UI->resize(507, 383);
        formLayout = new QFormLayout(ConfigProject_UI);
        formLayout->setObjectName("formLayout");
        formLayout->setContentsMargins(0, -1, -1, -1);
        kmessagewidget = new KMessageWidget(ConfigProject_UI);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setWordWrap(true);
        kmessagewidget->setCloseButtonVisible(false);
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("help-hint");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        kmessagewidget->setIcon(icon);

        formLayout->setWidget(1, QFormLayout::ItemRole::SpanningRole, kmessagewidget);

        label_project_folder = new QLabel(ConfigProject_UI);
        label_project_folder->setObjectName("label_project_folder");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_project_folder);

        default_folder = new QRadioButton(ConfigProject_UI);
        default_folder->setObjectName("default_folder");
        default_folder->setChecked(true);

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, default_folder);

        kcfg_sameprojectfolder = new QRadioButton(ConfigProject_UI);
        kcfg_sameprojectfolder->setObjectName("kcfg_sameprojectfolder");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, kcfg_sameprojectfolder);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        kcfg_customprojectfolder = new QRadioButton(ConfigProject_UI);
        kcfg_customprojectfolder->setObjectName("kcfg_customprojectfolder");

        horizontalLayout_2->addWidget(kcfg_customprojectfolder);

        projecturl = new KUrlRequester(ConfigProject_UI);
        projecturl->setObjectName("projecturl");
        projecturl->setEnabled(false);

        horizontalLayout_2->addWidget(projecturl);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout_2);

        line = new QFrame(ConfigProject_UI);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, line);

        profile_box = new QGroupBox(ConfigProject_UI);
        profile_box->setObjectName("profile_box");
        profile_box->setFlat(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, profile_box);

        label_video_tracks = new QLabel(ConfigProject_UI);
        label_video_tracks->setObjectName("label_video_tracks");

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_video_tracks);

        kcfg_videotracks = new QSpinBox(ConfigProject_UI);
        kcfg_videotracks->setObjectName("kcfg_videotracks");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_videotracks);

        label_audio_tracks = new QLabel(ConfigProject_UI);
        label_audio_tracks->setObjectName("label_audio_tracks");

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_audio_tracks);

        kcfg_audiotracks = new QSpinBox(ConfigProject_UI);
        kcfg_audiotracks->setObjectName("kcfg_audiotracks");

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_audiotracks);

        label_audio_channels = new QLabel(ConfigProject_UI);
        label_audio_channels->setObjectName("label_audio_channels");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_audio_channels);

        kcfg_audio_channels = new QComboBox(ConfigProject_UI);
        kcfg_audio_channels->addItem(QString());
        kcfg_audio_channels->addItem(QString());
        kcfg_audio_channels->addItem(QString());
        kcfg_audio_channels->setObjectName("kcfg_audio_channels");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, kcfg_audio_channels);

        label_preview_profile = new QLabel(ConfigProject_UI);
        label_preview_profile->setObjectName("label_preview_profile");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_preview_profile->sizePolicy().hasHeightForWidth());
        label_preview_profile->setSizePolicy(sizePolicy);

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_preview_profile);

        preview_profile_box = new QHBoxLayout();
        preview_profile_box->setObjectName("preview_profile_box");

        formLayout->setLayout(11, QFormLayout::ItemRole::FieldRole, preview_profile_box);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(12, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        line_2 = new QFrame(ConfigProject_UI);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(7, QFormLayout::ItemRole::SpanningRole, line_2);

        QWidget::setTabOrder(kcfg_videotracks, projecturl);

        retranslateUi(ConfigProject_UI);

        QMetaObject::connectSlotsByName(ConfigProject_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigProject_UI)
    {
        kmessagewidget->setText(tr2i18n("These are the default settings for new projects. To edit the parameters of the current project, use the project settings.", nullptr));
        label_project_folder->setText(tr2i18n("Project folder:", nullptr));
        default_folder->setText(tr2i18n("Default", nullptr));
        kcfg_sameprojectfolder->setText(tr2i18n("Parent folder of project file", nullptr));
        kcfg_customprojectfolder->setText(tr2i18n("Custom project folder:", nullptr));
        label_video_tracks->setText(tr2i18n("Video tracks:", nullptr));
        label_audio_tracks->setText(tr2i18n("Audio tracks:", nullptr));
        label_audio_channels->setText(tr2i18n("Audio channels:", nullptr));
        kcfg_audio_channels->setItemText(0, tr2i18n("2 channels (stereo)", nullptr));
        kcfg_audio_channels->setItemText(1, tr2i18n("4 channels", nullptr));
        kcfg_audio_channels->setItemText(2, tr2i18n("6 channels", nullptr));

        label_preview_profile->setText(tr2i18n("Timeline Preview profile:", nullptr));
        (void)ConfigProject_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigProject_UI: public Ui_ConfigProject_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGPROJECT_UI_H

