/****************************************************************************
** Meta object code from reading C++ file 'noteswidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/project/dialogs/noteswidget.h"
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'noteswidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN11NotesWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto NotesWidget::qt_create_metaobjectdata<qt_meta_tag_ZN11NotesWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "NotesWidget",
        "insertNotesTimecode",
        "",
        "insertTextNote",
        "text",
        "seekProject",
        "reAssign",
        "anchors",
        "QList<QPoint>",
        "points",
        "bid",
        "offset",
        "createMarkers",
        "assignProjectNote",
        "assignProjectNoteToTimelineClip"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'insertNotesTimecode'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'insertTextNote'
        QtMocHelpers::SignalData<void(const QString &)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'seekProject'
        QtMocHelpers::SignalData<void(const QString)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'reAssign'
        QtMocHelpers::SignalData<void(const QStringList, const QList<QPoint>, QString, int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 }, { QMetaType::Int, 11 },
        }}),
        // Signal 'reAssign'
        QtMocHelpers::SignalData<void(const QStringList, const QList<QPoint>, QString)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { 0x80000000 | 8, 9 }, { QMetaType::QString, 10 },
        }}),
        // Signal 'reAssign'
        QtMocHelpers::SignalData<void(const QStringList, const QList<QPoint>)>(6, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QStringList, 7 }, { 0x80000000 | 8, 9 },
        }}),
        // Slot 'createMarkers'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'assignProjectNote'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'assignProjectNoteToTimelineClip'
        QtMocHelpers::SlotData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotesWidget, qt_meta_tag_ZN11NotesWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject NotesWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QTextEdit::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11NotesWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11NotesWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11NotesWidgetE_t>.metaTypes,
    nullptr
} };

void NotesWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotesWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->insertNotesTimecode(); break;
        case 1: _t->insertTextNote((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->seekProject((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->reAssign((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 4: _t->reAssign((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 5: _t->reAssign((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<QPoint>>>(_a[2]))); break;
        case 6: _t->createMarkers(); break;
        case 7: _t->assignProjectNote(); break;
        case 8: _t->assignProjectNoteToTimelineClip(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotesWidget::*)()>(_a, &NotesWidget::insertNotesTimecode, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotesWidget::*)(const QString & )>(_a, &NotesWidget::insertTextNote, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotesWidget::*)(const QString )>(_a, &NotesWidget::seekProject, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotesWidget::*)(const QStringList , const QList<QPoint> , QString , int )>(_a, &NotesWidget::reAssign, 3))
            return;
    }
}

const QMetaObject *NotesWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *NotesWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11NotesWidgetE_t>.strings))
        return static_cast<void*>(this);
    return QTextEdit::qt_metacast(_clname);
}

int NotesWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QTextEdit::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void NotesWidget::insertNotesTimecode()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void NotesWidget::insertTextNote(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void NotesWidget::seekProject(const QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void NotesWidget::reAssign(const QStringList _t1, const QList<QPoint> _t2, QString _t3, int _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3, _t4);
}
QT_WARNING_POP
