/****************************************************************************
** Meta object code from reading C++ file 'abstractcollapsiblewidget.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/effects/effectstack/view/abstractcollapsiblewidget.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractcollapsiblewidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractCollapsibleWidget::qt_create_metaobjectdata<qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractCollapsibleWidget",
        "addEffect",
        "",
        "QDomElement",
        "e",
        "changeEffectPosition",
        "QList<int>",
        "upwards",
        "moveEffect",
        "current_pos",
        "new_pos",
        "groupIndex",
        "groupName",
        "reloadEffects",
        "reloadEffect",
        "path",
        "seekToPos"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'addEffect'
        QtMocHelpers::SignalData<void(const QDomElement &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Signal 'changeEffectPosition'
        QtMocHelpers::SignalData<void(const QList<int> &, bool)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 2 }, { QMetaType::Bool, 7 },
        }}),
        // Signal 'moveEffect'
        QtMocHelpers::SignalData<void(const QList<int> &, int, int, const QString &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 6, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 }, { QMetaType::QString, 12 },
        }}),
        // Signal 'reloadEffects'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'reloadEffect'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 15 },
        }}),
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractCollapsibleWidget, qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractCollapsibleWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>.metaTypes,
    nullptr
} };

void AbstractCollapsibleWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractCollapsibleWidget *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->addEffect((*reinterpret_cast<std::add_pointer_t<QDomElement>>(_a[1]))); break;
        case 1: _t->changeEffectPosition((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 2: _t->moveEffect((*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4]))); break;
        case 3: _t->reloadEffects(); break;
        case 4: _t->reloadEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 5: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)(const QDomElement & )>(_a, &AbstractCollapsibleWidget::addEffect, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)(const QList<int> & , bool )>(_a, &AbstractCollapsibleWidget::changeEffectPosition, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)(const QList<int> & , int , int , const QString & )>(_a, &AbstractCollapsibleWidget::moveEffect, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)()>(_a, &AbstractCollapsibleWidget::reloadEffects, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)(const QString & )>(_a, &AbstractCollapsibleWidget::reloadEffect, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractCollapsibleWidget::*)(int )>(_a, &AbstractCollapsibleWidget::seekToPos, 5))
            return;
    }
}

const QMetaObject *AbstractCollapsibleWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractCollapsibleWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN25AbstractCollapsibleWidgetE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::CollapsibleWidget_UI"))
        return static_cast< Ui::CollapsibleWidget_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int AbstractCollapsibleWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    return _id;
}

// SIGNAL 0
void AbstractCollapsibleWidget::addEffect(const QDomElement & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractCollapsibleWidget::changeEffectPosition(const QList<int> & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void AbstractCollapsibleWidget::moveEffect(const QList<int> & _t1, int _t2, int _t3, const QString & _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 3
void AbstractCollapsibleWidget::reloadEffects()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void AbstractCollapsibleWidget::reloadEffect(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractCollapsibleWidget::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
QT_WARNING_POP
