/****************************************************************************
** Meta object code from reading C++ file 'projectmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/project/projectmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'projectmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14ProjectManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ProjectManager::qt_create_metaobjectdata<qt_meta_tag_ZN14ProjectManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ProjectManager",
        "newFile",
        "",
        "profileName",
        "showProjectSettings",
        "slotOpenFile",
        "openLastFile",
        "slotLoadOnOpen",
        "slotLoadHeadless",
        "QUrl",
        "projectUrl",
        "saveFile",
        "saveFileAs",
        "saveACopy",
        "outputFileName",
        "saveOverExistingFile",
        "closeCurrentDocument",
        "saveChanges",
        "quit",
        "openFile",
        "url",
        "slotStartAutoSave",
        "slotResetProfiles",
        "reloadThumbs",
        "slotResetConsumers",
        "fullReset",
        "slotDisableTimelineEffects",
        "disable",
        "slotSwitchTrackDisabled",
        "slotSwitchAllTrackDisabled",
        "slotSwitchTrackLock",
        "slotSwitchAllTrackLock",
        "slotSwitchTrackActive",
        "slotSwitchAllTrackActive",
        "slotMakeAllTrackActive",
        "slotRestoreTargetTracks",
        "slotSwitchTrackTarget",
        "setDocumentNotes",
        "QString&",
        "notes",
        "deprecatedBinIds",
        "adjustProjectDuration",
        "duration",
        "activateAsset",
        "QVariantMap",
        "effectData",
        "slotAddProjectNote",
        "slotAddTextNote",
        "text",
        "seekTimeline",
        "frameAndTrack",
        "slotCreateSequenceFromSelection",
        "showTrackEffectStack",
        "tid",
        "slotRevert",
        "updateSequenceDuration",
        "QUuid",
        "uuid",
        "slotOpenBackup",
        "slotAutoSave",
        "slotMoveProgress",
        "KJob*",
        "progress",
        "slotMoveFinished",
        "job",
        "handleLog",
        "message"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'newFile'
        QtMocHelpers::SlotData<void(QString, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Slot 'newFile'
        QtMocHelpers::SlotData<void(QString)>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'newFile'
        QtMocHelpers::SlotData<void(bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'newFile'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotOpenFile'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'openLastFile'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoadOnOpen'
        QtMocHelpers::SlotData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotLoadHeadless'
        QtMocHelpers::SlotData<void(const QUrl &)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 10 },
        }}),
        // Slot 'saveFile'
        QtMocHelpers::SlotData<bool()>(11, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool(bool)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 13 },
        }}),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool()>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool(const QString &, bool, bool)>(12, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 15 }, { QMetaType::Bool, 13 },
        }}),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool(const QString &, bool)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 15 },
        }}),
        // Slot 'saveFileAs'
        QtMocHelpers::SlotData<bool(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'closeCurrentDocument'
        QtMocHelpers::SlotData<bool(bool, bool)>(16, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Slot 'closeCurrentDocument'
        QtMocHelpers::SlotData<bool(bool)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 17 },
        }}),
        // Slot 'closeCurrentDocument'
        QtMocHelpers::SlotData<bool()>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'openFile'
        QtMocHelpers::SlotData<void(const QUrl &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 9, 20 },
        }}),
        // Slot 'slotStartAutoSave'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotResetProfiles'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'slotResetConsumers'
        QtMocHelpers::SlotData<void(bool)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'slotDisableTimelineEffects'
        QtMocHelpers::SlotData<void(bool)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 27 },
        }}),
        // Slot 'slotSwitchTrackDisabled'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchAllTrackDisabled'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchTrackLock'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchAllTrackLock'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchTrackActive'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchAllTrackActive'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotMakeAllTrackActive'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRestoreTargetTracks'
        QtMocHelpers::SlotData<void()>(35, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchTrackTarget'
        QtMocHelpers::SlotData<void()>(36, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setDocumentNotes'
        QtMocHelpers::SlotData<void(QString &, QStringList)>(37, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 38, 39 }, { QMetaType::QStringList, 40 },
        }}),
        // Slot 'setDocumentNotes'
        QtMocHelpers::SlotData<void(QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 38, 39 },
        }}),
        // Slot 'adjustProjectDuration'
        QtMocHelpers::SlotData<void(int)>(41, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 42 },
        }}),
        // Slot 'activateAsset'
        QtMocHelpers::SlotData<void(const QVariantMap &)>(43, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 44, 45 },
        }}),
        // Slot 'slotAddProjectNote'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotAddTextNote'
        QtMocHelpers::SlotData<void(const QString &)>(47, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 48 },
        }}),
        // Slot 'seekTimeline'
        QtMocHelpers::SlotData<void(const QString &)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 50 },
        }}),
        // Slot 'slotCreateSequenceFromSelection'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showTrackEffectStack'
        QtMocHelpers::SlotData<void(int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 53 },
        }}),
        // Slot 'slotRevert'
        QtMocHelpers::SlotData<void()>(54, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateSequenceDuration'
        QtMocHelpers::SlotData<void(const QUuid &)>(55, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 56, 57 },
        }}),
        // Slot 'slotOpenBackup'
        QtMocHelpers::SlotData<bool(const QUrl &)>(58, 2, QMC::AccessPrivate, QMetaType::Bool, {{
            { 0x80000000 | 9, 20 },
        }}),
        // Slot 'slotOpenBackup'
        QtMocHelpers::SlotData<bool()>(58, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'slotAutoSave'
        QtMocHelpers::SlotData<void()>(59, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMoveProgress'
        QtMocHelpers::SlotData<void(KJob *, unsigned long)>(60, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 2 }, { QMetaType::ULong, 62 },
        }}),
        // Slot 'slotMoveFinished'
        QtMocHelpers::SlotData<void(KJob *)>(63, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 61, 64 },
        }}),
        // Slot 'handleLog'
        QtMocHelpers::SlotData<void(const QString &)>(65, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 66 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ProjectManager, qt_meta_tag_ZN14ProjectManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ProjectManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProjectManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProjectManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14ProjectManagerE_t>.metaTypes,
    nullptr
} };

void ProjectManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ProjectManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->newFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->newFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->newFile((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->newFile(); break;
        case 4: _t->slotOpenFile(); break;
        case 5: _t->openLastFile(); break;
        case 6: _t->slotLoadOnOpen(); break;
        case 7: _t->slotLoadHeadless((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 8: { bool _r = _t->saveFile();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->saveFileAs((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: { bool _r = _t->saveFileAs();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 11: { bool _r = _t->saveFileAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: { bool _r = _t->saveFileAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: { bool _r = _t->saveFileAs((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { bool _r = _t->closeCurrentDocument((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 15: { bool _r = _t->closeCurrentDocument((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 16: { bool _r = _t->closeCurrentDocument();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: _t->openFile((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 18: _t->slotStartAutoSave(); break;
        case 19: _t->slotResetProfiles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 20: _t->slotResetConsumers((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->slotDisableTimelineEffects((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->slotSwitchTrackDisabled(); break;
        case 23: _t->slotSwitchAllTrackDisabled(); break;
        case 24: _t->slotSwitchTrackLock(); break;
        case 25: _t->slotSwitchAllTrackLock(); break;
        case 26: _t->slotSwitchTrackActive(); break;
        case 27: _t->slotSwitchAllTrackActive(); break;
        case 28: _t->slotMakeAllTrackActive(); break;
        case 29: _t->slotRestoreTargetTracks(); break;
        case 30: _t->slotSwitchTrackTarget(); break;
        case 31: _t->setDocumentNotes((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 32: _t->setDocumentNotes((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1]))); break;
        case 33: _t->adjustProjectDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 34: _t->activateAsset((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 35: _t->slotAddProjectNote(); break;
        case 36: _t->slotAddTextNote((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 37: _t->seekTimeline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 38: _t->slotCreateSequenceFromSelection(); break;
        case 39: _t->showTrackEffectStack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 40: _t->slotRevert(); break;
        case 41: _t->updateSequenceDuration((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1]))); break;
        case 42: { bool _r = _t->slotOpenBackup((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 43: { bool _r = _t->slotOpenBackup();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 44: _t->slotAutoSave(); break;
        case 45: _t->slotMoveProgress((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ulong>>(_a[2]))); break;
        case 46: _t->slotMoveFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 47: _t->handleLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *ProjectManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ProjectManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14ProjectManagerE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ProjectManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 48)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 48;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 48)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 48;
    }
    return _id;
}
QT_WARNING_POP
