/********************************************************************************
** Form generated from reading UI file 'clipspeed_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CLIPSPEED_UI_H
#define UI_CLIPSPEED_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSlider>
#include <QtWidgets/QSpacerItem>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"
#include "widgets/precisionspinbox.h"

QT_BEGIN_NAMESPACE

class Ui_ClipSpeed_UI
{
public:
    QGridLayout *gridLayout;
    KMessageWidget *infoMessage;
    QCheckBox *pitchCompensate;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QSlider *speedSlider;
    PrecisionSpinBox *precisionSpin;
    QDialogButtonBox *buttonBox;
    QSpacerItem *verticalSpacer;
    QCheckBox *checkBox;
    QHBoxLayout *destination_layout;
    QLabel *label_dest;
    KUrlRequester *kurlrequester;
    QHBoxLayout *durationLayout;

    void setupUi(QDialog *ClipSpeed_UI)
    {
        if (ClipSpeed_UI->objectName().isEmpty())
            ClipSpeed_UI->setObjectName("ClipSpeed_UI");
        ClipSpeed_UI->resize(434, 234);
        gridLayout = new QGridLayout(ClipSpeed_UI);
        gridLayout->setObjectName("gridLayout");
        infoMessage = new KMessageWidget(ClipSpeed_UI);
        infoMessage->setObjectName("infoMessage");

        gridLayout->addWidget(infoMessage, 5, 0, 1, 3);

        pitchCompensate = new QCheckBox(ClipSpeed_UI);
        pitchCompensate->setObjectName("pitchCompensate");

        gridLayout->addWidget(pitchCompensate, 3, 0, 1, 2);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        label = new QLabel(ClipSpeed_UI);
        label->setObjectName("label");

        horizontalLayout->addWidget(label);

        speedSlider = new QSlider(ClipSpeed_UI);
        speedSlider->setObjectName("speedSlider");
        QSizePolicy sizePolicy(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(speedSlider->sizePolicy().hasHeightForWidth());
        speedSlider->setSizePolicy(sizePolicy);
        speedSlider->setMinimum(1);
        speedSlider->setMaximum(1000);
        speedSlider->setSliderPosition(100);
        speedSlider->setOrientation(Qt::Orientation::Horizontal);
        speedSlider->setTickPosition(QSlider::TickPosition::TicksAbove);

        horizontalLayout->addWidget(speedSlider);

        precisionSpin = new PrecisionSpinBox(ClipSpeed_UI);
        precisionSpin->setObjectName("precisionSpin");

        horizontalLayout->addWidget(precisionSpin);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 3);

        buttonBox = new QDialogButtonBox(ClipSpeed_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout->addWidget(buttonBox, 6, 2, 1, 1);

        verticalSpacer = new QSpacerItem(20, 0, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 4, 1, 1, 1);

        checkBox = new QCheckBox(ClipSpeed_UI);
        checkBox->setObjectName("checkBox");

        gridLayout->addWidget(checkBox, 3, 2, 1, 1);

        destination_layout = new QHBoxLayout();
        destination_layout->setObjectName("destination_layout");
        label_dest = new QLabel(ClipSpeed_UI);
        label_dest->setObjectName("label_dest");

        destination_layout->addWidget(label_dest);

        kurlrequester = new KUrlRequester(ClipSpeed_UI);
        kurlrequester->setObjectName("kurlrequester");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kurlrequester->sizePolicy().hasHeightForWidth());
        kurlrequester->setSizePolicy(sizePolicy1);

        destination_layout->addWidget(kurlrequester);


        gridLayout->addLayout(destination_layout, 0, 0, 1, 3);

        durationLayout = new QHBoxLayout();
        durationLayout->setObjectName("durationLayout");

        gridLayout->addLayout(durationLayout, 2, 0, 1, 3);

        QWidget::setTabOrder(kurlrequester, speedSlider);
        QWidget::setTabOrder(speedSlider, precisionSpin);
        QWidget::setTabOrder(precisionSpin, pitchCompensate);
        QWidget::setTabOrder(pitchCompensate, checkBox);

        retranslateUi(ClipSpeed_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ClipSpeed_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ClipSpeed_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(ClipSpeed_UI);
    } // setupUi

    void retranslateUi(QDialog *ClipSpeed_UI)
    {
        ClipSpeed_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        pitchCompensate->setText(tr2i18n("Pitch compensation", nullptr));
        label->setText(tr2i18n("Speed", nullptr));
        checkBox->setText(tr2i18n("Reverse clip", nullptr));
        label_dest->setText(tr2i18n("Destination", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ClipSpeed_UI: public Ui_ClipSpeed_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CLIPSPEED_UI_H

