/********************************************************************************
** Form generated from reading UI file 'waveform_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WAVEFORM_UI_H
#define UI_WAVEFORM_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Waveform_UI
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *headerLayout;
    QSpacerItem *horizontalSpacer;
    QToolButton *hamburgerButton;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Waveform_UI)
    {
        if (Waveform_UI->objectName().isEmpty())
            Waveform_UI->setObjectName("Waveform_UI");
        Waveform_UI->resize(400, 300);
        verticalLayout = new QVBoxLayout(Waveform_UI);
        verticalLayout->setSpacing(0);
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        headerLayout = new QHBoxLayout();
        headerLayout->setSpacing(0);
        headerLayout->setObjectName("headerLayout");
        headerLayout->setContentsMargins(4, 4, 4, 4);
        horizontalSpacer = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        headerLayout->addItem(horizontalSpacer);

        hamburgerButton = new QToolButton(Waveform_UI);
        hamburgerButton->setObjectName("hamburgerButton");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("application-menu")));
        hamburgerButton->setIcon(icon);
        hamburgerButton->setAutoRaise(true);
        hamburgerButton->setPopupMode(QToolButton::InstantPopup);

        headerLayout->addWidget(hamburgerButton);


        verticalLayout->addLayout(headerLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);


        retranslateUi(Waveform_UI);

        QMetaObject::connectSlotsByName(Waveform_UI);
    } // setupUi

    void retranslateUi(QWidget *Waveform_UI)
    {
#if QT_CONFIG(tooltip)
        hamburgerButton->setToolTip(tr2i18n("Settings", nullptr));
#endif // QT_CONFIG(tooltip)
        (void)Waveform_UI;
    } // retranslateUi

};

namespace Ui {
    class Waveform_UI: public Ui_Waveform_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // WAVEFORM_UI_H

