/********************************************************************************
** Form generated from reading UI file 'cutjobdialog_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CUTJOBDIALOG_UI_H
#define UI_CUTJOBDIALOG_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QToolButton>
#include <klocalizedstring.h>
#include "kmessagewidget.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_CutJobDialog_UI
{
public:
    QGridLayout *gridLayout;
    QComboBox *vcodec;
    QLabel *info_label;
    QLabel *video_codec;
    QTextEdit *extra_params;
    QLabel *audio_codec;
    QComboBox *acodec;
    QLabel *label_2;
    QSpacerItem *verticalSpacer;
    QToolButton *button_more;
    QCheckBox *add_clip;
    QLabel *label;
    QHBoxLayout *horizontalLayout;
    QLabel *destination_label;
    KUrlRequester *file_url;
    QDialogButtonBox *buttonBox;
    KMessageWidget *message;

    void setupUi(QDialog *CutJobDialog_UI)
    {
        if (CutJobDialog_UI->objectName().isEmpty())
            CutJobDialog_UI->setObjectName("CutJobDialog_UI");
        CutJobDialog_UI->resize(355, 373);
        gridLayout = new QGridLayout(CutJobDialog_UI);
        gridLayout->setObjectName("gridLayout");
        vcodec = new QComboBox(CutJobDialog_UI);
        vcodec->setObjectName("vcodec");

        gridLayout->addWidget(vcodec, 2, 2, 1, 3);

        info_label = new QLabel(CutJobDialog_UI);
        info_label->setObjectName("info_label");

        gridLayout->addWidget(info_label, 0, 0, 1, 4);

        video_codec = new QLabel(CutJobDialog_UI);
        video_codec->setObjectName("video_codec");

        gridLayout->addWidget(video_codec, 2, 1, 1, 1);

        extra_params = new QTextEdit(CutJobDialog_UI);
        extra_params->setObjectName("extra_params");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(extra_params->sizePolicy().hasHeightForWidth());
        extra_params->setSizePolicy(sizePolicy);

        gridLayout->addWidget(extra_params, 5, 0, 1, 5);

        audio_codec = new QLabel(CutJobDialog_UI);
        audio_codec->setObjectName("audio_codec");

        gridLayout->addWidget(audio_codec, 3, 1, 1, 1);

        acodec = new QComboBox(CutJobDialog_UI);
        acodec->setObjectName("acodec");

        gridLayout->addWidget(acodec, 3, 2, 1, 3);

        label_2 = new QLabel(CutJobDialog_UI);
        label_2->setObjectName("label_2");

        gridLayout->addWidget(label_2, 3, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 7, 2, 1, 1);

        button_more = new QToolButton(CutJobDialog_UI);
        button_more->setObjectName("button_more");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("configure")));
        button_more->setIcon(icon);
        button_more->setCheckable(true);
        button_more->setAutoRaise(false);

        gridLayout->addWidget(button_more, 0, 4, 1, 1);

        add_clip = new QCheckBox(CutJobDialog_UI);
        add_clip->setObjectName("add_clip");

        gridLayout->addWidget(add_clip, 4, 0, 1, 5);

        label = new QLabel(CutJobDialog_UI);
        label->setObjectName("label");

        gridLayout->addWidget(label, 2, 0, 1, 1);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        destination_label = new QLabel(CutJobDialog_UI);
        destination_label->setObjectName("destination_label");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(destination_label->sizePolicy().hasHeightForWidth());
        destination_label->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(destination_label);

        file_url = new KUrlRequester(CutJobDialog_UI);
        file_url->setObjectName("file_url");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(file_url->sizePolicy().hasHeightForWidth());
        file_url->setSizePolicy(sizePolicy2);

        horizontalLayout->addWidget(file_url);


        gridLayout->addLayout(horizontalLayout, 1, 0, 1, 5);

        buttonBox = new QDialogButtonBox(CutJobDialog_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Cancel|QDialogButtonBox::Ok);

        gridLayout->addWidget(buttonBox, 7, 3, 1, 2);

        message = new KMessageWidget(CutJobDialog_UI);
        message->setObjectName("message");
        message->setMessageType(KMessageWidget::Information);

        gridLayout->addWidget(message, 6, 0, 1, 5);


        retranslateUi(CutJobDialog_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, CutJobDialog_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, CutJobDialog_UI, qOverload<>(&QDialog::reject));
        QObject::connect(button_more, &QToolButton::toggled, extra_params, &QTextEdit::setVisible);

        QMetaObject::connectSlotsByName(CutJobDialog_UI);
    } // setupUi

    void retranslateUi(QDialog *CutJobDialog_UI)
    {
        CutJobDialog_UI->setWindowTitle(tr2i18n("Cut Clip", nullptr));
        info_label->setText(QString());
        video_codec->setText(tr2i18n("TextLabel", nullptr));
        audio_codec->setText(tr2i18n("TextLabel", nullptr));
        label_2->setText(tr2i18n("Audio", nullptr));
#if QT_CONFIG(tooltip)
        button_more->setToolTip(tr2i18n("Configure the job.", nullptr));
#endif // QT_CONFIG(tooltip)
        button_more->setText(tr2i18n("...", nullptr));
        add_clip->setText(tr2i18n("Add clip to project", nullptr));
        label->setText(tr2i18n("Video", nullptr));
        destination_label->setText(tr2i18n("Save to", nullptr));
    } // retranslateUi

};

namespace Ui {
    class CutJobDialog_UI: public Ui_CutJobDialog_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CUTJOBDIALOG_UI_H

