/********************************************************************************
** Form generated from reading UI file 'testproxy_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TESTPROXY_UI_H
#define UI_TESTPROXY_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QTreeWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_TestProxy_UI
{
public:
    QGridLayout *gridLayout;
    QDialogButtonBox *buttonBox;
    QTreeWidget *resultList;
    KMessageWidget *infoWidget;
    QPlainTextEdit *paramBox;

    void setupUi(QDialog *TestProxy_UI)
    {
        if (TestProxy_UI->objectName().isEmpty())
            TestProxy_UI->setObjectName("TestProxy_UI");
        TestProxy_UI->resize(272, 377);
        gridLayout = new QGridLayout(TestProxy_UI);
        gridLayout->setObjectName("gridLayout");
        buttonBox = new QDialogButtonBox(TestProxy_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::Apply|QDialogButtonBox::Close);

        gridLayout->addWidget(buttonBox, 3, 0, 1, 1);

        resultList = new QTreeWidget(TestProxy_UI);
        resultList->setObjectName("resultList");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(resultList->sizePolicy().hasHeightForWidth());
        resultList->setSizePolicy(sizePolicy);
        resultList->setRootIsDecorated(false);
        resultList->setSortingEnabled(true);
        resultList->setAllColumnsShowFocus(true);
        resultList->header()->setProperty("showSortIndicator", QVariant(true));

        gridLayout->addWidget(resultList, 0, 0, 1, 1);

        infoWidget = new KMessageWidget(TestProxy_UI);
        infoWidget->setObjectName("infoWidget");
        infoWidget->setCloseButtonVisible(false);

        gridLayout->addWidget(infoWidget, 2, 0, 1, 1);

        paramBox = new QPlainTextEdit(TestProxy_UI);
        paramBox->setObjectName("paramBox");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(paramBox->sizePolicy().hasHeightForWidth());
        paramBox->setSizePolicy(sizePolicy1);
        paramBox->setReadOnly(true);

        gridLayout->addWidget(paramBox, 1, 0, 1, 1);


        retranslateUi(TestProxy_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, TestProxy_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, TestProxy_UI, qOverload<>(&QDialog::reject));

        QMetaObject::connectSlotsByName(TestProxy_UI);
    } // setupUi

    void retranslateUi(QDialog *TestProxy_UI)
    {
        TestProxy_UI->setWindowTitle(tr2i18n("Dialog", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = resultList->headerItem();
        ___qtreewidgetitem->setText(2, tr2i18n("File Size", nullptr));
        ___qtreewidgetitem->setText(1, tr2i18n("Render Time", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("Profile", nullptr));
    } // retranslateUi

};

namespace Ui {
    class TestProxy_UI: public Ui_TestProxy_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // TESTPROXY_UI_H

