/********************************************************************************
** Form generated from reading UI file 'bezierspline_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_BEZIERSPLINE_UI_H
#define UI_BEZIERSPLINE_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_BezierSpline_UI
{
public:
    QGridLayout *gridLayout;
    QHBoxLayout *horizontalLayout_2;
    QVBoxLayout *widgetPoint;
    QWidget *widget;
    QVBoxLayout *verticalLayout_4;
    QVBoxLayout *layoutP;
    QToolButton *buttonDeletePoint;
    QGridLayout *handlesLayout;
    QHBoxLayout *layoutH1;
    QToolButton *buttonLinkHandles;
    QHBoxLayout *layoutH2;
    QHBoxLayout *horizontalLayout_4;
    QToolButton *buttonResetSpline;
    QToolButton *buttonShowPixmap;
    QToolButton *buttonGridChange;
    QToolButton *buttonZoomIn;
    QToolButton *buttonZoomOut;
    QToolButton *buttonShowAllHandles;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *BezierSpline_UI)
    {
        if (BezierSpline_UI->objectName().isEmpty())
            BezierSpline_UI->setObjectName("BezierSpline_UI");
        BezierSpline_UI->resize(292, 36);
        gridLayout = new QGridLayout(BezierSpline_UI);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(0, 0, 0, 0);
        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        widgetPoint = new QVBoxLayout();
        widgetPoint->setObjectName("widgetPoint");
        widget = new QWidget(BezierSpline_UI);
        widget->setObjectName("widget");
        verticalLayout_4 = new QVBoxLayout(widget);
        verticalLayout_4->setSpacing(6);
        verticalLayout_4->setObjectName("verticalLayout_4");
        verticalLayout_4->setContentsMargins(0, 0, 0, 0);
        layoutP = new QVBoxLayout();
        layoutP->setObjectName("layoutP");

        verticalLayout_4->addLayout(layoutP);


        widgetPoint->addWidget(widget);


        horizontalLayout_2->addLayout(widgetPoint);

        buttonDeletePoint = new QToolButton(BezierSpline_UI);
        buttonDeletePoint->setObjectName("buttonDeletePoint");
        QIcon icon;
        QString iconThemeName = QString::fromUtf8("list-remove");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon = QIcon::fromTheme(iconThemeName);
        } else {
            icon.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        buttonDeletePoint->setIcon(icon);
        buttonDeletePoint->setAutoRaise(true);

        horizontalLayout_2->addWidget(buttonDeletePoint);

        handlesLayout = new QGridLayout();
        handlesLayout->setSpacing(0);
        handlesLayout->setObjectName("handlesLayout");
        layoutH1 = new QHBoxLayout();
        layoutH1->setObjectName("layoutH1");

        handlesLayout->addLayout(layoutH1, 0, 0, 1, 1);

        buttonLinkHandles = new QToolButton(BezierSpline_UI);
        buttonLinkHandles->setObjectName("buttonLinkHandles");
        QIcon icon1;
        iconThemeName = QString::fromUtf8("edit-link");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon1 = QIcon::fromTheme(iconThemeName);
        } else {
            icon1.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        buttonLinkHandles->setIcon(icon1);
        buttonLinkHandles->setCheckable(true);
        buttonLinkHandles->setAutoRaise(true);

        handlesLayout->addWidget(buttonLinkHandles, 0, 1, 1, 1);

        layoutH2 = new QHBoxLayout();
        layoutH2->setObjectName("layoutH2");

        handlesLayout->addLayout(layoutH2, 1, 0, 1, 1);


        horizontalLayout_2->addLayout(handlesLayout);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        buttonResetSpline = new QToolButton(BezierSpline_UI);
        buttonResetSpline->setObjectName("buttonResetSpline");
        QIcon icon2(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        buttonResetSpline->setIcon(icon2);
        buttonResetSpline->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonResetSpline);

        buttonShowPixmap = new QToolButton(BezierSpline_UI);
        buttonShowPixmap->setObjectName("buttonShowPixmap");
        buttonShowPixmap->setCheckable(true);
        buttonShowPixmap->setChecked(true);
        buttonShowPixmap->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonShowPixmap);

        buttonGridChange = new QToolButton(BezierSpline_UI);
        buttonGridChange->setObjectName("buttonGridChange");
        QIcon icon3(QIcon::fromTheme(QString::fromUtf8("view-grid")));
        buttonGridChange->setIcon(icon3);
        buttonGridChange->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonGridChange);

        buttonZoomIn = new QToolButton(BezierSpline_UI);
        buttonZoomIn->setObjectName("buttonZoomIn");
        QIcon icon4;
        iconThemeName = QString::fromUtf8("zoom-in");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon4 = QIcon::fromTheme(iconThemeName);
        } else {
            icon4.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        buttonZoomIn->setIcon(icon4);
        buttonZoomIn->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonZoomIn);

        buttonZoomOut = new QToolButton(BezierSpline_UI);
        buttonZoomOut->setObjectName("buttonZoomOut");
        QIcon icon5;
        iconThemeName = QString::fromUtf8("zoom-out");
        if (QIcon::hasThemeIcon(iconThemeName)) {
            icon5 = QIcon::fromTheme(iconThemeName);
        } else {
            icon5.addFile(QString::fromUtf8("."), QSize(), QIcon::Mode::Normal, QIcon::State::Off);
        }
        buttonZoomOut->setIcon(icon5);
        buttonZoomOut->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonZoomOut);

        buttonShowAllHandles = new QToolButton(BezierSpline_UI);
        buttonShowAllHandles->setObjectName("buttonShowAllHandles");
        QIcon icon6(QIcon::fromTheme(QString::fromUtf8("draw-bezier-curves")));
        buttonShowAllHandles->setIcon(icon6);
        buttonShowAllHandles->setCheckable(true);
        buttonShowAllHandles->setChecked(true);
        buttonShowAllHandles->setAutoRaise(true);

        horizontalLayout_4->addWidget(buttonShowAllHandles);


        horizontalLayout_2->addLayout(horizontalLayout_4);


        gridLayout->addLayout(horizontalLayout_2, 0, 0, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 0, 1, 1);


        retranslateUi(BezierSpline_UI);

        QMetaObject::connectSlotsByName(BezierSpline_UI);
    } // setupUi

    void retranslateUi(QWidget *BezierSpline_UI)
    {
#if QT_CONFIG(tooltip)
        buttonDeletePoint->setToolTip(tr2i18n("Delete current point.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonDeletePoint->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonLinkHandles->setToolTip(tr2i18n("Link the handles' position for current point.<br />Results in a natural spline.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonLinkHandles->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonResetSpline->setToolTip(tr2i18n("Reset the selected spline.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonResetSpline->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonShowPixmap->setToolTip(tr2i18n("Show background indicating changes caused by modifying the curve.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonShowPixmap->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonGridChange->setToolTip(tr2i18n("Increases the number of lines in the grid.<br />After 8 lines it will begin from 0 again.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonGridChange->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonZoomIn->setToolTip(tr2i18n("Zoom in", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonZoomIn->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonZoomOut->setToolTip(tr2i18n("Zoom out", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonZoomOut->setText(tr2i18n("...", nullptr));
#if QT_CONFIG(tooltip)
        buttonShowAllHandles->setToolTip(tr2i18n("Show handles for all points or only for the selected one.", nullptr));
#endif // QT_CONFIG(tooltip)
        buttonShowAllHandles->setText(tr2i18n("...", nullptr));
        (void)BezierSpline_UI;
    } // retranslateUi

};

namespace Ui {
    class BezierSpline_UI: public Ui_BezierSpline_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // BEZIERSPLINE_UI_H

