/********************************************************************************
** Form generated from reading UI file 'spectrogram_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SPECTROGRAM_UI_H
#define UI_SPECTROGRAM_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"

QT_BEGIN_NAMESPACE

class Ui_Spectrogram_UI
{
public:
    QGridLayout *gridLayout;
    KComboBox *windowSize;
    KComboBox *windowFunction;
    QSpacerItem *verticalSpacer;
    QSpacerItem *horizontalSpacer_2;
    QLabel *labelFFTSize;
    QLabel *labelFFTSizeNumber;
    QSpacerItem *horizontalSpacer_3;

    void setupUi(QWidget *Spectrogram_UI)
    {
        if (Spectrogram_UI->objectName().isEmpty())
            Spectrogram_UI->setObjectName("Spectrogram_UI");
        Spectrogram_UI->resize(605, 300);
        gridLayout = new QGridLayout(Spectrogram_UI);
        gridLayout->setObjectName("gridLayout");
        windowSize = new KComboBox(Spectrogram_UI);
        windowSize->setObjectName("windowSize");

        gridLayout->addWidget(windowSize, 0, 5, 1, 1);

        windowFunction = new KComboBox(Spectrogram_UI);
        windowFunction->setObjectName("windowFunction");

        gridLayout->addWidget(windowFunction, 0, 4, 1, 1);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        gridLayout->addItem(verticalSpacer, 1, 5, 1, 1);

        horizontalSpacer_2 = new QSpacerItem(10, 20, QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_2, 0, 0, 1, 1);

        labelFFTSize = new QLabel(Spectrogram_UI);
        labelFFTSize->setObjectName("labelFFTSize");

        gridLayout->addWidget(labelFFTSize, 0, 1, 1, 1);

        labelFFTSizeNumber = new QLabel(Spectrogram_UI);
        labelFFTSizeNumber->setObjectName("labelFFTSizeNumber");
        labelFFTSizeNumber->setText(QString::fromUtf8(""));

        gridLayout->addWidget(labelFFTSizeNumber, 0, 2, 1, 1);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        gridLayout->addItem(horizontalSpacer_3, 0, 3, 1, 1);


        retranslateUi(Spectrogram_UI);

        QMetaObject::connectSlotsByName(Spectrogram_UI);
    } // setupUi

    void retranslateUi(QWidget *Spectrogram_UI)
    {
        labelFFTSize->setText(tr2i18n("True FFT size:", nullptr));
        (void)Spectrogram_UI;
    } // retranslateUi

};

namespace Ui {
    class Spectrogram_UI: public Ui_Spectrogram_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SPECTROGRAM_UI_H

