/********************************************************************************
** Form generated from reading UI file 'listdependencyparamwidget_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LISTDEPENDENCYPARAMWIDGET_UI_H
#define UI_LISTDEPENDENCYPARAMWIDGET_UI_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ListDependencyParamWidget_UI
{
public:
    QGridLayout *gridLayout;
    QWidget *m_widgetComment;
    QGridLayout *_2;
    KMessageWidget *m_infoMessage;
    QComboBox *m_list;

    void setupUi(QWidget *ListDependencyParamWidget_UI)
    {
        if (ListDependencyParamWidget_UI->objectName().isEmpty())
            ListDependencyParamWidget_UI->setObjectName("ListDependencyParamWidget_UI");
        ListDependencyParamWidget_UI->resize(304, 84);
        gridLayout = new QGridLayout(ListDependencyParamWidget_UI);
        gridLayout->setSpacing(0);
        gridLayout->setObjectName("gridLayout");
        gridLayout->setContentsMargins(-1, 0, 0, 0);
        m_widgetComment = new QWidget(ListDependencyParamWidget_UI);
        m_widgetComment->setObjectName("m_widgetComment");
        _2 = new QGridLayout(m_widgetComment);
        _2->setSpacing(0);
        _2->setObjectName("_2");
        _2->setContentsMargins(0, 0, 0, 0);

        gridLayout->addWidget(m_widgetComment, 2, 0, 1, 2);

        m_infoMessage = new KMessageWidget(ListDependencyParamWidget_UI);
        m_infoMessage->setObjectName("m_infoMessage");
        m_infoMessage->setWordWrap(true);

        gridLayout->addWidget(m_infoMessage, 1, 0, 1, 2);

        m_list = new QComboBox(ListDependencyParamWidget_UI);
        m_list->setObjectName("m_list");

        gridLayout->addWidget(m_list, 0, 0, 1, 2);


        retranslateUi(ListDependencyParamWidget_UI);

        QMetaObject::connectSlotsByName(ListDependencyParamWidget_UI);
    } // setupUi

    void retranslateUi(QWidget *ListDependencyParamWidget_UI)
    {
        (void)ListDependencyParamWidget_UI;
    } // retranslateUi

};

namespace Ui {
    class ListDependencyParamWidget_UI: public Ui_ListDependencyParamWidget_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // LISTDEPENDENCYPARAMWIDGET_UI_H

