/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/mainwindow.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "MainWindow",
        "abortRenderJob",
        "",
        "url",
        "abortAllRenderJobs",
        "configurationChanged",
        "setPreviewProgress",
        "setRenderProgress",
        "displayMessage",
        "MessageType",
        "displaySelectionMessage",
        "displayProgressMessage",
        "canBeStopped",
        "updateRenderWidgetProfile",
        "clearAssetPanel",
        "itemId",
        "assetPanelWarning",
        "service",
        "message",
        "log",
        "adjustAssetPanelRange",
        "in",
        "out",
        "enableUndo",
        "enable",
        "removeBinDock",
        "name",
        "connectDockAfterInit",
        "QDockWidget*",
        "slotReloadEffects",
        "paths",
        "setRenderingProgress",
        "progress",
        "frame",
        "setRenderingFinished",
        "status",
        "error",
        "addProjectClip",
        "folder",
        "addTimelineClip",
        "addEffect",
        "effectId",
        "scriptRender",
        "exitApp",
        "Q_NOREPLY",
        "slotSwitchVideoThumbs",
        "slotSwitchAudioThumbs",
        "appHelpActivated",
        "cleanRestart",
        "clean",
        "forceQuit",
        "slotPreferences",
        "slotShowPreferencePage",
        "Kdenlive::ConfigPage",
        "page",
        "option",
        "connectDocument",
        "slotRefreshProfiles",
        "slotZoomIn",
        "zoomOnMouse",
        "slotZoomOut",
        "slotSwitchTimelineZone",
        "toggled",
        "slotDownloadResources",
        "slotInitSubtitle",
        "QMap<QString,QString>",
        "subProperties",
        "QUuid",
        "uuid",
        "slotEditSubtitle",
        "slotShowSubtitles",
        "show",
        "slotTranscode",
        "urls",
        "slotFriendlyTranscode",
        "binId",
        "checkProfile",
        "slotAddSubtitle",
        "text",
        "showSubtitleTrack",
        "updateProjectPath",
        "path",
        "slotUpdateCompositeAction",
        "slotUpdateProjectDuration",
        "pos",
        "slotUpdateZoneDuration",
        "slotCleanProject",
        "slotEditProjectSettings",
        "ix",
        "slotSetZoom",
        "value",
        "slotUpdateDocumentState",
        "modified",
        "manageClipJobs",
        "AbstractTask::JOBTYPE",
        "type",
        "QWidget*",
        "parentWidget",
        "slotDeleteItem",
        "slotExportSubtitle",
        "slotUpdateMousePosition",
        "duration",
        "slotClipInProjectTree",
        "ObjectId",
        "ownerId",
        "seekToStart",
        "slotNormalizeAudioChannel",
        "normalize",
        "fetchFolderSize",
        "KIO::filesize_t",
        "slotEditKeys",
        "slotEditToolbars",
        "loadDockActions",
        "updateConfiguration",
        "slotConnectMonitors",
        "slotSwitchMarkersComments",
        "slotSwitchSnap",
        "slotSwitchClipOverlays",
        "slotShowTimelineTags",
        "slotMouseZoomOnPlayhead",
        "slotRenderProject",
        "slotStopRenderProject",
        "slotFullScreen",
        "finishUiSetup",
        "slotRestart",
        "slotFitZoom",
        "slotUpdateZoomSliderToolTip",
        "zoomlevel",
        "updateZoomSlider",
        "slotShowZoomSliderToolTip",
        "slotAddClipMarker",
        "slotDeleteClipMarker",
        "allowGuideDeletion",
        "slotDeleteAllClipMarkers",
        "slotDeleteAllSequenceMarkers",
        "slotEditClipMarker",
        "slotAddMarkerGuideQuickly",
        "slotAddMarkerWithCategory",
        "slotCutTimelineClip",
        "slotCutTimelineAllClips",
        "slotInsertClipOverwrite",
        "slotInsertClipInsert",
        "slotExtractZone",
        "slotLiftZone",
        "slotCreateRangeMarkerFromZone",
        "slotCreateRangeMarkerFromZoneQuick",
        "slotPreviewRender",
        "slotStopPreviewRender",
        "slotDefinePreviewRender",
        "slotRemovePreviewRender",
        "slotClearPreviewRender",
        "resetZones",
        "slotSelectTimelineClip",
        "slotSelectTimelineZone",
        "slotSelectTimelineTransition",
        "slotDeselectTimelineClip",
        "slotDeselectTimelineTransition",
        "slotSelectAddTimelineClip",
        "slotSelectAddTimelineTransition",
        "slotAddEffect",
        "QAction*",
        "result",
        "slotAddTransition",
        "slotAddProjectClip",
        "QUrl",
        "folderInfo",
        "slotAddTextNote",
        "slotAddProjectClipList",
        "QList<QUrl>",
        "slotChangeTool",
        "action",
        "slotChangeEdit",
        "slotSetTool",
        "ToolType::ProjectTool",
        "tool",
        "slotSnapForward",
        "slotSnapRewind",
        "slotGuideForward",
        "slotGuideRewind",
        "slotClipStart",
        "slotClipEnd",
        "slotSelectClipInTimeline",
        "slotClipInTimeline",
        "clipId",
        "QList<int>",
        "ids",
        "slotInsertSpace",
        "slotRemoveSpace",
        "slotRemoveSpaceInAllTracks",
        "slotRemoveAllSpacesInTrack",
        "slotRemoveAllClipsInTrack",
        "slotAddGuide",
        "slotEditGuide",
        "slotExportGuides",
        "slotLockGuides",
        "lock",
        "slotDeleteGuide",
        "slotDeleteAllGuides",
        "slotCopy",
        "slotCut",
        "slotPaste",
        "slotPasteEffects",
        "slotResizeItemStart",
        "slotResizeItemEnd",
        "configureNotifications",
        "slotSeparateAudioChannel",
        "slotAutoTrackHeight",
        "slotInsertTrack",
        "slotDeleteTrack",
        "slotSwitchTrackAudioStream",
        "slotShowTrackRec",
        "checked",
        "slotSelectTrack",
        "slotSelectAllTracks",
        "slotUnselectAllTracks",
        "slotRunWizard",
        "slotGroupClips",
        "slotUnGroupClips",
        "slotEditItemDuration",
        "slotSplitAV",
        "slotSwitchClip",
        "slotSetAudioAlignReference",
        "slotAlignAudio",
        "slotSetTimecodeReference",
        "slotAlignTimecode",
        "slotUpdateTimelineView",
        "slotTranscodeClip",
        "slotArchiveProject",
        "slotSetDocumentRenderProfile",
        "props",
        "slotUpdateTimecodeFormat",
        "applyToolMessageStyling",
        "applyZoomLevelButtonStyling",
        "slotRemoveFocus",
        "slotShutdown",
        "slotSwitchMonitors",
        "slotSwitchMonitorOverlay",
        "slotSwitchDropFrames",
        "drop",
        "slotCheckRenderStatus",
        "slotInsertZoneToTree",
        "slotFocusTimecode",
        "slotUpdateProxySettings",
        "slotDisableProxies",
        "slotProcessImportKeyframes",
        "GraphicsRectItem",
        "tag",
        "keyframes",
        "slotAlignPlayheadToMousePos",
        "slotThemeChanged",
        "triggerKey",
        "QKeyEvent*",
        "ev",
        "slotUpdateMonitorOverlays",
        "id",
        "code",
        "createSplitOverlay",
        "std::shared_ptr<Mlt::Filter>",
        "filter",
        "removeSplitOverlay",
        "buildGenerator",
        "slotCheckTabPosition",
        "slotToggleAutoPreview",
        "showTimelineToolbarMenu",
        "QPoint",
        "slotManageCache",
        "showMenuBar",
        "slotUpdateCompositing",
        "setTimelineToolbarIconSize",
        "a",
        "slotEditItemSpeed",
        "slotRemapItemTime",
        "resetTimelineTracks",
        "slotGrabItem",
        "slotCollapse",
        "slotCollapseAll",
        "slotAudioZoomIn",
        "slotAudioZoomOut",
        "slotAudioZoomReset",
        "slotAudioZoomCycle",
        "slotExtractClip",
        "slotSaveZoneToBin",
        "slotExpandClip",
        "slotActivateAudioTrackSequence",
        "slotActivateVideoTrackSequence",
        "slotActivateTarget",
        "slotDisableSubtitle",
        "slotLockSubtitle",
        "slotImportSubtitle",
        "slotManageSubtitle",
        "slotSpeechRecognition",
        "slotCopyDebugInfo",
        "slotRemoveBinDock",
        "slotSearchGuide",
        "slotSearchBin",
        "slotCreateSequenceFromSelection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'abortRenderJob'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'abortAllRenderJobs'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'configurationChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'setPreviewProgress'
        QtMocHelpers::SignalData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'setRenderProgress'
        QtMocHelpers::SignalData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'displayMessage'
        QtMocHelpers::SignalData<void(const QString &, MessageType, int)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'displaySelectionMessage'
        QtMocHelpers::SignalData<void(const QString &)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 },
        }}),
        // Signal 'displayProgressMessage'
        QtMocHelpers::SignalData<void(const QString &, MessageType, int, bool)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 }, { QMetaType::Bool, 12 },
        }}),
        // Signal 'displayProgressMessage'
        QtMocHelpers::SignalData<void(const QString &, MessageType, int)>(11, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 2 }, { 0x80000000 | 9, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'updateRenderWidgetProfile'
        QtMocHelpers::SignalData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clearAssetPanel'
        QtMocHelpers::SignalData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Signal 'clearAssetPanel'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Signal 'assetPanelWarning'
        QtMocHelpers::SignalData<void(const QString, const QString, const QString)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 },
        }}),
        // Signal 'assetPanelWarning'
        QtMocHelpers::SignalData<void(const QString, const QString)>(16, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 17 }, { QMetaType::QString, 18 },
        }}),
        // Signal 'adjustAssetPanelRange'
        QtMocHelpers::SignalData<void(int, int, int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 }, { QMetaType::Int, 21 }, { QMetaType::Int, 22 },
        }}),
        // Signal 'enableUndo'
        QtMocHelpers::SignalData<void(bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Signal 'removeBinDock'
        QtMocHelpers::SignalData<void(const QString &)>(25, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Signal 'connectDockAfterInit'
        QtMocHelpers::SignalData<void(QDockWidget *)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 28, 2 },
        }}),
        // Slot 'slotReloadEffects'
        QtMocHelpers::SlotData<void(const QStringList &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 30 },
        }}),
        // Slot 'setRenderingProgress'
        QtMocHelpers::SlotData<void(const QString &, int, int)>(31, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 32 }, { QMetaType::Int, 33 },
        }}),
        // Slot 'setRenderingFinished'
        QtMocHelpers::SlotData<void(const QString &, int, const QString &)>(34, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Int, 35 }, { QMetaType::QString, 36 },
        }}),
        // Slot 'addProjectClip'
        QtMocHelpers::SlotData<void(const QString &, const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::QString, 38 },
        }}),
        // Slot 'addProjectClip'
        QtMocHelpers::SlotData<void(const QString &)>(37, 2, QMC::AccessPublic | QMC::MethodCloned | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'addTimelineClip'
        QtMocHelpers::SlotData<void(const QString &)>(39, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'addEffect'
        QtMocHelpers::SlotData<void(const QString &)>(40, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 41 },
        }}),
        // Slot 'scriptRender'
        QtMocHelpers::SlotData<void(const QString &)>(42, 2, QMC::AccessPublic | QMC::MethodScriptable, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'exitApp'
        QtMocHelpers::SlotData<void()>(43, 44, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchVideoThumbs'
        QtMocHelpers::SlotData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSwitchAudioThumbs'
        QtMocHelpers::SlotData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'appHelpActivated'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'cleanRestart'
        QtMocHelpers::SlotData<void(bool, bool)>(48, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 49 }, { QMetaType::Bool, 50 },
        }}),
        // Slot 'cleanRestart'
        QtMocHelpers::SlotData<void(bool)>(48, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'slotPreferences'
        QtMocHelpers::SlotData<void()>(51, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotShowPreferencePage'
        QtMocHelpers::SlotData<void(Kdenlive::ConfigPage, int)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 53, 54 }, { QMetaType::Int, 55 },
        }}),
        // Slot 'slotShowPreferencePage'
        QtMocHelpers::SlotData<void(Kdenlive::ConfigPage)>(52, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 53, 54 },
        }}),
        // Slot 'connectDocument'
        QtMocHelpers::SlotData<void()>(56, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotRefreshProfiles'
        QtMocHelpers::SlotData<void()>(57, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void(bool)>(58, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'slotZoomIn'
        QtMocHelpers::SlotData<void()>(58, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void(bool)>(60, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 59 },
        }}),
        // Slot 'slotZoomOut'
        QtMocHelpers::SlotData<void()>(60, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSwitchTimelineZone'
        QtMocHelpers::SlotData<void(bool)>(61, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 62 },
        }}),
        // Slot 'slotDownloadResources'
        QtMocHelpers::SlotData<void()>(63, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotInitSubtitle'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &, const QUuid &)>(64, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 }, { 0x80000000 | 67, 68 },
        }}),
        // Slot 'slotEditSubtitle'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 65, 66 },
        }}),
        // Slot 'slotEditSubtitle'
        QtMocHelpers::SlotData<void()>(69, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotShowSubtitles'
        QtMocHelpers::SlotData<void(bool)>(70, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 71 },
        }}),
        // Slot 'slotTranscode'
        QtMocHelpers::SlotData<void(const QStringList &)>(72, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 73 },
        }}),
        // Slot 'slotTranscode'
        QtMocHelpers::SlotData<void()>(72, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotFriendlyTranscode'
        QtMocHelpers::SlotData<void(const QString &, bool)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Bool, 76 },
        }}),
        // Slot 'slotAddSubtitle'
        QtMocHelpers::SlotData<void(const QString &)>(77, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 78 },
        }}),
        // Slot 'slotAddSubtitle'
        QtMocHelpers::SlotData<void()>(77, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'showSubtitleTrack'
        QtMocHelpers::SlotData<void()>(79, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateProjectPath'
        QtMocHelpers::SlotData<void(const QString &)>(80, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 81 },
        }}),
        // Slot 'slotUpdateCompositeAction'
        QtMocHelpers::SlotData<void(bool)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slotUpdateProjectDuration'
        QtMocHelpers::SlotData<void(int)>(83, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 84 },
        }}),
        // Slot 'slotUpdateZoneDuration'
        QtMocHelpers::SlotData<void()>(85, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotCleanProject'
        QtMocHelpers::SlotData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotEditProjectSettings'
        QtMocHelpers::SlotData<void(int)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 88 },
        }}),
        // Slot 'slotEditProjectSettings'
        QtMocHelpers::SlotData<void()>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSetZoom'
        QtMocHelpers::SlotData<void(int, bool)>(89, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 90 }, { QMetaType::Bool, 59 },
        }}),
        // Slot 'slotSetZoom'
        QtMocHelpers::SlotData<void(int)>(89, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotUpdateDocumentState'
        QtMocHelpers::SlotData<void(bool)>(91, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 92 },
        }}),
        // Slot 'manageClipJobs'
        QtMocHelpers::SlotData<void(AbstractTask::JOBTYPE, QWidget *)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 94, 95 }, { 0x80000000 | 96, 97 },
        }}),
        // Slot 'manageClipJobs'
        QtMocHelpers::SlotData<void(AbstractTask::JOBTYPE)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 94, 95 },
        }}),
        // Slot 'manageClipJobs'
        QtMocHelpers::SlotData<void()>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotDeleteItem'
        QtMocHelpers::SlotData<void()>(98, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotExportSubtitle'
        QtMocHelpers::SlotData<void()>(99, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotUpdateMousePosition'
        QtMocHelpers::SlotData<void(int, int)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 84 }, { QMetaType::Int, 101 },
        }}),
        // Slot 'slotUpdateMousePosition'
        QtMocHelpers::SlotData<void(int)>(100, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 84 },
        }}),
        // Slot 'slotClipInProjectTree'
        QtMocHelpers::SlotData<void(ObjectId, bool)>(102, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 103, 104 }, { QMetaType::Bool, 105 },
        }}),
        // Slot 'slotClipInProjectTree'
        QtMocHelpers::SlotData<void(ObjectId)>(102, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 103, 104 },
        }}),
        // Slot 'slotClipInProjectTree'
        QtMocHelpers::SlotData<void()>(102, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotNormalizeAudioChannel'
        QtMocHelpers::SlotData<void(bool)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 107 },
        }}),
        // Slot 'fetchFolderSize'
        QtMocHelpers::SlotData<KIO::filesize_t(const QString)>(108, 2, QMC::AccessPublic, 0x80000000 | 109, {{
            { QMetaType::QString, 81 },
        }}),
        // Slot 'slotEditKeys'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditToolbars'
        QtMocHelpers::SlotData<void()>(111, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadDockActions'
        QtMocHelpers::SlotData<void()>(112, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateConfiguration'
        QtMocHelpers::SlotData<void()>(113, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotConnectMonitors'
        QtMocHelpers::SlotData<void()>(114, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchMarkersComments'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchSnap'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchClipOverlays'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowTimelineTags'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotMouseZoomOnPlayhead'
        QtMocHelpers::SlotData<void()>(119, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRenderProject'
        QtMocHelpers::SlotData<void()>(120, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStopRenderProject'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFullScreen'
        QtMocHelpers::SlotData<void()>(122, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'finishUiSetup'
        QtMocHelpers::SlotData<void()>(123, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRestart'
        QtMocHelpers::SlotData<void(bool)>(124, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 49 },
        }}),
        // Slot 'slotRestart'
        QtMocHelpers::SlotData<void()>(124, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotFitZoom'
        QtMocHelpers::SlotData<void()>(125, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateZoomSliderToolTip'
        QtMocHelpers::SlotData<void(int)>(126, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 127 },
        }}),
        // Slot 'updateZoomSlider'
        QtMocHelpers::SlotData<void(int)>(128, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 90 },
        }}),
        // Slot 'slotShowZoomSliderToolTip'
        QtMocHelpers::SlotData<void(int)>(129, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 127 },
        }}),
        // Slot 'slotShowZoomSliderToolTip'
        QtMocHelpers::SlotData<void()>(129, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotAddClipMarker'
        QtMocHelpers::SlotData<void()>(130, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteClipMarker'
        QtMocHelpers::SlotData<void(bool)>(131, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 132 },
        }}),
        // Slot 'slotDeleteClipMarker'
        QtMocHelpers::SlotData<void()>(131, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotDeleteAllClipMarkers'
        QtMocHelpers::SlotData<void()>(133, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteAllSequenceMarkers'
        QtMocHelpers::SlotData<void()>(134, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditClipMarker'
        QtMocHelpers::SlotData<void()>(135, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddMarkerGuideQuickly'
        QtMocHelpers::SlotData<void()>(136, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddMarkerWithCategory'
        QtMocHelpers::SlotData<void()>(137, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCutTimelineClip'
        QtMocHelpers::SlotData<void()>(138, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCutTimelineAllClips'
        QtMocHelpers::SlotData<void()>(139, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInsertClipOverwrite'
        QtMocHelpers::SlotData<void()>(140, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInsertClipInsert'
        QtMocHelpers::SlotData<void()>(141, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExtractZone'
        QtMocHelpers::SlotData<void()>(142, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLiftZone'
        QtMocHelpers::SlotData<void()>(143, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateRangeMarkerFromZone'
        QtMocHelpers::SlotData<void()>(144, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateRangeMarkerFromZoneQuick'
        QtMocHelpers::SlotData<void()>(145, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPreviewRender'
        QtMocHelpers::SlotData<void()>(146, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotStopPreviewRender'
        QtMocHelpers::SlotData<void()>(147, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDefinePreviewRender'
        QtMocHelpers::SlotData<void()>(148, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemovePreviewRender'
        QtMocHelpers::SlotData<void()>(149, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClearPreviewRender'
        QtMocHelpers::SlotData<void(bool)>(150, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 151 },
        }}),
        // Slot 'slotClearPreviewRender'
        QtMocHelpers::SlotData<void()>(150, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'slotSelectTimelineClip'
        QtMocHelpers::SlotData<void()>(152, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectTimelineZone'
        QtMocHelpers::SlotData<void()>(153, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectTimelineTransition'
        QtMocHelpers::SlotData<void()>(154, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeselectTimelineClip'
        QtMocHelpers::SlotData<void()>(155, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeselectTimelineTransition'
        QtMocHelpers::SlotData<void()>(156, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectAddTimelineClip'
        QtMocHelpers::SlotData<void()>(157, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectAddTimelineTransition'
        QtMocHelpers::SlotData<void()>(158, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddEffect'
        QtMocHelpers::SlotData<void(QAction *)>(159, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 161 },
        }}),
        // Slot 'slotAddTransition'
        QtMocHelpers::SlotData<void(QAction *)>(162, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 161 },
        }}),
        // Slot 'slotAddProjectClip'
        QtMocHelpers::SlotData<void(const QUrl &, const QString &)>(163, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 164, 3 }, { QMetaType::QString, 165 },
        }}),
        // Slot 'slotAddTextNote'
        QtMocHelpers::SlotData<void(const QString &)>(166, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 78 },
        }}),
        // Slot 'slotAddProjectClipList'
        QtMocHelpers::SlotData<void(const QList<QUrl> &)>(167, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 168, 73 },
        }}),
        // Slot 'slotChangeTool'
        QtMocHelpers::SlotData<void(QAction *)>(169, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 170 },
        }}),
        // Slot 'slotChangeEdit'
        QtMocHelpers::SlotData<void(QAction *)>(171, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 170 },
        }}),
        // Slot 'slotSetTool'
        QtMocHelpers::SlotData<void(ToolType::ProjectTool)>(172, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 173, 174 },
        }}),
        // Slot 'slotSnapForward'
        QtMocHelpers::SlotData<void()>(175, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSnapRewind'
        QtMocHelpers::SlotData<void()>(176, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGuideForward'
        QtMocHelpers::SlotData<void()>(177, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGuideRewind'
        QtMocHelpers::SlotData<void()>(178, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClipStart'
        QtMocHelpers::SlotData<void()>(179, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClipEnd'
        QtMocHelpers::SlotData<void()>(180, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectClipInTimeline'
        QtMocHelpers::SlotData<void()>(181, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotClipInTimeline'
        QtMocHelpers::SlotData<void(const QString &, const QList<int> &)>(182, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 183 }, { 0x80000000 | 184, 185 },
        }}),
        // Slot 'slotInsertSpace'
        QtMocHelpers::SlotData<void()>(186, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveSpace'
        QtMocHelpers::SlotData<void()>(187, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveSpaceInAllTracks'
        QtMocHelpers::SlotData<void()>(188, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveAllSpacesInTrack'
        QtMocHelpers::SlotData<void()>(189, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveAllClipsInTrack'
        QtMocHelpers::SlotData<void()>(190, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAddGuide'
        QtMocHelpers::SlotData<void()>(191, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditGuide'
        QtMocHelpers::SlotData<void()>(192, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExportGuides'
        QtMocHelpers::SlotData<void()>(193, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLockGuides'
        QtMocHelpers::SlotData<void(bool)>(194, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 195 },
        }}),
        // Slot 'slotDeleteGuide'
        QtMocHelpers::SlotData<void()>(196, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteAllGuides'
        QtMocHelpers::SlotData<void()>(197, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopy'
        QtMocHelpers::SlotData<void()>(198, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCut'
        QtMocHelpers::SlotData<void()>(199, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPaste'
        QtMocHelpers::SlotData<void()>(200, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotPasteEffects'
        QtMocHelpers::SlotData<void()>(201, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResizeItemStart'
        QtMocHelpers::SlotData<void()>(202, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotResizeItemEnd'
        QtMocHelpers::SlotData<void()>(203, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'configureNotifications'
        QtMocHelpers::SlotData<void()>(204, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSeparateAudioChannel'
        QtMocHelpers::SlotData<void()>(205, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAutoTrackHeight'
        QtMocHelpers::SlotData<void(bool)>(206, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'slotInsertTrack'
        QtMocHelpers::SlotData<void()>(207, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDeleteTrack'
        QtMocHelpers::SlotData<void()>(208, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchTrackAudioStream'
        QtMocHelpers::SlotData<void()>(209, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShowTrackRec'
        QtMocHelpers::SlotData<void(bool)>(210, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 211 },
        }}),
        // Slot 'slotSelectTrack'
        QtMocHelpers::SlotData<void()>(212, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSelectAllTracks'
        QtMocHelpers::SlotData<void()>(213, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUnselectAllTracks'
        QtMocHelpers::SlotData<void()>(214, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRunWizard'
        QtMocHelpers::SlotData<void()>(215, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGroupClips'
        QtMocHelpers::SlotData<void()>(216, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUnGroupClips'
        QtMocHelpers::SlotData<void()>(217, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotEditItemDuration'
        QtMocHelpers::SlotData<void()>(218, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSplitAV'
        QtMocHelpers::SlotData<void()>(219, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchClip'
        QtMocHelpers::SlotData<void()>(220, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetAudioAlignReference'
        QtMocHelpers::SlotData<void()>(221, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAlignAudio'
        QtMocHelpers::SlotData<void()>(222, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetTimecodeReference'
        QtMocHelpers::SlotData<void()>(223, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAlignTimecode'
        QtMocHelpers::SlotData<void()>(224, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateTimelineView'
        QtMocHelpers::SlotData<void(QAction *)>(225, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 170 },
        }}),
        // Slot 'slotTranscodeClip'
        QtMocHelpers::SlotData<void()>(226, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotArchiveProject'
        QtMocHelpers::SlotData<void()>(227, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSetDocumentRenderProfile'
        QtMocHelpers::SlotData<void(const QMap<QString,QString> &)>(228, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 65, 229 },
        }}),
        // Slot 'slotUpdateTimecodeFormat'
        QtMocHelpers::SlotData<void(int)>(230, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 88 },
        }}),
        // Slot 'applyToolMessageStyling'
        QtMocHelpers::SlotData<void()>(231, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'applyZoomLevelButtonStyling'
        QtMocHelpers::SlotData<void()>(232, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveFocus'
        QtMocHelpers::SlotData<void()>(233, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotShutdown'
        QtMocHelpers::SlotData<void()>(234, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchMonitors'
        QtMocHelpers::SlotData<void()>(235, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSwitchMonitorOverlay'
        QtMocHelpers::SlotData<void(QAction *)>(236, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 2 },
        }}),
        // Slot 'slotSwitchDropFrames'
        QtMocHelpers::SlotData<void(bool)>(237, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 238 },
        }}),
        // Slot 'slotCheckRenderStatus'
        QtMocHelpers::SlotData<void()>(239, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotInsertZoneToTree'
        QtMocHelpers::SlotData<void()>(240, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFocusTimecode'
        QtMocHelpers::SlotData<void()>(241, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotUpdateProxySettings'
        QtMocHelpers::SlotData<void()>(242, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDisableProxies'
        QtMocHelpers::SlotData<void()>(243, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotProcessImportKeyframes'
        QtMocHelpers::SlotData<void(GraphicsRectItem, const QString &, const QString &)>(244, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 245, 95 }, { QMetaType::QString, 246 }, { QMetaType::QString, 247 },
        }}),
        // Slot 'slotAlignPlayheadToMousePos'
        QtMocHelpers::SlotData<void()>(248, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotThemeChanged'
        QtMocHelpers::SlotData<void(const QString &)>(249, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'triggerKey'
        QtMocHelpers::SlotData<void(QKeyEvent *)>(250, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 251, 252 },
        }}),
        // Slot 'slotUpdateMonitorOverlays'
        QtMocHelpers::SlotData<void(int, int)>(253, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 254 }, { QMetaType::Int, 255 },
        }}),
        // Slot 'createSplitOverlay'
        QtMocHelpers::SlotData<void(std::shared_ptr<Mlt::Filter>)>(256, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 257, 258 },
        }}),
        // Slot 'removeSplitOverlay'
        QtMocHelpers::SlotData<void()>(259, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'buildGenerator'
        QtMocHelpers::SlotData<void(QAction *)>(260, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 170 },
        }}),
        // Slot 'slotCheckTabPosition'
        QtMocHelpers::SlotData<void()>(261, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotToggleAutoPreview'
        QtMocHelpers::SlotData<void(bool)>(262, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 24 },
        }}),
        // Slot 'showTimelineToolbarMenu'
        QtMocHelpers::SlotData<void(const QPoint &)>(263, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 264, 84 },
        }}),
        // Slot 'slotManageCache'
        QtMocHelpers::SlotData<void()>(265, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showMenuBar'
        QtMocHelpers::SlotData<void(bool)>(266, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 71 },
        }}),
        // Slot 'slotUpdateCompositing'
        QtMocHelpers::SlotData<void(bool)>(267, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 211 },
        }}),
        // Slot 'setTimelineToolbarIconSize'
        QtMocHelpers::SlotData<void(QAction *)>(268, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 160, 269 },
        }}),
        // Slot 'slotEditItemSpeed'
        QtMocHelpers::SlotData<void()>(270, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemapItemTime'
        QtMocHelpers::SlotData<void()>(271, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'resetTimelineTracks'
        QtMocHelpers::SlotData<void()>(272, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotGrabItem'
        QtMocHelpers::SlotData<void()>(273, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCollapse'
        QtMocHelpers::SlotData<void()>(274, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCollapseAll'
        QtMocHelpers::SlotData<void()>(275, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAudioZoomIn'
        QtMocHelpers::SlotData<void()>(276, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAudioZoomOut'
        QtMocHelpers::SlotData<void()>(277, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAudioZoomReset'
        QtMocHelpers::SlotData<void()>(278, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotAudioZoomCycle'
        QtMocHelpers::SlotData<void()>(279, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExtractClip'
        QtMocHelpers::SlotData<void()>(280, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSaveZoneToBin'
        QtMocHelpers::SlotData<void()>(281, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotExpandClip'
        QtMocHelpers::SlotData<void()>(282, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivateAudioTrackSequence'
        QtMocHelpers::SlotData<void()>(283, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivateVideoTrackSequence'
        QtMocHelpers::SlotData<void()>(284, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotActivateTarget'
        QtMocHelpers::SlotData<void()>(285, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotDisableSubtitle'
        QtMocHelpers::SlotData<void()>(286, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotLockSubtitle'
        QtMocHelpers::SlotData<void()>(287, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotImportSubtitle'
        QtMocHelpers::SlotData<void()>(288, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotManageSubtitle'
        QtMocHelpers::SlotData<void()>(289, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSpeechRecognition'
        QtMocHelpers::SlotData<void()>(290, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCopyDebugInfo'
        QtMocHelpers::SlotData<void()>(291, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotRemoveBinDock'
        QtMocHelpers::SlotData<void(const QString &)>(292, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'slotSearchGuide'
        QtMocHelpers::SlotData<void()>(293, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotSearchBin'
        QtMocHelpers::SlotData<void()>(294, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotCreateSequenceFromSelection'
        QtMocHelpers::SlotData<void()>(295, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10MainWindowE_t>.metaTypes,
    nullptr
} };

void MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->abortRenderJob((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->abortAllRenderJobs(); break;
        case 2: _t->configurationChanged(); break;
        case 3: _t->setPreviewProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->setRenderProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 6: _t->displaySelectionMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->displayProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 8: _t->displayProgressMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 9: _t->updateRenderWidgetProfile(); break;
        case 10: _t->clearAssetPanel((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->clearAssetPanel(); break;
        case 12: _t->assetPanelWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 13: _t->assetPanelWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 14: _t->adjustAssetPanelRange((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 15: _t->enableUndo((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 16: _t->removeBinDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 17: _t->connectDockAfterInit((*reinterpret_cast<std::add_pointer_t<QDockWidget*>>(_a[1]))); break;
        case 18: _t->slotReloadEffects((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 19: _t->setRenderingProgress((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 20: _t->setRenderingFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 21: _t->addProjectClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 22: _t->addProjectClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->addTimelineClip((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->addEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->scriptRender((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->exitApp(); break;
        case 27: _t->slotSwitchVideoThumbs(); break;
        case 28: _t->slotSwitchAudioThumbs(); break;
        case 29: _t->appHelpActivated(); break;
        case 30: _t->cleanRestart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 31: _t->cleanRestart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 32: _t->slotPreferences(); break;
        case 33: _t->slotShowPreferencePage((*reinterpret_cast<std::add_pointer_t<Kdenlive::ConfigPage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 34: _t->slotShowPreferencePage((*reinterpret_cast<std::add_pointer_t<Kdenlive::ConfigPage>>(_a[1]))); break;
        case 35: _t->connectDocument(); break;
        case 36: _t->slotRefreshProfiles(); break;
        case 37: _t->slotZoomIn((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 38: _t->slotZoomIn(); break;
        case 39: _t->slotZoomOut((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 40: _t->slotZoomOut(); break;
        case 41: _t->slotSwitchTimelineZone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->slotDownloadResources(); break;
        case 43: _t->slotInitSubtitle((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[2]))); break;
        case 44: _t->slotEditSubtitle((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 45: _t->slotEditSubtitle(); break;
        case 46: _t->slotShowSubtitles((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 47: _t->slotTranscode((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 48: _t->slotTranscode(); break;
        case 49: _t->slotFriendlyTranscode((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 50: _t->slotAddSubtitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 51: _t->slotAddSubtitle(); break;
        case 52: _t->showSubtitleTrack(); break;
        case 53: _t->updateProjectPath((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 54: _t->slotUpdateCompositeAction((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 55: _t->slotUpdateProjectDuration((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 56: _t->slotUpdateZoneDuration(); break;
        case 57: _t->slotCleanProject(); break;
        case 58: _t->slotEditProjectSettings((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 59: _t->slotEditProjectSettings(); break;
        case 60: _t->slotSetZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 61: _t->slotSetZoom((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 62: _t->slotUpdateDocumentState((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 63: _t->manageClipJobs((*reinterpret_cast<std::add_pointer_t<AbstractTask::JOBTYPE>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QWidget*>>(_a[2]))); break;
        case 64: _t->manageClipJobs((*reinterpret_cast<std::add_pointer_t<AbstractTask::JOBTYPE>>(_a[1]))); break;
        case 65: _t->manageClipJobs(); break;
        case 66: _t->slotDeleteItem(); break;
        case 67: _t->slotExportSubtitle(); break;
        case 68: _t->slotUpdateMousePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 69: _t->slotUpdateMousePosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 70: _t->slotClipInProjectTree((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 71: _t->slotClipInProjectTree((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1]))); break;
        case 72: _t->slotClipInProjectTree(); break;
        case 73: _t->slotNormalizeAudioChannel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: { KIO::filesize_t _r = _t->fetchFolderSize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<KIO::filesize_t*>(_a[0]) = std::move(_r); }  break;
        case 75: _t->slotEditKeys(); break;
        case 76: _t->slotEditToolbars(); break;
        case 77: _t->loadDockActions(); break;
        case 78: _t->updateConfiguration(); break;
        case 79: _t->slotConnectMonitors(); break;
        case 80: _t->slotSwitchMarkersComments(); break;
        case 81: _t->slotSwitchSnap(); break;
        case 82: _t->slotSwitchClipOverlays(); break;
        case 83: _t->slotShowTimelineTags(); break;
        case 84: _t->slotMouseZoomOnPlayhead(); break;
        case 85: _t->slotRenderProject(); break;
        case 86: _t->slotStopRenderProject(); break;
        case 87: _t->slotFullScreen(); break;
        case 88: _t->finishUiSetup(); break;
        case 89: _t->slotRestart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 90: _t->slotRestart(); break;
        case 91: _t->slotFitZoom(); break;
        case 92: _t->slotUpdateZoomSliderToolTip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 93: _t->updateZoomSlider((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 94: _t->slotShowZoomSliderToolTip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 95: _t->slotShowZoomSliderToolTip(); break;
        case 96: _t->slotAddClipMarker(); break;
        case 97: _t->slotDeleteClipMarker((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 98: _t->slotDeleteClipMarker(); break;
        case 99: _t->slotDeleteAllClipMarkers(); break;
        case 100: _t->slotDeleteAllSequenceMarkers(); break;
        case 101: _t->slotEditClipMarker(); break;
        case 102: _t->slotAddMarkerGuideQuickly(); break;
        case 103: _t->slotAddMarkerWithCategory(); break;
        case 104: _t->slotCutTimelineClip(); break;
        case 105: _t->slotCutTimelineAllClips(); break;
        case 106: _t->slotInsertClipOverwrite(); break;
        case 107: _t->slotInsertClipInsert(); break;
        case 108: _t->slotExtractZone(); break;
        case 109: _t->slotLiftZone(); break;
        case 110: _t->slotCreateRangeMarkerFromZone(); break;
        case 111: _t->slotCreateRangeMarkerFromZoneQuick(); break;
        case 112: _t->slotPreviewRender(); break;
        case 113: _t->slotStopPreviewRender(); break;
        case 114: _t->slotDefinePreviewRender(); break;
        case 115: _t->slotRemovePreviewRender(); break;
        case 116: _t->slotClearPreviewRender((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 117: _t->slotClearPreviewRender(); break;
        case 118: _t->slotSelectTimelineClip(); break;
        case 119: _t->slotSelectTimelineZone(); break;
        case 120: _t->slotSelectTimelineTransition(); break;
        case 121: _t->slotDeselectTimelineClip(); break;
        case 122: _t->slotDeselectTimelineTransition(); break;
        case 123: _t->slotSelectAddTimelineClip(); break;
        case 124: _t->slotSelectAddTimelineTransition(); break;
        case 125: _t->slotAddEffect((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 126: _t->slotAddTransition((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 127: _t->slotAddProjectClip((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 128: _t->slotAddTextNote((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 129: _t->slotAddProjectClipList((*reinterpret_cast<std::add_pointer_t<QList<QUrl>>>(_a[1]))); break;
        case 130: _t->slotChangeTool((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 131: _t->slotChangeEdit((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 132: _t->slotSetTool((*reinterpret_cast<std::add_pointer_t<ToolType::ProjectTool>>(_a[1]))); break;
        case 133: _t->slotSnapForward(); break;
        case 134: _t->slotSnapRewind(); break;
        case 135: _t->slotGuideForward(); break;
        case 136: _t->slotGuideRewind(); break;
        case 137: _t->slotClipStart(); break;
        case 138: _t->slotClipEnd(); break;
        case 139: _t->slotSelectClipInTimeline(); break;
        case 140: _t->slotClipInTimeline((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[2]))); break;
        case 141: _t->slotInsertSpace(); break;
        case 142: _t->slotRemoveSpace(); break;
        case 143: _t->slotRemoveSpaceInAllTracks(); break;
        case 144: _t->slotRemoveAllSpacesInTrack(); break;
        case 145: _t->slotRemoveAllClipsInTrack(); break;
        case 146: _t->slotAddGuide(); break;
        case 147: _t->slotEditGuide(); break;
        case 148: _t->slotExportGuides(); break;
        case 149: _t->slotLockGuides((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 150: _t->slotDeleteGuide(); break;
        case 151: _t->slotDeleteAllGuides(); break;
        case 152: _t->slotCopy(); break;
        case 153: _t->slotCut(); break;
        case 154: _t->slotPaste(); break;
        case 155: _t->slotPasteEffects(); break;
        case 156: _t->slotResizeItemStart(); break;
        case 157: _t->slotResizeItemEnd(); break;
        case 158: _t->configureNotifications(); break;
        case 159: _t->slotSeparateAudioChannel(); break;
        case 160: _t->slotAutoTrackHeight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 161: _t->slotInsertTrack(); break;
        case 162: _t->slotDeleteTrack(); break;
        case 163: _t->slotSwitchTrackAudioStream(); break;
        case 164: _t->slotShowTrackRec((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 165: _t->slotSelectTrack(); break;
        case 166: _t->slotSelectAllTracks(); break;
        case 167: _t->slotUnselectAllTracks(); break;
        case 168: _t->slotRunWizard(); break;
        case 169: _t->slotGroupClips(); break;
        case 170: _t->slotUnGroupClips(); break;
        case 171: _t->slotEditItemDuration(); break;
        case 172: _t->slotSplitAV(); break;
        case 173: _t->slotSwitchClip(); break;
        case 174: _t->slotSetAudioAlignReference(); break;
        case 175: _t->slotAlignAudio(); break;
        case 176: _t->slotSetTimecodeReference(); break;
        case 177: _t->slotAlignTimecode(); break;
        case 178: _t->slotUpdateTimelineView((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 179: _t->slotTranscodeClip(); break;
        case 180: _t->slotArchiveProject(); break;
        case 181: _t->slotSetDocumentRenderProfile((*reinterpret_cast<std::add_pointer_t<QMap<QString,QString>>>(_a[1]))); break;
        case 182: _t->slotUpdateTimecodeFormat((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 183: _t->applyToolMessageStyling(); break;
        case 184: _t->applyZoomLevelButtonStyling(); break;
        case 185: _t->slotRemoveFocus(); break;
        case 186: _t->slotShutdown(); break;
        case 187: _t->slotSwitchMonitors(); break;
        case 188: _t->slotSwitchMonitorOverlay((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 189: _t->slotSwitchDropFrames((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 190: _t->slotCheckRenderStatus(); break;
        case 191: _t->slotInsertZoneToTree(); break;
        case 192: _t->slotFocusTimecode(); break;
        case 193: _t->slotUpdateProxySettings(); break;
        case 194: _t->slotDisableProxies(); break;
        case 195: _t->slotProcessImportKeyframes((*reinterpret_cast<std::add_pointer_t<GraphicsRectItem>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 196: _t->slotAlignPlayheadToMousePos(); break;
        case 197: _t->slotThemeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 198: _t->triggerKey((*reinterpret_cast<std::add_pointer_t<QKeyEvent*>>(_a[1]))); break;
        case 199: _t->slotUpdateMonitorOverlays((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 200: _t->createSplitOverlay((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<Mlt::Filter>>>(_a[1]))); break;
        case 201: _t->removeSplitOverlay(); break;
        case 202: _t->buildGenerator((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 203: _t->slotCheckTabPosition(); break;
        case 204: _t->slotToggleAutoPreview((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 205: _t->showTimelineToolbarMenu((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 206: _t->slotManageCache(); break;
        case 207: _t->showMenuBar((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 208: _t->slotUpdateCompositing((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 209: _t->setTimelineToolbarIconSize((*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[1]))); break;
        case 210: _t->slotEditItemSpeed(); break;
        case 211: _t->slotRemapItemTime(); break;
        case 212: _t->resetTimelineTracks(); break;
        case 213: _t->slotGrabItem(); break;
        case 214: _t->slotCollapse(); break;
        case 215: _t->slotCollapseAll(); break;
        case 216: _t->slotAudioZoomIn(); break;
        case 217: _t->slotAudioZoomOut(); break;
        case 218: _t->slotAudioZoomReset(); break;
        case 219: _t->slotAudioZoomCycle(); break;
        case 220: _t->slotExtractClip(); break;
        case 221: _t->slotSaveZoneToBin(); break;
        case 222: _t->slotExpandClip(); break;
        case 223: _t->slotActivateAudioTrackSequence(); break;
        case 224: _t->slotActivateVideoTrackSequence(); break;
        case 225: _t->slotActivateTarget(); break;
        case 226: _t->slotDisableSubtitle(); break;
        case 227: _t->slotLockSubtitle(); break;
        case 228: _t->slotImportSubtitle(); break;
        case 229: _t->slotManageSubtitle(); break;
        case 230: _t->slotSpeechRecognition(); break;
        case 231: _t->slotCopyDebugInfo(); break;
        case 232: _t->slotRemoveBinDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 233: _t->slotSearchGuide(); break;
        case 234: _t->slotSearchBin(); break;
        case 235: _t->slotCreateSequenceFromSelection(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 17:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDockWidget* >(); break;
            }
            break;
        case 63:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWidget* >(); break;
            }
            break;
        case 125:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 126:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 130:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 131:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 140:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        case 178:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 188:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 202:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 209:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & )>(_a, &MainWindow::abortRenderJob, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::abortAllRenderJobs, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::configurationChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int )>(_a, &MainWindow::setPreviewProgress, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int )>(_a, &MainWindow::setRenderProgress, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & , MessageType , int )>(_a, &MainWindow::displayMessage, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & )>(_a, &MainWindow::displaySelectionMessage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & , MessageType , int , bool )>(_a, &MainWindow::displayProgressMessage, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)()>(_a, &MainWindow::updateRenderWidgetProfile, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int )>(_a, &MainWindow::clearAssetPanel, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString , const QString , const QString )>(_a, &MainWindow::assetPanelWarning, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(int , int , int )>(_a, &MainWindow::adjustAssetPanelRange, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(bool )>(_a, &MainWindow::enableUndo, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(const QString & )>(_a, &MainWindow::removeBinDock, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (MainWindow::*)(QDockWidget * )>(_a, &MainWindow::connectDockAfterInit, 17))
            return;
    }
}

const QMetaObject *MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 236)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 236;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 236)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 236;
    }
    return _id;
}

// SIGNAL 0
void MainWindow::abortRenderJob(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void MainWindow::abortAllRenderJobs()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void MainWindow::configurationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void MainWindow::setPreviewProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void MainWindow::setRenderProgress(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void MainWindow::displayMessage(const QString & _t1, MessageType _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1, _t2, _t3);
}

// SIGNAL 6
void MainWindow::displaySelectionMessage(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void MainWindow::displayProgressMessage(const QString & _t1, MessageType _t2, int _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 9
void MainWindow::updateRenderWidgetProfile()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void MainWindow::clearAssetPanel(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1);
}

// SIGNAL 12
void MainWindow::assetPanelWarning(const QString _t1, const QString _t2, const QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2, _t3);
}

// SIGNAL 14
void MainWindow::adjustAssetPanelRange(int _t1, int _t2, int _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 14, nullptr, _t1, _t2, _t3);
}

// SIGNAL 15
void MainWindow::enableUndo(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void MainWindow::removeBinDock(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 16, nullptr, _t1);
}

// SIGNAL 17
void MainWindow::connectDockAfterInit(QDockWidget * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 17, nullptr, _t1);
}
QT_WARNING_POP
