/********************************************************************************
** Form generated from reading UI file 'projectsettings_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PROJECTSETTINGS_UI_H
#define UI_PROJECTSETTINGS_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAbstractButton>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QDialogButtonBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPlainTextEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QTreeWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kcombobox.h"
#include "kmessagewidget.h"
#include "kseparator.h"
#include "ktreewidgetsearchline.h"
#include "kurlrequester.h"

QT_BEGIN_NAMESPACE

class Ui_ProjectSettings_UI
{
public:
    QGridLayout *gridLayout_3;
    QDialogButtonBox *buttonBox;
    QTabWidget *tabWidget;
    QWidget *tab;
    QFormLayout *formLayout;
    QLabel *label_4;
    QRadioButton *default_folder;
    QRadioButton *same_folder;
    QHBoxLayout *horizontalLayout;
    QRadioButton *custom_folder;
    KUrlRequester *project_folder;
    KSeparator *kseparator_3;
    QGroupBox *profile_box;
    KSeparator *kseparator;
    QLabel *label_video_tracks;
    QSpinBox *video_tracks;
    QLabel *label_audio_tracks;
    QSpinBox *audio_tracks;
    QLabel *label_audio_channels;
    QComboBox *audio_channels;
    QLabel *label_thumbnails;
    QCheckBox *video_thumbs;
    QCheckBox *audio_thumbs;
    QLabel *label_25;
    QHBoxLayout *preview_profile_box;
    QWidget *tab_4;
    QVBoxLayout *verticalLayout;
    QGroupBox *proxy_box;
    QGridLayout *gridLayout;
    QCheckBox *generate_proxy;
    QSpinBox *proxy_imagesize;
    QCheckBox *generate_imageproxy;
    QSpinBox *proxy_imageminsize;
    QLabel *label_24;
    QPlainTextEdit *proxyparams;
    QFormLayout *formLayout_3;
    QLineEdit *le_suffix_proxy;
    QLabel *l_suffix_proxy;
    QLineEdit *le_prefix_proxy;
    QLabel *l_prefix_proxy;
    QLineEdit *le_relPathProxyToOrig;
    QLabel *l_relPathProxyToOrig;
    QLineEdit *le_suffix_clip;
    QLabel *l_suffix_clip;
    QLineEdit *le_prefix_clip;
    QLabel *l_prefix_clip;
    QLabel *l_relPathOrigToProxy;
    QLineEdit *le_relPathOrigToProxy;
    QLabel *label_3;
    QSpinBox *proxy_minsize;
    KSeparator *kseparator_2;
    QSpinBox *proxy_resize;
    QLabel *image_label;
    KSeparator *kseparator_4;
    QHBoxLayout *horizontalLayout_2;
    KComboBox *proxy_profile;
    QToolButton *checkProxy;
    QToolButton *proxy_showprofileinfo;
    QToolButton *proxy_manageprofile;
    KSeparator *kseparator_5;
    QHBoxLayout *horizontalLayout_4;
    QComboBox *external_proxy_profile;
    QToolButton *manage_external;
    QCheckBox *external_proxy;
    QSpacerItem *verticalSpacer;
    QWidget *tab_5;
    QWidget *tab_3;
    QGridLayout *gridLayout_6;
    QTreeWidget *metadata_list;
    QHBoxLayout *horizontalLayout_3;
    QToolButton *add_metadata;
    QToolButton *delete_metadata;
    QSpacerItem *horizontalSpacer_3;
    QWidget *tab_2;
    QGridLayout *gridLayout_4;
    QLabel *label_fonts;
    QListWidget *fonts_list;
    QTreeWidget *files_list;
    KTreeWidgetSearchLine *list_search;
    QLabel *unused_size;
    QLabel *used_size;
    QLabel *label_13;
    QPushButton *button_export;
    QLabel *files_count;
    QLabel *used_count;
    QLabel *label_6;
    QPushButton *delete_unused;
    QLabel *label_12;
    QLabel *unused_count;
    KMessageWidget *file_message;

    void setupUi(QDialog *ProjectSettings_UI)
    {
        if (ProjectSettings_UI->objectName().isEmpty())
            ProjectSettings_UI->setObjectName("ProjectSettings_UI");
        ProjectSettings_UI->resize(614, 704);
        gridLayout_3 = new QGridLayout(ProjectSettings_UI);
        gridLayout_3->setObjectName("gridLayout_3");
        buttonBox = new QDialogButtonBox(ProjectSettings_UI);
        buttonBox->setObjectName("buttonBox");
        buttonBox->setOrientation(Qt::Orientation::Horizontal);
        buttonBox->setStandardButtons(QDialogButtonBox::StandardButton::Cancel|QDialogButtonBox::StandardButton::Ok);

        gridLayout_3->addWidget(buttonBox, 2, 0, 1, 1);

        tabWidget = new QTabWidget(ProjectSettings_UI);
        tabWidget->setObjectName("tabWidget");
        tabWidget->setDocumentMode(true);
        tab = new QWidget();
        tab->setObjectName("tab");
        formLayout = new QFormLayout(tab);
        formLayout->setObjectName("formLayout");
        label_4 = new QLabel(tab);
        label_4->setObjectName("label_4");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_4);

        default_folder = new QRadioButton(tab);
        default_folder->setObjectName("default_folder");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, default_folder);

        same_folder = new QRadioButton(tab);
        same_folder->setObjectName("same_folder");

        formLayout->setWidget(3, QFormLayout::ItemRole::FieldRole, same_folder);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        custom_folder = new QRadioButton(tab);
        custom_folder->setObjectName("custom_folder");
        custom_folder->setAutoExclusive(true);

        horizontalLayout->addWidget(custom_folder);

        project_folder = new KUrlRequester(tab);
        project_folder->setObjectName("project_folder");
        project_folder->setEnabled(false);

        horizontalLayout->addWidget(project_folder);


        formLayout->setLayout(4, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        kseparator_3 = new KSeparator(tab);
        kseparator_3->setObjectName("kseparator_3");

        formLayout->setWidget(5, QFormLayout::ItemRole::SpanningRole, kseparator_3);

        profile_box = new QGroupBox(tab);
        profile_box->setObjectName("profile_box");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::MinimumExpanding);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(profile_box->sizePolicy().hasHeightForWidth());
        profile_box->setSizePolicy(sizePolicy);
        profile_box->setFlat(true);

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, profile_box);

        kseparator = new KSeparator(tab);
        kseparator->setObjectName("kseparator");

        formLayout->setWidget(9, QFormLayout::ItemRole::SpanningRole, kseparator);

        label_video_tracks = new QLabel(tab);
        label_video_tracks->setObjectName("label_video_tracks");

        formLayout->setWidget(10, QFormLayout::ItemRole::LabelRole, label_video_tracks);

        video_tracks = new QSpinBox(tab);
        video_tracks->setObjectName("video_tracks");

        formLayout->setWidget(10, QFormLayout::ItemRole::FieldRole, video_tracks);

        label_audio_tracks = new QLabel(tab);
        label_audio_tracks->setObjectName("label_audio_tracks");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_audio_tracks);

        audio_tracks = new QSpinBox(tab);
        audio_tracks->setObjectName("audio_tracks");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, audio_tracks);

        label_audio_channels = new QLabel(tab);
        label_audio_channels->setObjectName("label_audio_channels");

        formLayout->setWidget(15, QFormLayout::ItemRole::LabelRole, label_audio_channels);

        audio_channels = new QComboBox(tab);
        audio_channels->addItem(QString());
        audio_channels->addItem(QString());
        audio_channels->addItem(QString());
        audio_channels->setObjectName("audio_channels");
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(audio_channels->sizePolicy().hasHeightForWidth());
        audio_channels->setSizePolicy(sizePolicy1);

        formLayout->setWidget(15, QFormLayout::ItemRole::FieldRole, audio_channels);

        label_thumbnails = new QLabel(tab);
        label_thumbnails->setObjectName("label_thumbnails");

        formLayout->setWidget(16, QFormLayout::ItemRole::LabelRole, label_thumbnails);

        video_thumbs = new QCheckBox(tab);
        video_thumbs->setObjectName("video_thumbs");

        formLayout->setWidget(16, QFormLayout::ItemRole::FieldRole, video_thumbs);

        audio_thumbs = new QCheckBox(tab);
        audio_thumbs->setObjectName("audio_thumbs");

        formLayout->setWidget(17, QFormLayout::ItemRole::FieldRole, audio_thumbs);

        label_25 = new QLabel(tab);
        label_25->setObjectName("label_25");
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(label_25->sizePolicy().hasHeightForWidth());
        label_25->setSizePolicy(sizePolicy2);

        formLayout->setWidget(21, QFormLayout::ItemRole::LabelRole, label_25);

        preview_profile_box = new QHBoxLayout();
        preview_profile_box->setObjectName("preview_profile_box");

        formLayout->setLayout(21, QFormLayout::ItemRole::FieldRole, preview_profile_box);

        tabWidget->addTab(tab, QString());
        tab_4 = new QWidget();
        tab_4->setObjectName("tab_4");
        verticalLayout = new QVBoxLayout(tab_4);
        verticalLayout->setObjectName("verticalLayout");
        proxy_box = new QGroupBox(tab_4);
        proxy_box->setObjectName("proxy_box");
        proxy_box->setFlat(true);
        proxy_box->setCheckable(true);
        gridLayout = new QGridLayout(proxy_box);
        gridLayout->setObjectName("gridLayout");
        generate_proxy = new QCheckBox(proxy_box);
        generate_proxy->setObjectName("generate_proxy");

        gridLayout->addWidget(generate_proxy, 1, 1, 1, 1);

        proxy_imagesize = new QSpinBox(proxy_box);
        proxy_imagesize->setObjectName("proxy_imagesize");
        proxy_imagesize->setEnabled(true);
        proxy_imagesize->setMinimum(200);
        proxy_imagesize->setMaximum(100000);
        proxy_imagesize->setValue(800);

        gridLayout->addWidget(proxy_imagesize, 7, 2, 1, 1);

        generate_imageproxy = new QCheckBox(proxy_box);
        generate_imageproxy->setObjectName("generate_imageproxy");

        gridLayout->addWidget(generate_imageproxy, 6, 0, 1, 2);

        proxy_imageminsize = new QSpinBox(proxy_box);
        proxy_imageminsize->setObjectName("proxy_imageminsize");
        proxy_imageminsize->setMinimum(500);
        proxy_imageminsize->setMaximum(100000);
        proxy_imageminsize->setValue(2000);

        gridLayout->addWidget(proxy_imageminsize, 6, 2, 1, 1);

        label_24 = new QLabel(proxy_box);
        label_24->setObjectName("label_24");
        sizePolicy2.setHeightForWidth(label_24->sizePolicy().hasHeightForWidth());
        label_24->setSizePolicy(sizePolicy2);

        gridLayout->addWidget(label_24, 3, 1, 1, 1);

        proxyparams = new QPlainTextEdit(proxy_box);
        proxyparams->setObjectName("proxyparams");
        QSizePolicy sizePolicy3(QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Maximum);
        sizePolicy3.setHorizontalStretch(0);
        sizePolicy3.setVerticalStretch(0);
        sizePolicy3.setHeightForWidth(proxyparams->sizePolicy().hasHeightForWidth());
        proxyparams->setSizePolicy(sizePolicy3);
        proxyparams->setReadOnly(true);

        gridLayout->addWidget(proxyparams, 4, 2, 1, 1);

        formLayout_3 = new QFormLayout();
        formLayout_3->setObjectName("formLayout_3");
        formLayout_3->setRowWrapPolicy(QFormLayout::RowWrapPolicy::DontWrapRows);
        le_suffix_proxy = new QLineEdit(proxy_box);
        le_suffix_proxy->setObjectName("le_suffix_proxy");
        le_suffix_proxy->setFrame(false);
        le_suffix_proxy->setReadOnly(true);

        formLayout_3->setWidget(5, QFormLayout::ItemRole::FieldRole, le_suffix_proxy);

        l_suffix_proxy = new QLabel(proxy_box);
        l_suffix_proxy->setObjectName("l_suffix_proxy");

        formLayout_3->setWidget(5, QFormLayout::ItemRole::LabelRole, l_suffix_proxy);

        le_prefix_proxy = new QLineEdit(proxy_box);
        le_prefix_proxy->setObjectName("le_prefix_proxy");
        le_prefix_proxy->setFrame(false);
        le_prefix_proxy->setReadOnly(true);

        formLayout_3->setWidget(4, QFormLayout::ItemRole::FieldRole, le_prefix_proxy);

        l_prefix_proxy = new QLabel(proxy_box);
        l_prefix_proxy->setObjectName("l_prefix_proxy");

        formLayout_3->setWidget(4, QFormLayout::ItemRole::LabelRole, l_prefix_proxy);

        le_relPathProxyToOrig = new QLineEdit(proxy_box);
        le_relPathProxyToOrig->setObjectName("le_relPathProxyToOrig");
        le_relPathProxyToOrig->setFrame(false);
        le_relPathProxyToOrig->setReadOnly(true);

        formLayout_3->setWidget(3, QFormLayout::ItemRole::FieldRole, le_relPathProxyToOrig);

        l_relPathProxyToOrig = new QLabel(proxy_box);
        l_relPathProxyToOrig->setObjectName("l_relPathProxyToOrig");

        formLayout_3->setWidget(3, QFormLayout::ItemRole::LabelRole, l_relPathProxyToOrig);

        le_suffix_clip = new QLineEdit(proxy_box);
        le_suffix_clip->setObjectName("le_suffix_clip");
        le_suffix_clip->setFrame(false);
        le_suffix_clip->setReadOnly(true);

        formLayout_3->setWidget(2, QFormLayout::ItemRole::FieldRole, le_suffix_clip);

        l_suffix_clip = new QLabel(proxy_box);
        l_suffix_clip->setObjectName("l_suffix_clip");

        formLayout_3->setWidget(2, QFormLayout::ItemRole::LabelRole, l_suffix_clip);

        le_prefix_clip = new QLineEdit(proxy_box);
        le_prefix_clip->setObjectName("le_prefix_clip");
        le_prefix_clip->setFrame(false);
        le_prefix_clip->setReadOnly(true);

        formLayout_3->setWidget(1, QFormLayout::ItemRole::FieldRole, le_prefix_clip);

        l_prefix_clip = new QLabel(proxy_box);
        l_prefix_clip->setObjectName("l_prefix_clip");

        formLayout_3->setWidget(1, QFormLayout::ItemRole::LabelRole, l_prefix_clip);

        l_relPathOrigToProxy = new QLabel(proxy_box);
        l_relPathOrigToProxy->setObjectName("l_relPathOrigToProxy");

        formLayout_3->setWidget(0, QFormLayout::ItemRole::LabelRole, l_relPathOrigToProxy);

        le_relPathOrigToProxy = new QLineEdit(proxy_box);
        le_relPathOrigToProxy->setObjectName("le_relPathOrigToProxy");
        le_relPathOrigToProxy->setFocusPolicy(Qt::FocusPolicy::NoFocus);
        le_relPathOrigToProxy->setFrame(false);
        le_relPathOrigToProxy->setReadOnly(true);

        formLayout_3->setWidget(0, QFormLayout::ItemRole::FieldRole, le_relPathOrigToProxy);


        gridLayout->addLayout(formLayout_3, 11, 2, 1, 1);

        label_3 = new QLabel(proxy_box);
        label_3->setObjectName("label_3");

        gridLayout->addWidget(label_3, 2, 1, 1, 1);

        proxy_minsize = new QSpinBox(proxy_box);
        proxy_minsize->setObjectName("proxy_minsize");
        proxy_minsize->setMaximum(10000);
        proxy_minsize->setValue(1000);

        gridLayout->addWidget(proxy_minsize, 1, 2, 1, 1);

        kseparator_2 = new KSeparator(proxy_box);
        kseparator_2->setObjectName("kseparator_2");

        gridLayout->addWidget(kseparator_2, 5, 0, 1, 3);

        proxy_resize = new QSpinBox(proxy_box);
        proxy_resize->setObjectName("proxy_resize");
        proxy_resize->setMinimum(200);
        proxy_resize->setMaximum(100000);

        gridLayout->addWidget(proxy_resize, 2, 2, 1, 1);

        image_label = new QLabel(proxy_box);
        image_label->setObjectName("image_label");
        image_label->setEnabled(true);

        gridLayout->addWidget(image_label, 7, 1, 1, 1);

        kseparator_4 = new KSeparator(proxy_box);
        kseparator_4->setObjectName("kseparator_4");

        gridLayout->addWidget(kseparator_4, 8, 0, 1, 3);

        horizontalLayout_2 = new QHBoxLayout();
        horizontalLayout_2->setObjectName("horizontalLayout_2");
        proxy_profile = new KComboBox(proxy_box);
        proxy_profile->setObjectName("proxy_profile");
        sizePolicy1.setHeightForWidth(proxy_profile->sizePolicy().hasHeightForWidth());
        proxy_profile->setSizePolicy(sizePolicy1);

        horizontalLayout_2->addWidget(proxy_profile);

        checkProxy = new QToolButton(proxy_box);
        checkProxy->setObjectName("checkProxy");

        horizontalLayout_2->addWidget(checkProxy);

        proxy_showprofileinfo = new QToolButton(proxy_box);
        proxy_showprofileinfo->setObjectName("proxy_showprofileinfo");
        proxy_showprofileinfo->setCheckable(true);

        horizontalLayout_2->addWidget(proxy_showprofileinfo);

        proxy_manageprofile = new QToolButton(proxy_box);
        proxy_manageprofile->setObjectName("proxy_manageprofile");

        horizontalLayout_2->addWidget(proxy_manageprofile);


        gridLayout->addLayout(horizontalLayout_2, 3, 2, 1, 1);

        kseparator_5 = new KSeparator(proxy_box);
        kseparator_5->setObjectName("kseparator_5");

        gridLayout->addWidget(kseparator_5, 0, 1, 1, 2);

        horizontalLayout_4 = new QHBoxLayout();
        horizontalLayout_4->setObjectName("horizontalLayout_4");
        external_proxy_profile = new QComboBox(proxy_box);
        external_proxy_profile->setObjectName("external_proxy_profile");

        horizontalLayout_4->addWidget(external_proxy_profile);

        manage_external = new QToolButton(proxy_box);
        manage_external->setObjectName("manage_external");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("configure")));
        manage_external->setIcon(icon);

        horizontalLayout_4->addWidget(manage_external);


        gridLayout->addLayout(horizontalLayout_4, 9, 2, 1, 1);

        external_proxy = new QCheckBox(proxy_box);
        external_proxy->setObjectName("external_proxy");

        gridLayout->addWidget(external_proxy, 9, 0, 1, 2);


        verticalLayout->addWidget(proxy_box);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        tabWidget->addTab(tab_4, QString());
        tab_5 = new QWidget();
        tab_5->setObjectName("tab_5");
        tabWidget->addTab(tab_5, QString());
        tab_3 = new QWidget();
        tab_3->setObjectName("tab_3");
        gridLayout_6 = new QGridLayout(tab_3);
        gridLayout_6->setObjectName("gridLayout_6");
        metadata_list = new QTreeWidget(tab_3);
        metadata_list->setObjectName("metadata_list");
        metadata_list->setAlternatingRowColors(true);
        metadata_list->setRootIsDecorated(false);
        metadata_list->setAllColumnsShowFocus(true);
        metadata_list->setColumnCount(2);
        metadata_list->header()->setVisible(false);

        gridLayout_6->addWidget(metadata_list, 0, 0, 1, 1);

        horizontalLayout_3 = new QHBoxLayout();
        horizontalLayout_3->setObjectName("horizontalLayout_3");
        add_metadata = new QToolButton(tab_3);
        add_metadata->setObjectName("add_metadata");

        horizontalLayout_3->addWidget(add_metadata);

        delete_metadata = new QToolButton(tab_3);
        delete_metadata->setObjectName("delete_metadata");

        horizontalLayout_3->addWidget(delete_metadata);

        horizontalSpacer_3 = new QSpacerItem(40, 20, QSizePolicy::Policy::Expanding, QSizePolicy::Policy::Minimum);

        horizontalLayout_3->addItem(horizontalSpacer_3);


        gridLayout_6->addLayout(horizontalLayout_3, 1, 0, 1, 1);

        tabWidget->addTab(tab_3, QString());
        tab_2 = new QWidget();
        tab_2->setObjectName("tab_2");
        gridLayout_4 = new QGridLayout(tab_2);
        gridLayout_4->setObjectName("gridLayout_4");
        label_fonts = new QLabel(tab_2);
        label_fonts->setObjectName("label_fonts");

        gridLayout_4->addWidget(label_fonts, 4, 0, 1, 1);

        fonts_list = new QListWidget(tab_2);
        fonts_list->setObjectName("fonts_list");
        fonts_list->setAlternatingRowColors(true);

        gridLayout_4->addWidget(fonts_list, 5, 0, 1, 5);

        files_list = new QTreeWidget(tab_2);
        QTreeWidgetItem *__qtreewidgetitem = new QTreeWidgetItem();
        __qtreewidgetitem->setText(0, QString::fromUtf8("1"));
        files_list->setHeaderItem(__qtreewidgetitem);
        files_list->setObjectName("files_list");
        files_list->setAlternatingRowColors(true);
        files_list->setRootIsDecorated(false);
        files_list->setItemsExpandable(false);
        files_list->setHeaderHidden(true);
        files_list->setExpandsOnDoubleClick(false);

        gridLayout_4->addWidget(files_list, 3, 0, 1, 5);

        list_search = new KTreeWidgetSearchLine(tab_2);
        list_search->setObjectName("list_search");

        gridLayout_4->addWidget(list_search, 2, 3, 1, 2);

        unused_size = new QLabel(tab_2);
        unused_size->setObjectName("unused_size");

        gridLayout_4->addWidget(unused_size, 1, 3, 1, 1);

        used_size = new QLabel(tab_2);
        used_size->setObjectName("used_size");

        gridLayout_4->addWidget(used_size, 0, 3, 1, 1);

        label_13 = new QLabel(tab_2);
        label_13->setObjectName("label_13");

        gridLayout_4->addWidget(label_13, 2, 0, 1, 1);

        button_export = new QPushButton(tab_2);
        button_export->setObjectName("button_export");

        gridLayout_4->addWidget(button_export, 6, 0, 1, 2);

        files_count = new QLabel(tab_2);
        files_count->setObjectName("files_count");

        gridLayout_4->addWidget(files_count, 2, 2, 1, 1);

        used_count = new QLabel(tab_2);
        used_count->setObjectName("used_count");

        gridLayout_4->addWidget(used_count, 0, 2, 1, 1);

        label_6 = new QLabel(tab_2);
        label_6->setObjectName("label_6");

        gridLayout_4->addWidget(label_6, 1, 0, 1, 1);

        delete_unused = new QPushButton(tab_2);
        delete_unused->setObjectName("delete_unused");

        gridLayout_4->addWidget(delete_unused, 1, 4, 1, 1);

        label_12 = new QLabel(tab_2);
        label_12->setObjectName("label_12");

        gridLayout_4->addWidget(label_12, 0, 0, 1, 2);

        unused_count = new QLabel(tab_2);
        unused_count->setObjectName("unused_count");

        gridLayout_4->addWidget(unused_count, 1, 2, 1, 1);

        file_message = new KMessageWidget(tab_2);
        file_message->setObjectName("file_message");

        gridLayout_4->addWidget(file_message, 7, 0, 1, 5);

        tabWidget->addTab(tab_2, QString());

        gridLayout_3->addWidget(tabWidget, 1, 0, 1, 1);

        QWidget::setTabOrder(project_folder, generate_proxy);
        QWidget::setTabOrder(generate_proxy, metadata_list);
        QWidget::setTabOrder(metadata_list, add_metadata);
        QWidget::setTabOrder(add_metadata, delete_metadata);
        QWidget::setTabOrder(delete_metadata, delete_unused);
        QWidget::setTabOrder(delete_unused, list_search);
        QWidget::setTabOrder(list_search, files_list);
        QWidget::setTabOrder(files_list, fonts_list);
        QWidget::setTabOrder(fonts_list, button_export);

        retranslateUi(ProjectSettings_UI);
        QObject::connect(buttonBox, &QDialogButtonBox::accepted, ProjectSettings_UI, qOverload<>(&QDialog::accept));
        QObject::connect(buttonBox, &QDialogButtonBox::rejected, ProjectSettings_UI, qOverload<>(&QDialog::reject));
        QObject::connect(custom_folder, SIGNAL(toggled(bool)), project_folder, SLOT(setEnabled(bool)));

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(ProjectSettings_UI);
    } // setupUi

    void retranslateUi(QDialog *ProjectSettings_UI)
    {
        ProjectSettings_UI->setWindowTitle(tr2i18n("Project Settings", nullptr));
#if QT_CONFIG(tooltip)
        label_4->setToolTip(tr2i18n(" Used to store proxy clips, thumbnails, previews", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(whatsthis)
        label_4->setWhatsThis(tr2i18n(" The project folder is the place where assets like proxy clips, thumbnails or previews get stored.", nullptr));
#endif // QT_CONFIG(whatsthis)
        label_4->setText(tr2i18n("Project folder:", nullptr));
        default_folder->setText(tr2i18n("Default folder", nullptr));
        same_folder->setText(tr2i18n("Parent folder of the project file", nullptr));
        custom_folder->setText(tr2i18n("Custom:", nullptr));
        label_video_tracks->setText(tr2i18n("Video tracks:", nullptr));
        label_audio_tracks->setText(tr2i18n("Audio tracks:", nullptr));
        label_audio_channels->setText(tr2i18n("Audio channels:", nullptr));
        audio_channels->setItemText(0, tr2i18n("2 Channels (Stereo)", nullptr));
        audio_channels->setItemText(1, tr2i18n("4 Channels", nullptr));
        audio_channels->setItemText(2, tr2i18n("6 Channels", nullptr));

        label_thumbnails->setText(tr2i18n("Thumbnails:", nullptr));
        video_thumbs->setText(tr2i18n("Video", nullptr));
        audio_thumbs->setText(tr2i18n("Audio", nullptr));
        label_25->setText(tr2i18n("Timeline Preview:", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab), tr2i18n("Settings", nullptr));
        proxy_box->setTitle(tr2i18n("Proxy clips", nullptr));
        generate_proxy->setText(tr2i18n("Generate for videos larger than", nullptr));
        proxy_imagesize->setSuffix(tr2i18n("pixels", nullptr));
        generate_imageproxy->setText(tr2i18n("Generate for images larger than", nullptr));
        proxy_imageminsize->setSuffix(tr2i18n("pixels", nullptr));
        label_24->setText(tr2i18n("Encoding profile:", nullptr));
        l_suffix_proxy->setText(tr2i18n("Suffix of proxy:", nullptr));
        l_prefix_proxy->setText(tr2i18n("Prefix of proxy:", nullptr));
        l_relPathProxyToOrig->setText(tr2i18n("Relative path from proxy to clip:", nullptr));
        l_suffix_clip->setText(tr2i18n("Suffix of clip:", nullptr));
        l_prefix_clip->setText(tr2i18n("Prefix of clip:", nullptr));
        l_relPathOrigToProxy->setText(tr2i18n("Relative path from clip to proxy:", nullptr));
        label_3->setText(tr2i18n("Proxy video resize (width)", nullptr));
        proxy_minsize->setSuffix(tr2i18n("pixels", nullptr));
        proxy_resize->setSuffix(tr2i18n("pixels", nullptr));
        image_label->setText(tr2i18n("Proxy image size", nullptr));
        checkProxy->setText(tr2i18n("...", nullptr));
        proxy_showprofileinfo->setText(tr2i18n("...", nullptr));
        proxy_manageprofile->setText(tr2i18n("...", nullptr));
        manage_external->setText(tr2i18n("...", nullptr));
        external_proxy->setText(tr2i18n("Camcorder proxy clips", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_4), tr2i18n("Proxy", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_5), tr2i18n("Markers", nullptr));
        QTreeWidgetItem *___qtreewidgetitem = metadata_list->headerItem();
        ___qtreewidgetitem->setText(1, tr2i18n("2", nullptr));
        ___qtreewidgetitem->setText(0, tr2i18n("1", nullptr));
        add_metadata->setText(tr2i18n("...", nullptr));
        delete_metadata->setText(tr2i18n("...", nullptr));
        tabWidget->setTabText(tabWidget->indexOf(tab_3), tr2i18n("Metadata", nullptr));
        label_fonts->setText(tr2i18n("Fonts", nullptr));
        unused_size->setText(QString());
        used_size->setText(QString());
        label_13->setText(tr2i18n("Project files:", nullptr));
        button_export->setText(tr2i18n("Plain Text Export...", nullptr));
        files_count->setText(QString());
        used_count->setText(QString());
        label_6->setText(tr2i18n("Unused clips:", nullptr));
        delete_unused->setText(tr2i18n("Delete files", nullptr));
        label_12->setText(tr2i18n("Clips used in project:", nullptr));
        unused_count->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(tab_2), tr2i18n("Project Files", nullptr));
    } // retranslateUi

};

namespace Ui {
    class ProjectSettings_UI: public Ui_ProjectSettings_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // PROJECTSETTINGS_UI_H

