/****************************************************************************
** Meta object code from reading C++ file 'core.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/core.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtGui/qtextcursor.h>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'core.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4CoreE_t {};
} // unnamed namespace

template <> constexpr inline auto Core::qt_create_metaobjectdata<qt_meta_tag_ZN4CoreE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Core",
        "coreIsReady",
        "",
        "updateLibraryPath",
        "showConfigDialog",
        "Kdenlive::ConfigPage",
        "finalizeRecording",
        "QUuid",
        "uuid",
        "captureFile",
        "autoScrollChanged",
        "centeredPlayheadChanged",
        "loadingMessageNewStage",
        "message",
        "max",
        "loadingMessageIncrease",
        "loadingMessageHide",
        "processDragEnd",
        "closeSplash",
        "speechModelUpdate",
        "SpeechToTextEngine::EngineType",
        "engine",
        "models",
        "updateEffectZone",
        "QPoint",
        "p",
        "withUndo",
        "disconnectEffectStack",
        "remapClip",
        "cid",
        "monitorProfileUpdated",
        "updatePalette",
        "clipInstanceResized",
        "binId",
        "audioLevelsAvailable",
        "QList<double>",
        "levels",
        "audioLevelsConfigChanged",
        "updateMixerLevels",
        "pos",
        "switchTimelineRecord",
        "on",
        "recordAudio",
        "tid",
        "record",
        "updateProjectTimecode",
        "refreshActiveGuides",
        "updateDefaultMarkerCategory",
        "speechEngineChanged",
        "autoTrackHeight",
        "gotMissingClipsCount",
        "total",
        "used",
        "stopProgressTask",
        "binClipDeleted",
        "mltWarning",
        "requestShowBinEffectStack",
        "clipName",
        "std::shared_ptr<EffectStackModel>",
        "QSize",
        "frameSize",
        "showKeyframes",
        "saveGuideCategories",
        "saveTimelinePreview",
        "path",
        "enableBuildInTransform",
        "samConfigUpdated",
        "switchMaskPanel",
        "show",
        "transcodeProgress",
        "ObjectId",
        "id",
        "progress",
        "startAutoSave",
        "displayBinMessage",
        "text",
        "type",
        "QList<QAction*>",
        "actions",
        "showClose",
        "BinMessage::BinCategory",
        "messageCategory",
        "displayBinLogMessage",
        "logInfo",
        "updateRenderOffset",
        "hideBars",
        "switchTitleBars",
        "loadLayoutById",
        "layoutId",
        "onlyIfNoPrevious",
        "switchDarkPalette",
        "dark",
        "mainWindowReady",
        "loadLayoutFromData",
        "layout",
        "adjustLayoutToDar",
        "GUISetupDone",
        "triggerAction",
        "name",
        "actionText",
        "addActionToCollection",
        "QAction*",
        "action",
        "displayMessage",
        "MessageType",
        "timeout",
        "buildLumaThumbs",
        "values",
        "nameForLumaFile",
        "filename",
        "setDocumentModified",
        "showEffectZone",
        "std::pair<int,int>",
        "inOut",
        "checked",
        "updateMasterZones",
        "testProxies",
        "updateMonitorProfile",
        "addBin",
        "transcodeFriendlyFile",
        "checkProfile",
        "resetAudioMonitoring",
        "setAudioMonitoring",
        "startRecording",
        "allowCountDown",
        "monitorAudio",
        "monitor",
        "openDocumentationLink",
        "QUrl",
        "link",
        "openLink",
        "displayBinMessagePrivate",
        "displayBinLogMessagePrivate",
        "cleanRestart",
        "cleanAndRestart",
        "startFromGuessedProfile",
        "descriptiveString",
        "fps",
        "interlaced",
        "vTracks",
        "aTracks"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'coreIsReady'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateLibraryPath'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showConfigDialog'
        QtMocHelpers::SignalData<void(Kdenlive::ConfigPage, int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'finalizeRecording'
        QtMocHelpers::SignalData<void(const QUuid, const QString &)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { QMetaType::QString, 9 },
        }}),
        // Signal 'autoScrollChanged'
        QtMocHelpers::SignalData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'centeredPlayheadChanged'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingMessageNewStage'
        QtMocHelpers::SignalData<void(const QString &, int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { QMetaType::Int, 14 },
        }}),
        // Signal 'loadingMessageNewStage'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'loadingMessageIncrease'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadingMessageHide'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processDragEnd'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'closeSplash'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speechModelUpdate'
        QtMocHelpers::SignalData<void(SpeechToTextEngine::EngineType, const QStringList)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 }, { QMetaType::QStringList, 22 },
        }}),
        // Signal 'updateEffectZone'
        QtMocHelpers::SignalData<void(const QPoint, bool)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Signal 'disconnectEffectStack'
        QtMocHelpers::SignalData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'remapClip'
        QtMocHelpers::SignalData<void(int)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'monitorProfileUpdated'
        QtMocHelpers::SignalData<void()>(30, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updatePalette'
        QtMocHelpers::SignalData<void()>(31, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipInstanceResized'
        QtMocHelpers::SignalData<void(const QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 },
        }}),
        // Signal 'audioLevelsAvailable'
        QtMocHelpers::SignalData<void(const QVector<double> &)>(34, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 35, 36 },
        }}),
        // Signal 'audioLevelsConfigChanged'
        QtMocHelpers::SignalData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateMixerLevels'
        QtMocHelpers::SignalData<void(int)>(38, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 39 },
        }}),
        // Signal 'switchTimelineRecord'
        QtMocHelpers::SignalData<void(bool)>(40, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 41 },
        }}),
        // Signal 'recordAudio'
        QtMocHelpers::SignalData<void(int, bool)>(42, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 }, { QMetaType::Bool, 44 },
        }}),
        // Signal 'updateProjectTimecode'
        QtMocHelpers::SignalData<void()>(45, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'refreshActiveGuides'
        QtMocHelpers::SignalData<void()>(46, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateDefaultMarkerCategory'
        QtMocHelpers::SignalData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speechEngineChanged'
        QtMocHelpers::SignalData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoTrackHeight'
        QtMocHelpers::SignalData<void(bool)>(49, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'gotMissingClipsCount'
        QtMocHelpers::SignalData<void(int, int)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 51 }, { QMetaType::Int, 52 },
        }}),
        // Signal 'stopProgressTask'
        QtMocHelpers::SignalData<void()>(53, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binClipDeleted'
        QtMocHelpers::SignalData<void(int)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 29 },
        }}),
        // Signal 'mltWarning'
        QtMocHelpers::SignalData<void(const QString &)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 },
        }}),
        // Signal 'requestShowBinEffectStack'
        QtMocHelpers::SignalData<void(const QString &, std::shared_ptr<EffectStackModel>, QSize, bool)>(56, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 57 }, { 0x80000000 | 58, 2 }, { 0x80000000 | 59, 60 }, { QMetaType::Bool, 61 },
        }}),
        // Signal 'saveGuideCategories'
        QtMocHelpers::SignalData<void()>(62, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'saveTimelinePreview'
        QtMocHelpers::SignalData<void(const QString &)>(63, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 64 },
        }}),
        // Signal 'enableBuildInTransform'
        QtMocHelpers::SignalData<void()>(65, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'samConfigUpdated'
        QtMocHelpers::SignalData<void()>(66, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'switchMaskPanel'
        QtMocHelpers::SignalData<void(bool)>(67, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 68 },
        }}),
        // Signal 'transcodeProgress'
        QtMocHelpers::SignalData<void(ObjectId, int)>(69, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 }, { QMetaType::Int, 72 },
        }}),
        // Signal 'startAutoSave'
        QtMocHelpers::SignalData<void()>(73, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayBinMessage'
        QtMocHelpers::SignalData<void(const QString &, int, const QList<QAction*> &, bool, BinMessage::BinCategory)>(74, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 }, { QMetaType::Bool, 79 },
            { 0x80000000 | 80, 81 },
        }}),
        // Signal 'displayBinMessage'
        QtMocHelpers::SignalData<void(const QString &, int, const QList<QAction*> &, bool)>(74, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 }, { QMetaType::Bool, 79 },
        }}),
        // Signal 'displayBinMessage'
        QtMocHelpers::SignalData<void(const QString &, int, const QList<QAction*> &)>(74, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 },
        }}),
        // Signal 'displayBinMessage'
        QtMocHelpers::SignalData<void(const QString &, int)>(74, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 },
        }}),
        // Signal 'displayBinLogMessage'
        QtMocHelpers::SignalData<void(const QString &, int, const QString)>(82, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { QMetaType::QString, 83 },
        }}),
        // Signal 'updateRenderOffset'
        QtMocHelpers::SignalData<void()>(84, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hideBars'
        QtMocHelpers::SignalData<void(bool)>(85, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Signal 'switchTitleBars'
        QtMocHelpers::SignalData<void()>(86, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadLayoutById'
        QtMocHelpers::SignalData<void(QString, bool)>(87, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 88 }, { QMetaType::Bool, 89 },
        }}),
        // Signal 'loadLayoutById'
        QtMocHelpers::SignalData<void(QString)>(87, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 88 },
        }}),
        // Signal 'switchDarkPalette'
        QtMocHelpers::SignalData<void(bool)>(90, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 91 },
        }}),
        // Signal 'mainWindowReady'
        QtMocHelpers::SignalData<void()>(92, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'loadLayoutFromData'
        QtMocHelpers::SignalData<void(const QString, bool)>(93, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 94 }, { QMetaType::Bool, 89 },
        }}),
        // Signal 'loadLayoutFromData'
        QtMocHelpers::SignalData<void(const QString)>(93, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 94 },
        }}),
        // Signal 'adjustLayoutToDar'
        QtMocHelpers::SignalData<void()>(95, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'GUISetupDone'
        QtMocHelpers::SignalData<void()>(96, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'triggerAction'
        QtMocHelpers::SlotData<void(const QString &)>(97, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 98 },
        }}),
        // Slot 'actionText'
        QtMocHelpers::SlotData<const QString(const QString &)>(99, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 98 },
        }}),
        // Slot 'addActionToCollection'
        QtMocHelpers::SlotData<void(const QString &, QAction *)>(100, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 98 }, { 0x80000000 | 101, 102 },
        }}),
        // Slot 'displayMessage'
        QtMocHelpers::SlotData<void(const QString &, MessageType, int)>(103, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 104, 76 }, { QMetaType::Int, 105 },
        }}),
        // Slot 'displayMessage'
        QtMocHelpers::SlotData<void(const QString &, MessageType)>(103, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 13 }, { 0x80000000 | 104, 76 },
        }}),
        // Slot 'buildLumaThumbs'
        QtMocHelpers::SlotData<void(const QStringList &)>(106, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 107 },
        }}),
        // Slot 'nameForLumaFile'
        QtMocHelpers::SlotData<const QString(const QString &)>(108, 2, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 109 },
        }}),
        // Slot 'setDocumentModified'
        QtMocHelpers::SlotData<void()>(110, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showEffectZone'
        QtMocHelpers::SlotData<void(ObjectId, QPair<int,int>, bool)>(111, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 70, 71 }, { 0x80000000 | 112, 113 }, { QMetaType::Bool, 114 },
        }}),
        // Slot 'updateMasterZones'
        QtMocHelpers::SlotData<void()>(115, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'testProxies'
        QtMocHelpers::SlotData<void()>(116, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateMonitorProfile'
        QtMocHelpers::SlotData<void()>(117, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'addBin'
        QtMocHelpers::SlotData<void(const QString &)>(118, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 71 },
        }}),
        // Slot 'addBin'
        QtMocHelpers::SlotData<void()>(118, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void),
        // Slot 'transcodeFriendlyFile'
        QtMocHelpers::SlotData<void(const QString &, bool)>(119, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 33 }, { QMetaType::Bool, 120 },
        }}),
        // Slot 'resetAudioMonitoring'
        QtMocHelpers::SlotData<void()>(121, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setAudioMonitoring'
        QtMocHelpers::SlotData<void(bool)>(122, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'startRecording'
        QtMocHelpers::SlotData<void(bool)>(123, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 124 },
        }}),
        // Slot 'monitorAudio'
        QtMocHelpers::SlotData<void(int, bool)>(125, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 43 }, { QMetaType::Bool, 126 },
        }}),
        // Slot 'openDocumentationLink'
        QtMocHelpers::SlotData<void(const QUrl &)>(127, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 128, 129 },
        }}),
        // Slot 'openLink'
        QtMocHelpers::SlotData<void(const QUrl &)>(130, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 128, 129 },
        }}),
        // Slot 'displayBinMessagePrivate'
        QtMocHelpers::SlotData<void(const QString &, int, const QList<QAction*> &, bool, BinMessage::BinCategory)>(131, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 }, { QMetaType::Bool, 79 },
            { 0x80000000 | 80, 81 },
        }}),
        // Slot 'displayBinMessagePrivate'
        QtMocHelpers::SlotData<void(const QString &, int, const QList<QAction*> &, bool)>(131, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 }, { QMetaType::Bool, 79 },
        }}),
        // Slot 'displayBinMessagePrivate'
        QtMocHelpers::SlotData<void(const QString &, int, const QList<QAction*> &)>(131, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { 0x80000000 | 77, 78 },
        }}),
        // Slot 'displayBinMessagePrivate'
        QtMocHelpers::SlotData<void(const QString &, int)>(131, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 },
        }}),
        // Slot 'displayBinLogMessagePrivate'
        QtMocHelpers::SlotData<void(const QString &, int, const QString)>(132, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 75 }, { QMetaType::Int, 76 }, { QMetaType::QString, 83 },
        }}),
        // Slot 'cleanRestart'
        QtMocHelpers::SlotData<void(bool)>(133, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 134 },
        }}),
        // Slot 'startFromGuessedProfile'
        QtMocHelpers::SlotData<void(QString, QString, bool, int, int)>(135, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 136 }, { QMetaType::QString, 137 }, { QMetaType::Bool, 138 }, { QMetaType::Int, 139 },
            { QMetaType::Int, 140 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<Core, qt_meta_tag_ZN4CoreE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Core::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4CoreE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4CoreE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4CoreE_t>.metaTypes,
    nullptr
} };

void Core::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<Core *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->coreIsReady(); break;
        case 1: _t->updateLibraryPath(); break;
        case 2: _t->showConfigDialog((*reinterpret_cast<std::add_pointer_t<Kdenlive::ConfigPage>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: _t->finalizeRecording((*reinterpret_cast<std::add_pointer_t<QUuid>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 4: _t->autoScrollChanged(); break;
        case 5: _t->centeredPlayheadChanged(); break;
        case 6: _t->loadingMessageNewStage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 7: _t->loadingMessageNewStage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->loadingMessageIncrease(); break;
        case 9: _t->loadingMessageHide(); break;
        case 10: _t->processDragEnd(); break;
        case 11: _t->closeSplash(); break;
        case 12: _t->speechModelUpdate((*reinterpret_cast<std::add_pointer_t<SpeechToTextEngine::EngineType>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 13: _t->updateEffectZone((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->disconnectEffectStack(); break;
        case 15: _t->remapClip((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->monitorProfileUpdated(); break;
        case 17: _t->updatePalette(); break;
        case 18: _t->clipInstanceResized((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 19: _t->audioLevelsAvailable((*reinterpret_cast<std::add_pointer_t<QList<double>>>(_a[1]))); break;
        case 20: _t->audioLevelsConfigChanged(); break;
        case 21: _t->updateMixerLevels((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 22: _t->switchTimelineRecord((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 23: _t->recordAudio((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 24: _t->updateProjectTimecode(); break;
        case 25: _t->refreshActiveGuides(); break;
        case 26: _t->updateDefaultMarkerCategory(); break;
        case 27: _t->speechEngineChanged(); break;
        case 28: _t->autoTrackHeight((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 29: _t->gotMissingClipsCount((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 30: _t->stopProgressTask(); break;
        case 31: _t->binClipDeleted((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 32: _t->mltWarning((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 33: _t->requestShowBinEffectStack((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectStackModel>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QSize>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 34: _t->saveGuideCategories(); break;
        case 35: _t->saveTimelinePreview((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 36: _t->enableBuildInTransform(); break;
        case 37: _t->samConfigUpdated(); break;
        case 38: _t->switchMaskPanel((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 39: _t->transcodeProgress((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 40: _t->startAutoSave(); break;
        case 41: _t->displayBinMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BinMessage::BinCategory>>(_a[5]))); break;
        case 42: _t->displayBinMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 43: _t->displayBinMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3]))); break;
        case 44: _t->displayBinMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 45: _t->displayBinLogMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 46: _t->updateRenderOffset(); break;
        case 47: _t->hideBars((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 48: _t->switchTitleBars(); break;
        case 49: _t->loadLayoutById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 50: _t->loadLayoutById((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 51: _t->switchDarkPalette((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 52: _t->mainWindowReady(); break;
        case 53: _t->loadLayoutFromData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 54: _t->loadLayoutFromData((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 55: _t->adjustLayoutToDar(); break;
        case 56: _t->GUISetupDone(); break;
        case 57: _t->triggerAction((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 58: { QString _r = _t->actionText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 59: _t->addActionToCollection((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QAction*>>(_a[2]))); break;
        case 60: _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 61: _t->displayMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<MessageType>>(_a[2]))); break;
        case 62: _t->buildLumaThumbs((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 63: { QString _r = _t->nameForLumaFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 64: _t->setDocumentModified(); break;
        case 65: _t->showEffectZone((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 66: _t->updateMasterZones(); break;
        case 67: _t->testProxies(); break;
        case 68: _t->updateMonitorProfile(); break;
        case 69: _t->addBin((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 70: _t->addBin(); break;
        case 71: _t->transcodeFriendlyFile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 72: _t->resetAudioMonitoring(); break;
        case 73: _t->setAudioMonitoring((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 74: _t->startRecording((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 75: _t->monitorAudio((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 76: _t->openDocumentationLink((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 77: _t->openLink((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 78: _t->displayBinMessagePrivate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<BinMessage::BinCategory>>(_a[5]))); break;
        case 79: _t->displayBinMessagePrivate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[4]))); break;
        case 80: _t->displayBinMessagePrivate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<QAction*>>>(_a[3]))); break;
        case 81: _t->displayBinMessagePrivate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 82: _t->displayBinLogMessagePrivate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 83: _t->cleanRestart((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 84: _t->startFromGuessedProfile((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[5]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 19:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<double> >(); break;
            }
            break;
        case 41:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 42:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 43:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 59:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QAction* >(); break;
            }
            break;
        case 78:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 79:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        case 80:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<QAction*> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::coreIsReady, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::updateLibraryPath, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(Kdenlive::ConfigPage , int )>(_a, &Core::showConfigDialog, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QUuid , const QString & )>(_a, &Core::finalizeRecording, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::autoScrollChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::centeredPlayheadChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & , int )>(_a, &Core::loadingMessageNewStage, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::loadingMessageIncrease, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::loadingMessageHide, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::processDragEnd, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::closeSplash, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(SpeechToTextEngine::EngineType , const QStringList )>(_a, &Core::speechModelUpdate, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QPoint , bool )>(_a, &Core::updateEffectZone, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::disconnectEffectStack, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(int )>(_a, &Core::remapClip, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::monitorProfileUpdated, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::updatePalette, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & )>(_a, &Core::clipInstanceResized, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QVector<double> & )>(_a, &Core::audioLevelsAvailable, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::audioLevelsConfigChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(int )>(_a, &Core::updateMixerLevels, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bool )>(_a, &Core::switchTimelineRecord, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(int , bool )>(_a, &Core::recordAudio, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::updateProjectTimecode, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::refreshActiveGuides, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::updateDefaultMarkerCategory, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::speechEngineChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bool )>(_a, &Core::autoTrackHeight, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(int , int )>(_a, &Core::gotMissingClipsCount, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::stopProgressTask, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(int )>(_a, &Core::binClipDeleted, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & )>(_a, &Core::mltWarning, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & , std::shared_ptr<EffectStackModel> , QSize , bool )>(_a, &Core::requestShowBinEffectStack, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::saveGuideCategories, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & )>(_a, &Core::saveTimelinePreview, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::enableBuildInTransform, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::samConfigUpdated, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bool )>(_a, &Core::switchMaskPanel, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(ObjectId , int )>(_a, &Core::transcodeProgress, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::startAutoSave, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & , int , const QList<QAction*> & , bool , BinMessage::BinCategory )>(_a, &Core::displayBinMessage, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString & , int , const QString )>(_a, &Core::displayBinLogMessage, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::updateRenderOffset, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bool )>(_a, &Core::hideBars, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::switchTitleBars, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(QString , bool )>(_a, &Core::loadLayoutById, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(bool )>(_a, &Core::switchDarkPalette, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::mainWindowReady, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)(const QString , bool )>(_a, &Core::loadLayoutFromData, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::adjustLayoutToDar, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (Core::*)()>(_a, &Core::GUISetupDone, 56))
            return;
    }
}

const QMetaObject *Core::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Core::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4CoreE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Core::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 85)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 85;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 85)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 85;
    }
    return _id;
}

// SIGNAL 0
void Core::coreIsReady()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void Core::updateLibraryPath()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void Core::showConfigDialog(Kdenlive::ConfigPage _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1, _t2);
}

// SIGNAL 3
void Core::finalizeRecording(const QUuid _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2);
}

// SIGNAL 4
void Core::autoScrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void Core::centeredPlayheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void Core::loadingMessageNewStage(const QString & _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 8
void Core::loadingMessageIncrease()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void Core::loadingMessageHide()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void Core::processDragEnd()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void Core::closeSplash()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void Core::speechModelUpdate(SpeechToTextEngine::EngineType _t1, const QStringList _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 12, nullptr, _t1, _t2);
}

// SIGNAL 13
void Core::updateEffectZone(const QPoint _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 13, nullptr, _t1, _t2);
}

// SIGNAL 14
void Core::disconnectEffectStack()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void Core::remapClip(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 15, nullptr, _t1);
}

// SIGNAL 16
void Core::monitorProfileUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void Core::updatePalette()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void Core::clipInstanceResized(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 18, nullptr, _t1);
}

// SIGNAL 19
void Core::audioLevelsAvailable(const QVector<double> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 19, nullptr, _t1);
}

// SIGNAL 20
void Core::audioLevelsConfigChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void Core::updateMixerLevels(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 21, nullptr, _t1);
}

// SIGNAL 22
void Core::switchTimelineRecord(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 22, nullptr, _t1);
}

// SIGNAL 23
void Core::recordAudio(int _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 23, nullptr, _t1, _t2);
}

// SIGNAL 24
void Core::updateProjectTimecode()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void Core::refreshActiveGuides()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void Core::updateDefaultMarkerCategory()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void Core::speechEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void Core::autoTrackHeight(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 28, nullptr, _t1);
}

// SIGNAL 29
void Core::gotMissingClipsCount(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 29, nullptr, _t1, _t2);
}

// SIGNAL 30
void Core::stopProgressTask()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void Core::binClipDeleted(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 31, nullptr, _t1);
}

// SIGNAL 32
void Core::mltWarning(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 32, nullptr, _t1);
}

// SIGNAL 33
void Core::requestShowBinEffectStack(const QString & _t1, std::shared_ptr<EffectStackModel> _t2, QSize _t3, bool _t4)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 33, nullptr, _t1, _t2, _t3, _t4);
}

// SIGNAL 34
void Core::saveGuideCategories()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void Core::saveTimelinePreview(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 35, nullptr, _t1);
}

// SIGNAL 36
void Core::enableBuildInTransform()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void Core::samConfigUpdated()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void Core::switchMaskPanel(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 38, nullptr, _t1);
}

// SIGNAL 39
void Core::transcodeProgress(ObjectId _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 39, nullptr, _t1, _t2);
}

// SIGNAL 40
void Core::startAutoSave()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void Core::displayBinMessage(const QString & _t1, int _t2, const QList<QAction*> & _t3, bool _t4, BinMessage::BinCategory _t5)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 41, nullptr, _t1, _t2, _t3, _t4, _t5);
}

// SIGNAL 45
void Core::displayBinLogMessage(const QString & _t1, int _t2, const QString _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 45, nullptr, _t1, _t2, _t3);
}

// SIGNAL 46
void Core::updateRenderOffset()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void Core::hideBars(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 47, nullptr, _t1);
}

// SIGNAL 48
void Core::switchTitleBars()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void Core::loadLayoutById(QString _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 49, nullptr, _t1, _t2);
}

// SIGNAL 51
void Core::switchDarkPalette(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 51, nullptr, _t1);
}

// SIGNAL 52
void Core::mainWindowReady()
{
    QMetaObject::activate(this, &staticMetaObject, 52, nullptr);
}

// SIGNAL 53
void Core::loadLayoutFromData(const QString _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 53, nullptr, _t1, _t2);
}

// SIGNAL 55
void Core::adjustLayoutToDar()
{
    QMetaObject::activate(this, &staticMetaObject, 55, nullptr);
}

// SIGNAL 56
void Core::GUISetupDone()
{
    QMetaObject::activate(this, &staticMetaObject, 56, nullptr);
}
QT_WARNING_POP
