/****************************************************************************
** Meta object code from reading C++ file 'abstractpythoninterface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/pythoninterfaces/abstractpythoninterface.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'abstractpythoninterface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN23AbstractPythonInterfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto AbstractPythonInterface::qt_create_metaobjectdata<qt_meta_tag_ZN23AbstractPythonInterfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "AbstractPythonInterface",
        "setupError",
        "",
        "message",
        "setupMessage",
        "KMessageWidget::MessageType",
        "messageType",
        "checkVersionsResult",
        "versions",
        "dependenciesMissing",
        "messages",
        "dependenciesAvailable",
        "proposeUpdate",
        "scriptFeedback",
        "script",
        "args",
        "installFeedback",
        "gotPythonSize",
        "concurrentScriptFinished",
        "scriptFinished",
        "scriptStarted",
        "abortScript",
        "venvSetupChanged",
        "installStatusChanged",
        "checkDependencies",
        "force",
        "async",
        "checkDependenciesConcurrently",
        "checkVersionsConcurrently",
        "installMissingDependencies",
        "checkSetup",
        "requestInstall",
        "bool*",
        "newInstall",
        "rebuildVenv"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'setupError'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'setupMessage'
        QtMocHelpers::SignalData<void(const QString &, KMessageWidget::MessageType)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { 0x80000000 | 5, 6 },
        }}),
        // Signal 'setupMessage'
        QtMocHelpers::SignalData<void(const QString &)>(4, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'checkVersionsResult'
        QtMocHelpers::SignalData<void(const QStringList &)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 8 },
        }}),
        // Signal 'dependenciesMissing'
        QtMocHelpers::SignalData<void(const QStringList &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 10 },
        }}),
        // Signal 'dependenciesAvailable'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proposeUpdate'
        QtMocHelpers::SignalData<void(const QString &)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'scriptFeedback'
        QtMocHelpers::SignalData<void(const QString &, const QStringList, const QStringList)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QStringList, 15 }, { QMetaType::QStringList, 3 },
        }}),
        // Signal 'installFeedback'
        QtMocHelpers::SignalData<void(const QString &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'gotPythonSize'
        QtMocHelpers::SignalData<void(const QString &)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'concurrentScriptFinished'
        QtMocHelpers::SignalData<void(const QString &, const QStringList &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QStringList, 15 },
        }}),
        // Signal 'scriptFinished'
        QtMocHelpers::SignalData<void(const QStringList &)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QStringList, 15 },
        }}),
        // Signal 'scriptStarted'
        QtMocHelpers::SignalData<void()>(20, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortScript'
        QtMocHelpers::SignalData<void()>(21, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'venvSetupChanged'
        QtMocHelpers::SignalData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'installStatusChanged'
        QtMocHelpers::SignalData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkDependencies'
        QtMocHelpers::SlotData<bool(bool, bool)>(24, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 25 }, { QMetaType::Bool, 26 },
        }}),
        // Slot 'checkDependencies'
        QtMocHelpers::SlotData<bool(bool)>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 25 },
        }}),
        // Slot 'checkDependencies'
        QtMocHelpers::SlotData<bool()>(24, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'checkDependenciesConcurrently'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'checkVersionsConcurrently'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'installMissingDependencies'
        QtMocHelpers::SlotData<bool()>(29, 2, QMC::AccessPublic, QMetaType::Bool),
        // Slot 'checkSetup'
        QtMocHelpers::SlotData<bool(bool, bool *)>(30, 2, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::Bool, 31 }, { 0x80000000 | 32, 33 },
        }}),
        // Slot 'checkSetup'
        QtMocHelpers::SlotData<bool(bool)>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'checkSetup'
        QtMocHelpers::SlotData<bool()>(30, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Bool),
        // Slot 'rebuildVenv'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<AbstractPythonInterface, qt_meta_tag_ZN23AbstractPythonInterfaceE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject AbstractPythonInterface::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPythonInterfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPythonInterfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23AbstractPythonInterfaceE_t>.metaTypes,
    nullptr
} };

void AbstractPythonInterface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AbstractPythonInterface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->setupError((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->setupMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 2: _t->setupMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->checkVersionsResult((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 4: _t->dependenciesMissing((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 5: _t->dependenciesAvailable(); break;
        case 6: _t->proposeUpdate((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->scriptFeedback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 8: _t->installFeedback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 9: _t->gotPythonSize((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 10: _t->concurrentScriptFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 11: _t->scriptFinished((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 12: _t->scriptStarted(); break;
        case 13: _t->abortScript(); break;
        case 14: _t->venvSetupChanged(); break;
        case 15: _t->installStatusChanged(); break;
        case 16: { bool _r = _t->checkDependencies((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 17: { bool _r = _t->checkDependencies((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 18: { bool _r = _t->checkDependencies();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 19: _t->checkDependenciesConcurrently(); break;
        case 20: _t->checkVersionsConcurrently(); break;
        case 21: { bool _r = _t->installMissingDependencies();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 22: { bool _r = _t->checkSetup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool*>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 23: { bool _r = _t->checkSetup((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 24: { bool _r = _t->checkSetup();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 25: _t->rebuildVenv(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & )>(_a, &AbstractPythonInterface::setupError, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & , KMessageWidget::MessageType )>(_a, &AbstractPythonInterface::setupMessage, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QStringList & )>(_a, &AbstractPythonInterface::checkVersionsResult, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QStringList & )>(_a, &AbstractPythonInterface::dependenciesMissing, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)()>(_a, &AbstractPythonInterface::dependenciesAvailable, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & )>(_a, &AbstractPythonInterface::proposeUpdate, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & , const QStringList , const QStringList )>(_a, &AbstractPythonInterface::scriptFeedback, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & )>(_a, &AbstractPythonInterface::installFeedback, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & )>(_a, &AbstractPythonInterface::gotPythonSize, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QString & , const QStringList & )>(_a, &AbstractPythonInterface::concurrentScriptFinished, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)(const QStringList & )>(_a, &AbstractPythonInterface::scriptFinished, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)()>(_a, &AbstractPythonInterface::scriptStarted, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)()>(_a, &AbstractPythonInterface::abortScript, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)()>(_a, &AbstractPythonInterface::venvSetupChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (AbstractPythonInterface::*)()>(_a, &AbstractPythonInterface::installStatusChanged, 15))
            return;
    }
}

const QMetaObject *AbstractPythonInterface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *AbstractPythonInterface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23AbstractPythonInterfaceE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int AbstractPythonInterface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 26;
    }
    return _id;
}

// SIGNAL 0
void AbstractPythonInterface::setupError(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void AbstractPythonInterface::setupMessage(const QString & _t1, KMessageWidget::MessageType _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 3
void AbstractPythonInterface::checkVersionsResult(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void AbstractPythonInterface::dependenciesMissing(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void AbstractPythonInterface::dependenciesAvailable()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void AbstractPythonInterface::proposeUpdate(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void AbstractPythonInterface::scriptFeedback(const QString & _t1, const QStringList _t2, const QStringList _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3);
}

// SIGNAL 8
void AbstractPythonInterface::installFeedback(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1);
}

// SIGNAL 9
void AbstractPythonInterface::gotPythonSize(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 9, nullptr, _t1);
}

// SIGNAL 10
void AbstractPythonInterface::concurrentScriptFinished(const QString & _t1, const QStringList & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 10, nullptr, _t1, _t2);
}

// SIGNAL 11
void AbstractPythonInterface::scriptFinished(const QStringList & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 11, nullptr, _t1);
}

// SIGNAL 12
void AbstractPythonInterface::scriptStarted()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void AbstractPythonInterface::abortScript()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void AbstractPythonInterface::venvSetupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void AbstractPythonInterface::installStatusChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}
namespace {
struct qt_meta_tag_ZN23PythonDependencyMessageE_t {};
} // unnamed namespace

template <> constexpr inline auto PythonDependencyMessage::qt_create_metaobjectdata<qt_meta_tag_ZN23PythonDependencyMessageE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PythonDependencyMessage",
        "checkAfterInstall",
        "",
        "doShowMessage",
        "message",
        "KMessageWidget::MessageType",
        "messageType"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'checkAfterInstall'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'doShowMessage'
        QtMocHelpers::SlotData<void(const QString &, KMessageWidget::MessageType)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { 0x80000000 | 5, 6 },
        }}),
        // Slot 'doShowMessage'
        QtMocHelpers::SlotData<void(const QString &)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PythonDependencyMessage, qt_meta_tag_ZN23PythonDependencyMessageE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PythonDependencyMessage::staticMetaObject = { {
    QMetaObject::SuperData::link<KMessageWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23PythonDependencyMessageE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23PythonDependencyMessageE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN23PythonDependencyMessageE_t>.metaTypes,
    nullptr
} };

void PythonDependencyMessage::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PythonDependencyMessage *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->checkAfterInstall(); break;
        case 1: _t->doShowMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<KMessageWidget::MessageType>>(_a[2]))); break;
        case 2: _t->doShowMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *PythonDependencyMessage::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PythonDependencyMessage::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN23PythonDependencyMessageE_t>.strings))
        return static_cast<void*>(this);
    return KMessageWidget::qt_metacast(_clname);
}

int PythonDependencyMessage::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KMessageWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
