/****************************************************************************
** Meta object code from reading C++ file 'effectstackview.hpp'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/effects/effectstack/view/effectstackview.hpp"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'effectstackview.hpp' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN14WidgetDelegateE_t {};
} // unnamed namespace

template <> constexpr inline auto WidgetDelegate::qt_create_metaobjectdata<qt_meta_tag_ZN14WidgetDelegateE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "WidgetDelegate"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WidgetDelegate, qt_meta_tag_ZN14WidgetDelegateE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject WidgetDelegate::staticMetaObject = { {
    QMetaObject::SuperData::link<QStyledItemDelegate::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetDelegateE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetDelegateE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN14WidgetDelegateE_t>.metaTypes,
    nullptr
} };

void WidgetDelegate::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WidgetDelegate *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *WidgetDelegate::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *WidgetDelegate::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN14WidgetDelegateE_t>.strings))
        return static_cast<void*>(this);
    return QStyledItemDelegate::qt_metacast(_clname);
}

int WidgetDelegate::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStyledItemDelegate::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN15EffectStackViewE_t {};
} // unnamed namespace

template <> constexpr inline auto EffectStackView::qt_create_metaobjectdata<qt_meta_tag_ZN15EffectStackViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "EffectStackView",
        "switchCollapsedView",
        "",
        "row",
        "seekToPos",
        "reloadEffect",
        "path",
        "updateEnabledState",
        "removeCurrentEffect",
        "blockWheelEvent",
        "block",
        "checkScrollBar",
        "scrollView",
        "QRect",
        "checkDragScrolling",
        "updateEffectsGroupesInstances",
        "abortSam",
        "effectsCountChanged",
        "slotSaveStack",
        "updateSamProgress",
        "progress",
        "exportStep",
        "slotSwitchCollapseAll",
        "refresh",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "slotCollapseAllEffects",
        "collapse",
        "slotAdjustDelegate",
        "std::shared_ptr<EffectItemModel>",
        "effectModel",
        "height",
        "slotDeleteEffect",
        "effect",
        "loadEffects",
        "updateTreeHeight",
        "slotFocusEffect",
        "changeEnabledState",
        "activateEffect",
        "ix",
        "active",
        "setDropTargetEffect",
        "transcodeProgress",
        "ObjectId",
        "owner",
        "launchObjectMask"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'switchCollapsedView'
        QtMocHelpers::SignalData<void(int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 3 },
        }}),
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Signal 'reloadEffect'
        QtMocHelpers::SignalData<void(const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 6 },
        }}),
        // Signal 'updateEnabledState'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'removeCurrentEffect'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blockWheelEvent'
        QtMocHelpers::SignalData<void(bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 },
        }}),
        // Signal 'checkScrollBar'
        QtMocHelpers::SignalData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollView'
        QtMocHelpers::SignalData<void(QRect)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 13, 2 },
        }}),
        // Signal 'checkDragScrolling'
        QtMocHelpers::SignalData<void()>(14, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'updateEffectsGroupesInstances'
        QtMocHelpers::SignalData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'abortSam'
        QtMocHelpers::SignalData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectsCountChanged'
        QtMocHelpers::SignalData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotSaveStack'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateSamProgress'
        QtMocHelpers::SlotData<void(int, bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 }, { QMetaType::Bool, 21 },
        }}),
        // Slot 'updateSamProgress'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotSwitchCollapseAll'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'refresh'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(23, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 25 }, { 0x80000000 | 24, 26 }, { 0x80000000 | 27, 28 },
        }}),
        // Slot 'slotCollapseAllEffects'
        QtMocHelpers::SlotData<void(bool)>(29, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 30 },
        }}),
        // Slot 'slotAdjustDelegate'
        QtMocHelpers::SlotData<void(const std::shared_ptr<EffectItemModel> &, int)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 33 }, { QMetaType::Int, 34 },
        }}),
        // Slot 'slotDeleteEffect'
        QtMocHelpers::SlotData<void(const std::shared_ptr<EffectItemModel> &)>(35, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 32, 36 },
        }}),
        // Slot 'loadEffects'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateTreeHeight'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotFocusEffect'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'changeEnabledState'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'activateEffect'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'setDropTargetEffect'
        QtMocHelpers::SlotData<void(const QModelIndex &, bool)>(44, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 24, 42 }, { QMetaType::Bool, 43 },
        }}),
        // Slot 'transcodeProgress'
        QtMocHelpers::SlotData<void(ObjectId, int)>(45, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 46, 47 }, { QMetaType::Int, 20 },
        }}),
        // Slot 'launchObjectMask'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<EffectStackView, qt_meta_tag_ZN15EffectStackViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject EffectStackView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EffectStackViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EffectStackViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15EffectStackViewE_t>.metaTypes,
    nullptr
} };

void EffectStackView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<EffectStackView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->switchCollapsedView((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 1: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 2: _t->reloadEffect((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 3: _t->updateEnabledState(); break;
        case 4: _t->removeCurrentEffect(); break;
        case 5: _t->blockWheelEvent((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->checkScrollBar(); break;
        case 7: _t->scrollView((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 8: _t->checkDragScrolling(); break;
        case 9: _t->updateEffectsGroupesInstances(); break;
        case 10: _t->abortSam(); break;
        case 11: _t->effectsCountChanged(); break;
        case 12: _t->slotSaveStack(); break;
        case 13: _t->updateSamProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 14: _t->updateSamProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->slotSwitchCollapseAll(); break;
        case 16: _t->refresh((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 17: _t->slotCollapseAllEffects((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->slotAdjustDelegate((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 19: _t->slotDeleteEffect((*reinterpret_cast<std::add_pointer_t<std::shared_ptr<EffectItemModel>>>(_a[1]))); break;
        case 20: _t->loadEffects(); break;
        case 21: _t->updateTreeHeight(); break;
        case 22: _t->slotFocusEffect(); break;
        case 23: _t->changeEnabledState(); break;
        case 24: _t->activateEffect((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 25: _t->setDropTargetEffect((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 26: _t->transcodeProgress((*reinterpret_cast<std::add_pointer_t<ObjectId>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 27: _t->launchObjectMask(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 16:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)(int )>(_a, &EffectStackView::switchCollapsedView, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)(int )>(_a, &EffectStackView::seekToPos, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)(const QString & )>(_a, &EffectStackView::reloadEffect, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::updateEnabledState, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::removeCurrentEffect, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)(bool )>(_a, &EffectStackView::blockWheelEvent, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::checkScrollBar, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)(QRect )>(_a, &EffectStackView::scrollView, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::checkDragScrolling, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::updateEffectsGroupesInstances, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::abortSam, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (EffectStackView::*)()>(_a, &EffectStackView::effectsCountChanged, 11))
            return;
    }
}

const QMetaObject *EffectStackView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *EffectStackView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15EffectStackViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int EffectStackView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void EffectStackView::switchCollapsedView(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void EffectStackView::seekToPos(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void EffectStackView::reloadEffect(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void EffectStackView::updateEnabledState()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void EffectStackView::removeCurrentEffect()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void EffectStackView::blockWheelEvent(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void EffectStackView::checkScrollBar()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void EffectStackView::scrollView(QRect _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void EffectStackView::checkDragScrolling()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void EffectStackView::updateEffectsGroupesInstances()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void EffectStackView::abortSam()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void EffectStackView::effectsCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}
QT_WARNING_POP
