/********************************************************************************
** Form generated from reading UI file 'configsdl_ui.ui'
**
** Created by: Qt User Interface Compiler version 6.11.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGSDL_UI_H
#define UI_CONFIGSDL_UI_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QFrame>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QToolButton>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>
#include "kmessagewidget.h"

QT_BEGIN_NAMESPACE

class Ui_ConfigSdl_UI
{
public:
    QFormLayout *formLayout;
    QLabel *label;
    QCheckBox *kcfg_play_monitor_on_click;
    QLabel *label_6;
    QComboBox *fullscreen_monitor;
    QFrame *line;
    KMessageWidget *kmessagewidget;
    QLabel *label_gpu;
    QCheckBox *kcfg_gpu_accel;
    QFrame *line_2;
    QLabel *label_audio_backend;
    QComboBox *kcfg_audio_backend;
    QLabel *label_audio_driver;
    QComboBox *kcfg_audio_driver;
    QLabel *label_audio_device;
    QComboBox *kcfg_audio_device;
    QFrame *line_3;
    QLabel *label_2;
    QCheckBox *kcfg_external_display;
    QLabel *label_5;
    QHBoxLayout *horizontalLayout;
    QComboBox *kcfg_blackmagic_output_device;
    QToolButton *reload_blackmagic;
    QSpacerItem *verticalSpacer;
    QLabel *label_3;
    QCheckBox *kcfg_mirrorMonitorOnFullscreen;

    void setupUi(QWidget *ConfigSdl_UI)
    {
        if (ConfigSdl_UI->objectName().isEmpty())
            ConfigSdl_UI->setObjectName("ConfigSdl_UI");
        ConfigSdl_UI->resize(557, 394);
        formLayout = new QFormLayout(ConfigSdl_UI);
        formLayout->setObjectName("formLayout");
        label = new QLabel(ConfigSdl_UI);
        label->setObjectName("label");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, label);

        kcfg_play_monitor_on_click = new QCheckBox(ConfigSdl_UI);
        kcfg_play_monitor_on_click->setObjectName("kcfg_play_monitor_on_click");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, kcfg_play_monitor_on_click);

        label_6 = new QLabel(ConfigSdl_UI);
        label_6->setObjectName("label_6");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, label_6);

        fullscreen_monitor = new QComboBox(ConfigSdl_UI);
        fullscreen_monitor->setObjectName("fullscreen_monitor");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, fullscreen_monitor);

        line = new QFrame(ConfigSdl_UI);
        line->setObjectName("line");
        line->setFrameShape(QFrame::Shape::HLine);
        line->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(3, QFormLayout::ItemRole::SpanningRole, line);

        kmessagewidget = new KMessageWidget(ConfigSdl_UI);
        kmessagewidget->setObjectName("kmessagewidget");
        kmessagewidget->setWordWrap(true);
        kmessagewidget->setCloseButtonVisible(false);

        formLayout->setWidget(4, QFormLayout::ItemRole::SpanningRole, kmessagewidget);

        label_gpu = new QLabel(ConfigSdl_UI);
        label_gpu->setObjectName("label_gpu");

        formLayout->setWidget(5, QFormLayout::ItemRole::LabelRole, label_gpu);

        kcfg_gpu_accel = new QCheckBox(ConfigSdl_UI);
        kcfg_gpu_accel->setObjectName("kcfg_gpu_accel");

        formLayout->setWidget(5, QFormLayout::ItemRole::FieldRole, kcfg_gpu_accel);

        line_2 = new QFrame(ConfigSdl_UI);
        line_2->setObjectName("line_2");
        line_2->setFrameShape(QFrame::Shape::HLine);
        line_2->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(6, QFormLayout::ItemRole::SpanningRole, line_2);

        label_audio_backend = new QLabel(ConfigSdl_UI);
        label_audio_backend->setObjectName("label_audio_backend");

        formLayout->setWidget(7, QFormLayout::ItemRole::LabelRole, label_audio_backend);

        kcfg_audio_backend = new QComboBox(ConfigSdl_UI);
        kcfg_audio_backend->setObjectName("kcfg_audio_backend");

        formLayout->setWidget(7, QFormLayout::ItemRole::FieldRole, kcfg_audio_backend);

        label_audio_driver = new QLabel(ConfigSdl_UI);
        label_audio_driver->setObjectName("label_audio_driver");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Maximum, QSizePolicy::Policy::Preferred);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(label_audio_driver->sizePolicy().hasHeightForWidth());
        label_audio_driver->setSizePolicy(sizePolicy);
        label_audio_driver->setWordWrap(false);

        formLayout->setWidget(8, QFormLayout::ItemRole::LabelRole, label_audio_driver);

        kcfg_audio_driver = new QComboBox(ConfigSdl_UI);
        kcfg_audio_driver->setObjectName("kcfg_audio_driver");

        formLayout->setWidget(8, QFormLayout::ItemRole::FieldRole, kcfg_audio_driver);

        label_audio_device = new QLabel(ConfigSdl_UI);
        label_audio_device->setObjectName("label_audio_device");
        label_audio_device->setWordWrap(false);

        formLayout->setWidget(9, QFormLayout::ItemRole::LabelRole, label_audio_device);

        kcfg_audio_device = new QComboBox(ConfigSdl_UI);
        kcfg_audio_device->setObjectName("kcfg_audio_device");

        formLayout->setWidget(9, QFormLayout::ItemRole::FieldRole, kcfg_audio_device);

        line_3 = new QFrame(ConfigSdl_UI);
        line_3->setObjectName("line_3");
        line_3->setFrameShape(QFrame::Shape::HLine);
        line_3->setFrameShadow(QFrame::Shadow::Sunken);

        formLayout->setWidget(10, QFormLayout::ItemRole::SpanningRole, line_3);

        label_2 = new QLabel(ConfigSdl_UI);
        label_2->setObjectName("label_2");

        formLayout->setWidget(11, QFormLayout::ItemRole::LabelRole, label_2);

        kcfg_external_display = new QCheckBox(ConfigSdl_UI);
        kcfg_external_display->setObjectName("kcfg_external_display");

        formLayout->setWidget(11, QFormLayout::ItemRole::FieldRole, kcfg_external_display);

        label_5 = new QLabel(ConfigSdl_UI);
        label_5->setObjectName("label_5");

        formLayout->setWidget(12, QFormLayout::ItemRole::LabelRole, label_5);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName("horizontalLayout");
        kcfg_blackmagic_output_device = new QComboBox(ConfigSdl_UI);
        kcfg_blackmagic_output_device->setObjectName("kcfg_blackmagic_output_device");
        kcfg_blackmagic_output_device->setEnabled(true);
        QSizePolicy sizePolicy1(QSizePolicy::Policy::MinimumExpanding, QSizePolicy::Policy::Fixed);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(kcfg_blackmagic_output_device->sizePolicy().hasHeightForWidth());
        kcfg_blackmagic_output_device->setSizePolicy(sizePolicy1);

        horizontalLayout->addWidget(kcfg_blackmagic_output_device);

        reload_blackmagic = new QToolButton(ConfigSdl_UI);
        reload_blackmagic->setObjectName("reload_blackmagic");
        QIcon icon(QIcon::fromTheme(QString::fromUtf8("view-refresh")));
        reload_blackmagic->setIcon(icon);

        horizontalLayout->addWidget(reload_blackmagic);


        formLayout->setLayout(12, QFormLayout::ItemRole::FieldRole, horizontalLayout);

        verticalSpacer = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        formLayout->setItem(13, QFormLayout::ItemRole::LabelRole, verticalSpacer);

        label_3 = new QLabel(ConfigSdl_UI);
        label_3->setObjectName("label_3");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, label_3);

        kcfg_mirrorMonitorOnFullscreen = new QCheckBox(ConfigSdl_UI);
        kcfg_mirrorMonitorOnFullscreen->setObjectName("kcfg_mirrorMonitorOnFullscreen");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, kcfg_mirrorMonitorOnFullscreen);


        retranslateUi(ConfigSdl_UI);

        QMetaObject::connectSlotsByName(ConfigSdl_UI);
    } // setupUi

    void retranslateUi(QWidget *ConfigSdl_UI)
    {
        label->setText(tr2i18n("Play/pause monitor on mouse click", nullptr));
        kcfg_play_monitor_on_click->setText(tr2i18n("Enable", nullptr));
        label_6->setText(tr2i18n("Monitor for fullscreen output:", nullptr));
        kmessagewidget->setText(tr2i18n("Warning: changes to the drivers and devices can make Kdenlive unstable. Change only if you know what you do.", nullptr));
        label_gpu->setText(tr2i18n("GPU processing (Movit library):", nullptr));
        kcfg_gpu_accel->setText(tr2i18n("Enable - restart Kdenlive to apply", nullptr));
        label_audio_backend->setText(tr2i18n("Audio Backend:", nullptr));
        label_audio_driver->setText(tr2i18n("Audio driver:", nullptr));
        label_audio_device->setText(tr2i18n("Audio device:", nullptr));
        label_2->setText(tr2i18n("External display (Blackmagic card):", nullptr));
        kcfg_external_display->setText(tr2i18n("Enable", nullptr));
        label_5->setText(tr2i18n("Output device:", nullptr));
        reload_blackmagic->setText(tr2i18n("...", nullptr));
        label_3->setText(tr2i18n("Mirror monitor on fullscreen:", nullptr));
        kcfg_mirrorMonitorOnFullscreen->setText(tr2i18n("Enable", nullptr));
        (void)ConfigSdl_UI;
    } // retranslateUi

};

namespace Ui {
    class ConfigSdl_UI: public Ui_ConfigSdl_UI {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGSDL_UI_H

