/****************************************************************************
** Meta object code from reading C++ file 'pluginssettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/settings/pluginssettings.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginssettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN10SpeechListE_t {};
} // unnamed namespace

template <> constexpr inline auto SpeechList::qt_create_metaobjectdata<qt_meta_tag_ZN10SpeechListE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "SpeechList",
        "getDictionary",
        "",
        "QUrl",
        "url"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'getDictionary'
        QtMocHelpers::SignalData<void(const QUrl)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SpeechList, qt_meta_tag_ZN10SpeechListE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject SpeechList::staticMetaObject = { {
    QMetaObject::SuperData::link<QListWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpeechListE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpeechListE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN10SpeechListE_t>.metaTypes,
    nullptr
} };

void SpeechList::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SpeechList *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->getDictionary((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (SpeechList::*)(const QUrl )>(_a, &SpeechList::getDictionary, 0))
            return;
    }
}

const QMetaObject *SpeechList::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *SpeechList::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN10SpeechListE_t>.strings))
        return static_cast<void*>(this);
    return QListWidget::qt_metacast(_clname);
}

int SpeechList::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QListWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void SpeechList::getDictionary(const QUrl _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN15PluginsSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginsSettings::qt_create_metaobjectdata<qt_meta_tag_ZN15PluginsSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginsSettings",
        "openBrowserUrl",
        "",
        "url",
        "parseDictionaries",
        "slotParseVoskDictionaries",
        "getDictionary",
        "QUrl",
        "sourceUrl",
        "removeDictionary",
        "downloadModelFinished",
        "KJob*",
        "job",
        "processArchive",
        "path",
        "doShowSpeechMessage",
        "message",
        "messageType",
        "slotCheckSttConfig",
        "showSpeechLog",
        "jobData",
        "showSamLog",
        "downloadJobDone",
        "success",
        "downloadSamModel",
        "downloadSamModels",
        "installSamModelIfEmpty",
        "reloadSamModels",
        "doDeleteSamVenv",
        "doDeleteWrVenv",
        "doDeleteSamModels",
        "checkSamEnvironement",
        "afterInstall",
        "gotWhisperFeedback",
        "scriptName",
        "args",
        "whisperFinished",
        "whisperAvailable",
        "whisperMissing",
        "gotSamFeedback",
        "samFinished",
        "samMissing",
        "samDependenciesChecked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'openBrowserUrl'
        QtMocHelpers::SignalData<void(const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'parseDictionaries'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'slotParseVoskDictionaries'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'getDictionary'
        QtMocHelpers::SlotData<void(const QUrl &)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'getDictionary'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'removeDictionary'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'downloadModelFinished'
        QtMocHelpers::SlotData<void(KJob *)>(10, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Slot 'processArchive'
        QtMocHelpers::SlotData<void(const QString &)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'doShowSpeechMessage'
        QtMocHelpers::SlotData<void(const QString &, int)>(15, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 },
        }}),
        // Slot 'slotCheckSttConfig'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'showSpeechLog'
        QtMocHelpers::SlotData<void(const QString &)>(19, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'showSamLog'
        QtMocHelpers::SlotData<void(const QString &)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 20 },
        }}),
        // Slot 'downloadJobDone'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 23 },
        }}),
        // Slot 'downloadSamModel'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Slot 'downloadSamModels'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'installSamModelIfEmpty'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'reloadSamModels'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doDeleteSamVenv'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doDeleteWrVenv'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'doDeleteSamModels'
        QtMocHelpers::SlotData<void()>(30, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'checkSamEnvironement'
        QtMocHelpers::SlotData<void(bool)>(31, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 32 },
        }}),
        // Slot 'checkSamEnvironement'
        QtMocHelpers::SlotData<void()>(31, 2, QMC::AccessPrivate | QMC::MethodCloned, QMetaType::Void),
        // Slot 'gotWhisperFeedback'
        QtMocHelpers::SlotData<void(const QString &, const QStringList, const QStringList)>(33, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QStringList, 35 }, { QMetaType::QStringList, 20 },
        }}),
        // Slot 'whisperFinished'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(36, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QStringList, 35 },
        }}),
        // Slot 'whisperAvailable'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'whisperMissing'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'gotSamFeedback'
        QtMocHelpers::SlotData<void(const QString &, const QStringList, const QStringList)>(39, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QStringList, 35 }, { QMetaType::QStringList, 20 },
        }}),
        // Slot 'samFinished'
        QtMocHelpers::SlotData<void(const QString &, const QStringList &)>(40, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 34 }, { QMetaType::QStringList, 35 },
        }}),
        // Slot 'samMissing'
        QtMocHelpers::SlotData<void(const QStringList &)>(41, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QStringList, 2 },
        }}),
        // Slot 'samDependenciesChecked'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPrivate, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginsSettings, qt_meta_tag_ZN15PluginsSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PluginsSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PluginsSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PluginsSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN15PluginsSettingsE_t>.metaTypes,
    nullptr
} };

void PluginsSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginsSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->openBrowserUrl((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->parseDictionaries(); break;
        case 2: _t->slotParseVoskDictionaries(); break;
        case 3: _t->getDictionary((*reinterpret_cast<std::add_pointer_t<QUrl>>(_a[1]))); break;
        case 4: _t->getDictionary(); break;
        case 5: _t->removeDictionary(); break;
        case 6: _t->downloadModelFinished((*reinterpret_cast<std::add_pointer_t<KJob*>>(_a[1]))); break;
        case 7: _t->processArchive((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 8: _t->doShowSpeechMessage((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 9: _t->slotCheckSttConfig(); break;
        case 10: _t->showSpeechLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 11: _t->showSamLog((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 12: _t->downloadJobDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->downloadSamModel((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 14: _t->downloadSamModels(); break;
        case 15: _t->installSamModelIfEmpty(); break;
        case 16: _t->reloadSamModels(); break;
        case 17: _t->doDeleteSamVenv(); break;
        case 18: _t->doDeleteWrVenv(); break;
        case 19: _t->doDeleteSamModels(); break;
        case 20: _t->checkSamEnvironement((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 21: _t->checkSamEnvironement(); break;
        case 22: _t->gotWhisperFeedback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 23: _t->whisperFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 24: _t->whisperAvailable(); break;
        case 25: _t->whisperMissing(); break;
        case 26: _t->gotSamFeedback((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[3]))); break;
        case 27: _t->samFinished((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2]))); break;
        case 28: _t->samMissing((*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[1]))); break;
        case 29: _t->samDependenciesChecked(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginsSettings::*)(const QString & )>(_a, &PluginsSettings::openBrowserUrl, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginsSettings::*)()>(_a, &PluginsSettings::parseDictionaries, 1))
            return;
    }
}

const QMetaObject *PluginsSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginsSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN15PluginsSettingsE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::ConfigSpeech_UI"))
        return static_cast< Ui::ConfigSpeech_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int PluginsSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 30)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 30;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 30)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 30;
    }
    return _id;
}

// SIGNAL 0
void PluginsSettings::openBrowserUrl(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PluginsSettings::parseDictionaries()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
