/****************************************************************************
** Meta object code from reading C++ file 'timeremap.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kdenlive-26.04.1/src/dialogs/timeremap.h"
#include <QtNetwork/QSslPreSharedKeyAuthenticator>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'timeremap.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9RemapViewE_t {};
} // unnamed namespace

template <> constexpr inline auto RemapView::qt_create_metaobjectdata<qt_meta_tag_ZN9RemapViewE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "RemapView",
        "seekToPos",
        "",
        "selectedKf",
        "std::pair<int,int>",
        "std::pair<double,double>",
        "std::pair<bool,bool>",
        "atEnd",
        "updateSpeeds",
        "atKeyframe",
        "isKeyframe",
        "last",
        "updateKeyframes",
        "resize",
        "updateKeyframesWithUndo",
        "QMap<int,int>",
        "updatedKeyframes",
        "previousKeyframes",
        "updateMaxDuration",
        "updateInPos",
        "pos",
        "updateOutPos",
        "slotSetPosition",
        "slotSetBottomPosition",
        "addKeyframe",
        "goNext",
        "goPrev",
        "updateBeforeSpeed",
        "speed",
        "updateAfterSpeed",
        "toggleMoveNext",
        "moveNext",
        "reloadProducer",
        "centerCurrentKeyframe",
        "centerCurrentTopKeyframe"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'seekToPos'
        QtMocHelpers::SignalData<void(int, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 2 }, { QMetaType::Int, 2 },
        }}),
        // Signal 'selectedKf'
        QtMocHelpers::SignalData<void(std::pair<int,int>, std::pair<double,double>, std::pair<bool,bool>)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'selectedKf'
        QtMocHelpers::SignalData<void(std::pair<int,int>, std::pair<double,double>)>(3, 2, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { 0x80000000 | 4, 2 }, { 0x80000000 | 5, 2 },
        }}),
        // Signal 'updateSpeeds'
        QtMocHelpers::SignalData<void(std::pair<double,double>)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Signal 'atKeyframe'
        QtMocHelpers::SignalData<void(bool, bool)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 10 }, { QMetaType::Bool, 11 },
        }}),
        // Signal 'updateKeyframes'
        QtMocHelpers::SignalData<void(bool)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 13 },
        }}),
        // Signal 'updateKeyframesWithUndo'
        QtMocHelpers::SignalData<void(QMap<int,int>, QMap<int,int>)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 15, 16 }, { 0x80000000 | 15, 17 },
        }}),
        // Signal 'updateMaxDuration'
        QtMocHelpers::SignalData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateInPos'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'updateOutPos'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotSetPosition'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'slotSetBottomPosition'
        QtMocHelpers::SlotData<void(int)>(23, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
        // Slot 'addKeyframe'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goNext'
        QtMocHelpers::SlotData<void()>(25, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'goPrev'
        QtMocHelpers::SlotData<void()>(26, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateBeforeSpeed'
        QtMocHelpers::SlotData<void(double)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 28 },
        }}),
        // Slot 'updateAfterSpeed'
        QtMocHelpers::SlotData<void(double)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Double, 28 },
        }}),
        // Slot 'toggleMoveNext'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
        // Slot 'reloadProducer'
        QtMocHelpers::SlotData<void()>(32, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerCurrentKeyframe'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'centerCurrentTopKeyframe'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<RemapView, qt_meta_tag_ZN9RemapViewE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject RemapView::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RemapViewE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RemapViewE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9RemapViewE_t>.metaTypes,
    nullptr
} };

void RemapView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<RemapView *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->seekToPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->selectedKf((*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<double,double>>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<std::pair<bool,bool>>>(_a[3]))); break;
        case 2: _t->selectedKf((*reinterpret_cast<std::add_pointer_t<std::pair<int,int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<std::pair<double,double>>>(_a[2]))); break;
        case 3: _t->updateSpeeds((*reinterpret_cast<std::add_pointer_t<std::pair<double,double>>>(_a[1]))); break;
        case 4: _t->atKeyframe((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 5: _t->updateKeyframes((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->updateKeyframesWithUndo((*reinterpret_cast<std::add_pointer_t<QMap<int,int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<int,int>>>(_a[2]))); break;
        case 7: _t->updateMaxDuration(); break;
        case 8: _t->updateInPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->updateOutPos((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->slotSetPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->slotSetBottomPosition((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 12: _t->addKeyframe(); break;
        case 13: _t->goNext(); break;
        case 14: _t->goPrev(); break;
        case 15: _t->updateBeforeSpeed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 16: _t->updateAfterSpeed((*reinterpret_cast<std::add_pointer_t<double>>(_a[1]))); break;
        case 17: _t->toggleMoveNext((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 18: _t->reloadProducer(); break;
        case 19: _t->centerCurrentKeyframe(); break;
        case 20: _t->centerCurrentTopKeyframe(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(int , int )>(_a, &RemapView::seekToPos, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(std::pair<int,int> , std::pair<double,double> , std::pair<bool,bool> )>(_a, &RemapView::selectedKf, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(std::pair<double,double> )>(_a, &RemapView::updateSpeeds, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(bool , bool )>(_a, &RemapView::atKeyframe, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(bool )>(_a, &RemapView::updateKeyframes, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)(QMap<int,int> , QMap<int,int> )>(_a, &RemapView::updateKeyframesWithUndo, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (RemapView::*)()>(_a, &RemapView::updateMaxDuration, 7))
            return;
    }
}

const QMetaObject *RemapView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *RemapView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9RemapViewE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int RemapView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 21)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 21;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 21)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 21;
    }
    return _id;
}

// SIGNAL 0
void RemapView::seekToPos(int _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void RemapView::selectedKf(std::pair<int,int> _t1, std::pair<double,double> _t2, std::pair<bool,bool> _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2, _t3);
}

// SIGNAL 3
void RemapView::updateSpeeds(std::pair<double,double> _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void RemapView::atKeyframe(bool _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void RemapView::updateKeyframes(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void RemapView::updateKeyframesWithUndo(QMap<int,int> _t1, QMap<int,int> _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1, _t2);
}

// SIGNAL 7
void RemapView::updateMaxDuration()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
namespace {
struct qt_meta_tag_ZN9TimeRemapE_t {};
} // unnamed namespace

template <> constexpr inline auto TimeRemap::qt_create_metaobjectdata<qt_meta_tag_ZN9TimeRemapE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "TimeRemap",
        "updateKeyframes",
        "",
        "updateKeyframesWithUndo",
        "QMap<int,int>",
        "updatedKeyframes",
        "previousKeyframes",
        "checkClipUpdate",
        "QModelIndex",
        "topLeft",
        "bottomRight",
        "QList<int>",
        "roles",
        "switchRemapParam",
        "monitorSeek",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'updateKeyframes'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'updateKeyframesWithUndo'
        QtMocHelpers::SlotData<void(const QMap<int,int> &, const QMap<int,int> &)>(3, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 4, 6 },
        }}),
        // Slot 'checkClipUpdate'
        QtMocHelpers::SlotData<void(const QModelIndex &, const QModelIndex &, const QVector<int> &)>(7, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 8, 9 }, { 0x80000000 | 8, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Slot 'switchRemapParam'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'monitorSeek'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TimeRemap, qt_meta_tag_ZN9TimeRemapE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject TimeRemap::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TimeRemapE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TimeRemapE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9TimeRemapE_t>.metaTypes,
    nullptr
} };

void TimeRemap::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TimeRemap *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->updateKeyframes(); break;
        case 1: _t->updateKeyframesWithUndo((*reinterpret_cast<std::add_pointer_t<QMap<int,int>>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QMap<int,int>>>(_a[2]))); break;
        case 2: _t->checkClipUpdate((*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QModelIndex>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QList<int>>>(_a[3]))); break;
        case 3: _t->switchRemapParam(); break;
        case 4: _t->monitorSeek((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QList<int> >(); break;
            }
            break;
        }
    }
}

const QMetaObject *TimeRemap::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TimeRemap::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9TimeRemapE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::TimeRemap_UI"))
        return static_cast< Ui::TimeRemap_UI*>(this);
    return QWidget::qt_metacast(_clname);
}

int TimeRemap::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}
QT_WARNING_POP
