// This file is generated by kconfig_compiler_kf6 from kdenlivesettings.kcfg.
// All changes you do to this file will be lost.
#ifndef KDENLIVESETTINGS_H
#define KDENLIVESETTINGS_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>
#include <qqmlintegration.h>

class QQmlEngine;
class QJSEngine;

class KdenliveSettings : public KConfigSkeleton
{
  Q_OBJECT
  QML_ELEMENT
  QML_SINGLETON
  public:

    static KdenliveSettings *self();
    static KdenliveSettings *create(QQmlEngine *, QJSEngine *);
    ~KdenliveSettings() override;

    /**
      Set Bin treeview headers state.
    */
    static
    void setTreeviewheaders( const QString & v )
    {
      if (v != self()->mTreeviewheaders && !self()->isTreeviewheadersImmutable()) {
        self()->mTreeviewheaders = v;
        Q_EMIT self()->treeviewheadersChanged();
      }
    }

    Q_PROPERTY(QString treeviewheaders READ treeviewheaders WRITE setTreeviewheaders NOTIFY treeviewheadersChanged)
    Q_PROPERTY(bool isTreeviewheadersImmutable READ isTreeviewheadersImmutable CONSTANT)
    /**
      Get Bin treeview headers state.
    */
    static
    QString treeviewheaders()
    {
      return self()->mTreeviewheaders;
    }

    /**
      Is Bin treeview headers state. Immutable
    */
    static
    bool isTreeviewheadersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "treeviewheaders" ) );
    }

    /**
      Set Bin sorting column.
    */
    static
    void setBinSorting( int v )
    {
      if (v != self()->mBinSorting && !self()->isBinSortingImmutable()) {
        self()->mBinSorting = v;
        Q_EMIT self()->binSortingChanged();
      }
    }

    Q_PROPERTY(int binSorting READ binSorting WRITE setBinSorting NOTIFY binSortingChanged)
    Q_PROPERTY(bool isBinSortingImmutable READ isBinSortingImmutable CONSTANT)
    Q_PROPERTY(int defaultBinSortingValue READ defaultBinSortingValue CONSTANT)
    /**
      Get Bin sorting column.
    */
    static
    int binSorting()
    {
      return self()->mBinSorting;
    }

    /**
      Is Bin sorting column. Immutable
    */
    static
    bool isBinSortingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "binSorting" ) );
    }

    /**
      Get Bin sorting column. default value
    */
    static
    int defaultBinSortingValue()
    {
        return defaultBinSortingValue_helper();
    }

    /**
      Set Bin view mode.
    */
    static
    void setBinMode( int v )
    {
      if (v != self()->mBinMode && !self()->isBinModeImmutable()) {
        self()->mBinMode = v;
        Q_EMIT self()->binModeChanged();
      }
    }

    Q_PROPERTY(int binMode READ binMode WRITE setBinMode NOTIFY binModeChanged)
    Q_PROPERTY(bool isBinModeImmutable READ isBinModeImmutable CONSTANT)
    Q_PROPERTY(int defaultBinModeValue READ defaultBinModeValue CONSTANT)
    /**
      Get Bin view mode.
    */
    static
    int binMode()
    {
      return self()->mBinMode;
    }

    /**
      Is Bin view mode. Immutable
    */
    static
    bool isBinModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "binMode" ) );
    }

    /**
      Get Bin view mode. default value
    */
    static
    int defaultBinModeValue()
    {
        return defaultBinModeValue_helper();
    }

    /**
      Set Bin default zoom.
    */
    static
    void setBin_zoom( int v )
    {
      if (v != self()->mBin_zoom && !self()->isBin_zoomImmutable()) {
        self()->mBin_zoom = v;
        Q_EMIT self()->bin_zoomChanged();
      }
    }

    Q_PROPERTY(int bin_zoom READ bin_zoom WRITE setBin_zoom NOTIFY bin_zoomChanged)
    Q_PROPERTY(bool isBin_zoomImmutable READ isBin_zoomImmutable CONSTANT)
    Q_PROPERTY(int defaultBin_zoomValue READ defaultBin_zoomValue CONSTANT)
    /**
      Get Bin default zoom.
    */
    static
    int bin_zoom()
    {
      return self()->mBin_zoom;
    }

    /**
      Is Bin default zoom. Immutable
    */
    static
    bool isBin_zoomImmutable()
    {
      return self()->isImmutable( QStringLiteral( "bin_zoom" ) );
    }

    /**
      Get Bin default zoom. default value
    */
    static
    int defaultBin_zoomValue()
    {
        return defaultBin_zoomValue_helper();
    }

    /**
      Set User added clip file extensions.
    */
    static
    void setAddedExtensions( const QString & v )
    {
      if (v != self()->mAddedExtensions && !self()->isAddedExtensionsImmutable()) {
        self()->mAddedExtensions = v;
        Q_EMIT self()->addedExtensionsChanged();
      }
    }

    Q_PROPERTY(QString addedExtensions READ addedExtensions WRITE setAddedExtensions NOTIFY addedExtensionsChanged)
    Q_PROPERTY(bool isAddedExtensionsImmutable READ isAddedExtensionsImmutable CONSTANT)
    /**
      Get User added clip file extensions.
    */
    static
    QString addedExtensions()
    {
      return self()->mAddedExtensions;
    }

    /**
      Is User added clip file extensions. Immutable
    */
    static
    bool isAddedExtensionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "addedExtensions" ) );
    }

    /**
      Set Generate and show video preview when moving mouse over clip thumbnail.
    */
    static
    void setHoverPreview( bool v )
    {
      if (v != self()->mHoverPreview && !self()->isHoverPreviewImmutable()) {
        self()->mHoverPreview = v;
        Q_EMIT self()->hoverPreviewChanged();
      }
    }

    Q_PROPERTY(bool hoverPreview READ hoverPreview WRITE setHoverPreview NOTIFY hoverPreviewChanged)
    Q_PROPERTY(bool isHoverPreviewImmutable READ isHoverPreviewImmutable CONSTANT)
    Q_PROPERTY(bool defaultHoverPreviewValue READ defaultHoverPreviewValue CONSTANT)
    /**
      Get Generate and show video preview when moving mouse over clip thumbnail.
    */
    static
    bool hoverPreview()
    {
      return self()->mHoverPreview;
    }

    /**
      Is Generate and show video preview when moving mouse over clip thumbnail. Immutable
    */
    static
    bool isHoverPreviewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "hoverPreview" ) );
    }

    /**
      Get Generate and show video preview when moving mouse over clip thumbnail. default value
    */
    static
    bool defaultHoverPreviewValue()
    {
        return defaultHoverPreviewValue_helper();
    }

    /**
      Set Count of Bins to open by default.
    */
    static
    void setBinsCount( int v )
    {
      if (v != self()->mBinsCount && !self()->isBinsCountImmutable()) {
        self()->mBinsCount = v;
        Q_EMIT self()->binsCountChanged();
      }
    }

    Q_PROPERTY(int binsCount READ binsCount WRITE setBinsCount NOTIFY binsCountChanged)
    Q_PROPERTY(bool isBinsCountImmutable READ isBinsCountImmutable CONSTANT)
    Q_PROPERTY(int defaultBinsCountValue READ defaultBinsCountValue CONSTANT)
    /**
      Get Count of Bins to open by default.
    */
    static
    int binsCount()
    {
      return self()->mBinsCount;
    }

    /**
      Is Count of Bins to open by default. Immutable
    */
    static
    bool isBinsCountImmutable()
    {
      return self()->isImmutable( QStringLiteral( "binsCount" ) );
    }

    /**
      Get Count of Bins to open by default. default value
    */
    static
    int defaultBinsCountValue()
    {
        return defaultBinsCountValue_helper();
    }

    /**
      Set Scene split detection threshold.
    */
    static
    void setScenesplitthreshold( int v )
    {
      if (v != self()->mScenesplitthreshold && !self()->isScenesplitthresholdImmutable()) {
        self()->mScenesplitthreshold = v;
        Q_EMIT self()->scenesplitthresholdChanged();
      }
    }

    Q_PROPERTY(int scenesplitthreshold READ scenesplitthreshold WRITE setScenesplitthreshold NOTIFY scenesplitthresholdChanged)
    Q_PROPERTY(bool isScenesplitthresholdImmutable READ isScenesplitthresholdImmutable CONSTANT)
    Q_PROPERTY(int defaultScenesplitthresholdValue READ defaultScenesplitthresholdValue CONSTANT)
    /**
      Get Scene split detection threshold.
    */
    static
    int scenesplitthreshold()
    {
      return self()->mScenesplitthreshold;
    }

    /**
      Is Scene split detection threshold. Immutable
    */
    static
    bool isScenesplitthresholdImmutable()
    {
      return self()->isImmutable( QStringLiteral( "scenesplitthreshold" ) );
    }

    /**
      Get Scene split detection threshold. default value
    */
    static
    int defaultScenesplitthresholdValue()
    {
        return defaultScenesplitthresholdValue_helper();
    }

    /**
      Set Add markers on Scene split.
    */
    static
    void setScenesplitmarkers( bool v )
    {
      if (v != self()->mScenesplitmarkers && !self()->isScenesplitmarkersImmutable()) {
        self()->mScenesplitmarkers = v;
        Q_EMIT self()->scenesplitmarkersChanged();
      }
    }

    Q_PROPERTY(bool scenesplitmarkers READ scenesplitmarkers WRITE setScenesplitmarkers NOTIFY scenesplitmarkersChanged)
    Q_PROPERTY(bool isScenesplitmarkersImmutable READ isScenesplitmarkersImmutable CONSTANT)
    Q_PROPERTY(bool defaultScenesplitmarkersValue READ defaultScenesplitmarkersValue CONSTANT)
    /**
      Get Add markers on Scene split.
    */
    static
    bool scenesplitmarkers()
    {
      return self()->mScenesplitmarkers;
    }

    /**
      Is Add markers on Scene split. Immutable
    */
    static
    bool isScenesplitmarkersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "scenesplitmarkers" ) );
    }

    /**
      Get Add markers on Scene split. default value
    */
    static
    bool defaultScenesplitmarkersValue()
    {
        return defaultScenesplitmarkersValue_helper();
    }

    /**
      Set Add range markers on Scene split.
    */
    static
    void setScenesplitrangemarkers( bool v )
    {
      if (v != self()->mScenesplitrangemarkers && !self()->isScenesplitrangemarkersImmutable()) {
        self()->mScenesplitrangemarkers = v;
        Q_EMIT self()->scenesplitrangemarkersChanged();
      }
    }

    Q_PROPERTY(bool scenesplitrangemarkers READ scenesplitrangemarkers WRITE setScenesplitrangemarkers NOTIFY scenesplitrangemarkersChanged)
    Q_PROPERTY(bool isScenesplitrangemarkersImmutable READ isScenesplitrangemarkersImmutable CONSTANT)
    Q_PROPERTY(bool defaultScenesplitrangemarkersValue READ defaultScenesplitrangemarkersValue CONSTANT)
    /**
      Get Add range markers on Scene split.
    */
    static
    bool scenesplitrangemarkers()
    {
      return self()->mScenesplitrangemarkers;
    }

    /**
      Is Add range markers on Scene split. Immutable
    */
    static
    bool isScenesplitrangemarkersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "scenesplitrangemarkers" ) );
    }

    /**
      Get Add range markers on Scene split. default value
    */
    static
    bool defaultScenesplitrangemarkersValue()
    {
        return defaultScenesplitrangemarkersValue_helper();
    }

    /**
      Set Add subclips on Scene split.
    */
    static
    void setScenesplitsubclips( bool v )
    {
      if (v != self()->mScenesplitsubclips && !self()->isScenesplitsubclipsImmutable()) {
        self()->mScenesplitsubclips = v;
        Q_EMIT self()->scenesplitsubclipsChanged();
      }
    }

    Q_PROPERTY(bool scenesplitsubclips READ scenesplitsubclips WRITE setScenesplitsubclips NOTIFY scenesplitsubclipsChanged)
    Q_PROPERTY(bool isScenesplitsubclipsImmutable READ isScenesplitsubclipsImmutable CONSTANT)
    Q_PROPERTY(bool defaultScenesplitsubclipsValue READ defaultScenesplitsubclipsValue CONSTANT)
    /**
      Get Add subclips on Scene split.
    */
    static
    bool scenesplitsubclips()
    {
      return self()->mScenesplitsubclips;
    }

    /**
      Is Add subclips on Scene split. Immutable
    */
    static
    bool isScenesplitsubclipsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "scenesplitsubclips" ) );
    }

    /**
      Get Add subclips on Scene split. default value
    */
    static
    bool defaultScenesplitsubclipsValue()
    {
        return defaultScenesplitsubclipsValue_helper();
    }

    /**
      Set Number of months to discard cache data.
    */
    static
    void setCleanCacheMonths( int v )
    {
      if (v != self()->mCleanCacheMonths && !self()->isCleanCacheMonthsImmutable()) {
        self()->mCleanCacheMonths = v;
        Q_EMIT self()->cleanCacheMonthsChanged();
      }
    }

    Q_PROPERTY(int cleanCacheMonths READ cleanCacheMonths WRITE setCleanCacheMonths NOTIFY cleanCacheMonthsChanged)
    Q_PROPERTY(bool isCleanCacheMonthsImmutable READ isCleanCacheMonthsImmutable CONSTANT)
    Q_PROPERTY(int defaultCleanCacheMonthsValue READ defaultCleanCacheMonthsValue CONSTANT)
    /**
      Get Number of months to discard cache data.
    */
    static
    int cleanCacheMonths()
    {
      return self()->mCleanCacheMonths;
    }

    /**
      Is Number of months to discard cache data. Immutable
    */
    static
    bool isCleanCacheMonthsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "cleanCacheMonths" ) );
    }

    /**
      Get Number of months to discard cache data. default value
    */
    static
    int defaultCleanCacheMonthsValue()
    {
        return defaultCleanCacheMonthsValue_helper();
    }

    /**
      Set Open last project on startup.
    */
    static
    void setOpenlastproject( bool v )
    {
      if (v != self()->mOpenlastproject && !self()->isOpenlastprojectImmutable()) {
        self()->mOpenlastproject = v;
        Q_EMIT self()->openlastprojectChanged();
      }
    }

    Q_PROPERTY(bool openlastproject READ openlastproject WRITE setOpenlastproject NOTIFY openlastprojectChanged)
    Q_PROPERTY(bool isOpenlastprojectImmutable READ isOpenlastprojectImmutable CONSTANT)
    Q_PROPERTY(bool defaultOpenlastprojectValue READ defaultOpenlastprojectValue CONSTANT)
    /**
      Get Open last project on startup.
    */
    static
    bool openlastproject()
    {
      return self()->mOpenlastproject;
    }

    /**
      Is Open last project on startup. Immutable
    */
    static
    bool isOpenlastprojectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "openlastproject" ) );
    }

    /**
      Get Open last project on startup. default value
    */
    static
    bool defaultOpenlastprojectValue()
    {
        return defaultOpenlastprojectValue_helper();
    }

    /**
      Set Enable autosave.
    */
    static
    void setCrashrecovery( bool v )
    {
      if (v != self()->mCrashrecovery && !self()->isCrashrecoveryImmutable()) {
        self()->mCrashrecovery = v;
        Q_EMIT self()->crashrecoveryChanged();
      }
    }

    Q_PROPERTY(bool crashrecovery READ crashrecovery WRITE setCrashrecovery NOTIFY crashrecoveryChanged)
    Q_PROPERTY(bool isCrashrecoveryImmutable READ isCrashrecoveryImmutable CONSTANT)
    Q_PROPERTY(bool defaultCrashrecoveryValue READ defaultCrashrecoveryValue CONSTANT)
    /**
      Get Enable autosave.
    */
    static
    bool crashrecovery()
    {
      return self()->mCrashrecovery;
    }

    /**
      Is Enable autosave. Immutable
    */
    static
    bool isCrashrecoveryImmutable()
    {
      return self()->isImmutable( QStringLiteral( "crashrecovery" ) );
    }

    /**
      Get Enable autosave. default value
    */
    static
    bool defaultCrashrecoveryValue()
    {
        return defaultCrashrecoveryValue_helper();
    }

    /**
      Set Autosave frequency in seconds.
    */
    static
    void setAutosave_time( int v )
    {
      if (v != self()->mAutosave_time && !self()->isAutosave_timeImmutable()) {
        self()->mAutosave_time = v;
        Q_EMIT self()->autosave_timeChanged();
      }
    }

    Q_PROPERTY(int autosave_time READ autosave_time WRITE setAutosave_time NOTIFY autosave_timeChanged)
    Q_PROPERTY(bool isAutosave_timeImmutable READ isAutosave_timeImmutable CONSTANT)
    Q_PROPERTY(int defaultAutosave_timeValue READ defaultAutosave_timeValue CONSTANT)
    /**
      Get Autosave frequency in seconds.
    */
    static
    int autosave_time()
    {
      return self()->mAutosave_time;
    }

    /**
      Is Autosave frequency in seconds. Immutable
    */
    static
    bool isAutosave_timeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autosave_time" ) );
    }

    /**
      Get Autosave frequency in seconds. default value
    */
    static
    int defaultAutosave_timeValue()
    {
        return defaultAutosave_timeValue_helper();
    }

    /**
      Set Autosave when we reach this count of undo entries.
    */
    static
    void setAutosave_ops( int v )
    {
      if (v != self()->mAutosave_ops && !self()->isAutosave_opsImmutable()) {
        self()->mAutosave_ops = v;
        Q_EMIT self()->autosave_opsChanged();
      }
    }

    Q_PROPERTY(int autosave_ops READ autosave_ops WRITE setAutosave_ops NOTIFY autosave_opsChanged)
    Q_PROPERTY(bool isAutosave_opsImmutable READ isAutosave_opsImmutable CONSTANT)
    Q_PROPERTY(int defaultAutosave_opsValue READ defaultAutosave_opsValue CONSTANT)
    /**
      Get Autosave when we reach this count of undo entries.
    */
    static
    int autosave_ops()
    {
      return self()->mAutosave_ops;
    }

    /**
      Is Autosave when we reach this count of undo entries. Immutable
    */
    static
    bool isAutosave_opsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autosave_ops" ) );
    }

    /**
      Get Autosave when we reach this count of undo entries. default value
    */
    static
    int defaultAutosave_opsValue()
    {
        return defaultAutosave_opsValue_helper();
    }

    /**
      Set Select tab position in dockwidgets.
    */
    static
    void setTabposition( int v )
    {
      if (v != self()->mTabposition && !self()->isTabpositionImmutable()) {
        self()->mTabposition = v;
        Q_EMIT self()->tabpositionChanged();
      }
    }

    Q_PROPERTY(int tabposition READ tabposition WRITE setTabposition NOTIFY tabpositionChanged)
    Q_PROPERTY(bool isTabpositionImmutable READ isTabpositionImmutable CONSTANT)
    Q_PROPERTY(int defaultTabpositionValue READ defaultTabpositionValue CONSTANT)
    /**
      Get Select tab position in dockwidgets.
    */
    static
    int tabposition()
    {
      return self()->mTabposition;
    }

    /**
      Is Select tab position in dockwidgets. Immutable
    */
    static
    bool isTabpositionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "tabposition" ) );
    }

    /**
      Get Select tab position in dockwidgets. default value
    */
    static
    int defaultTabpositionValue()
    {
        return defaultTabpositionValue_helper();
    }

    /**
      Set Check if document profile is same as first imported clip.
    */
    static
    void setCheckfirstprojectclip( bool v )
    {
      if (v != self()->mCheckfirstprojectclip && !self()->isCheckfirstprojectclipImmutable()) {
        self()->mCheckfirstprojectclip = v;
        Q_EMIT self()->checkfirstprojectclipChanged();
      }
    }

    Q_PROPERTY(bool checkfirstprojectclip READ checkfirstprojectclip WRITE setCheckfirstprojectclip NOTIFY checkfirstprojectclipChanged)
    Q_PROPERTY(bool isCheckfirstprojectclipImmutable READ isCheckfirstprojectclipImmutable CONSTANT)
    Q_PROPERTY(bool defaultCheckfirstprojectclipValue READ defaultCheckfirstprojectclipValue CONSTANT)
    /**
      Get Check if document profile is same as first imported clip.
    */
    static
    bool checkfirstprojectclip()
    {
      return self()->mCheckfirstprojectclip;
    }

    /**
      Is Check if document profile is same as first imported clip. Immutable
    */
    static
    bool isCheckfirstprojectclipImmutable()
    {
      return self()->isImmutable( QStringLiteral( "checkfirstprojectclip" ) );
    }

    /**
      Get Check if document profile is same as first imported clip. default value
    */
    static
    bool defaultCheckfirstprojectclipValue()
    {
        return defaultCheckfirstprojectclipValue_helper();
    }

    /**
      Set On clip import, add a Transform effect to keep the clip's original frame size.
    */
    static
    void setKeep_original_frame_size( bool v )
    {
      if (v != self()->mKeep_original_frame_size && !self()->isKeep_original_frame_sizeImmutable()) {
        self()->mKeep_original_frame_size = v;
        Q_EMIT self()->keep_original_frame_sizeChanged();
      }
    }

    Q_PROPERTY(bool keep_original_frame_size READ keep_original_frame_size WRITE setKeep_original_frame_size NOTIFY keep_original_frame_sizeChanged)
    Q_PROPERTY(bool isKeep_original_frame_sizeImmutable READ isKeep_original_frame_sizeImmutable CONSTANT)
    Q_PROPERTY(bool defaultKeep_original_frame_sizeValue READ defaultKeep_original_frame_sizeValue CONSTANT)
    /**
      Get On clip import, add a Transform effect to keep the clip's original frame size.
    */
    static
    bool keep_original_frame_size()
    {
      return self()->mKeep_original_frame_size;
    }

    /**
      Is On clip import, add a Transform effect to keep the clip's original frame size. Immutable
    */
    static
    bool isKeep_original_frame_sizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "keep_original_frame_size" ) );
    }

    /**
      Get On clip import, add a Transform effect to keep the clip's original frame size. default value
    */
    static
    bool defaultKeep_original_frame_sizeValue()
    {
        return defaultKeep_original_frame_sizeValue_helper();
    }

    /**
      Set Export image using source resolution.
    */
    static
    void setExportframe_usingsourceres( bool v )
    {
      if (v != self()->mExportframe_usingsourceres && !self()->isExportframe_usingsourceresImmutable()) {
        self()->mExportframe_usingsourceres = v;
        Q_EMIT self()->exportframe_usingsourceresChanged();
      }
    }

    Q_PROPERTY(bool exportframe_usingsourceres READ exportframe_usingsourceres WRITE setExportframe_usingsourceres NOTIFY exportframe_usingsourceresChanged)
    Q_PROPERTY(bool isExportframe_usingsourceresImmutable READ isExportframe_usingsourceresImmutable CONSTANT)
    Q_PROPERTY(bool defaultExportframe_usingsourceresValue READ defaultExportframe_usingsourceresValue CONSTANT)
    /**
      Get Export image using source resolution.
    */
    static
    bool exportframe_usingsourceres()
    {
      return self()->mExportframe_usingsourceres;
    }

    /**
      Is Export image using source resolution. Immutable
    */
    static
    bool isExportframe_usingsourceresImmutable()
    {
      return self()->isImmutable( QStringLiteral( "exportframe_usingsourceres" ) );
    }

    /**
      Get Export image using source resolution. default value
    */
    static
    bool defaultExportframe_usingsourceresValue()
    {
        return defaultExportframe_usingsourceresValue_helper();
    }

    /**
      Set Default color clip duration.
    */
    static
    void setColor_duration( const QString & v )
    {
      if (v != self()->mColor_duration && !self()->isColor_durationImmutable()) {
        self()->mColor_duration = v;
        Q_EMIT self()->color_durationChanged();
      }
    }

    Q_PROPERTY(QString color_duration READ color_duration WRITE setColor_duration NOTIFY color_durationChanged)
    Q_PROPERTY(bool isColor_durationImmutable READ isColor_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultColor_durationValue READ defaultColor_durationValue CONSTANT)
    /**
      Get Default color clip duration.
    */
    static
    QString color_duration()
    {
      return self()->mColor_duration;
    }

    /**
      Is Default color clip duration. Immutable
    */
    static
    bool isColor_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "color_duration" ) );
    }

    /**
      Get Default color clip duration. default value
    */
    static
    QString defaultColor_durationValue()
    {
        return defaultColor_durationValue_helper();
    }

    /**
      Set Default image clip duration.
    */
    static
    void setImage_duration( const QString & v )
    {
      if (v != self()->mImage_duration && !self()->isImage_durationImmutable()) {
        self()->mImage_duration = v;
        Q_EMIT self()->image_durationChanged();
      }
    }

    Q_PROPERTY(QString image_duration READ image_duration WRITE setImage_duration NOTIFY image_durationChanged)
    Q_PROPERTY(bool isImage_durationImmutable READ isImage_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultImage_durationValue READ defaultImage_durationValue CONSTANT)
    /**
      Get Default image clip duration.
    */
    static
    QString image_duration()
    {
      return self()->mImage_duration;
    }

    /**
      Is Default image clip duration. Immutable
    */
    static
    bool isImage_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "image_duration" ) );
    }

    /**
      Get Default image clip duration. default value
    */
    static
    QString defaultImage_durationValue()
    {
        return defaultImage_durationValue_helper();
    }

    /**
      Set Default image sequence frame duration.
    */
    static
    void setSequence_duration( const QString & v )
    {
      if (v != self()->mSequence_duration && !self()->isSequence_durationImmutable()) {
        self()->mSequence_duration = v;
        Q_EMIT self()->sequence_durationChanged();
      }
    }

    Q_PROPERTY(QString sequence_duration READ sequence_duration WRITE setSequence_duration NOTIFY sequence_durationChanged)
    Q_PROPERTY(bool isSequence_durationImmutable READ isSequence_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultSequence_durationValue READ defaultSequence_durationValue CONSTANT)
    /**
      Get Default image sequence frame duration.
    */
    static
    QString sequence_duration()
    {
      return self()->mSequence_duration;
    }

    /**
      Is Default image sequence frame duration. Immutable
    */
    static
    bool isSequence_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sequence_duration" ) );
    }

    /**
      Get Default image sequence frame duration. default value
    */
    static
    QString defaultSequence_durationValue()
    {
        return defaultSequence_durationValue_helper();
    }

    /**
      Set Default image sequence frame duration.
    */
    static
    void setFade_duration( const QString & v )
    {
      if (v != self()->mFade_duration && !self()->isFade_durationImmutable()) {
        self()->mFade_duration = v;
        Q_EMIT self()->fade_durationChanged();
      }
    }

    Q_PROPERTY(QString fade_duration READ fade_duration WRITE setFade_duration NOTIFY fade_durationChanged)
    Q_PROPERTY(bool isFade_durationImmutable READ isFade_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultFade_durationValue READ defaultFade_durationValue CONSTANT)
    /**
      Get Default image sequence frame duration.
    */
    static
    QString fade_duration()
    {
      return self()->mFade_duration;
    }

    /**
      Is Default image sequence frame duration. Immutable
    */
    static
    bool isFade_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fade_duration" ) );
    }

    /**
      Get Default image sequence frame duration. default value
    */
    static
    QString defaultFade_durationValue()
    {
        return defaultFade_durationValue_helper();
    }

    /**
      Set Default mix transition duration.
    */
    static
    void setMix_duration( const QString & v )
    {
      if (v != self()->mMix_duration && !self()->isMix_durationImmutable()) {
        self()->mMix_duration = v;
        Q_EMIT self()->mix_durationChanged();
      }
    }

    Q_PROPERTY(QString mix_duration READ mix_duration WRITE setMix_duration NOTIFY mix_durationChanged)
    Q_PROPERTY(bool isMix_durationImmutable READ isMix_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultMix_durationValue READ defaultMix_durationValue CONSTANT)
    /**
      Get Default mix transition duration.
    */
    static
    QString mix_duration()
    {
      return self()->mMix_duration;
    }

    /**
      Is Default mix transition duration. Immutable
    */
    static
    bool isMix_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mix_duration" ) );
    }

    /**
      Get Default mix transition duration. default value
    */
    static
    QString defaultMix_durationValue()
    {
        return defaultMix_durationValue_helper();
    }

    /**
      Set Default subtitle duration.
    */
    static
    void setSubtitle_duration( const QString & v )
    {
      if (v != self()->mSubtitle_duration && !self()->isSubtitle_durationImmutable()) {
        self()->mSubtitle_duration = v;
        Q_EMIT self()->subtitle_durationChanged();
      }
    }

    Q_PROPERTY(QString subtitle_duration READ subtitle_duration WRITE setSubtitle_duration NOTIFY subtitle_durationChanged)
    Q_PROPERTY(bool isSubtitle_durationImmutable READ isSubtitle_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultSubtitle_durationValue READ defaultSubtitle_durationValue CONSTANT)
    /**
      Get Default subtitle duration.
    */
    static
    QString subtitle_duration()
    {
      return self()->mSubtitle_duration;
    }

    /**
      Is Default subtitle duration. Immutable
    */
    static
    bool isSubtitle_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "subtitle_duration" ) );
    }

    /**
      Get Default subtitle duration. default value
    */
    static
    QString defaultSubtitle_durationValue()
    {
        return defaultSubtitle_durationValue_helper();
    }

    /**
      Set Automatically import image sequences.
    */
    static
    void setAutoimagesequence( bool v )
    {
      if (v != self()->mAutoimagesequence && !self()->isAutoimagesequenceImmutable()) {
        self()->mAutoimagesequence = v;
        Q_EMIT self()->autoimagesequenceChanged();
      }
    }

    Q_PROPERTY(bool autoimagesequence READ autoimagesequence WRITE setAutoimagesequence NOTIFY autoimagesequenceChanged)
    Q_PROPERTY(bool isAutoimagesequenceImmutable READ isAutoimagesequenceImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutoimagesequenceValue READ defaultAutoimagesequenceValue CONSTANT)
    /**
      Get Automatically import image sequences.
    */
    static
    bool autoimagesequence()
    {
      return self()->mAutoimagesequence;
    }

    /**
      Is Automatically import image sequences. Immutable
    */
    static
    bool isAutoimagesequenceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autoimagesequence" ) );
    }

    /**
      Get Automatically import image sequences. default value
    */
    static
    bool defaultAutoimagesequenceValue()
    {
        return defaultAutoimagesequenceValue_helper();
    }

    /**
      Set Ignore the subfolder structure (all clips in subfolders are added to the toplevel folder)
    */
    static
    void setIgnoresubdirstructure( bool v )
    {
      if (v != self()->mIgnoresubdirstructure && !self()->isIgnoresubdirstructureImmutable()) {
        self()->mIgnoresubdirstructure = v;
        Q_EMIT self()->ignoresubdirstructureChanged();
      }
    }

    Q_PROPERTY(bool ignoresubdirstructure READ ignoresubdirstructure WRITE setIgnoresubdirstructure NOTIFY ignoresubdirstructureChanged)
    Q_PROPERTY(bool isIgnoresubdirstructureImmutable READ isIgnoresubdirstructureImmutable CONSTANT)
    Q_PROPERTY(bool defaultIgnoresubdirstructureValue READ defaultIgnoresubdirstructureValue CONSTANT)
    /**
      Get Ignore the subfolder structure (all clips in subfolders are added to the toplevel folder)
    */
    static
    bool ignoresubdirstructure()
    {
      return self()->mIgnoresubdirstructure;
    }

    /**
      Is Ignore the subfolder structure (all clips in subfolders are added to the toplevel folder) Immutable
    */
    static
    bool isIgnoresubdirstructureImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ignoresubdirstructure" ) );
    }

    /**
      Get Ignore the subfolder structure (all clips in subfolders are added to the toplevel folder) default value
    */
    static
    bool defaultIgnoresubdirstructureValue()
    {
        return defaultIgnoresubdirstructureValue_helper();
    }

    /**
      Set Add a filter to disable default image scaling.
    */
    static
    void setDisableimagescaling( bool v )
    {
      if (v != self()->mDisableimagescaling && !self()->isDisableimagescalingImmutable()) {
        self()->mDisableimagescaling = v;
        Q_EMIT self()->disableimagescalingChanged();
      }
    }

    Q_PROPERTY(bool disableimagescaling READ disableimagescaling WRITE setDisableimagescaling NOTIFY disableimagescalingChanged)
    Q_PROPERTY(bool isDisableimagescalingImmutable READ isDisableimagescalingImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisableimagescalingValue READ defaultDisableimagescalingValue CONSTANT)
    /**
      Get Add a filter to disable default image scaling.
    */
    static
    bool disableimagescaling()
    {
      return self()->mDisableimagescaling;
    }

    /**
      Is Add a filter to disable default image scaling. Immutable
    */
    static
    bool isDisableimagescalingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "disableimagescaling" ) );
    }

    /**
      Get Add a filter to disable default image scaling. default value
    */
    static
    bool defaultDisableimagescalingValue()
    {
        return defaultDisableimagescalingValue_helper();
    }

    /**
      Set Automatically import all streams in multi streams clips.
    */
    static
    void setAutomultistreams( bool v )
    {
      if (v != self()->mAutomultistreams && !self()->isAutomultistreamsImmutable()) {
        self()->mAutomultistreams = v;
        Q_EMIT self()->automultistreamsChanged();
      }
    }

    Q_PROPERTY(bool automultistreams READ automultistreams WRITE setAutomultistreams NOTIFY automultistreamsChanged)
    Q_PROPERTY(bool isAutomultistreamsImmutable READ isAutomultistreamsImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutomultistreamsValue READ defaultAutomultistreamsValue CONSTANT)
    /**
      Get Automatically import all streams in multi streams clips.
    */
    static
    bool automultistreams()
    {
      return self()->mAutomultistreams;
    }

    /**
      Is Automatically import all streams in multi streams clips. Immutable
    */
    static
    bool isAutomultistreamsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "automultistreams" ) );
    }

    /**
      Get Automatically import all streams in multi streams clips. default value
    */
    static
    bool defaultAutomultistreamsValue()
    {
        return defaultAutomultistreamsValue_helper();
    }

    /**
      Set Get h264 metadata using exiftool.
    */
    static
    void setUse_exiftool( bool v )
    {
      if (v != self()->mUse_exiftool && !self()->isUse_exiftoolImmutable()) {
        self()->mUse_exiftool = v;
        Q_EMIT self()->use_exiftoolChanged();
      }
    }

    Q_PROPERTY(bool use_exiftool READ use_exiftool WRITE setUse_exiftool NOTIFY use_exiftoolChanged)
    Q_PROPERTY(bool isUse_exiftoolImmutable READ isUse_exiftoolImmutable CONSTANT)
    Q_PROPERTY(bool defaultUse_exiftoolValue READ defaultUse_exiftoolValue CONSTANT)
    /**
      Get Get h264 metadata using exiftool.
    */
    static
    bool use_exiftool()
    {
      return self()->mUse_exiftool;
    }

    /**
      Is Get h264 metadata using exiftool. Immutable
    */
    static
    bool isUse_exiftoolImmutable()
    {
      return self()->isImmutable( QStringLiteral( "use_exiftool" ) );
    }

    /**
      Get Get h264 metadata using exiftool. default value
    */
    static
    bool defaultUse_exiftoolValue()
    {
        return defaultUse_exiftoolValue_helper();
    }

    /**
      Set Get h264 metadata using exiftool.
    */
    static
    void setUse_magicLantern( bool v )
    {
      if (v != self()->mUse_magicLantern && !self()->isUse_magicLanternImmutable()) {
        self()->mUse_magicLantern = v;
        Q_EMIT self()->use_magicLanternChanged();
      }
    }

    Q_PROPERTY(bool use_magicLantern READ use_magicLantern WRITE setUse_magicLantern NOTIFY use_magicLanternChanged)
    Q_PROPERTY(bool isUse_magicLanternImmutable READ isUse_magicLanternImmutable CONSTANT)
    Q_PROPERTY(bool defaultUse_magicLanternValue READ defaultUse_magicLanternValue CONSTANT)
    /**
      Get Get h264 metadata using exiftool.
    */
    static
    bool use_magicLantern()
    {
      return self()->mUse_magicLantern;
    }

    /**
      Is Get h264 metadata using exiftool. Immutable
    */
    static
    bool isUse_magicLanternImmutable()
    {
      return self()->isImmutable( QStringLiteral( "use_magicLantern" ) );
    }

    /**
      Get Get h264 metadata using exiftool. default value
    */
    static
    bool defaultUse_magicLanternValue()
    {
        return defaultUse_magicLanternValue_helper();
    }

    /**
      Set Default title clip duration.
    */
    static
    void setTitle_duration( const QString & v )
    {
      if (v != self()->mTitle_duration && !self()->isTitle_durationImmutable()) {
        self()->mTitle_duration = v;
        Q_EMIT self()->title_durationChanged();
      }
    }

    Q_PROPERTY(QString title_duration READ title_duration WRITE setTitle_duration NOTIFY title_durationChanged)
    Q_PROPERTY(bool isTitle_durationImmutable READ isTitle_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultTitle_durationValue READ defaultTitle_durationValue CONSTANT)
    /**
      Get Default title clip duration.
    */
    static
    QString title_duration()
    {
      return self()->mTitle_duration;
    }

    /**
      Is Default title clip duration. Immutable
    */
    static
    bool isTitle_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "title_duration" ) );
    }

    /**
      Get Default title clip duration. default value
    */
    static
    QString defaultTitle_durationValue()
    {
        return defaultTitle_durationValue_helper();
    }

    /**
      Set Default transition duration.
    */
    static
    void setTransition_duration( const QString & v )
    {
      if (v != self()->mTransition_duration && !self()->isTransition_durationImmutable()) {
        self()->mTransition_duration = v;
        Q_EMIT self()->transition_durationChanged();
      }
    }

    Q_PROPERTY(QString transition_duration READ transition_duration WRITE setTransition_duration NOTIFY transition_durationChanged)
    Q_PROPERTY(bool isTransition_durationImmutable READ isTransition_durationImmutable CONSTANT)
    Q_PROPERTY(QString defaultTransition_durationValue READ defaultTransition_durationValue CONSTANT)
    /**
      Get Default transition duration.
    */
    static
    QString transition_duration()
    {
      return self()->mTransition_duration;
    }

    /**
      Is Default transition duration. Immutable
    */
    static
    bool isTransition_durationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transition_duration" ) );
    }

    /**
      Get Default transition duration. default value
    */
    static
    QString defaultTransition_durationValue()
    {
        return defaultTransition_durationValue_helper();
    }

    /**
      Set Only display include list assets.
    */
    static
    void setEnableAssetsIncludeList( bool v )
    {
      if (v != self()->mEnableAssetsIncludeList && !self()->isEnableAssetsIncludeListImmutable()) {
        self()->mEnableAssetsIncludeList = v;
        Q_EMIT self()->enableAssetsIncludeListChanged();
      }
    }

    Q_PROPERTY(bool enableAssetsIncludeList READ enableAssetsIncludeList WRITE setEnableAssetsIncludeList NOTIFY enableAssetsIncludeListChanged)
    Q_PROPERTY(bool isEnableAssetsIncludeListImmutable READ isEnableAssetsIncludeListImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableAssetsIncludeListValue READ defaultEnableAssetsIncludeListValue CONSTANT)
    /**
      Get Only display include list assets.
    */
    static
    bool enableAssetsIncludeList()
    {
      return self()->mEnableAssetsIncludeList;
    }

    /**
      Is Only display include list assets. Immutable
    */
    static
    bool isEnableAssetsIncludeListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableAssetsIncludeList" ) );
    }

    /**
      Get Only display include list assets. default value
    */
    static
    bool defaultEnableAssetsIncludeListValue()
    {
        return defaultEnableAssetsIncludeListValue_helper();
    }

    /**
      Set Splitter data for height of the info box.
    */
    static
    void setEffectsInfoHeight( const QString & v )
    {
      if (v != self()->mEffectsInfoHeight && !self()->isEffectsInfoHeightImmutable()) {
        self()->mEffectsInfoHeight = v;
        Q_EMIT self()->effectsInfoHeightChanged();
      }
    }

    Q_PROPERTY(QString effectsInfoHeight READ effectsInfoHeight WRITE setEffectsInfoHeight NOTIFY effectsInfoHeightChanged)
    Q_PROPERTY(bool isEffectsInfoHeightImmutable READ isEffectsInfoHeightImmutable CONSTANT)
    /**
      Get Splitter data for height of the info box.
    */
    static
    QString effectsInfoHeight()
    {
      return self()->mEffectsInfoHeight;
    }

    /**
      Is Splitter data for height of the info box. Immutable
    */
    static
    bool isEffectsInfoHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "effectsInfoHeight" ) );
    }

    /**
      Set Shall we show the info box.
    */
    static
    void setShowEffectsInfo( bool v )
    {
      if (v != self()->mShowEffectsInfo && !self()->isShowEffectsInfoImmutable()) {
        self()->mShowEffectsInfo = v;
        Q_EMIT self()->showEffectsInfoChanged();
      }
    }

    Q_PROPERTY(bool showEffectsInfo READ showEffectsInfo WRITE setShowEffectsInfo NOTIFY showEffectsInfoChanged)
    Q_PROPERTY(bool isShowEffectsInfoImmutable READ isShowEffectsInfoImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowEffectsInfoValue READ defaultShowEffectsInfoValue CONSTANT)
    /**
      Get Shall we show the info box.
    */
    static
    bool showEffectsInfo()
    {
      return self()->mShowEffectsInfo;
    }

    /**
      Is Shall we show the info box. Immutable
    */
    static
    bool isShowEffectsInfoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showEffectsInfo" ) );
    }

    /**
      Get Shall we show the info box. default value
    */
    static
    bool defaultShowEffectsInfoValue()
    {
        return defaultShowEffectsInfoValue_helper();
    }

    /**
      Set Splitter data for height of the info box.
    */
    static
    void setTransitionsInfoHeight( const QString & v )
    {
      if (v != self()->mTransitionsInfoHeight && !self()->isTransitionsInfoHeightImmutable()) {
        self()->mTransitionsInfoHeight = v;
        Q_EMIT self()->transitionsInfoHeightChanged();
      }
    }

    Q_PROPERTY(QString transitionsInfoHeight READ transitionsInfoHeight WRITE setTransitionsInfoHeight NOTIFY transitionsInfoHeightChanged)
    Q_PROPERTY(bool isTransitionsInfoHeightImmutable READ isTransitionsInfoHeightImmutable CONSTANT)
    /**
      Get Splitter data for height of the info box.
    */
    static
    QString transitionsInfoHeight()
    {
      return self()->mTransitionsInfoHeight;
    }

    /**
      Is Splitter data for height of the info box. Immutable
    */
    static
    bool isTransitionsInfoHeightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transitionsInfoHeight" ) );
    }

    /**
      Set Shall we show the info box.
    */
    static
    void setShowTransitionsInfo( bool v )
    {
      if (v != self()->mShowTransitionsInfo && !self()->isShowTransitionsInfoImmutable()) {
        self()->mShowTransitionsInfo = v;
        Q_EMIT self()->showTransitionsInfoChanged();
      }
    }

    Q_PROPERTY(bool showTransitionsInfo READ showTransitionsInfo WRITE setShowTransitionsInfo NOTIFY showTransitionsInfoChanged)
    Q_PROPERTY(bool isShowTransitionsInfoImmutable READ isShowTransitionsInfoImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowTransitionsInfoValue READ defaultShowTransitionsInfoValue CONSTANT)
    /**
      Get Shall we show the info box.
    */
    static
    bool showTransitionsInfo()
    {
      return self()->mShowTransitionsInfo;
    }

    /**
      Is Shall we show the info box. Immutable
    */
    static
    bool isShowTransitionsInfoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showTransitionsInfo" ) );
    }

    /**
      Get Shall we show the info box. default value
    */
    static
    bool defaultShowTransitionsInfoValue()
    {
        return defaultShowTransitionsInfoValue_helper();
    }

    /**
      Set Disable parameters when the effect is disabled.
    */
    static
    void setDisable_effect_parameters( bool v )
    {
      if (v != self()->mDisable_effect_parameters && !self()->isDisable_effect_parametersImmutable()) {
        self()->mDisable_effect_parameters = v;
        Q_EMIT self()->disable_effect_parametersChanged();
      }
    }

    Q_PROPERTY(bool disable_effect_parameters READ disable_effect_parameters WRITE setDisable_effect_parameters NOTIFY disable_effect_parametersChanged)
    Q_PROPERTY(bool isDisable_effect_parametersImmutable READ isDisable_effect_parametersImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisable_effect_parametersValue READ defaultDisable_effect_parametersValue CONSTANT)
    /**
      Get Disable parameters when the effect is disabled.
    */
    static
    bool disable_effect_parameters()
    {
      return self()->mDisable_effect_parameters;
    }

    /**
      Is Disable parameters when the effect is disabled. Immutable
    */
    static
    bool isDisable_effect_parametersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "disable_effect_parameters" ) );
    }

    /**
      Get Disable parameters when the effect is disabled. default value
    */
    static
    bool defaultDisable_effect_parametersValue()
    {
        return defaultDisable_effect_parametersValue_helper();
    }

    /**
      Set Default fps filter for project profile.
    */
    static
    void setProfile_fps_filter( const QString & v )
    {
      if (v != self()->mProfile_fps_filter && !self()->isProfile_fps_filterImmutable()) {
        self()->mProfile_fps_filter = v;
        Q_EMIT self()->profile_fps_filterChanged();
      }
    }

    Q_PROPERTY(QString profile_fps_filter READ profile_fps_filter WRITE setProfile_fps_filter NOTIFY profile_fps_filterChanged)
    Q_PROPERTY(bool isProfile_fps_filterImmutable READ isProfile_fps_filterImmutable CONSTANT)
    /**
      Get Default fps filter for project profile.
    */
    static
    QString profile_fps_filter()
    {
      return self()->mProfile_fps_filter;
    }

    /**
      Is Default fps filter for project profile. Immutable
    */
    static
    bool isProfile_fps_filterImmutable()
    {
      return self()->isImmutable( QStringLiteral( "profile_fps_filter" ) );
    }

    /**
      Set Default scanning filter for project profile.
    */
    static
    void setProfile_scanning_filter( const QString & v )
    {
      if (v != self()->mProfile_scanning_filter && !self()->isProfile_scanning_filterImmutable()) {
        self()->mProfile_scanning_filter = v;
        Q_EMIT self()->profile_scanning_filterChanged();
      }
    }

    Q_PROPERTY(QString profile_scanning_filter READ profile_scanning_filter WRITE setProfile_scanning_filter NOTIFY profile_scanning_filterChanged)
    Q_PROPERTY(bool isProfile_scanning_filterImmutable READ isProfile_scanning_filterImmutable CONSTANT)
    /**
      Get Default scanning filter for project profile.
    */
    static
    QString profile_scanning_filter()
    {
      return self()->mProfile_scanning_filter;
    }

    /**
      Is Default scanning filter for project profile. Immutable
    */
    static
    bool isProfile_scanning_filterImmutable()
    {
      return self()->isImmutable( QStringLiteral( "profile_scanning_filter" ) );
    }

    /**
      Set Default OpenGL backend (Qt::AAUseOpenGLES).
    */
    static
    void setOpengl_backend( int v )
    {
      if (v != self()->mOpengl_backend && !self()->isOpengl_backendImmutable()) {
        self()->mOpengl_backend = v;
        Q_EMIT self()->opengl_backendChanged();
      }
    }

    Q_PROPERTY(int opengl_backend READ opengl_backend WRITE setOpengl_backend NOTIFY opengl_backendChanged)
    Q_PROPERTY(bool isOpengl_backendImmutable READ isOpengl_backendImmutable CONSTANT)
    Q_PROPERTY(int defaultOpengl_backendValue READ defaultOpengl_backendValue CONSTANT)
    /**
      Get Default OpenGL backend (Qt::AAUseOpenGLES).
    */
    static
    int opengl_backend()
    {
      return self()->mOpengl_backend;
    }

    /**
      Is Default OpenGL backend (Qt::AAUseOpenGLES). Immutable
    */
    static
    bool isOpengl_backendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "opengl_backend" ) );
    }

    /**
      Get Default OpenGL backend (Qt::AAUseOpenGLES). default value
    */
    static
    int defaultOpengl_backendValue()
    {
        return defaultOpengl_backendValue_helper();
    }

    /**
      Set Default number of video tracks.
    */
    static
    void setVideotracks( int v )
    {
      if (v != self()->mVideotracks && !self()->isVideotracksImmutable()) {
        self()->mVideotracks = v;
        Q_EMIT self()->videotracksChanged();
      }
    }

    Q_PROPERTY(int videotracks READ videotracks WRITE setVideotracks NOTIFY videotracksChanged)
    Q_PROPERTY(bool isVideotracksImmutable READ isVideotracksImmutable CONSTANT)
    Q_PROPERTY(int defaultVideotracksValue READ defaultVideotracksValue CONSTANT)
    /**
      Get Default number of video tracks.
    */
    static
    int videotracks()
    {
      return self()->mVideotracks;
    }

    /**
      Is Default number of video tracks. Immutable
    */
    static
    bool isVideotracksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "videotracks" ) );
    }

    /**
      Get Default number of video tracks. default value
    */
    static
    int defaultVideotracksValue()
    {
        return defaultVideotracksValue_helper();
    }

    /**
      Set Default number of audio tracks.
    */
    static
    void setAudiotracks( int v )
    {
      if (v != self()->mAudiotracks && !self()->isAudiotracksImmutable()) {
        self()->mAudiotracks = v;
        Q_EMIT self()->audiotracksChanged();
      }
    }

    Q_PROPERTY(int audiotracks READ audiotracks WRITE setAudiotracks NOTIFY audiotracksChanged)
    Q_PROPERTY(bool isAudiotracksImmutable READ isAudiotracksImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiotracksValue READ defaultAudiotracksValue CONSTANT)
    /**
      Get Default number of audio tracks.
    */
    static
    int audiotracks()
    {
      return self()->mAudiotracks;
    }

    /**
      Is Default number of audio tracks. Immutable
    */
    static
    bool isAudiotracksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiotracks" ) );
    }

    /**
      Get Default number of audio tracks. default value
    */
    static
    int defaultAudiotracksValue()
    {
        return defaultAudiotracksValue_helper();
    }

    /**
      Set Default number of audio channels per track.
    */
    static
    void setAudio_channels( int v )
    {
      if (v != self()->mAudio_channels && !self()->isAudio_channelsImmutable()) {
        self()->mAudio_channels = v;
        Q_EMIT self()->audio_channelsChanged();
      }
    }

    Q_PROPERTY(int audio_channels READ audio_channels WRITE setAudio_channels NOTIFY audio_channelsChanged)
    Q_PROPERTY(bool isAudio_channelsImmutable READ isAudio_channelsImmutable CONSTANT)
    Q_PROPERTY(int defaultAudio_channelsValue READ defaultAudio_channelsValue CONSTANT)
    /**
      Get Default number of audio channels per track.
    */
    static
    int audio_channels()
    {
      return self()->mAudio_channels;
    }

    /**
      Is Default number of audio channels per track. Immutable
    */
    static
    bool isAudio_channelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audio_channels" ) );
    }

    /**
      Get Default number of audio channels per track. default value
    */
    static
    int defaultAudio_channelsValue()
    {
        return defaultAudio_channelsValue_helper();
    }

    /**
      Set Enable proxy clips.
    */
    static
    void setEnableproxy( bool v )
    {
      if (v != self()->mEnableproxy && !self()->isEnableproxyImmutable()) {
        self()->mEnableproxy = v;
        Q_EMIT self()->enableproxyChanged();
      }
    }

    Q_PROPERTY(bool enableproxy READ enableproxy WRITE setEnableproxy NOTIFY enableproxyChanged)
    Q_PROPERTY(bool isEnableproxyImmutable READ isEnableproxyImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableproxyValue READ defaultEnableproxyValue CONSTANT)
    /**
      Get Enable proxy clips.
    */
    static
    bool enableproxy()
    {
      return self()->mEnableproxy;
    }

    /**
      Is Enable proxy clips. Immutable
    */
    static
    bool isEnableproxyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableproxy" ) );
    }

    /**
      Get Enable proxy clips. default value
    */
    static
    bool defaultEnableproxyValue()
    {
        return defaultEnableproxyValue_helper();
    }

    /**
      Set Enable proxy clips.
    */
    static
    void setExternalproxy( bool v )
    {
      if (v != self()->mExternalproxy && !self()->isExternalproxyImmutable()) {
        self()->mExternalproxy = v;
        Q_EMIT self()->externalproxyChanged();
      }
    }

    Q_PROPERTY(bool externalproxy READ externalproxy WRITE setExternalproxy NOTIFY externalproxyChanged)
    Q_PROPERTY(bool isExternalproxyImmutable READ isExternalproxyImmutable CONSTANT)
    Q_PROPERTY(bool defaultExternalproxyValue READ defaultExternalproxyValue CONSTANT)
    /**
      Get Enable proxy clips.
    */
    static
    bool externalproxy()
    {
      return self()->mExternalproxy;
    }

    /**
      Is Enable proxy clips. Immutable
    */
    static
    bool isExternalproxyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "externalproxy" ) );
    }

    /**
      Get Enable proxy clips. default value
    */
    static
    bool defaultExternalproxyValue()
    {
        return defaultExternalproxyValue_helper();
    }

    /**
      Set Auto generate proxy for new clips.
    */
    static
    void setGenerateproxy( bool v )
    {
      if (v != self()->mGenerateproxy && !self()->isGenerateproxyImmutable()) {
        self()->mGenerateproxy = v;
        Q_EMIT self()->generateproxyChanged();
      }
    }

    Q_PROPERTY(bool generateproxy READ generateproxy WRITE setGenerateproxy NOTIFY generateproxyChanged)
    Q_PROPERTY(bool isGenerateproxyImmutable READ isGenerateproxyImmutable CONSTANT)
    Q_PROPERTY(bool defaultGenerateproxyValue READ defaultGenerateproxyValue CONSTANT)
    /**
      Get Auto generate proxy for new clips.
    */
    static
    bool generateproxy()
    {
      return self()->mGenerateproxy;
    }

    /**
      Is Auto generate proxy for new clips. Immutable
    */
    static
    bool isGenerateproxyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "generateproxy" ) );
    }

    /**
      Get Auto generate proxy for new clips. default value
    */
    static
    bool defaultGenerateproxyValue()
    {
        return defaultGenerateproxyValue_helper();
    }

    /**
      Set index for the external proxy clips combo.
    */
    static
    void setExternal_proxy_profile( int v )
    {
      if (v != self()->mExternal_proxy_profile && !self()->isExternal_proxy_profileImmutable()) {
        self()->mExternal_proxy_profile = v;
        Q_EMIT self()->external_proxy_profileChanged();
      }
    }

    Q_PROPERTY(int external_proxy_profile READ external_proxy_profile WRITE setExternal_proxy_profile NOTIFY external_proxy_profileChanged)
    Q_PROPERTY(bool isExternal_proxy_profileImmutable READ isExternal_proxy_profileImmutable CONSTANT)
    /**
      Get index for the external proxy clips combo.
    */
    static
    int external_proxy_profile()
    {
      return self()->mExternal_proxy_profile;
    }

    /**
      Is index for the external proxy clips combo. Immutable
    */
    static
    bool isExternal_proxy_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "external_proxy_profile" ) );
    }

    /**
      Set Pattern to find external proxy clips.
    */
    static
    void setExternalProxyProfile( const QString & v )
    {
      if (v != self()->mExternalProxyProfile && !self()->isExternalProxyProfileImmutable()) {
        self()->mExternalProxyProfile = v;
        Q_EMIT self()->externalProxyProfileChanged();
      }
    }

    Q_PROPERTY(QString externalProxyProfile READ externalProxyProfile WRITE setExternalProxyProfile NOTIFY externalProxyProfileChanged)
    Q_PROPERTY(bool isExternalProxyProfileImmutable READ isExternalProxyProfileImmutable CONSTANT)
    /**
      Get Pattern to find external proxy clips.
    */
    static
    QString externalProxyProfile()
    {
      return self()->mExternalProxyProfile;
    }

    /**
      Is Pattern to find external proxy clips. Immutable
    */
    static
    bool isExternalProxyProfileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "externalProxyProfile" ) );
    }

    /**
      Set Auto generate proxy for new image clips.
    */
    static
    void setGenerateimageproxy( bool v )
    {
      if (v != self()->mGenerateimageproxy && !self()->isGenerateimageproxyImmutable()) {
        self()->mGenerateimageproxy = v;
        Q_EMIT self()->generateimageproxyChanged();
      }
    }

    Q_PROPERTY(bool generateimageproxy READ generateimageproxy WRITE setGenerateimageproxy NOTIFY generateimageproxyChanged)
    Q_PROPERTY(bool isGenerateimageproxyImmutable READ isGenerateimageproxyImmutable CONSTANT)
    Q_PROPERTY(bool defaultGenerateimageproxyValue READ defaultGenerateimageproxyValue CONSTANT)
    /**
      Get Auto generate proxy for new image clips.
    */
    static
    bool generateimageproxy()
    {
      return self()->mGenerateimageproxy;
    }

    /**
      Is Auto generate proxy for new image clips. Immutable
    */
    static
    bool isGenerateimageproxyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "generateimageproxy" ) );
    }

    /**
      Get Auto generate proxy for new image clips. default value
    */
    static
    bool defaultGenerateimageproxyValue()
    {
        return defaultGenerateimageproxyValue_helper();
    }

    /**
      Set Minimum source size for proxy creation.
    */
    static
    void setProxyminsize( int v )
    {
      if (v != self()->mProxyminsize && !self()->isProxyminsizeImmutable()) {
        self()->mProxyminsize = v;
        Q_EMIT self()->proxyminsizeChanged();
      }
    }

    Q_PROPERTY(int proxyminsize READ proxyminsize WRITE setProxyminsize NOTIFY proxyminsizeChanged)
    Q_PROPERTY(bool isProxyminsizeImmutable READ isProxyminsizeImmutable CONSTANT)
    Q_PROPERTY(int defaultProxyminsizeValue READ defaultProxyminsizeValue CONSTANT)
    /**
      Get Minimum source size for proxy creation.
    */
    static
    int proxyminsize()
    {
      return self()->mProxyminsize;
    }

    /**
      Is Minimum source size for proxy creation. Immutable
    */
    static
    bool isProxyminsizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyminsize" ) );
    }

    /**
      Get Minimum source size for proxy creation. default value
    */
    static
    int defaultProxyminsizeValue()
    {
        return defaultProxyminsizeValue_helper();
    }

    /**
      Set Minimum source size for proxy creation.
    */
    static
    void setProxyimageminsize( int v )
    {
      if (v != self()->mProxyimageminsize && !self()->isProxyimageminsizeImmutable()) {
        self()->mProxyimageminsize = v;
        Q_EMIT self()->proxyimageminsizeChanged();
      }
    }

    Q_PROPERTY(int proxyimageminsize READ proxyimageminsize WRITE setProxyimageminsize NOTIFY proxyimageminsizeChanged)
    Q_PROPERTY(bool isProxyimageminsizeImmutable READ isProxyimageminsizeImmutable CONSTANT)
    Q_PROPERTY(int defaultProxyimageminsizeValue READ defaultProxyimageminsizeValue CONSTANT)
    /**
      Get Minimum source size for proxy creation.
    */
    static
    int proxyimageminsize()
    {
      return self()->mProxyimageminsize;
    }

    /**
      Is Minimum source size for proxy creation. Immutable
    */
    static
    bool isProxyimageminsizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyimageminsize" ) );
    }

    /**
      Get Minimum source size for proxy creation. default value
    */
    static
    int defaultProxyimageminsizeValue()
    {
        return defaultProxyimageminsizeValue_helper();
    }

    /**
      Set Rescale size for image proxy creation.
    */
    static
    void setProxyimagesize( int v )
    {
      if (v != self()->mProxyimagesize && !self()->isProxyimagesizeImmutable()) {
        self()->mProxyimagesize = v;
        Q_EMIT self()->proxyimagesizeChanged();
      }
    }

    Q_PROPERTY(int proxyimagesize READ proxyimagesize WRITE setProxyimagesize NOTIFY proxyimagesizeChanged)
    Q_PROPERTY(bool isProxyimagesizeImmutable READ isProxyimagesizeImmutable CONSTANT)
    Q_PROPERTY(int defaultProxyimagesizeValue READ defaultProxyimagesizeValue CONSTANT)
    /**
      Get Rescale size for image proxy creation.
    */
    static
    int proxyimagesize()
    {
      return self()->mProxyimagesize;
    }

    /**
      Is Rescale size for image proxy creation. Immutable
    */
    static
    bool isProxyimagesizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyimagesize" ) );
    }

    /**
      Get Rescale size for image proxy creation. default value
    */
    static
    int defaultProxyimagesizeValue()
    {
        return defaultProxyimagesizeValue_helper();
    }

    /**
      Set Default frame width for proxy clips.
    */
    static
    void setProxyscale( int v )
    {
      if (v != self()->mProxyscale && !self()->isProxyscaleImmutable()) {
        self()->mProxyscale = v;
        Q_EMIT self()->proxyscaleChanged();
      }
    }

    Q_PROPERTY(int proxyscale READ proxyscale WRITE setProxyscale NOTIFY proxyscaleChanged)
    Q_PROPERTY(bool isProxyscaleImmutable READ isProxyscaleImmutable CONSTANT)
    Q_PROPERTY(int defaultProxyscaleValue READ defaultProxyscaleValue CONSTANT)
    /**
      Get Default frame width for proxy clips.
    */
    static
    int proxyscale()
    {
      return self()->mProxyscale;
    }

    /**
      Is Default frame width for proxy clips. Immutable
    */
    static
    bool isProxyscaleImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyscale" ) );
    }

    /**
      Get Default frame width for proxy clips. default value
    */
    static
    int defaultProxyscaleValue()
    {
        return defaultProxyscaleValue_helper();
    }

    /**
      Set Should the lower video track also be composited.
    */
    static
    void setEnforceLowerTrackCompositing( bool v )
    {
      if (v != self()->mEnforceLowerTrackCompositing && !self()->isEnforceLowerTrackCompositingImmutable()) {
        self()->mEnforceLowerTrackCompositing = v;
        Q_EMIT self()->enforceLowerTrackCompositingChanged();
      }
    }

    Q_PROPERTY(bool enforceLowerTrackCompositing READ enforceLowerTrackCompositing WRITE setEnforceLowerTrackCompositing NOTIFY enforceLowerTrackCompositingChanged)
    Q_PROPERTY(bool isEnforceLowerTrackCompositingImmutable READ isEnforceLowerTrackCompositingImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnforceLowerTrackCompositingValue READ defaultEnforceLowerTrackCompositingValue CONSTANT)
    /**
      Get Should the lower video track also be composited.
    */
    static
    bool enforceLowerTrackCompositing()
    {
      return self()->mEnforceLowerTrackCompositing;
    }

    /**
      Is Should the lower video track also be composited. Immutable
    */
    static
    bool isEnforceLowerTrackCompositingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enforceLowerTrackCompositing" ) );
    }

    /**
      Get Should the lower video track also be composited. default value
    */
    static
    bool defaultEnforceLowerTrackCompositingValue()
    {
        return defaultEnforceLowerTrackCompositingValue_helper();
    }

    /**
      Set File extension for proxy clips.
    */
    static
    void setProxyextension( const QString & v )
    {
      if (v != self()->mProxyextension && !self()->isProxyextensionImmutable()) {
        self()->mProxyextension = v;
        Q_EMIT self()->proxyextensionChanged();
      }
    }

    Q_PROPERTY(QString proxyextension READ proxyextension WRITE setProxyextension NOTIFY proxyextensionChanged)
    Q_PROPERTY(bool isProxyextensionImmutable READ isProxyextensionImmutable CONSTANT)
    /**
      Get File extension for proxy clips.
    */
    static
    QString proxyextension()
    {
      return self()->mProxyextension;
    }

    /**
      Is File extension for proxy clips. Immutable
    */
    static
    bool isProxyextensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyextension" ) );
    }

    /**
      Set Proxy clips transcoding parameters.
    */
    static
    void setProxyparams( const QString & v )
    {
      if (v != self()->mProxyparams && !self()->isProxyparamsImmutable()) {
        self()->mProxyparams = v;
        Q_EMIT self()->proxyparamsChanged();
      }
    }

    Q_PROPERTY(QString proxyparams READ proxyparams WRITE setProxyparams NOTIFY proxyparamsChanged)
    Q_PROPERTY(bool isProxyparamsImmutable READ isProxyparamsImmutable CONSTANT)
    /**
      Get Proxy clips transcoding parameters.
    */
    static
    QString proxyparams()
    {
      return self()->mProxyparams;
    }

    /**
      Is Proxy clips transcoding parameters. Immutable
    */
    static
    bool isProxyparamsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyparams" ) );
    }

    /**
      Set default proxy encoding profile.
    */
    static
    void setProxy_profile( int v )
    {
      if (v != self()->mProxy_profile && !self()->isProxy_profileImmutable()) {
        self()->mProxy_profile = v;
        Q_EMIT self()->proxy_profileChanged();
      }
    }

    Q_PROPERTY(int proxy_profile READ proxy_profile WRITE setProxy_profile NOTIFY proxy_profileChanged)
    Q_PROPERTY(bool isProxy_profileImmutable READ isProxy_profileImmutable CONSTANT)
    Q_PROPERTY(int defaultProxy_profileValue READ defaultProxy_profileValue CONSTANT)
    /**
      Get default proxy encoding profile.
    */
    static
    int proxy_profile()
    {
      return self()->mProxy_profile;
    }

    /**
      Is default proxy encoding profile. Immutable
    */
    static
    bool isProxy_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxy_profile" ) );
    }

    /**
      Get default proxy encoding profile. default value
    */
    static
    int defaultProxy_profileValue()
    {
        return defaultProxy_profileValue_helper();
    }

    /**
      Set File extension for proxy clips.
    */
    static
    void setProxyalphaextension( const QString & v )
    {
      if (v != self()->mProxyalphaextension && !self()->isProxyalphaextensionImmutable()) {
        self()->mProxyalphaextension = v;
        Q_EMIT self()->proxyalphaextensionChanged();
      }
    }

    Q_PROPERTY(QString proxyalphaextension READ proxyalphaextension WRITE setProxyalphaextension NOTIFY proxyalphaextensionChanged)
    Q_PROPERTY(bool isProxyalphaextensionImmutable READ isProxyalphaextensionImmutable CONSTANT)
    /**
      Get File extension for proxy clips.
    */
    static
    QString proxyalphaextension()
    {
      return self()->mProxyalphaextension;
    }

    /**
      Is File extension for proxy clips. Immutable
    */
    static
    bool isProxyalphaextensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyalphaextension" ) );
    }

    /**
      Set Proxy clips transcoding parameters.
    */
    static
    void setProxyalphaparams( const QString & v )
    {
      if (v != self()->mProxyalphaparams && !self()->isProxyalphaparamsImmutable()) {
        self()->mProxyalphaparams = v;
        Q_EMIT self()->proxyalphaparamsChanged();
      }
    }

    Q_PROPERTY(QString proxyalphaparams READ proxyalphaparams WRITE setProxyalphaparams NOTIFY proxyalphaparamsChanged)
    Q_PROPERTY(bool isProxyalphaparamsImmutable READ isProxyalphaparamsImmutable CONSTANT)
    /**
      Get Proxy clips transcoding parameters.
    */
    static
    QString proxyalphaparams()
    {
      return self()->mProxyalphaparams;
    }

    /**
      Is Proxy clips transcoding parameters. Immutable
    */
    static
    bool isProxyalphaparamsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxyalphaparams" ) );
    }

    /**
      Set default proxy encoding profile.
    */
    static
    void setAlpha_profile( int v )
    {
      if (v != self()->mAlpha_profile && !self()->isAlpha_profileImmutable()) {
        self()->mAlpha_profile = v;
        Q_EMIT self()->alpha_profileChanged();
      }
    }

    Q_PROPERTY(int alpha_profile READ alpha_profile WRITE setAlpha_profile NOTIFY alpha_profileChanged)
    Q_PROPERTY(bool isAlpha_profileImmutable READ isAlpha_profileImmutable CONSTANT)
    Q_PROPERTY(int defaultAlpha_profileValue READ defaultAlpha_profileValue CONSTANT)
    /**
      Get default proxy encoding profile.
    */
    static
    int alpha_profile()
    {
      return self()->mAlpha_profile;
    }

    /**
      Is default proxy encoding profile. Immutable
    */
    static
    bool isAlpha_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "alpha_profile" ) );
    }

    /**
      Get default proxy encoding profile. default value
    */
    static
    int defaultAlpha_profileValue()
    {
        return defaultAlpha_profileValue_helper();
    }

    /**
      Set Name of the default transcoding profile for edit friendly convert.
    */
    static
    void setTranscodeFriendly( const QString & v )
    {
      if (v != self()->mTranscodeFriendly && !self()->isTranscodeFriendlyImmutable()) {
        self()->mTranscodeFriendly = v;
        Q_EMIT self()->transcodeFriendlyChanged();
      }
    }

    Q_PROPERTY(QString transcodeFriendly READ transcodeFriendly WRITE setTranscodeFriendly NOTIFY transcodeFriendlyChanged)
    Q_PROPERTY(bool isTranscodeFriendlyImmutable READ isTranscodeFriendlyImmutable CONSTANT)
    /**
      Get Name of the default transcoding profile for edit friendly convert.
    */
    static
    QString transcodeFriendly()
    {
      return self()->mTranscodeFriendly;
    }

    /**
      Is Name of the default transcoding profile for edit friendly convert. Immutable
    */
    static
    bool isTranscodeFriendlyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transcodeFriendly" ) );
    }

    /**
      Set When transcoding a clip, replace it by the transcoding version in project.
    */
    static
    void setTranscodingReplace( bool v )
    {
      if (v != self()->mTranscodingReplace && !self()->isTranscodingReplaceImmutable()) {
        self()->mTranscodingReplace = v;
        Q_EMIT self()->transcodingReplaceChanged();
      }
    }

    Q_PROPERTY(bool transcodingReplace READ transcodingReplace WRITE setTranscodingReplace NOTIFY transcodingReplaceChanged)
    Q_PROPERTY(bool isTranscodingReplaceImmutable READ isTranscodingReplaceImmutable CONSTANT)
    Q_PROPERTY(bool defaultTranscodingReplaceValue READ defaultTranscodingReplaceValue CONSTANT)
    /**
      Get When transcoding a clip, replace it by the transcoding version in project.
    */
    static
    bool transcodingReplace()
    {
      return self()->mTranscodingReplace;
    }

    /**
      Is When transcoding a clip, replace it by the transcoding version in project. Immutable
    */
    static
    bool isTranscodingReplaceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transcodingReplace" ) );
    }

    /**
      Get When transcoding a clip, replace it by the transcoding version in project. default value
    */
    static
    bool defaultTranscodingReplaceValue()
    {
        return defaultTranscodingReplaceValue_helper();
    }

    /**
      Set File extension for timeline preview.
    */
    static
    void setPreviewextension( const QString & v )
    {
      if (v != self()->mPreviewextension && !self()->isPreviewextensionImmutable()) {
        self()->mPreviewextension = v;
        Q_EMIT self()->previewextensionChanged();
      }
    }

    Q_PROPERTY(QString previewextension READ previewextension WRITE setPreviewextension NOTIFY previewextensionChanged)
    Q_PROPERTY(bool isPreviewextensionImmutable READ isPreviewextensionImmutable CONSTANT)
    /**
      Get File extension for timeline preview.
    */
    static
    QString previewextension()
    {
      return self()->mPreviewextension;
    }

    /**
      Is File extension for timeline preview. Immutable
    */
    static
    bool isPreviewextensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "previewextension" ) );
    }

    /**
      Set default preview encoding profile.
    */
    static
    void setPreview_profile( int v )
    {
      if (v != self()->mPreview_profile && !self()->isPreview_profileImmutable()) {
        self()->mPreview_profile = v;
        Q_EMIT self()->preview_profileChanged();
      }
    }

    Q_PROPERTY(int preview_profile READ preview_profile WRITE setPreview_profile NOTIFY preview_profileChanged)
    Q_PROPERTY(bool isPreview_profileImmutable READ isPreview_profileImmutable CONSTANT)
    Q_PROPERTY(int defaultPreview_profileValue READ defaultPreview_profileValue CONSTANT)
    /**
      Get default preview encoding profile.
    */
    static
    int preview_profile()
    {
      return self()->mPreview_profile;
    }

    /**
      Is default preview encoding profile. Immutable
    */
    static
    bool isPreview_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "preview_profile" ) );
    }

    /**
      Get default preview encoding profile. default value
    */
    static
    int defaultPreview_profileValue()
    {
        return defaultPreview_profileValue_helper();
    }

    /**
      Set Timeline preview encoding parameters.
    */
    static
    void setPreviewparams( const QString & v )
    {
      if (v != self()->mPreviewparams && !self()->isPreviewparamsImmutable()) {
        self()->mPreviewparams = v;
        Q_EMIT self()->previewparamsChanged();
      }
    }

    Q_PROPERTY(QString previewparams READ previewparams WRITE setPreviewparams NOTIFY previewparamsChanged)
    Q_PROPERTY(bool isPreviewparamsImmutable READ isPreviewparamsImmutable CONSTANT)
    /**
      Get Timeline preview encoding parameters.
    */
    static
    QString previewparams()
    {
      return self()->mPreviewparams;
    }

    /**
      Is Timeline preview encoding parameters. Immutable
    */
    static
    bool isPreviewparamsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "previewparams" ) );
    }

    /**
      Set Enable parallel processing for rendering.
    */
    static
    void setParallelrender( bool v )
    {
      if (v != self()->mParallelrender && !self()->isParallelrenderImmutable()) {
        self()->mParallelrender = v;
        Q_EMIT self()->parallelrenderChanged();
      }
    }

    Q_PROPERTY(bool parallelrender READ parallelrender WRITE setParallelrender NOTIFY parallelrenderChanged)
    Q_PROPERTY(bool isParallelrenderImmutable READ isParallelrenderImmutable CONSTANT)
    Q_PROPERTY(bool defaultParallelrenderValue READ defaultParallelrenderValue CONSTANT)
    /**
      Get Enable parallel processing for rendering.
    */
    static
    bool parallelrender()
    {
      return self()->mParallelrender;
    }

    /**
      Is Enable parallel processing for rendering. Immutable
    */
    static
    bool isParallelrenderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "parallelrender" ) );
    }

    /**
      Get Enable parallel processing for rendering. default value
    */
    static
    bool defaultParallelrenderValue()
    {
        return defaultParallelrenderValue_helper();
    }

    /**
      Set default interpolation for scaling operations.
    */
    static
    void setRenderInterp( const QString & v )
    {
      if (v != self()->mRenderInterp && !self()->isRenderInterpImmutable()) {
        self()->mRenderInterp = v;
        Q_EMIT self()->renderInterpChanged();
      }
    }

    Q_PROPERTY(QString renderInterp READ renderInterp WRITE setRenderInterp NOTIFY renderInterpChanged)
    Q_PROPERTY(bool isRenderInterpImmutable READ isRenderInterpImmutable CONSTANT)
    Q_PROPERTY(QString defaultRenderInterpValue READ defaultRenderInterpValue CONSTANT)
    /**
      Get default interpolation for scaling operations.
    */
    static
    QString renderInterp()
    {
      return self()->mRenderInterp;
    }

    /**
      Is default interpolation for scaling operations. Immutable
    */
    static
    bool isRenderInterpImmutable()
    {
      return self()->isImmutable( QStringLiteral( "renderInterp" ) );
    }

    /**
      Get default interpolation for scaling operations. default value
    */
    static
    QString defaultRenderInterpValue()
    {
        return defaultRenderInterpValue_helper();
    }

    /**
      Set default deinterlacer.
    */
    static
    void setRenderDeinterlacer( const QString & v )
    {
      if (v != self()->mRenderDeinterlacer && !self()->isRenderDeinterlacerImmutable()) {
        self()->mRenderDeinterlacer = v;
        Q_EMIT self()->renderDeinterlacerChanged();
      }
    }

    Q_PROPERTY(QString renderDeinterlacer READ renderDeinterlacer WRITE setRenderDeinterlacer NOTIFY renderDeinterlacerChanged)
    Q_PROPERTY(bool isRenderDeinterlacerImmutable READ isRenderDeinterlacerImmutable CONSTANT)
    Q_PROPERTY(QString defaultRenderDeinterlacerValue READ defaultRenderDeinterlacerValue CONSTANT)
    /**
      Get default deinterlacer.
    */
    static
    QString renderDeinterlacer()
    {
      return self()->mRenderDeinterlacer;
    }

    /**
      Is default deinterlacer. Immutable
    */
    static
    bool isRenderDeinterlacerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "renderDeinterlacer" ) );
    }

    /**
      Get default deinterlacer. default value
    */
    static
    QString defaultRenderDeinterlacerValue()
    {
        return defaultRenderDeinterlacerValue_helper();
    }

    /**
      Set Enables vaapi hw accel in encoders.
    */
    static
    void setVaapiEnabled( bool v )
    {
      if (v != self()->mVaapiEnabled && !self()->isVaapiEnabledImmutable()) {
        self()->mVaapiEnabled = v;
        Q_EMIT self()->vaapiEnabledChanged();
      }
    }

    Q_PROPERTY(bool vaapiEnabled READ vaapiEnabled WRITE setVaapiEnabled NOTIFY vaapiEnabledChanged)
    Q_PROPERTY(bool isVaapiEnabledImmutable READ isVaapiEnabledImmutable CONSTANT)
    Q_PROPERTY(bool defaultVaapiEnabledValue READ defaultVaapiEnabledValue CONSTANT)
    /**
      Get Enables vaapi hw accel in encoders.
    */
    static
    bool vaapiEnabled()
    {
      return self()->mVaapiEnabled;
    }

    /**
      Is Enables vaapi hw accel in encoders. Immutable
    */
    static
    bool isVaapiEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vaapiEnabled" ) );
    }

    /**
      Get Enables vaapi hw accel in encoders. default value
    */
    static
    bool defaultVaapiEnabledValue()
    {
        return defaultVaapiEnabledValue_helper();
    }

    /**
      Set Enables amf hw accel in encoders.
    */
    static
    void setAmfEnabled( bool v )
    {
      if (v != self()->mAmfEnabled && !self()->isAmfEnabledImmutable()) {
        self()->mAmfEnabled = v;
        Q_EMIT self()->amfEnabledChanged();
      }
    }

    Q_PROPERTY(bool amfEnabled READ amfEnabled WRITE setAmfEnabled NOTIFY amfEnabledChanged)
    Q_PROPERTY(bool isAmfEnabledImmutable READ isAmfEnabledImmutable CONSTANT)
    Q_PROPERTY(bool defaultAmfEnabledValue READ defaultAmfEnabledValue CONSTANT)
    /**
      Get Enables amf hw accel in encoders.
    */
    static
    bool amfEnabled()
    {
      return self()->mAmfEnabled;
    }

    /**
      Is Enables amf hw accel in encoders. Immutable
    */
    static
    bool isAmfEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "amfEnabled" ) );
    }

    /**
      Get Enables amf hw accel in encoders. default value
    */
    static
    bool defaultAmfEnabledValue()
    {
        return defaultAmfEnabledValue_helper();
    }

    /**
      Set Lists supported hw accel encoders.
    */
    static
    void setSupportedHWCodecs( const QStringList & v )
    {
      if (v != self()->mSupportedHWCodecs && !self()->isSupportedHWCodecsImmutable()) {
        self()->mSupportedHWCodecs = v;
        Q_EMIT self()->SupportedHWCodecsChanged();
      }
    }

    Q_PROPERTY(QStringList supportedHWCodecs READ supportedHWCodecs WRITE setSupportedHWCodecs NOTIFY SupportedHWCodecsChanged)
    Q_PROPERTY(bool isSupportedHWCodecsImmutable READ isSupportedHWCodecsImmutable CONSTANT)
    /**
      Get Lists supported hw accel encoders.
    */
    static
    QStringList supportedHWCodecs()
    {
      return self()->mSupportedHWCodecs;
    }

    /**
      Is Lists supported hw accel encoders. Immutable
    */
    static
    bool isSupportedHWCodecsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "SupportedHWCodecs" ) );
    }

    /**
      Set Enables nvenc hw accel scaling.
    */
    static
    void setNvScalingEnabled( bool v )
    {
      if (v != self()->mNvScalingEnabled && !self()->isNvScalingEnabledImmutable()) {
        self()->mNvScalingEnabled = v;
        Q_EMIT self()->nvScalingEnabledChanged();
      }
    }

    Q_PROPERTY(bool nvScalingEnabled READ nvScalingEnabled WRITE setNvScalingEnabled NOTIFY nvScalingEnabledChanged)
    Q_PROPERTY(bool isNvScalingEnabledImmutable READ isNvScalingEnabledImmutable CONSTANT)
    Q_PROPERTY(bool defaultNvScalingEnabledValue READ defaultNvScalingEnabledValue CONSTANT)
    /**
      Get Enables nvenc hw accel scaling.
    */
    static
    bool nvScalingEnabled()
    {
      return self()->mNvScalingEnabled;
    }

    /**
      Is Enables nvenc hw accel scaling. Immutable
    */
    static
    bool isNvScalingEnabledImmutable()
    {
      return self()->isImmutable( QStringLiteral( "nvScalingEnabled" ) );
    }

    /**
      Get Enables nvenc hw accel scaling. default value
    */
    static
    bool defaultNvScalingEnabledValue()
    {
        return defaultNvScalingEnabledValue_helper();
    }

    /**
      Set Enable hw decoding. String must be vaapi, nvdec, etc
    */
    static
    void setHwDecoding( const QString & v )
    {
      if (v != self()->mHwDecoding && !self()->isHwDecodingImmutable()) {
        self()->mHwDecoding = v;
        Q_EMIT self()->hwDecodingChanged();
      }
    }

    Q_PROPERTY(QString hwDecoding READ hwDecoding WRITE setHwDecoding NOTIFY hwDecodingChanged)
    Q_PROPERTY(bool isHwDecodingImmutable READ isHwDecodingImmutable CONSTANT)
    /**
      Get Enable hw decoding. String must be vaapi, nvdec, etc
    */
    static
    QString hwDecoding()
    {
      return self()->mHwDecoding;
    }

    /**
      Is Enable hw decoding. String must be vaapi, nvdec, etc Immutable
    */
    static
    bool isHwDecodingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "hwDecoding" ) );
    }

    /**
      Set Show render preset parameters as editable text.
    */
    static
    void setShowRenderTextParameters( bool v )
    {
      if (v != self()->mShowRenderTextParameters && !self()->isShowRenderTextParametersImmutable()) {
        self()->mShowRenderTextParameters = v;
        Q_EMIT self()->showRenderTextParametersChanged();
      }
    }

    Q_PROPERTY(bool showRenderTextParameters READ showRenderTextParameters WRITE setShowRenderTextParameters NOTIFY showRenderTextParametersChanged)
    Q_PROPERTY(bool isShowRenderTextParametersImmutable READ isShowRenderTextParametersImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowRenderTextParametersValue READ defaultShowRenderTextParametersValue CONSTANT)
    /**
      Get Show render preset parameters as editable text.
    */
    static
    bool showRenderTextParameters()
    {
      return self()->mShowRenderTextParameters;
    }

    /**
      Is Show render preset parameters as editable text. Immutable
    */
    static
    bool isShowRenderTextParametersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showRenderTextParameters" ) );
    }

    /**
      Get Show render preset parameters as editable text. default value
    */
    static
    bool defaultShowRenderTextParametersValue()
    {
        return defaultShowRenderTextParametersValue_helper();
    }

    /**
      Set Default width for timeline track headers.
    */
    static
    void setHeaderwidth( int v )
    {
      if (v != self()->mHeaderwidth && !self()->isHeaderwidthImmutable()) {
        self()->mHeaderwidth = v;
        Q_EMIT self()->headerwidthChanged();
      }
    }

    Q_PROPERTY(int headerwidth READ headerwidth WRITE setHeaderwidth NOTIFY headerwidthChanged)
    Q_PROPERTY(bool isHeaderwidthImmutable READ isHeaderwidthImmutable CONSTANT)
    Q_PROPERTY(int defaultHeaderwidthValue READ defaultHeaderwidthValue CONSTANT)
    /**
      Get Default width for timeline track headers.
    */
    static
    int headerwidth()
    {
      return self()->mHeaderwidth;
    }

    /**
      Is Default width for timeline track headers. Immutable
    */
    static
    bool isHeaderwidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "headerwidth" ) );
    }

    /**
      Get Default width for timeline track headers. default value
    */
    static
    int defaultHeaderwidthValue()
    {
        return defaultHeaderwidthValue_helper();
    }

    /**
      Set Default interpolation for keyframes.
    */
    static
    void setDefaultkeyframeinterp( int v )
    {
      if (v != self()->mDefaultkeyframeinterp && !self()->isDefaultkeyframeinterpImmutable()) {
        self()->mDefaultkeyframeinterp = v;
        Q_EMIT self()->defaultkeyframeinterpChanged();
      }
    }

    Q_PROPERTY(int defaultkeyframeinterp READ defaultkeyframeinterp WRITE setDefaultkeyframeinterp NOTIFY defaultkeyframeinterpChanged)
    Q_PROPERTY(bool isDefaultkeyframeinterpImmutable READ isDefaultkeyframeinterpImmutable CONSTANT)
    Q_PROPERTY(int defaultDefaultkeyframeinterpValue READ defaultDefaultkeyframeinterpValue CONSTANT)
    /**
      Get Default interpolation for keyframes.
    */
    static
    int defaultkeyframeinterp()
    {
      return self()->mDefaultkeyframeinterp;
    }

    /**
      Is Default interpolation for keyframes. Immutable
    */
    static
    bool isDefaultkeyframeinterpImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultkeyframeinterp" ) );
    }

    /**
      Get Default interpolation for keyframes. default value
    */
    static
    int defaultDefaultkeyframeinterpValue()
    {
        return defaultDefaultkeyframeinterpValue_helper();
    }

    /**
      Set Default size of video chunks for timeline preview.
    */
    static
    void setTimelinechunks( int v )
    {
      if (v != self()->mTimelinechunks && !self()->isTimelinechunksImmutable()) {
        self()->mTimelinechunks = v;
        Q_EMIT self()->timelinechunksChanged();
      }
    }

    Q_PROPERTY(int timelinechunks READ timelinechunks WRITE setTimelinechunks NOTIFY timelinechunksChanged)
    Q_PROPERTY(bool isTimelinechunksImmutable READ isTimelinechunksImmutable CONSTANT)
    Q_PROPERTY(int defaultTimelinechunksValue READ defaultTimelinechunksValue CONSTANT)
    /**
      Get Default size of video chunks for timeline preview.
    */
    static
    int timelinechunks()
    {
      return self()->mTimelinechunks;
    }

    /**
      Is Default size of video chunks for timeline preview. Immutable
    */
    static
    bool isTimelinechunksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "timelinechunks" ) );
    }

    /**
      Get Default size of video chunks for timeline preview. default value
    */
    static
    int defaultTimelinechunksValue()
    {
        return defaultTimelinechunksValue_helper();
    }

    /**
      Set Automatically regenerate dirty zones of timeline preview.
    */
    static
    void setAutopreview( bool v )
    {
      if (v != self()->mAutopreview && !self()->isAutopreviewImmutable()) {
        self()->mAutopreview = v;
        Q_EMIT self()->autopreviewChanged();
      }
    }

    Q_PROPERTY(bool autopreview READ autopreview WRITE setAutopreview NOTIFY autopreviewChanged)
    Q_PROPERTY(bool isAutopreviewImmutable READ isAutopreviewImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutopreviewValue READ defaultAutopreviewValue CONSTANT)
    /**
      Get Automatically regenerate dirty zones of timeline preview.
    */
    static
    bool autopreview()
    {
      return self()->mAutopreview;
    }

    /**
      Is Automatically regenerate dirty zones of timeline preview. Immutable
    */
    static
    bool isAutopreviewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autopreview" ) );
    }

    /**
      Get Automatically regenerate dirty zones of timeline preview. default value
    */
    static
    bool defaultAutopreviewValue()
    {
        return defaultAutopreviewValue_helper();
    }

    /**
      Set True when a timeline drag operation is in progress.
    */
    static
    void setDraginprogress( bool v )
    {
      if (v != self()->mDraginprogress && !self()->isDraginprogressImmutable()) {
        self()->mDraginprogress = v;
        Q_EMIT self()->draginprogressChanged();
      }
    }

    Q_PROPERTY(bool draginprogress READ draginprogress WRITE setDraginprogress NOTIFY draginprogressChanged)
    Q_PROPERTY(bool isDraginprogressImmutable READ isDraginprogressImmutable CONSTANT)
    Q_PROPERTY(bool defaultDraginprogressValue READ defaultDraginprogressValue CONSTANT)
    /**
      Get True when a timeline drag operation is in progress.
    */
    static
    bool draginprogress()
    {
      return self()->mDraginprogress;
    }

    /**
      Is True when a timeline drag operation is in progress. Immutable
    */
    static
    bool isDraginprogressImmutable()
    {
      return self()->isImmutable( QStringLiteral( "draginprogress" ) );
    }

    /**
      Get True when a timeline drag operation is in progress. default value
    */
    static
    bool defaultDraginprogressValue()
    {
        return defaultDraginprogressValue_helper();
    }

    /**
      Set Use proxy clips for preview rendering.
    */
    static
    void setProxypreview( bool v )
    {
      if (v != self()->mProxypreview && !self()->isProxypreviewImmutable()) {
        self()->mProxypreview = v;
        Q_EMIT self()->proxypreviewChanged();
      }
    }

    Q_PROPERTY(bool proxypreview READ proxypreview WRITE setProxypreview NOTIFY proxypreviewChanged)
    Q_PROPERTY(bool isProxypreviewImmutable READ isProxypreviewImmutable CONSTANT)
    Q_PROPERTY(bool defaultProxypreviewValue READ defaultProxypreviewValue CONSTANT)
    /**
      Get Use proxy clips for preview rendering.
    */
    static
    bool proxypreview()
    {
      return self()->mProxypreview;
    }

    /**
      Is Use proxy clips for preview rendering. Immutable
    */
    static
    bool isProxypreviewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxypreview" ) );
    }

    /**
      Get Use proxy clips for preview rendering. default value
    */
    static
    bool defaultProxypreviewValue()
    {
        return defaultProxypreviewValue_helper();
    }

    /**
      Set Should we enable all audio streams by default.
    */
    static
    void setMultistream( int v )
    {
      if (v != self()->mMultistream && !self()->isMultistreamImmutable()) {
        self()->mMultistream = v;
        Q_EMIT self()->multistreamChanged();
      }
    }

    Q_PROPERTY(int multistream READ multistream WRITE setMultistream NOTIFY multistreamChanged)
    Q_PROPERTY(bool isMultistreamImmutable READ isMultistreamImmutable CONSTANT)
    Q_PROPERTY(int defaultMultistreamValue READ defaultMultistreamValue CONSTANT)
    /**
      Get Should we enable all audio streams by default.
    */
    static
    int multistream()
    {
      return self()->mMultistream;
    }

    /**
      Is Should we enable all audio streams by default. Immutable
    */
    static
    bool isMultistreamImmutable()
    {
      return self()->isImmutable( QStringLiteral( "multistream" ) );
    }

    /**
      Get Should we enable all audio streams by default. default value
    */
    static
    int defaultMultistreamValue()
    {
        return defaultMultistreamValue_helper();
    }

    /**
      Set Check if project has enough tracks on multi stream clips, and propose to add new tracks.
    */
    static
    void setMultistream_checktrack( bool v )
    {
      if (v != self()->mMultistream_checktrack && !self()->isMultistream_checktrackImmutable()) {
        self()->mMultistream_checktrack = v;
        Q_EMIT self()->multistream_checktrackChanged();
      }
    }

    Q_PROPERTY(bool multistream_checktrack READ multistream_checktrack WRITE setMultistream_checktrack NOTIFY multistream_checktrackChanged)
    Q_PROPERTY(bool isMultistream_checktrackImmutable READ isMultistream_checktrackImmutable CONSTANT)
    Q_PROPERTY(bool defaultMultistream_checktrackValue READ defaultMultistream_checktrackValue CONSTANT)
    /**
      Get Check if project has enough tracks on multi stream clips, and propose to add new tracks.
    */
    static
    bool multistream_checktrack()
    {
      return self()->mMultistream_checktrack;
    }

    /**
      Is Check if project has enough tracks on multi stream clips, and propose to add new tracks. Immutable
    */
    static
    bool isMultistream_checktrackImmutable()
    {
      return self()->isImmutable( QStringLiteral( "multistream_checktrack" ) );
    }

    /**
      Get Check if project has enough tracks on multi stream clips, and propose to add new tracks. default value
    */
    static
    bool defaultMultistream_checktrackValue()
    {
        return defaultMultistream_checktrackValue_helper();
    }

    /**
      Set Display video thumbnails in timeline.
    */
    static
    void setVideothumbnails( bool v )
    {
      if (v != self()->mVideothumbnails && !self()->isVideothumbnailsImmutable()) {
        self()->mVideothumbnails = v;
        Q_EMIT self()->videothumbnailsChanged();
      }
    }

    Q_PROPERTY(bool videothumbnails READ videothumbnails WRITE setVideothumbnails NOTIFY videothumbnailsChanged)
    Q_PROPERTY(bool isVideothumbnailsImmutable READ isVideothumbnailsImmutable CONSTANT)
    Q_PROPERTY(bool defaultVideothumbnailsValue READ defaultVideothumbnailsValue CONSTANT)
    /**
      Get Display video thumbnails in timeline.
    */
    static
    bool videothumbnails()
    {
      return self()->mVideothumbnails;
    }

    /**
      Is Display video thumbnails in timeline. Immutable
    */
    static
    bool isVideothumbnailsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "videothumbnails" ) );
    }

    /**
      Get Display video thumbnails in timeline. default value
    */
    static
    bool defaultVideothumbnailsValue()
    {
        return defaultVideothumbnailsValue_helper();
    }

    /**
      Set Display audio thumbnails in timeline.
    */
    static
    void setAudiothumbnails( bool v )
    {
      if (v != self()->mAudiothumbnails && !self()->isAudiothumbnailsImmutable()) {
        self()->mAudiothumbnails = v;
        Q_EMIT self()->audiothumbnailsChanged();
      }
    }

    Q_PROPERTY(bool audiothumbnails READ audiothumbnails WRITE setAudiothumbnails NOTIFY audiothumbnailsChanged)
    Q_PROPERTY(bool isAudiothumbnailsImmutable READ isAudiothumbnailsImmutable CONSTANT)
    Q_PROPERTY(bool defaultAudiothumbnailsValue READ defaultAudiothumbnailsValue CONSTANT)
    /**
      Get Display audio thumbnails in timeline.
    */
    static
    bool audiothumbnails()
    {
      return self()->mAudiothumbnails;
    }

    /**
      Is Display audio thumbnails in timeline. Immutable
    */
    static
    bool isAudiothumbnailsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiothumbnails" ) );
    }

    /**
      Get Display audio thumbnails in timeline. default value
    */
    static
    bool defaultAudiothumbnailsValue()
    {
        return defaultAudiothumbnailsValue_helper();
    }

    /**
      Set Vertical scaler for audio waveform.
    */
    static
    void setWaveformScaler( int v )
    {
      if (v != self()->mWaveformScaler && !self()->isWaveformScalerImmutable()) {
        self()->mWaveformScaler = v;
        Q_EMIT self()->waveformScalerChanged();
      }
    }

    Q_PROPERTY(int waveformScaler READ waveformScaler WRITE setWaveformScaler NOTIFY waveformScalerChanged)
    Q_PROPERTY(bool isWaveformScalerImmutable READ isWaveformScalerImmutable CONSTANT)
    Q_PROPERTY(int defaultWaveformScalerValue READ defaultWaveformScalerValue CONSTANT)
    /**
      Get Vertical scaler for audio waveform.
    */
    static
    int waveformScaler()
    {
      return self()->mWaveformScaler;
    }

    /**
      Is Vertical scaler for audio waveform. Immutable
    */
    static
    bool isWaveformScalerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "waveformScaler" ) );
    }

    /**
      Get Vertical scaler for audio waveform. default value
    */
    static
    int defaultWaveformScalerValue()
    {
        return defaultWaveformScalerValue_helper();
    }

    /**
      Set Display clip markers comments in timeline.
    */
    static
    void setShowmarkers( bool v )
    {
      if (v != self()->mShowmarkers && !self()->isShowmarkersImmutable()) {
        self()->mShowmarkers = v;
        Q_EMIT self()->showmarkersChanged();
      }
    }

    Q_PROPERTY(bool showmarkers READ showmarkers WRITE setShowmarkers NOTIFY showmarkersChanged)
    Q_PROPERTY(bool isShowmarkersImmutable READ isShowmarkersImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowmarkersValue READ defaultShowmarkersValue CONSTANT)
    /**
      Get Display clip markers comments in timeline.
    */
    static
    bool showmarkers()
    {
      return self()->mShowmarkers;
    }

    /**
      Is Display clip markers comments in timeline. Immutable
    */
    static
    bool isShowmarkersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showmarkers" ) );
    }

    /**
      Get Display clip markers comments in timeline. default value
    */
    static
    bool defaultShowmarkersValue()
    {
        return defaultShowmarkersValue_helper();
    }

    /**
      Set Display all channels in audio thumbnails.
    */
    static
    void setDisplayallchannels( bool v )
    {
      if (v != self()->mDisplayallchannels && !self()->isDisplayallchannelsImmutable()) {
        self()->mDisplayallchannels = v;
        Q_EMIT self()->displayallchannelsChanged();
      }
    }

    Q_PROPERTY(bool displayallchannels READ displayallchannels WRITE setDisplayallchannels NOTIFY displayallchannelsChanged)
    Q_PROPERTY(bool isDisplayallchannelsImmutable READ isDisplayallchannelsImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayallchannelsValue READ defaultDisplayallchannelsValue CONSTANT)
    /**
      Get Display all channels in audio thumbnails.
    */
    static
    bool displayallchannels()
    {
      return self()->mDisplayallchannels;
    }

    /**
      Is Display all channels in audio thumbnails. Immutable
    */
    static
    bool isDisplayallchannelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "displayallchannels" ) );
    }

    /**
      Get Display all channels in audio thumbnails. default value
    */
    static
    bool defaultDisplayallchannelsValue()
    {
        return defaultDisplayallchannelsValue_helper();
    }

    /**
      Set Normalize audio channels in thumbnails.
    */
    static
    void setNormalizechannels( bool v )
    {
      if (v != self()->mNormalizechannels && !self()->isNormalizechannelsImmutable()) {
        self()->mNormalizechannels = v;
        Q_EMIT self()->normalizechannelsChanged();
      }
    }

    Q_PROPERTY(bool normalizechannels READ normalizechannels WRITE setNormalizechannels NOTIFY normalizechannelsChanged)
    Q_PROPERTY(bool isNormalizechannelsImmutable READ isNormalizechannelsImmutable CONSTANT)
    Q_PROPERTY(bool defaultNormalizechannelsValue READ defaultNormalizechannelsValue CONSTANT)
    /**
      Get Normalize audio channels in thumbnails.
    */
    static
    bool normalizechannels()
    {
      return self()->mNormalizechannels;
    }

    /**
      Is Normalize audio channels in thumbnails. Immutable
    */
    static
    bool isNormalizechannelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "normalizechannels" ) );
    }

    /**
      Get Normalize audio channels in thumbnails. default value
    */
    static
    bool defaultNormalizechannelsValue()
    {
        return defaultNormalizechannelsValue_helper();
    }

    /**
      Set Adjust all tracks height to fit in view.
    */
    static
    void setAutotrackheight( bool v )
    {
      if (v != self()->mAutotrackheight && !self()->isAutotrackheightImmutable()) {
        self()->mAutotrackheight = v;
        Q_EMIT self()->autotrackheightChanged();
      }
    }

    Q_PROPERTY(bool autotrackheight READ autotrackheight WRITE setAutotrackheight NOTIFY autotrackheightChanged)
    Q_PROPERTY(bool isAutotrackheightImmutable READ isAutotrackheightImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutotrackheightValue READ defaultAutotrackheightValue CONSTANT)
    /**
      Get Adjust all tracks height to fit in view.
    */
    static
    bool autotrackheight()
    {
      return self()->mAutotrackheight;
    }

    /**
      Is Adjust all tracks height to fit in view. Immutable
    */
    static
    bool isAutotrackheightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autotrackheight" ) );
    }

    /**
      Get Adjust all tracks height to fit in view. default value
    */
    static
    bool defaultAutotrackheightValue()
    {
        return defaultAutotrackheightValue_helper();
    }

    /**
      Set Auto scroll timeline while playing.
    */
    static
    void setAutoscroll( bool v )
    {
      if (v != self()->mAutoscroll && !self()->isAutoscrollImmutable()) {
        self()->mAutoscroll = v;
        Q_EMIT self()->autoscrollChanged();
      }
    }

    Q_PROPERTY(bool autoscroll READ autoscroll WRITE setAutoscroll NOTIFY autoscrollChanged)
    Q_PROPERTY(bool isAutoscrollImmutable READ isAutoscrollImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutoscrollValue READ defaultAutoscrollValue CONSTANT)
    /**
      Get Auto scroll timeline while playing.
    */
    static
    bool autoscroll()
    {
      return self()->mAutoscroll;
    }

    /**
      Is Auto scroll timeline while playing. Immutable
    */
    static
    bool isAutoscrollImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autoscroll" ) );
    }

    /**
      Get Auto scroll timeline while playing. default value
    */
    static
    bool defaultAutoscrollValue()
    {
        return defaultAutoscrollValue_helper();
    }

    /**
      Set Center timeline on playhead while playing or seeking.
    */
    static
    void setCenteredplayhead( bool v )
    {
      if (v != self()->mCenteredplayhead && !self()->isCenteredplayheadImmutable()) {
        self()->mCenteredplayhead = v;
        Q_EMIT self()->centeredplayheadChanged();
      }
    }

    Q_PROPERTY(bool centeredplayhead READ centeredplayhead WRITE setCenteredplayhead NOTIFY centeredplayheadChanged)
    Q_PROPERTY(bool isCenteredplayheadImmutable READ isCenteredplayheadImmutable CONSTANT)
    Q_PROPERTY(bool defaultCenteredplayheadValue READ defaultCenteredplayheadValue CONSTANT)
    /**
      Get Center timeline on playhead while playing or seeking.
    */
    static
    bool centeredplayhead()
    {
      return self()->mCenteredplayhead;
    }

    /**
      Is Center timeline on playhead while playing or seeking. Immutable
    */
    static
    bool isCenteredplayheadImmutable()
    {
      return self()->isImmutable( QStringLiteral( "centeredplayhead" ) );
    }

    /**
      Get Center timeline on playhead while playing or seeking. default value
    */
    static
    bool defaultCenteredplayheadValue()
    {
        return defaultCenteredplayheadValue_helper();
    }

    /**
      Set Jump to timeline start if playback is started on last frame in timeline.
    */
    static
    void setJumptostart( bool v )
    {
      if (v != self()->mJumptostart && !self()->isJumptostartImmutable()) {
        self()->mJumptostart = v;
        Q_EMIT self()->jumptostartChanged();
      }
    }

    Q_PROPERTY(bool jumptostart READ jumptostart WRITE setJumptostart NOTIFY jumptostartChanged)
    Q_PROPERTY(bool isJumptostartImmutable READ isJumptostartImmutable CONSTANT)
    Q_PROPERTY(bool defaultJumptostartValue READ defaultJumptostartValue CONSTANT)
    /**
      Get Jump to timeline start if playback is started on last frame in timeline.
    */
    static
    bool jumptostart()
    {
      return self()->mJumptostart;
    }

    /**
      Is Jump to timeline start if playback is started on last frame in timeline. Immutable
    */
    static
    bool isJumptostartImmutable()
    {
      return self()->isImmutable( QStringLiteral( "jumptostart" ) );
    }

    /**
      Get Jump to timeline start if playback is started on last frame in timeline. default value
    */
    static
    bool defaultJumptostartValue()
    {
        return defaultJumptostartValue_helper();
    }

    /**
      Set Pause playback when seeking.
    */
    static
    void setPauseonseek( bool v )
    {
      if (v != self()->mPauseonseek && !self()->isPauseonseekImmutable()) {
        self()->mPauseonseek = v;
        Q_EMIT self()->pauseonseekChanged();
      }
    }

    Q_PROPERTY(bool pauseonseek READ pauseonseek WRITE setPauseonseek NOTIFY pauseonseekChanged)
    Q_PROPERTY(bool isPauseonseekImmutable READ isPauseonseekImmutable CONSTANT)
    Q_PROPERTY(bool defaultPauseonseekValue READ defaultPauseonseekValue CONSTANT)
    /**
      Get Pause playback when seeking.
    */
    static
    bool pauseonseek()
    {
      return self()->mPauseonseek;
    }

    /**
      Is Pause playback when seeking. Immutable
    */
    static
    bool isPauseonseekImmutable()
    {
      return self()->isImmutable( QStringLiteral( "pauseonseek" ) );
    }

    /**
      Get Pause playback when seeking. default value
    */
    static
    bool defaultPauseonseekValue()
    {
        return defaultPauseonseekValue_helper();
    }

    /**
      Set Seek to clip when adding an effect.
    */
    static
    void setSeekonaddeffect( bool v )
    {
      if (v != self()->mSeekonaddeffect && !self()->isSeekonaddeffectImmutable()) {
        self()->mSeekonaddeffect = v;
        Q_EMIT self()->seekonaddeffectChanged();
      }
    }

    Q_PROPERTY(bool seekonaddeffect READ seekonaddeffect WRITE setSeekonaddeffect NOTIFY seekonaddeffectChanged)
    Q_PROPERTY(bool isSeekonaddeffectImmutable READ isSeekonaddeffectImmutable CONSTANT)
    Q_PROPERTY(bool defaultSeekonaddeffectValue READ defaultSeekonaddeffectValue CONSTANT)
    /**
      Get Seek to clip when adding an effect.
    */
    static
    bool seekonaddeffect()
    {
      return self()->mSeekonaddeffect;
    }

    /**
      Is Seek to clip when adding an effect. Immutable
    */
    static
    bool isSeekonaddeffectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "seekonaddeffect" ) );
    }

    /**
      Get Seek to clip when adding an effect. default value
    */
    static
    bool defaultSeekonaddeffectValue()
    {
        return defaultSeekonaddeffectValue_helper();
    }

    /**
      Set Enable built-in effects.
    */
    static
    void setEnableBuiltInEffects( bool v )
    {
      if (v != self()->mEnableBuiltInEffects && !self()->isEnableBuiltInEffectsImmutable()) {
        self()->mEnableBuiltInEffects = v;
        Q_EMIT self()->enableBuiltInEffectsChanged();
      }
    }

    Q_PROPERTY(bool enableBuiltInEffects READ enableBuiltInEffects WRITE setEnableBuiltInEffects NOTIFY enableBuiltInEffectsChanged)
    Q_PROPERTY(bool isEnableBuiltInEffectsImmutable READ isEnableBuiltInEffectsImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableBuiltInEffectsValue READ defaultEnableBuiltInEffectsValue CONSTANT)
    /**
      Get Enable built-in effects.
    */
    static
    bool enableBuiltInEffects()
    {
      return self()->mEnableBuiltInEffects;
    }

    /**
      Is Enable built-in effects. Immutable
    */
    static
    bool isEnableBuiltInEffectsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableBuiltInEffects" ) );
    }

    /**
      Get Enable built-in effects. default value
    */
    static
    bool defaultEnableBuiltInEffectsValue()
    {
        return defaultEnableBuiltInEffectsValue_helper();
    }

    /**
      Set Hide all effects that are not compatible with 10 bit.
    */
    static
    void setTenbitpipeline( bool v )
    {
      if (v != self()->mTenbitpipeline && !self()->isTenbitpipelineImmutable()) {
        self()->mTenbitpipeline = v;
        Q_EMIT self()->tenbitpipelineChanged();
      }
    }

    Q_PROPERTY(bool tenbitpipeline READ tenbitpipeline WRITE setTenbitpipeline NOTIFY tenbitpipelineChanged)
    Q_PROPERTY(bool isTenbitpipelineImmutable READ isTenbitpipelineImmutable CONSTANT)
    Q_PROPERTY(bool defaultTenbitpipelineValue READ defaultTenbitpipelineValue CONSTANT)
    /**
      Get Hide all effects that are not compatible with 10 bit.
    */
    static
    bool tenbitpipeline()
    {
      return self()->mTenbitpipeline;
    }

    /**
      Is Hide all effects that are not compatible with 10 bit. Immutable
    */
    static
    bool isTenbitpipelineImmutable()
    {
      return self()->isImmutable( QStringLiteral( "tenbitpipeline" ) );
    }

    /**
      Get Hide all effects that are not compatible with 10 bit. default value
    */
    static
    bool defaultTenbitpipelineValue()
    {
        return defaultTenbitpipelineValue_helper();
    }

    /**
      Set Filter effects by property.
    */
    static
    void setEffectsFilter( bool v )
    {
      if (v != self()->mEffectsFilter && !self()->isEffectsFilterImmutable()) {
        self()->mEffectsFilter = v;
        Q_EMIT self()->effectsFilterChanged();
      }
    }

    Q_PROPERTY(bool effectsFilter READ effectsFilter WRITE setEffectsFilter NOTIFY effectsFilterChanged)
    Q_PROPERTY(bool isEffectsFilterImmutable READ isEffectsFilterImmutable CONSTANT)
    Q_PROPERTY(bool defaultEffectsFilterValue READ defaultEffectsFilterValue CONSTANT)
    /**
      Get Filter effects by property.
    */
    static
    bool effectsFilter()
    {
      return self()->mEffectsFilter;
    }

    /**
      Is Filter effects by property. Immutable
    */
    static
    bool isEffectsFilterImmutable()
    {
      return self()->isImmutable( QStringLiteral( "effectsFilter" ) );
    }

    /**
      Get Filter effects by property. default value
    */
    static
    bool defaultEffectsFilterValue()
    {
        return defaultEffectsFilterValue_helper();
    }

    /**
      Set Filter transitions by property.
    */
    static
    void setTransitionsFilter( bool v )
    {
      if (v != self()->mTransitionsFilter && !self()->isTransitionsFilterImmutable()) {
        self()->mTransitionsFilter = v;
        Q_EMIT self()->transitionsFilterChanged();
      }
    }

    Q_PROPERTY(bool transitionsFilter READ transitionsFilter WRITE setTransitionsFilter NOTIFY transitionsFilterChanged)
    Q_PROPERTY(bool isTransitionsFilterImmutable READ isTransitionsFilterImmutable CONSTANT)
    Q_PROPERTY(bool defaultTransitionsFilterValue READ defaultTransitionsFilterValue CONSTANT)
    /**
      Get Filter transitions by property.
    */
    static
    bool transitionsFilter()
    {
      return self()->mTransitionsFilter;
    }

    /**
      Is Filter transitions by property. Immutable
    */
    static
    bool isTransitionsFilterImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transitionsFilter" ) );
    }

    /**
      Get Filter transitions by property. default value
    */
    static
    bool defaultTransitionsFilterValue()
    {
        return defaultTransitionsFilterValue_helper();
    }

    /**
      Set Scroll vertically with scroll wheel, horizontally with Shift + scroll wheel
    */
    static
    void setScrollvertically( bool v )
    {
      if (v != self()->mScrollvertically && !self()->isScrollverticallyImmutable()) {
        self()->mScrollvertically = v;
        Q_EMIT self()->scrollverticallyChanged();
      }
    }

    Q_PROPERTY(bool scrollvertically READ scrollvertically WRITE setScrollvertically NOTIFY scrollverticallyChanged)
    Q_PROPERTY(bool isScrollverticallyImmutable READ isScrollverticallyImmutable CONSTANT)
    Q_PROPERTY(bool defaultScrollverticallyValue READ defaultScrollverticallyValue CONSTANT)
    /**
      Get Scroll vertically with scroll wheel, horizontally with Shift + scroll wheel
    */
    static
    bool scrollvertically()
    {
      return self()->mScrollvertically;
    }

    /**
      Is Scroll vertically with scroll wheel, horizontally with Shift + scroll wheel Immutable
    */
    static
    bool isScrollverticallyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "scrollvertically" ) );
    }

    /**
      Get Scroll vertically with scroll wheel, horizontally with Shift + scroll wheel default value
    */
    static
    bool defaultScrollverticallyValue()
    {
        return defaultScrollverticallyValue_helper();
    }

    /**
      Set Tracks height in pixel.
    */
    static
    void setTrackheight( int v )
    {
      if (v != self()->mTrackheight && !self()->isTrackheightImmutable()) {
        self()->mTrackheight = v;
        Q_EMIT self()->trackheightChanged();
      }
    }

    Q_PROPERTY(int trackheight READ trackheight WRITE setTrackheight NOTIFY trackheightChanged)
    Q_PROPERTY(bool isTrackheightImmutable READ isTrackheightImmutable CONSTANT)
    Q_PROPERTY(int defaultTrackheightValue READ defaultTrackheightValue CONSTANT)
    /**
      Get Tracks height in pixel.
    */
    static
    int trackheight()
    {
      return self()->mTrackheight;
    }

    /**
      Is Tracks height in pixel. Immutable
    */
    static
    bool isTrackheightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "trackheight" ) );
    }

    /**
      Get Tracks height in pixel. default value
    */
    static
    int defaultTrackheightValue()
    {
        return defaultTrackheightValue_helper();
    }

    /**
      Set Display audio tracks grouped below video tracks.
    */
    static
    void setAudiotracksbelow( int v )
    {
      if (v != self()->mAudiotracksbelow && !self()->isAudiotracksbelowImmutable()) {
        self()->mAudiotracksbelow = v;
        Q_EMIT self()->audiotracksbelowChanged();
      }
    }

    Q_PROPERTY(int audiotracksbelow READ audiotracksbelow WRITE setAudiotracksbelow NOTIFY audiotracksbelowChanged)
    Q_PROPERTY(bool isAudiotracksbelowImmutable READ isAudiotracksbelowImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiotracksbelowValue READ defaultAudiotracksbelowValue CONSTANT)
    /**
      Get Display audio tracks grouped below video tracks.
    */
    static
    int audiotracksbelow()
    {
      return self()->mAudiotracksbelow;
    }

    /**
      Is Display audio tracks grouped below video tracks. Immutable
    */
    static
    bool isAudiotracksbelowImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiotracksbelow" ) );
    }

    /**
      Get Display audio tracks grouped below video tracks. default value
    */
    static
    int defaultAudiotracksbelowValue()
    {
        return defaultAudiotracksbelowValue_helper();
    }

    /**
      Set Raise property pane when selecting timeline clips.
    */
    static
    void setRaisepropsclips( bool v )
    {
      if (v != self()->mRaisepropsclips && !self()->isRaisepropsclipsImmutable()) {
        self()->mRaisepropsclips = v;
        Q_EMIT self()->raisepropsclipsChanged();
      }
    }

    Q_PROPERTY(bool raisepropsclips READ raisepropsclips WRITE setRaisepropsclips NOTIFY raisepropsclipsChanged)
    Q_PROPERTY(bool isRaisepropsclipsImmutable READ isRaisepropsclipsImmutable CONSTANT)
    Q_PROPERTY(bool defaultRaisepropsclipsValue READ defaultRaisepropsclipsValue CONSTANT)
    /**
      Get Raise property pane when selecting timeline clips.
    */
    static
    bool raisepropsclips()
    {
      return self()->mRaisepropsclips;
    }

    /**
      Is Raise property pane when selecting timeline clips. Immutable
    */
    static
    bool isRaisepropsclipsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "raisepropsclips" ) );
    }

    /**
      Get Raise property pane when selecting timeline clips. default value
    */
    static
    bool defaultRaisepropsclipsValue()
    {
        return defaultRaisepropsclipsValue_helper();
    }

    /**
      Set Raise property pane when selecting timeline compositions.
    */
    static
    void setRaisepropscompositions( bool v )
    {
      if (v != self()->mRaisepropscompositions && !self()->isRaisepropscompositionsImmutable()) {
        self()->mRaisepropscompositions = v;
        Q_EMIT self()->raisepropscompositionsChanged();
      }
    }

    Q_PROPERTY(bool raisepropscompositions READ raisepropscompositions WRITE setRaisepropscompositions NOTIFY raisepropscompositionsChanged)
    Q_PROPERTY(bool isRaisepropscompositionsImmutable READ isRaisepropscompositionsImmutable CONSTANT)
    Q_PROPERTY(bool defaultRaisepropscompositionsValue READ defaultRaisepropscompositionsValue CONSTANT)
    /**
      Get Raise property pane when selecting timeline compositions.
    */
    static
    bool raisepropscompositions()
    {
      return self()->mRaisepropscompositions;
    }

    /**
      Is Raise property pane when selecting timeline compositions. Immutable
    */
    static
    bool isRaisepropscompositionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "raisepropscompositions" ) );
    }

    /**
      Get Raise property pane when selecting timeline compositions. default value
    */
    static
    bool defaultRaisepropscompositionsValue()
    {
        return defaultRaisepropscompositionsValue_helper();
    }

    /**
      Set Raise property pane when selecting timeline mixes.
    */
    static
    void setRaisepropsmixes( bool v )
    {
      if (v != self()->mRaisepropsmixes && !self()->isRaisepropsmixesImmutable()) {
        self()->mRaisepropsmixes = v;
        Q_EMIT self()->raisepropsmixesChanged();
      }
    }

    Q_PROPERTY(bool raisepropsmixes READ raisepropsmixes WRITE setRaisepropsmixes NOTIFY raisepropsmixesChanged)
    Q_PROPERTY(bool isRaisepropsmixesImmutable READ isRaisepropsmixesImmutable CONSTANT)
    Q_PROPERTY(bool defaultRaisepropsmixesValue READ defaultRaisepropsmixesValue CONSTANT)
    /**
      Get Raise property pane when selecting timeline mixes.
    */
    static
    bool raisepropsmixes()
    {
      return self()->mRaisepropsmixes;
    }

    /**
      Is Raise property pane when selecting timeline mixes. Immutable
    */
    static
    bool isRaisepropsmixesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "raisepropsmixes" ) );
    }

    /**
      Get Raise property pane when selecting timeline mixes. default value
    */
    static
    bool defaultRaisepropsmixesValue()
    {
        return defaultRaisepropsmixesValue_helper();
    }

    /**
      Set Raise property pane when selecting timeline tracks.
    */
    static
    void setRaisepropstracks( bool v )
    {
      if (v != self()->mRaisepropstracks && !self()->isRaisepropstracksImmutable()) {
        self()->mRaisepropstracks = v;
        Q_EMIT self()->raisepropstracksChanged();
      }
    }

    Q_PROPERTY(bool raisepropstracks READ raisepropstracks WRITE setRaisepropstracks NOTIFY raisepropstracksChanged)
    Q_PROPERTY(bool isRaisepropstracksImmutable READ isRaisepropstracksImmutable CONSTANT)
    Q_PROPERTY(bool defaultRaisepropstracksValue READ defaultRaisepropstracksValue CONSTANT)
    /**
      Get Raise property pane when selecting timeline tracks.
    */
    static
    bool raisepropstracks()
    {
      return self()->mRaisepropstracks;
    }

    /**
      Is Raise property pane when selecting timeline tracks. Immutable
    */
    static
    bool isRaisepropstracksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "raisepropstracks" ) );
    }

    /**
      Get Raise property pane when selecting timeline tracks. default value
    */
    static
    bool defaultRaisepropstracksValue()
    {
        return defaultRaisepropstracksValue_helper();
    }

    /**
      Set Enable technical elements and info to debug the UI (for developers)
    */
    static
    void setUiDebugMode( bool v )
    {
      if (v != self()->mUiDebugMode && !self()->isUiDebugModeImmutable()) {
        self()->mUiDebugMode = v;
        Q_EMIT self()->uiDebugModeChanged();
      }
    }

    Q_PROPERTY(bool uiDebugMode READ uiDebugMode WRITE setUiDebugMode NOTIFY uiDebugModeChanged)
    Q_PROPERTY(bool isUiDebugModeImmutable READ isUiDebugModeImmutable CONSTANT)
    Q_PROPERTY(bool defaultUiDebugModeValue READ defaultUiDebugModeValue CONSTANT)
    /**
      Get Enable technical elements and info to debug the UI (for developers)
    */
    static
    bool uiDebugMode()
    {
      return self()->mUiDebugMode;
    }

    /**
      Is Enable technical elements and info to debug the UI (for developers) Immutable
    */
    static
    bool isUiDebugModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "uiDebugMode" ) );
    }

    /**
      Get Enable technical elements and info to debug the UI (for developers) default value
    */
    static
    bool defaultUiDebugModeValue()
    {
        return defaultUiDebugModeValue_helper();
    }

    /**
      Set Use Movit for GPU accelerated display and effects.
    */
    static
    void setGpu_accel( bool v )
    {
      if (v != self()->mGpu_accel && !self()->isGpu_accelImmutable()) {
        self()->mGpu_accel = v;
        Q_EMIT self()->gpu_accelChanged();
      }
    }

    Q_PROPERTY(bool gpu_accel READ gpu_accel WRITE setGpu_accel NOTIFY gpu_accelChanged)
    Q_PROPERTY(bool isGpu_accelImmutable READ isGpu_accelImmutable CONSTANT)
    Q_PROPERTY(bool defaultGpu_accelValue READ defaultGpu_accelValue CONSTANT)
    /**
      Get Use Movit for GPU accelerated display and effects.
    */
    static
    bool gpu_accel()
    {
      return self()->mGpu_accel;
    }

    /**
      Is Use Movit for GPU accelerated display and effects. Immutable
    */
    static
    bool isGpu_accelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "gpu_accel" ) );
    }

    /**
      Get Use Movit for GPU accelerated display and effects. default value
    */
    static
    bool defaultGpu_accelValue()
    {
        return defaultGpu_accelValue_helper();
    }

    /**
      Set Enable Audio Scrubbing
    */
    static
    void setAudio_scrub( bool v )
    {
      if (v != self()->mAudio_scrub && !self()->isAudio_scrubImmutable()) {
        self()->mAudio_scrub = v;
        Q_EMIT self()->audio_scrubChanged();
      }
    }

    Q_PROPERTY(bool audio_scrub READ audio_scrub WRITE setAudio_scrub NOTIFY audio_scrubChanged)
    Q_PROPERTY(bool isAudio_scrubImmutable READ isAudio_scrubImmutable CONSTANT)
    Q_PROPERTY(bool defaultAudio_scrubValue READ defaultAudio_scrubValue CONSTANT)
    /**
      Get Enable Audio Scrubbing
    */
    static
    bool audio_scrub()
    {
      return self()->mAudio_scrub;
    }

    /**
      Is Enable Audio Scrubbing Immutable
    */
    static
    bool isAudio_scrubImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audio_scrub" ) );
    }

    /**
      Get Enable Audio Scrubbing default value
    */
    static
    bool defaultAudio_scrubValue()
    {
        return defaultAudio_scrubValue_helper();
    }

    /**
      Set Detected audio backed.
    */
    static
    void setSdlAudioBackend( const QString & v )
    {
      if (v != self()->mSdlAudioBackend && !self()->isSdlAudioBackendImmutable()) {
        self()->mSdlAudioBackend = v;
        Q_EMIT self()->sdlAudioBackendChanged();
      }
    }

    Q_PROPERTY(QString sdlAudioBackend READ sdlAudioBackend WRITE setSdlAudioBackend NOTIFY sdlAudioBackendChanged)
    Q_PROPERTY(bool isSdlAudioBackendImmutable READ isSdlAudioBackendImmutable CONSTANT)
    Q_PROPERTY(QString defaultSdlAudioBackendValue READ defaultSdlAudioBackendValue CONSTANT)
    /**
      Get Detected audio backed.
    */
    static
    QString sdlAudioBackend()
    {
      return self()->mSdlAudioBackend;
    }

    /**
      Is Detected audio backed. Immutable
    */
    static
    bool isSdlAudioBackendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sdlAudioBackend" ) );
    }

    /**
      Get Detected audio backed. default value
    */
    static
    QString defaultSdlAudioBackendValue()
    {
        return defaultSdlAudioBackendValue_helper();
    }

    /**
      Set Audio backend index used for sound output.
    */
    static
    void setAudio_backend( int v )
    {
      if (v != self()->mAudio_backend && !self()->isAudio_backendImmutable()) {
        self()->mAudio_backend = v;
        Q_EMIT self()->audio_backendChanged();
      }
    }

    Q_PROPERTY(int audio_backend READ audio_backend WRITE setAudio_backend NOTIFY audio_backendChanged)
    Q_PROPERTY(bool isAudio_backendImmutable READ isAudio_backendImmutable CONSTANT)
    Q_PROPERTY(int defaultAudio_backendValue READ defaultAudio_backendValue CONSTANT)
    /**
      Get Audio backend index used for sound output.
    */
    static
    int audio_backend()
    {
      return self()->mAudio_backend;
    }

    /**
      Is Audio backend index used for sound output. Immutable
    */
    static
    bool isAudio_backendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audio_backend" ) );
    }

    /**
      Get Audio backend index used for sound output. default value
    */
    static
    int defaultAudio_backendValue()
    {
        return defaultAudio_backendValue_helper();
    }

    /**
      Set Audio backend used for sound output.
    */
    static
    void setAudiobackend( const QString & v )
    {
      if (v != self()->mAudiobackend && !self()->isAudiobackendImmutable()) {
        self()->mAudiobackend = v;
        Q_EMIT self()->audiobackendChanged();
      }
    }

    Q_PROPERTY(QString audiobackend READ audiobackend WRITE setAudiobackend NOTIFY audiobackendChanged)
    Q_PROPERTY(bool isAudiobackendImmutable READ isAudiobackendImmutable CONSTANT)
    Q_PROPERTY(QString defaultAudiobackendValue READ defaultAudiobackendValue CONSTANT)
    /**
      Get Audio backend used for sound output.
    */
    static
    QString audiobackend()
    {
      return self()->mAudiobackend;
    }

    /**
      Is Audio backend used for sound output. Immutable
    */
    static
    bool isAudiobackendImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiobackend" ) );
    }

    /**
      Get Audio backend used for sound output. default value
    */
    static
    QString defaultAudiobackendValue()
    {
        return defaultAudiobackendValue_helper();
    }

    /**
      Set SDL Audio driver used for sound output.
    */
    static
    void setAudio_driver( uint v )
    {
      if (v != self()->mAudio_driver && !self()->isAudio_driverImmutable()) {
        self()->mAudio_driver = v;
        Q_EMIT self()->audio_driverChanged();
      }
    }

    Q_PROPERTY(uint audio_driver READ audio_driver WRITE setAudio_driver NOTIFY audio_driverChanged)
    Q_PROPERTY(bool isAudio_driverImmutable READ isAudio_driverImmutable CONSTANT)
    Q_PROPERTY(uint defaultAudio_driverValue READ defaultAudio_driverValue CONSTANT)
    /**
      Get SDL Audio driver used for sound output.
    */
    static
    uint audio_driver()
    {
      return self()->mAudio_driver;
    }

    /**
      Is SDL Audio driver used for sound output. Immutable
    */
    static
    bool isAudio_driverImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audio_driver" ) );
    }

    /**
      Get SDL Audio driver used for sound output. default value
    */
    static
    uint defaultAudio_driverValue()
    {
        return defaultAudio_driverValue_helper();
    }

    /**
      Set SDL Audio device used for sound output.
    */
    static
    void setAudiodevicename( const QString & v )
    {
      if (v != self()->mAudiodevicename && !self()->isAudiodevicenameImmutable()) {
        self()->mAudiodevicename = v;
        Q_EMIT self()->audiodevicenameChanged();
      }
    }

    Q_PROPERTY(QString audiodevicename READ audiodevicename WRITE setAudiodevicename NOTIFY audiodevicenameChanged)
    Q_PROPERTY(bool isAudiodevicenameImmutable READ isAudiodevicenameImmutable CONSTANT)
    /**
      Get SDL Audio device used for sound output.
    */
    static
    QString audiodevicename()
    {
      return self()->mAudiodevicename;
    }

    /**
      Is SDL Audio device used for sound output. Immutable
    */
    static
    bool isAudiodevicenameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiodevicename" ) );
    }

    /**
      Set Audio driver used for sound output.
    */
    static
    void setAudiodrivername( const QString & v )
    {
      if (v != self()->mAudiodrivername && !self()->isAudiodrivernameImmutable()) {
        self()->mAudiodrivername = v;
        Q_EMIT self()->audiodrivernameChanged();
      }
    }

    Q_PROPERTY(QString audiodrivername READ audiodrivername WRITE setAudiodrivername NOTIFY audiodrivernameChanged)
    Q_PROPERTY(bool isAudiodrivernameImmutable READ isAudiodrivernameImmutable CONSTANT)
    /**
      Get Audio driver used for sound output.
    */
    static
    QString audiodrivername()
    {
      return self()->mAudiodrivername;
    }

    /**
      Is Audio driver used for sound output. Immutable
    */
    static
    bool isAudiodrivernameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiodrivername" ) );
    }

    /**
      Set Disable countdown before starting audio record.
    */
    static
    void setDisablereccountdown( bool v )
    {
      if (v != self()->mDisablereccountdown && !self()->isDisablereccountdownImmutable()) {
        self()->mDisablereccountdown = v;
        Q_EMIT self()->disablereccountdownChanged();
      }
    }

    Q_PROPERTY(bool disablereccountdown READ disablereccountdown WRITE setDisablereccountdown NOTIFY disablereccountdownChanged)
    Q_PROPERTY(bool isDisablereccountdownImmutable READ isDisablereccountdownImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisablereccountdownValue READ defaultDisablereccountdownValue CONSTANT)
    /**
      Get Disable countdown before starting audio record.
    */
    static
    bool disablereccountdown()
    {
      return self()->mDisablereccountdown;
    }

    /**
      Is Disable countdown before starting audio record. Immutable
    */
    static
    bool isDisablereccountdownImmutable()
    {
      return self()->isImmutable( QStringLiteral( "disablereccountdown" ) );
    }

    /**
      Get Disable countdown before starting audio record. default value
    */
    static
    bool defaultDisablereccountdownValue()
    {
        return defaultDisablereccountdownValue_helper();
    }

    /**
      Set Video driver used for output.
    */
    static
    void setVideodrivername( const QString & v )
    {
      if (v != self()->mVideodrivername && !self()->isVideodrivernameImmutable()) {
        self()->mVideodrivername = v;
        Q_EMIT self()->videodrivernameChanged();
      }
    }

    Q_PROPERTY(QString videodrivername READ videodrivername WRITE setVideodrivername NOTIFY videodrivernameChanged)
    Q_PROPERTY(bool isVideodrivernameImmutable READ isVideodrivernameImmutable CONSTANT)
    /**
      Get Video driver used for output.
    */
    static
    QString videodrivername()
    {
      return self()->mVideodrivername;
    }

    /**
      Is Video driver used for output. Immutable
    */
    static
    bool isVideodrivernameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "videodrivername" ) );
    }

    /**
      Set Audio device for SDL output.
    */
    static
    void setAudio_device( int v )
    {
      if (v != self()->mAudio_device && !self()->isAudio_deviceImmutable()) {
        self()->mAudio_device = v;
        Q_EMIT self()->audio_deviceChanged();
      }
    }

    Q_PROPERTY(int audio_device READ audio_device WRITE setAudio_device NOTIFY audio_deviceChanged)
    Q_PROPERTY(bool isAudio_deviceImmutable READ isAudio_deviceImmutable CONSTANT)
    /**
      Get Audio device for SDL output.
    */
    static
    int audio_device()
    {
      return self()->mAudio_device;
    }

    /**
      Is Audio device for SDL output. Immutable
    */
    static
    bool isAudio_deviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audio_device" ) );
    }

    /**
      Set Background color for OpenGL monitor.
    */
    static
    void setWindow_background( const QColor & v )
    {
      if (v != self()->mWindow_background && !self()->isWindow_backgroundImmutable()) {
        self()->mWindow_background = v;
        Q_EMIT self()->window_backgroundChanged();
      }
    }

    Q_PROPERTY(QColor window_background READ window_background WRITE setWindow_background NOTIFY window_backgroundChanged)
    Q_PROPERTY(bool isWindow_backgroundImmutable READ isWindow_backgroundImmutable CONSTANT)
    Q_PROPERTY(QColor defaultWindow_backgroundValue READ defaultWindow_backgroundValue CONSTANT)
    /**
      Get Background color for OpenGL monitor.
    */
    static
    QColor window_background()
    {
      return self()->mWindow_background;
    }

    /**
      Is Background color for OpenGL monitor. Immutable
    */
    static
    bool isWindow_backgroundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "window_background" ) );
    }

    /**
      Get Background color for OpenGL monitor. default value
    */
    static
    QColor defaultWindow_backgroundValue()
    {
        return defaultWindow_backgroundValue_helper();
    }

    /**
      Set Should we show the monitor grid.
    */
    static
    void setShowMonitorGrid( bool v )
    {
      if (v != self()->mShowMonitorGrid && !self()->isShowMonitorGridImmutable()) {
        self()->mShowMonitorGrid = v;
        Q_EMIT self()->showMonitorGridChanged();
      }
    }

    Q_PROPERTY(bool showMonitorGrid READ showMonitorGrid WRITE setShowMonitorGrid NOTIFY showMonitorGridChanged)
    Q_PROPERTY(bool isShowMonitorGridImmutable READ isShowMonitorGridImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowMonitorGridValue READ defaultShowMonitorGridValue CONSTANT)
    /**
      Get Should we show the monitor grid.
    */
    static
    bool showMonitorGrid()
    {
      return self()->mShowMonitorGrid;
    }

    /**
      Is Should we show the monitor grid. Immutable
    */
    static
    bool isShowMonitorGridImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showMonitorGrid" ) );
    }

    /**
      Get Should we show the monitor grid. default value
    */
    static
    bool defaultShowMonitorGridValue()
    {
        return defaultShowMonitorGridValue_helper();
    }

    /**
      Set Default size for grid horizontal spacing.
    */
    static
    void setMonitorGridH( int v )
    {
      if (v != self()->mMonitorGridH && !self()->isMonitorGridHImmutable()) {
        self()->mMonitorGridH = v;
        Q_EMIT self()->monitorGridHChanged();
      }
    }

    Q_PROPERTY(int monitorGridH READ monitorGridH WRITE setMonitorGridH NOTIFY monitorGridHChanged)
    Q_PROPERTY(bool isMonitorGridHImmutable READ isMonitorGridHImmutable CONSTANT)
    Q_PROPERTY(int defaultMonitorGridHValue READ defaultMonitorGridHValue CONSTANT)
    /**
      Get Default size for grid horizontal spacing.
    */
    static
    int monitorGridH()
    {
      return self()->mMonitorGridH;
    }

    /**
      Is Default size for grid horizontal spacing. Immutable
    */
    static
    bool isMonitorGridHImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitorGridH" ) );
    }

    /**
      Get Default size for grid horizontal spacing. default value
    */
    static
    int defaultMonitorGridHValue()
    {
        return defaultMonitorGridHValue_helper();
    }

    /**
      Set Default size for grid vertical spacing.
    */
    static
    void setMonitorGridV( int v )
    {
      if (v != self()->mMonitorGridV && !self()->isMonitorGridVImmutable()) {
        self()->mMonitorGridV = v;
        Q_EMIT self()->monitorGridVChanged();
      }
    }

    Q_PROPERTY(int monitorGridV READ monitorGridV WRITE setMonitorGridV NOTIFY monitorGridVChanged)
    Q_PROPERTY(bool isMonitorGridVImmutable READ isMonitorGridVImmutable CONSTANT)
    Q_PROPERTY(int defaultMonitorGridVValue READ defaultMonitorGridVValue CONSTANT)
    /**
      Get Default size for grid vertical spacing.
    */
    static
    int monitorGridV()
    {
      return self()->mMonitorGridV;
    }

    /**
      Is Default size for grid vertical spacing. Immutable
    */
    static
    bool isMonitorGridVImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitorGridV" ) );
    }

    /**
      Get Default size for grid vertical spacing. default value
    */
    static
    int defaultMonitorGridVValue()
    {
        return defaultMonitorGridVValue_helper();
    }

    /**
      Set Background color for clip monitor (only visible with transparent clips).
    */
    static
    void setMonitor_background( const QString & v )
    {
      if (v != self()->mMonitor_background && !self()->isMonitor_backgroundImmutable()) {
        self()->mMonitor_background = v;
        Q_EMIT self()->monitor_backgroundChanged();
      }
    }

    Q_PROPERTY(QString monitor_background READ monitor_background WRITE setMonitor_background NOTIFY monitor_backgroundChanged)
    Q_PROPERTY(bool isMonitor_backgroundImmutable READ isMonitor_backgroundImmutable CONSTANT)
    Q_PROPERTY(QString defaultMonitor_backgroundValue READ defaultMonitor_backgroundValue CONSTANT)
    /**
      Get Background color for clip monitor (only visible with transparent clips).
    */
    static
    QString monitor_background()
    {
      return self()->mMonitor_background;
    }

    /**
      Is Background color for clip monitor (only visible with transparent clips). Immutable
    */
    static
    bool isMonitor_backgroundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitor_background" ) );
    }

    /**
      Get Background color for clip monitor (only visible with transparent clips). default value
    */
    static
    QString defaultMonitor_backgroundValue()
    {
        return defaultMonitor_backgroundValue_helper();
    }

    /**
      Set Should we deinterlace monitor preview.
    */
    static
    void setMonitor_progressive( bool v )
    {
      if (v != self()->mMonitor_progressive && !self()->isMonitor_progressiveImmutable()) {
        self()->mMonitor_progressive = v;
        Q_EMIT self()->monitor_progressiveChanged();
      }
    }

    Q_PROPERTY(bool monitor_progressive READ monitor_progressive WRITE setMonitor_progressive NOTIFY monitor_progressiveChanged)
    Q_PROPERTY(bool isMonitor_progressiveImmutable READ isMonitor_progressiveImmutable CONSTANT)
    Q_PROPERTY(bool defaultMonitor_progressiveValue READ defaultMonitor_progressiveValue CONSTANT)
    /**
      Get Should we deinterlace monitor preview.
    */
    static
    bool monitor_progressive()
    {
      return self()->mMonitor_progressive;
    }

    /**
      Is Should we deinterlace monitor preview. Immutable
    */
    static
    bool isMonitor_progressiveImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitor_progressive" ) );
    }

    /**
      Get Should we deinterlace monitor preview. default value
    */
    static
    bool defaultMonitor_progressiveValue()
    {
        return defaultMonitor_progressiveValue_helper();
    }

    /**
      Set Volume used for SDL output.
    */
    static
    void setVolume( int v )
    {
      if (v != self()->mVolume && !self()->isVolumeImmutable()) {
        self()->mVolume = v;
        Q_EMIT self()->volumeChanged();
      }
    }

    Q_PROPERTY(int volume READ volume WRITE setVolume NOTIFY volumeChanged)
    Q_PROPERTY(bool isVolumeImmutable READ isVolumeImmutable CONSTANT)
    Q_PROPERTY(int defaultVolumeValue READ defaultVolumeValue CONSTANT)
    /**
      Get Volume used for SDL output.
    */
    static
    int volume()
    {
      return self()->mVolume;
    }

    /**
      Is Volume used for SDL output. Immutable
    */
    static
    bool isVolumeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "volume" ) );
    }

    /**
      Get Volume used for SDL output. default value
    */
    static
    int defaultVolumeValue()
    {
        return defaultVolumeValue_helper();
    }

    /**
      Set Allow framedropping in monitor playback.
    */
    static
    void setMonitor_dropframes( bool v )
    {
      if (v != self()->mMonitor_dropframes && !self()->isMonitor_dropframesImmutable()) {
        self()->mMonitor_dropframes = v;
        Q_EMIT self()->monitor_dropframesChanged();
      }
    }

    Q_PROPERTY(bool monitor_dropframes READ monitor_dropframes WRITE setMonitor_dropframes NOTIFY monitor_dropframesChanged)
    Q_PROPERTY(bool isMonitor_dropframesImmutable READ isMonitor_dropframesImmutable CONSTANT)
    Q_PROPERTY(bool defaultMonitor_dropframesValue READ defaultMonitor_dropframesValue CONSTANT)
    /**
      Get Allow framedropping in monitor playback.
    */
    static
    bool monitor_dropframes()
    {
      return self()->mMonitor_dropframes;
    }

    /**
      Is Allow framedropping in monitor playback. Immutable
    */
    static
    bool isMonitor_dropframesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitor_dropframes" ) );
    }

    /**
      Get Allow framedropping in monitor playback. default value
    */
    static
    bool defaultMonitor_dropframesValue()
    {
        return defaultMonitor_dropframesValue_helper();
    }

    /**
      Set Use Blackmagic device for video out.
    */
    static
    void setExternal_display( bool v )
    {
      if (v != self()->mExternal_display && !self()->isExternal_displayImmutable()) {
        self()->mExternal_display = v;
        Q_EMIT self()->external_displayChanged();
      }
    }

    Q_PROPERTY(bool external_display READ external_display WRITE setExternal_display NOTIFY external_displayChanged)
    Q_PROPERTY(bool isExternal_displayImmutable READ isExternal_displayImmutable CONSTANT)
    Q_PROPERTY(bool defaultExternal_displayValue READ defaultExternal_displayValue CONSTANT)
    /**
      Get Use Blackmagic device for video out.
    */
    static
    bool external_display()
    {
      return self()->mExternal_display;
    }

    /**
      Is Use Blackmagic device for video out. Immutable
    */
    static
    bool isExternal_displayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "external_display" ) );
    }

    /**
      Get Use Blackmagic device for video out. default value
    */
    static
    bool defaultExternal_displayValue()
    {
        return defaultExternal_displayValue_helper();
    }

    /**
      Set Blackmagic video output device.
    */
    static
    void setBlackmagic_output_device( int v )
    {
      if (v != self()->mBlackmagic_output_device && !self()->isBlackmagic_output_deviceImmutable()) {
        self()->mBlackmagic_output_device = v;
        Q_EMIT self()->blackmagic_output_deviceChanged();
      }
    }

    Q_PROPERTY(int blackmagic_output_device READ blackmagic_output_device WRITE setBlackmagic_output_device NOTIFY blackmagic_output_deviceChanged)
    Q_PROPERTY(bool isBlackmagic_output_deviceImmutable READ isBlackmagic_output_deviceImmutable CONSTANT)
    Q_PROPERTY(int defaultBlackmagic_output_deviceValue READ defaultBlackmagic_output_deviceValue CONSTANT)
    /**
      Get Blackmagic video output device.
    */
    static
    int blackmagic_output_device()
    {
      return self()->mBlackmagic_output_device;
    }

    /**
      Is Blackmagic video output device. Immutable
    */
    static
    bool isBlackmagic_output_deviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "blackmagic_output_device" ) );
    }

    /**
      Get Blackmagic video output device. default value
    */
    static
    int defaultBlackmagic_output_deviceValue()
    {
        return defaultBlackmagic_output_deviceValue_helper();
    }

    /**
      Set Play/pause monitor on click.
    */
    static
    void setPlay_monitor_on_click( bool v )
    {
      if (v != self()->mPlay_monitor_on_click && !self()->isPlay_monitor_on_clickImmutable()) {
        self()->mPlay_monitor_on_click = v;
        Q_EMIT self()->play_monitor_on_clickChanged();
      }
    }

    Q_PROPERTY(bool play_monitor_on_click READ play_monitor_on_click WRITE setPlay_monitor_on_click NOTIFY play_monitor_on_clickChanged)
    Q_PROPERTY(bool isPlay_monitor_on_clickImmutable READ isPlay_monitor_on_clickImmutable CONSTANT)
    Q_PROPERTY(bool defaultPlay_monitor_on_clickValue READ defaultPlay_monitor_on_clickValue CONSTANT)
    /**
      Get Play/pause monitor on click.
    */
    static
    bool play_monitor_on_click()
    {
      return self()->mPlay_monitor_on_click;
    }

    /**
      Is Play/pause monitor on click. Immutable
    */
    static
    bool isPlay_monitor_on_clickImmutable()
    {
      return self()->isImmutable( QStringLiteral( "play_monitor_on_click" ) );
    }

    /**
      Get Play/pause monitor on click. default value
    */
    static
    bool defaultPlay_monitor_on_clickValue()
    {
        return defaultPlay_monitor_on_clickValue_helper();
    }

    /**
      Set Whether to mirror the monitor on fullscreen instead of moving it.
    */
    static
    void setMirrorMonitorOnFullscreen( bool v )
    {
      if (v != self()->mMirrorMonitorOnFullscreen && !self()->isMirrorMonitorOnFullscreenImmutable()) {
        self()->mMirrorMonitorOnFullscreen = v;
        Q_EMIT self()->mirrorMonitorOnFullscreenChanged();
      }
    }

    Q_PROPERTY(bool mirrorMonitorOnFullscreen READ mirrorMonitorOnFullscreen WRITE setMirrorMonitorOnFullscreen NOTIFY mirrorMonitorOnFullscreenChanged)
    Q_PROPERTY(bool isMirrorMonitorOnFullscreenImmutable READ isMirrorMonitorOnFullscreenImmutable CONSTANT)
    Q_PROPERTY(bool defaultMirrorMonitorOnFullscreenValue READ defaultMirrorMonitorOnFullscreenValue CONSTANT)
    /**
      Get Whether to mirror the monitor on fullscreen instead of moving it.
    */
    static
    bool mirrorMonitorOnFullscreen()
    {
      return self()->mMirrorMonitorOnFullscreen;
    }

    /**
      Is Whether to mirror the monitor on fullscreen instead of moving it. Immutable
    */
    static
    bool isMirrorMonitorOnFullscreenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mirrorMonitorOnFullscreen" ) );
    }

    /**
      Get Whether to mirror the monitor on fullscreen instead of moving it. default value
    */
    static
    bool defaultMirrorMonitorOnFullscreenValue()
    {
        return defaultMirrorMonitorOnFullscreenValue_helper();
    }

    /**
      Set Monitor used for fullscreen output.
    */
    static
    void setFullscreen_monitor( const QString & v )
    {
      if (v != self()->mFullscreen_monitor && !self()->isFullscreen_monitorImmutable()) {
        self()->mFullscreen_monitor = v;
        Q_EMIT self()->fullscreen_monitorChanged();
      }
    }

    Q_PROPERTY(QString fullscreen_monitor READ fullscreen_monitor WRITE setFullscreen_monitor NOTIFY fullscreen_monitorChanged)
    Q_PROPERTY(bool isFullscreen_monitorImmutable READ isFullscreen_monitorImmutable CONSTANT)
    /**
      Get Monitor used for fullscreen output.
    */
    static
    QString fullscreen_monitor()
    {
      return self()->mFullscreen_monitor;
    }

    /**
      Is Monitor used for fullscreen output. Immutable
    */
    static
    bool isFullscreen_monitorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "fullscreen_monitor" ) );
    }

    /**
      Set Monitor used for fullscreen output.
    */
    static
    void setProject_monitor_fullscreen( const QString & v )
    {
      if (v != self()->mProject_monitor_fullscreen && !self()->isProject_monitor_fullscreenImmutable()) {
        self()->mProject_monitor_fullscreen = v;
        Q_EMIT self()->project_monitor_fullscreenChanged();
      }
    }

    Q_PROPERTY(QString project_monitor_fullscreen READ project_monitor_fullscreen WRITE setProject_monitor_fullscreen NOTIFY project_monitor_fullscreenChanged)
    Q_PROPERTY(bool isProject_monitor_fullscreenImmutable READ isProject_monitor_fullscreenImmutable CONSTANT)
    /**
      Get Monitor used for fullscreen output.
    */
    static
    QString project_monitor_fullscreen()
    {
      return self()->mProject_monitor_fullscreen;
    }

    /**
      Is Monitor used for fullscreen output. Immutable
    */
    static
    bool isProject_monitor_fullscreenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "project_monitor_fullscreen" ) );
    }

    /**
      Set Monitor used for fullscreen output.
    */
    static
    void setClip_monitor_fullscreen( const QString & v )
    {
      if (v != self()->mClip_monitor_fullscreen && !self()->isClip_monitor_fullscreenImmutable()) {
        self()->mClip_monitor_fullscreen = v;
        Q_EMIT self()->clip_monitor_fullscreenChanged();
      }
    }

    Q_PROPERTY(QString clip_monitor_fullscreen READ clip_monitor_fullscreen WRITE setClip_monitor_fullscreen NOTIFY clip_monitor_fullscreenChanged)
    Q_PROPERTY(bool isClip_monitor_fullscreenImmutable READ isClip_monitor_fullscreenImmutable CONSTANT)
    /**
      Get Monitor used for fullscreen output.
    */
    static
    QString clip_monitor_fullscreen()
    {
      return self()->mClip_monitor_fullscreen;
    }

    /**
      Is Monitor used for fullscreen output. Immutable
    */
    static
    bool isClip_monitor_fullscreenImmutable()
    {
      return self()->isImmutable( QStringLiteral( "clip_monitor_fullscreen" ) );
    }

    /**
      Set The preferred composition for track compositing.
    */
    static
    void setPreferredcomposite( const QString & v )
    {
      if (v != self()->mPreferredcomposite && !self()->isPreferredcompositeImmutable()) {
        self()->mPreferredcomposite = v;
        Q_EMIT self()->preferredcompositeChanged();
      }
    }

    Q_PROPERTY(QString preferredcomposite READ preferredcomposite WRITE setPreferredcomposite NOTIFY preferredcompositeChanged)
    Q_PROPERTY(bool isPreferredcompositeImmutable READ isPreferredcompositeImmutable CONSTANT)
    /**
      Get The preferred composition for track compositing.
    */
    static
    QString preferredcomposite()
    {
      return self()->mPreferredcomposite;
    }

    /**
      Is The preferred composition for track compositing. Immutable
    */
    static
    bool isPreferredcompositeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "preferredcomposite" ) );
    }

    /**
      Set The allowed compositions for track compositing (sorted by preference).
    */
    static
    void setCompositingList( const QStringList & v )
    {
      if (v != self()->mCompositingList && !self()->isCompositingListImmutable()) {
        self()->mCompositingList = v;
        Q_EMIT self()->compositingListChanged();
      }
    }

    Q_PROPERTY(QStringList compositingList READ compositingList WRITE setCompositingList NOTIFY compositingListChanged)
    Q_PROPERTY(bool isCompositingListImmutable READ isCompositingListImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultCompositingListValue READ defaultCompositingListValue CONSTANT)
    /**
      Get The allowed compositions for track compositing (sorted by preference).
    */
    static
    QStringList compositingList()
    {
      return self()->mCompositingList;
    }

    /**
      Is The allowed compositions for track compositing (sorted by preference). Immutable
    */
    static
    bool isCompositingListImmutable()
    {
      return self()->isImmutable( QStringLiteral( "compositingList" ) );
    }

    /**
      Get The allowed compositions for track compositing (sorted by preference). default value
    */
    static
    QStringList defaultCompositingListValue()
    {
        return defaultCompositingListValue_helper();
    }

    /**
      Set How to split subtitles when using the razor tool.
    */
    static
    void setSubtitle_razor_mode( int v )
    {
      if (v != self()->mSubtitle_razor_mode && !self()->isSubtitle_razor_modeImmutable()) {
        self()->mSubtitle_razor_mode = v;
        Q_EMIT self()->subtitle_razor_modeChanged();
      }
    }

    Q_PROPERTY(int subtitle_razor_mode READ subtitle_razor_mode WRITE setSubtitle_razor_mode NOTIFY subtitle_razor_modeChanged)
    Q_PROPERTY(bool isSubtitle_razor_modeImmutable READ isSubtitle_razor_modeImmutable CONSTANT)
    Q_PROPERTY(int defaultSubtitle_razor_modeValue READ defaultSubtitle_razor_modeValue CONSTANT)
    /**
      Get How to split subtitles when using the razor tool.
    */
    static
    int subtitle_razor_mode()
    {
      return self()->mSubtitle_razor_mode;
    }

    /**
      Is How to split subtitles when using the razor tool. Immutable
    */
    static
    bool isSubtitle_razor_modeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "subtitle_razor_mode" ) );
    }

    /**
      Get How to split subtitles when using the razor tool. default value
    */
    static
    int defaultSubtitle_razor_modeValue()
    {
        return defaultSubtitle_razor_modeValue_helper();
    }

    /**
      Set Mlt framework install path.
    */
    static
    void setMltpath( const QString & v )
    {
      if (v != self()->mMltpath && !self()->isMltpathImmutable()) {
        self()->mMltpath = v;
        Q_EMIT self()->mltpathChanged();
      }
    }

    Q_PROPERTY(QString mltpath READ mltpath WRITE setMltpath NOTIFY mltpathChanged)
    Q_PROPERTY(bool isMltpathImmutable READ isMltpathImmutable CONSTANT)
    /**
      Get Mlt framework install path.
    */
    static
    QString mltpath()
    {
      return self()->mMltpath;
    }

    /**
      Is Mlt framework install path. Immutable
    */
    static
    bool isMltpathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mltpath" ) );
    }

    /**
      Set Kdenlive renderer install path.
    */
    static
    void setKdenliverendererpath( const QString & v )
    {
      if (v != self()->mKdenliverendererpath && !self()->isKdenliverendererpathImmutable()) {
        self()->mKdenliverendererpath = v;
        Q_EMIT self()->kdenliverendererpathChanged();
      }
    }

    Q_PROPERTY(QString kdenliverendererpath READ kdenliverendererpath WRITE setKdenliverendererpath NOTIFY kdenliverendererpathChanged)
    Q_PROPERTY(bool isKdenliverendererpathImmutable READ isKdenliverendererpathImmutable CONSTANT)
    /**
      Get Kdenlive renderer install path.
    */
    static
    QString kdenliverendererpath()
    {
      return self()->mKdenliverendererpath;
    }

    /**
      Is Kdenlive renderer install path. Immutable
    */
    static
    bool isKdenliverendererpathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "kdenliverendererpath" ) );
    }

    /**
      Set Mlt melt renderer install path.
    */
    static
    void setMeltpath( const QString & v )
    {
      if (v != self()->mMeltpath && !self()->isMeltpathImmutable()) {
        self()->mMeltpath = v;
        Q_EMIT self()->meltpathChanged();
      }
    }

    Q_PROPERTY(QString meltpath READ meltpath WRITE setMeltpath NOTIFY meltpathChanged)
    Q_PROPERTY(bool isMeltpathImmutable READ isMeltpathImmutable CONSTANT)
    /**
      Get Mlt melt renderer install path.
    */
    static
    QString meltpath()
    {
      return self()->mMeltpath;
    }

    /**
      Is Mlt melt renderer install path. Immutable
    */
    static
    bool isMeltpathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "meltpath" ) );
    }

    /**
      Set FFmpeg / Libav binary path.
    */
    static
    void setFfmpegpath( const QString & v )
    {
      if (v != self()->mFfmpegpath && !self()->isFfmpegpathImmutable()) {
        self()->mFfmpegpath = v;
        Q_EMIT self()->ffmpegpathChanged();
      }
    }

    Q_PROPERTY(QString ffmpegpath READ ffmpegpath WRITE setFfmpegpath NOTIFY ffmpegpathChanged)
    Q_PROPERTY(bool isFfmpegpathImmutable READ isFfmpegpathImmutable CONSTANT)
    /**
      Get FFmpeg / Libav binary path.
    */
    static
    QString ffmpegpath()
    {
      return self()->mFfmpegpath;
    }

    /**
      Is FFmpeg / Libav binary path. Immutable
    */
    static
    bool isFfmpegpathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ffmpegpath" ) );
    }

    /**
      Set FFplay / avplay binary path.
    */
    static
    void setFfplaypath( const QString & v )
    {
      if (v != self()->mFfplaypath && !self()->isFfplaypathImmutable()) {
        self()->mFfplaypath = v;
        Q_EMIT self()->ffplaypathChanged();
      }
    }

    Q_PROPERTY(QString ffplaypath READ ffplaypath WRITE setFfplaypath NOTIFY ffplaypathChanged)
    Q_PROPERTY(bool isFfplaypathImmutable READ isFfplaypathImmutable CONSTANT)
    /**
      Get FFplay / avplay binary path.
    */
    static
    QString ffplaypath()
    {
      return self()->mFfplaypath;
    }

    /**
      Is FFplay / avplay binary path. Immutable
    */
    static
    bool isFfplaypathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ffplaypath" ) );
    }

    /**
      Set FFprobe / avprobe binary path.
    */
    static
    void setFfprobepath( const QString & v )
    {
      if (v != self()->mFfprobepath && !self()->isFfprobepathImmutable()) {
        self()->mFfprobepath = v;
        Q_EMIT self()->ffprobepathChanged();
      }
    }

    Q_PROPERTY(QString ffprobepath READ ffprobepath WRITE setFfprobepath NOTIFY ffprobepathChanged)
    Q_PROPERTY(bool isFfprobepathImmutable READ isFfprobepathImmutable CONSTANT)
    /**
      Get FFprobe / avprobe binary path.
    */
    static
    QString ffprobepath()
    {
      return self()->mFfprobepath;
    }

    /**
      Is FFprobe / avprobe binary path. Immutable
    */
    static
    bool isFfprobepathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "ffprobepath" ) );
    }

    /**
      Set Processing thread count.
    */
    static
    void setProcessingthreads( int v )
    {
      if (v != self()->mProcessingthreads && !self()->isProcessingthreadsImmutable()) {
        self()->mProcessingthreads = v;
        Q_EMIT self()->processingthreadsChanged();
      }
    }

    Q_PROPERTY(int processingthreads READ processingthreads WRITE setProcessingthreads NOTIFY processingthreadsChanged)
    Q_PROPERTY(bool isProcessingthreadsImmutable READ isProcessingthreadsImmutable CONSTANT)
    Q_PROPERTY(int defaultProcessingthreadsValue READ defaultProcessingthreadsValue CONSTANT)
    /**
      Get Processing thread count.
    */
    static
    int processingthreads()
    {
      return self()->mProcessingthreads;
    }

    /**
      Is Processing thread count. Immutable
    */
    static
    bool isProcessingthreadsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "processingthreads" ) );
    }

    /**
      Get Processing thread count. default value
    */
    static
    int defaultProcessingthreadsValue()
    {
        return defaultProcessingthreadsValue_helper();
    }

    /**
      Set Proxy creation processing thread count.
    */
    static
    void setProxythreads( int v )
    {
      if (v != self()->mProxythreads && !self()->isProxythreadsImmutable()) {
        self()->mProxythreads = v;
        Q_EMIT self()->proxythreadsChanged();
      }
    }

    Q_PROPERTY(int proxythreads READ proxythreads WRITE setProxythreads NOTIFY proxythreadsChanged)
    Q_PROPERTY(bool isProxythreadsImmutable READ isProxythreadsImmutable CONSTANT)
    Q_PROPERTY(int defaultProxythreadsValue READ defaultProxythreadsValue CONSTANT)
    /**
      Get Proxy creation processing thread count.
    */
    static
    int proxythreads()
    {
      return self()->mProxythreads;
    }

    /**
      Is Proxy creation processing thread count. Immutable
    */
    static
    bool isProxythreadsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "proxythreads" ) );
    }

    /**
      Get Proxy creation processing thread count. default value
    */
    static
    int defaultProxythreadsValue()
    {
        return defaultProxythreadsValue_helper();
    }

    /**
      Set FFmpeg encoding thread count.
    */
    static
    void setEncodethreads( int v )
    {
      if (v != self()->mEncodethreads && !self()->isEncodethreadsImmutable()) {
        self()->mEncodethreads = v;
        Q_EMIT self()->encodethreadsChanged();
      }
    }

    Q_PROPERTY(int encodethreads READ encodethreads WRITE setEncodethreads NOTIFY encodethreadsChanged)
    Q_PROPERTY(bool isEncodethreadsImmutable READ isEncodethreadsImmutable CONSTANT)
    Q_PROPERTY(int defaultEncodethreadsValue READ defaultEncodethreadsValue CONSTANT)
    /**
      Get FFmpeg encoding thread count.
    */
    static
    int encodethreads()
    {
      return self()->mEncodethreads;
    }

    /**
      Is FFmpeg encoding thread count. Immutable
    */
    static
    bool isEncodethreadsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "encodethreads" ) );
    }

    /**
      Get FFmpeg encoding thread count. default value
    */
    static
    int defaultEncodethreadsValue()
    {
        return defaultEncodethreadsValue_helper();
    }

    /**
      Set Default folder for tmp files.
    */
    static
    void setCurrenttmpfolder( const QString & v )
    {
      if (v != self()->mCurrenttmpfolder && !self()->isCurrenttmpfolderImmutable()) {
        self()->mCurrenttmpfolder = v;
        Q_EMIT self()->currenttmpfolderChanged();
      }
    }

    Q_PROPERTY(QString currenttmpfolder READ currenttmpfolder WRITE setCurrenttmpfolder NOTIFY currenttmpfolderChanged)
    Q_PROPERTY(bool isCurrenttmpfolderImmutable READ isCurrenttmpfolderImmutable CONSTANT)
    Q_PROPERTY(QString defaultCurrenttmpfolderValue READ defaultCurrenttmpfolderValue CONSTANT)
    /**
      Get Default folder for tmp files.
    */
    static
    QString currenttmpfolder()
    {
      return self()->mCurrenttmpfolder;
    }

    /**
      Is Default folder for tmp files. Immutable
    */
    static
    bool isCurrenttmpfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "currenttmpfolder" ) );
    }

    /**
      Get Default folder for tmp files. default value
    */
    static
    QString defaultCurrenttmpfolderValue()
    {
        return defaultCurrenttmpfolderValue_helper();
    }

    /**
      Set Kdenlive will periodically check if the cached data exceeds this limit. Data is in Mb
    */
    static
    void setMaxcachesize( int v )
    {
      if (v != self()->mMaxcachesize && !self()->isMaxcachesizeImmutable()) {
        self()->mMaxcachesize = v;
        Q_EMIT self()->maxcachesizeChanged();
      }
    }

    Q_PROPERTY(int maxcachesize READ maxcachesize WRITE setMaxcachesize NOTIFY maxcachesizeChanged)
    Q_PROPERTY(bool isMaxcachesizeImmutable READ isMaxcachesizeImmutable CONSTANT)
    Q_PROPERTY(int defaultMaxcachesizeValue READ defaultMaxcachesizeValue CONSTANT)
    /**
      Get Kdenlive will periodically check if the cached data exceeds this limit. Data is in Mb
    */
    static
    int maxcachesize()
    {
      return self()->mMaxcachesize;
    }

    /**
      Is Kdenlive will periodically check if the cached data exceeds this limit. Data is in Mb Immutable
    */
    static
    bool isMaxcachesizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maxcachesize" ) );
    }

    /**
      Get Kdenlive will periodically check if the cached data exceeds this limit. Data is in Mb default value
    */
    static
    int defaultMaxcachesizeValue()
    {
        return defaultMaxcachesizeValue_helper();
    }

    /**
      Set Automatically check for updates
    */
    static
    void setCheckForUpdate( bool v )
    {
      if (v != self()->mCheckForUpdate && !self()->isCheckForUpdateImmutable()) {
        self()->mCheckForUpdate = v;
        Q_EMIT self()->checkForUpdateChanged();
      }
    }

    Q_PROPERTY(bool checkForUpdate READ checkForUpdate WRITE setCheckForUpdate NOTIFY checkForUpdateChanged)
    Q_PROPERTY(bool isCheckForUpdateImmutable READ isCheckForUpdateImmutable CONSTANT)
    Q_PROPERTY(bool defaultCheckForUpdateValue READ defaultCheckForUpdateValue CONSTANT)
    /**
      Get Automatically check for updates
    */
    static
    bool checkForUpdate()
    {
      return self()->mCheckForUpdate;
    }

    /**
      Is Automatically check for updates Immutable
    */
    static
    bool isCheckForUpdateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "checkForUpdate" ) );
    }

    /**
      Get Automatically check for updates default value
    */
    static
    bool defaultCheckForUpdateValue()
    {
        return defaultCheckForUpdateValue_helper();
    }

    /**
      Set Disable sleep on playback/render
    */
    static
    void setUsePowerManagement( bool v )
    {
      if (v != self()->mUsePowerManagement && !self()->isUsePowerManagementImmutable()) {
        self()->mUsePowerManagement = v;
        Q_EMIT self()->usePowerManagementChanged();
      }
    }

    Q_PROPERTY(bool usePowerManagement READ usePowerManagement WRITE setUsePowerManagement NOTIFY usePowerManagementChanged)
    Q_PROPERTY(bool isUsePowerManagementImmutable READ isUsePowerManagementImmutable CONSTANT)
    Q_PROPERTY(bool defaultUsePowerManagementValue READ defaultUsePowerManagementValue CONSTANT)
    /**
      Get Disable sleep on playback/render
    */
    static
    bool usePowerManagement()
    {
      return self()->mUsePowerManagement;
    }

    /**
      Is Disable sleep on playback/render Immutable
    */
    static
    bool isUsePowerManagementImmutable()
    {
      return self()->isImmutable( QStringLiteral( "usePowerManagement" ) );
    }

    /**
      Get Disable sleep on playback/render default value
    */
    static
    bool defaultUsePowerManagementValue()
    {
        return defaultUsePowerManagementValue_helper();
    }

    /**
      Set Kdenlive will check every 2 weeks on startup if the cached data exceeds the defined maxcachesize. This is the last checked date
    */
    static
    void setLastCacheCheck( const QDateTime & v )
    {
      if (v != self()->mLastCacheCheck && !self()->isLastCacheCheckImmutable()) {
        self()->mLastCacheCheck = v;
        Q_EMIT self()->lastCacheCheckChanged();
      }
    }

    Q_PROPERTY(QDateTime lastCacheCheck READ lastCacheCheck WRITE setLastCacheCheck NOTIFY lastCacheCheckChanged)
    Q_PROPERTY(bool isLastCacheCheckImmutable READ isLastCacheCheckImmutable CONSTANT)
    /**
      Get Kdenlive will check every 2 weeks on startup if the cached data exceeds the defined maxcachesize. This is the last checked date
    */
    static
    QDateTime lastCacheCheck()
    {
      return self()->mLastCacheCheck;
    }

    /**
      Is Kdenlive will check every 2 weeks on startup if the cached data exceeds the defined maxcachesize. This is the last checked date Immutable
    */
    static
    bool isLastCacheCheckImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastCacheCheck" ) );
    }

    /**
      Set Default folder for project files.
    */
    static
    void setDefaultprojectfolder( const QString & v )
    {
      if (v != self()->mDefaultprojectfolder && !self()->isDefaultprojectfolderImmutable()) {
        self()->mDefaultprojectfolder = v;
        Q_EMIT self()->defaultprojectfolderChanged();
      }
    }

    Q_PROPERTY(QString defaultprojectfolder READ defaultprojectfolder WRITE setDefaultprojectfolder NOTIFY defaultprojectfolderChanged)
    Q_PROPERTY(bool isDefaultprojectfolderImmutable READ isDefaultprojectfolderImmutable CONSTANT)
    /**
      Get Default folder for project files.
    */
    static
    QString defaultprojectfolder()
    {
      return self()->mDefaultprojectfolder;
    }

    /**
      Is Default folder for project files. Immutable
    */
    static
    bool isDefaultprojectfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultprojectfolder" ) );
    }

    /**
      Set Don't use default XDG folders to store project files.
    */
    static
    void setCustomprojectfolder( bool v )
    {
      if (v != self()->mCustomprojectfolder && !self()->isCustomprojectfolderImmutable()) {
        self()->mCustomprojectfolder = v;
        Q_EMIT self()->customprojectfolderChanged();
      }
    }

    Q_PROPERTY(bool customprojectfolder READ customprojectfolder WRITE setCustomprojectfolder NOTIFY customprojectfolderChanged)
    Q_PROPERTY(bool isCustomprojectfolderImmutable READ isCustomprojectfolderImmutable CONSTANT)
    Q_PROPERTY(bool defaultCustomprojectfolderValue READ defaultCustomprojectfolderValue CONSTANT)
    /**
      Get Don't use default XDG folders to store project files.
    */
    static
    bool customprojectfolder()
    {
      return self()->mCustomprojectfolder;
    }

    /**
      Is Don't use default XDG folders to store project files. Immutable
    */
    static
    bool isCustomprojectfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "customprojectfolder" ) );
    }

    /**
      Get Don't use default XDG folders to store project files. default value
    */
    static
    bool defaultCustomprojectfolderValue()
    {
        return defaultCustomprojectfolderValue_helper();
    }

    /**
      Set Use the parent folder of the *.kdenlive file to store project files.
    */
    static
    void setSameprojectfolder( bool v )
    {
      if (v != self()->mSameprojectfolder && !self()->isSameprojectfolderImmutable()) {
        self()->mSameprojectfolder = v;
        Q_EMIT self()->sameprojectfolderChanged();
      }
    }

    Q_PROPERTY(bool sameprojectfolder READ sameprojectfolder WRITE setSameprojectfolder NOTIFY sameprojectfolderChanged)
    Q_PROPERTY(bool isSameprojectfolderImmutable READ isSameprojectfolderImmutable CONSTANT)
    Q_PROPERTY(bool defaultSameprojectfolderValue READ defaultSameprojectfolderValue CONSTANT)
    /**
      Get Use the parent folder of the *.kdenlive file to store project files.
    */
    static
    bool sameprojectfolder()
    {
      return self()->mSameprojectfolder;
    }

    /**
      Is Use the parent folder of the *.kdenlive file to store project files. Immutable
    */
    static
    bool isSameprojectfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sameprojectfolder" ) );
    }

    /**
      Get Use the parent folder of the *.kdenlive file to store project files. default value
    */
    static
    bool defaultSameprojectfolderValue()
    {
        return defaultSameprojectfolderValue_helper();
    }

    /**
      Set Save captured files to project folder by default.
    */
    static
    void setCapturetoprojectfolder( int v )
    {
      if (v != self()->mCapturetoprojectfolder && !self()->isCapturetoprojectfolderImmutable()) {
        self()->mCapturetoprojectfolder = v;
        Q_EMIT self()->capturetoprojectfolderChanged();
      }
    }

    Q_PROPERTY(int capturetoprojectfolder READ capturetoprojectfolder WRITE setCapturetoprojectfolder NOTIFY capturetoprojectfolderChanged)
    Q_PROPERTY(bool isCapturetoprojectfolderImmutable READ isCapturetoprojectfolderImmutable CONSTANT)
    Q_PROPERTY(int defaultCapturetoprojectfolderValue READ defaultCapturetoprojectfolderValue CONSTANT)
    /**
      Get Save captured files to project folder by default.
    */
    static
    int capturetoprojectfolder()
    {
      return self()->mCapturetoprojectfolder;
    }

    /**
      Is Save captured files to project folder by default. Immutable
    */
    static
    bool isCapturetoprojectfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "capturetoprojectfolder" ) );
    }

    /**
      Get Save captured files to project folder by default. default value
    */
    static
    int defaultCapturetoprojectfolderValue()
    {
        return defaultCapturetoprojectfolderValue_helper();
    }

    /**
      Set Default folder for captured files.
    */
    static
    void setCapturefolder( const QString & v )
    {
      if (v != self()->mCapturefolder && !self()->isCapturefolderImmutable()) {
        self()->mCapturefolder = v;
        Q_EMIT self()->capturefolderChanged();
      }
    }

    Q_PROPERTY(QString capturefolder READ capturefolder WRITE setCapturefolder NOTIFY capturefolderChanged)
    Q_PROPERTY(bool isCapturefolderImmutable READ isCapturefolderImmutable CONSTANT)
    Q_PROPERTY(QString defaultCapturefolderValue READ defaultCapturefolderValue CONSTANT)
    /**
      Get Default folder for captured files.
    */
    static
    QString capturefolder()
    {
      return self()->mCapturefolder;
    }

    /**
      Is Default folder for captured files. Immutable
    */
    static
    bool isCapturefolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "capturefolder" ) );
    }

    /**
      Get Default folder for captured files. default value
    */
    static
    QString defaultCapturefolderValue()
    {
        return defaultCapturefolderValue_helper();
    }

    /**
      Set Default subfolder of project file for captures.
    */
    static
    void setCaptureprojectsubfolder( const QString & v )
    {
      if (v != self()->mCaptureprojectsubfolder && !self()->isCaptureprojectsubfolderImmutable()) {
        self()->mCaptureprojectsubfolder = v;
        Q_EMIT self()->captureprojectsubfolderChanged();
      }
    }

    Q_PROPERTY(QString captureprojectsubfolder READ captureprojectsubfolder WRITE setCaptureprojectsubfolder NOTIFY captureprojectsubfolderChanged)
    Q_PROPERTY(bool isCaptureprojectsubfolderImmutable READ isCaptureprojectsubfolderImmutable CONSTANT)
    /**
      Get Default subfolder of project file for captures.
    */
    static
    QString captureprojectsubfolder()
    {
      return self()->mCaptureprojectsubfolder;
    }

    /**
      Is Default subfolder of project file for captures. Immutable
    */
    static
    bool isCaptureprojectsubfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "captureprojectsubfolder" ) );
    }

    /**
      Set Open Library in default system folder.
    */
    static
    void setLibrarytodefaultfolder( bool v )
    {
      if (v != self()->mLibrarytodefaultfolder && !self()->isLibrarytodefaultfolderImmutable()) {
        self()->mLibrarytodefaultfolder = v;
        Q_EMIT self()->librarytodefaultfolderChanged();
      }
    }

    Q_PROPERTY(bool librarytodefaultfolder READ librarytodefaultfolder WRITE setLibrarytodefaultfolder NOTIFY librarytodefaultfolderChanged)
    Q_PROPERTY(bool isLibrarytodefaultfolderImmutable READ isLibrarytodefaultfolderImmutable CONSTANT)
    Q_PROPERTY(bool defaultLibrarytodefaultfolderValue READ defaultLibrarytodefaultfolderValue CONSTANT)
    /**
      Get Open Library in default system folder.
    */
    static
    bool librarytodefaultfolder()
    {
      return self()->mLibrarytodefaultfolder;
    }

    /**
      Is Open Library in default system folder. Immutable
    */
    static
    bool isLibrarytodefaultfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "librarytodefaultfolder" ) );
    }

    /**
      Get Open Library in default system folder. default value
    */
    static
    bool defaultLibrarytodefaultfolderValue()
    {
        return defaultLibrarytodefaultfolderValue_helper();
    }

    /**
      Set Save titles, scripted renderings in default system folder.
    */
    static
    void setVideotodefaultfolder( int v )
    {
      if (v != self()->mVideotodefaultfolder && !self()->isVideotodefaultfolderImmutable()) {
        self()->mVideotodefaultfolder = v;
        Q_EMIT self()->videotodefaultfolderChanged();
      }
    }

    Q_PROPERTY(int videotodefaultfolder READ videotodefaultfolder WRITE setVideotodefaultfolder NOTIFY videotodefaultfolderChanged)
    Q_PROPERTY(bool isVideotodefaultfolderImmutable READ isVideotodefaultfolderImmutable CONSTANT)
    Q_PROPERTY(int defaultVideotodefaultfolderValue READ defaultVideotodefaultfolderValue CONSTANT)
    /**
      Get Save titles, scripted renderings in default system folder.
    */
    static
    int videotodefaultfolder()
    {
      return self()->mVideotodefaultfolder;
    }

    /**
      Is Save titles, scripted renderings in default system folder. Immutable
    */
    static
    bool isVideotodefaultfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "videotodefaultfolder" ) );
    }

    /**
      Get Save titles, scripted renderings in default system folder. default value
    */
    static
    int defaultVideotodefaultfolderValue()
    {
        return defaultVideotodefaultfolderValue_helper();
    }

    /**
      Set Default folder for library.
    */
    static
    void setLibraryfolder( const QString & v )
    {
      if (v != self()->mLibraryfolder && !self()->isLibraryfolderImmutable()) {
        self()->mLibraryfolder = v;
        Q_EMIT self()->libraryfolderChanged();
      }
    }

    Q_PROPERTY(QString libraryfolder READ libraryfolder WRITE setLibraryfolder NOTIFY libraryfolderChanged)
    Q_PROPERTY(bool isLibraryfolderImmutable READ isLibraryfolderImmutable CONSTANT)
    /**
      Get Default folder for library.
    */
    static
    QString libraryfolder()
    {
      return self()->mLibraryfolder;
    }

    /**
      Is Default folder for library. Immutable
    */
    static
    bool isLibraryfolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "libraryfolder" ) );
    }

    /**
      Set Default folder for various stored files, like titles, scripted rendering.
    */
    static
    void setVideofolder( const QString & v )
    {
      if (v != self()->mVideofolder && !self()->isVideofolderImmutable()) {
        self()->mVideofolder = v;
        Q_EMIT self()->videofolderChanged();
      }
    }

    Q_PROPERTY(QString videofolder READ videofolder WRITE setVideofolder NOTIFY videofolderChanged)
    Q_PROPERTY(bool isVideofolderImmutable READ isVideofolderImmutable CONSTANT)
    /**
      Get Default folder for various stored files, like titles, scripted rendering.
    */
    static
    QString videofolder()
    {
      return self()->mVideofolder;
    }

    /**
      Is Default folder for various stored files, like titles, scripted rendering. Immutable
    */
    static
    bool isVideofolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "videofolder" ) );
    }

    /**
      Set Default image editing application.
    */
    static
    void setDefaultimageapp( const QString & v )
    {
      if (v != self()->mDefaultimageapp && !self()->isDefaultimageappImmutable()) {
        self()->mDefaultimageapp = v;
        Q_EMIT self()->defaultimageappChanged();
      }
    }

    Q_PROPERTY(QString defaultimageapp READ defaultimageapp WRITE setDefaultimageapp NOTIFY defaultimageappChanged)
    Q_PROPERTY(bool isDefaultimageappImmutable READ isDefaultimageappImmutable CONSTANT)
    /**
      Get Default image editing application.
    */
    static
    QString defaultimageapp()
    {
      return self()->mDefaultimageapp;
    }

    /**
      Is Default image editing application. Immutable
    */
    static
    bool isDefaultimageappImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultimageapp" ) );
    }

    /**
      Set Default audio editing application name.
    */
    static
    void setDefaultaudioapp( const QString & v )
    {
      if (v != self()->mDefaultaudioapp && !self()->isDefaultaudioappImmutable()) {
        self()->mDefaultaudioapp = v;
        Q_EMIT self()->defaultaudioappChanged();
      }
    }

    Q_PROPERTY(QString defaultaudioapp READ defaultaudioapp WRITE setDefaultaudioapp NOTIFY defaultaudioappChanged)
    Q_PROPERTY(bool isDefaultaudioappImmutable READ isDefaultaudioappImmutable CONSTANT)
    /**
      Get Default audio editing application name.
    */
    static
    QString defaultaudioapp()
    {
      return self()->mDefaultaudioapp;
    }

    /**
      Is Default audio editing application name. Immutable
    */
    static
    bool isDefaultaudioappImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultaudioapp" ) );
    }

    /**
      Set Path to the Glaxnimate application.
    */
    static
    void setGlaxnimatePath( const QString & v )
    {
      if (v != self()->mGlaxnimatePath && !self()->isGlaxnimatePathImmutable()) {
        self()->mGlaxnimatePath = v;
        Q_EMIT self()->glaxnimatePathChanged();
      }
    }

    Q_PROPERTY(QString glaxnimatePath READ glaxnimatePath WRITE setGlaxnimatePath NOTIFY glaxnimatePathChanged)
    Q_PROPERTY(bool isGlaxnimatePathImmutable READ isGlaxnimatePathImmutable CONSTANT)
    /**
      Get Path to the Glaxnimate application.
    */
    static
    QString glaxnimatePath()
    {
      return self()->mGlaxnimatePath;
    }

    /**
      Is Path to the Glaxnimate application. Immutable
    */
    static
    bool isGlaxnimatePathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "glaxnimatePath" ) );
    }

    /**
      Set Default video editing application name.
    */
    static
    void setDefaultvideoapp( const QString & v )
    {
      if (v != self()->mDefaultvideoapp && !self()->isDefaultvideoappImmutable()) {
        self()->mDefaultvideoapp = v;
        Q_EMIT self()->defaultvideoappChanged();
      }
    }

    Q_PROPERTY(QString defaultvideoapp READ defaultvideoapp WRITE setDefaultvideoapp NOTIFY defaultvideoappChanged)
    Q_PROPERTY(bool isDefaultvideoappImmutable READ isDefaultvideoappImmutable CONSTANT)
    /**
      Get Default video editing application name.
    */
    static
    QString defaultvideoapp()
    {
      return self()->mDefaultvideoapp;
    }

    /**
      Is Default video editing application name. Immutable
    */
    static
    bool isDefaultvideoappImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultvideoapp" ) );
    }

    /**
      Set Use lower CPU priority for proxy and transcode tasks
    */
    static
    void setNice_tasks( bool v )
    {
      if (v != self()->mNice_tasks && !self()->isNice_tasksImmutable()) {
        self()->mNice_tasks = v;
        Q_EMIT self()->nice_tasksChanged();
      }
    }

    Q_PROPERTY(bool nice_tasks READ nice_tasks WRITE setNice_tasks NOTIFY nice_tasksChanged)
    Q_PROPERTY(bool isNice_tasksImmutable READ isNice_tasksImmutable CONSTANT)
    Q_PROPERTY(bool defaultNice_tasksValue READ defaultNice_tasksValue CONSTANT)
    /**
      Get Use lower CPU priority for proxy and transcode tasks
    */
    static
    bool nice_tasks()
    {
      return self()->mNice_tasks;
    }

    /**
      Is Use lower CPU priority for proxy and transcode tasks Immutable
    */
    static
    bool isNice_tasksImmutable()
    {
      return self()->isImmutable( QStringLiteral( "nice_tasks" ) );
    }

    /**
      Get Use lower CPU priority for proxy and transcode tasks default value
    */
    static
    bool defaultNice_tasksValue()
    {
        return defaultNice_tasksValue_helper();
    }

    /**
      Set Default format for guides export
    */
    static
    void setExportGuidesFormat( const QString & v )
    {
      if (v != self()->mExportGuidesFormat && !self()->isExportGuidesFormatImmutable()) {
        self()->mExportGuidesFormat = v;
        Q_EMIT self()->exportGuidesFormatChanged();
      }
    }

    Q_PROPERTY(QString exportGuidesFormat READ exportGuidesFormat WRITE setExportGuidesFormat NOTIFY exportGuidesFormatChanged)
    Q_PROPERTY(bool isExportGuidesFormatImmutable READ isExportGuidesFormatImmutable CONSTANT)
    /**
      Get Default format for guides export
    */
    static
    QString exportGuidesFormat()
    {
      return self()->mExportGuidesFormat;
    }

    /**
      Is Default format for guides export Immutable
    */
    static
    bool isExportGuidesFormatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "exportGuidesFormat" ) );
    }

    /**
      Set Default interval to insert multiple guides
    */
    static
    void setMultipleguidesinterval( double v )
    {
      if (v != self()->mMultipleguidesinterval && !self()->isMultipleguidesintervalImmutable()) {
        self()->mMultipleguidesinterval = v;
        Q_EMIT self()->multipleguidesintervalChanged();
      }
    }

    Q_PROPERTY(double multipleguidesinterval READ multipleguidesinterval WRITE setMultipleguidesinterval NOTIFY multipleguidesintervalChanged)
    Q_PROPERTY(bool isMultipleguidesintervalImmutable READ isMultipleguidesintervalImmutable CONSTANT)
    Q_PROPERTY(double defaultMultipleguidesintervalValue READ defaultMultipleguidesintervalValue CONSTANT)
    /**
      Get Default interval to insert multiple guides
    */
    static
    double multipleguidesinterval()
    {
      return self()->mMultipleguidesinterval;
    }

    /**
      Is Default interval to insert multiple guides Immutable
    */
    static
    bool isMultipleguidesintervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "multipleguidesinterval" ) );
    }

    /**
      Get Default interval to insert multiple guides default value
    */
    static
    double defaultMultipleguidesintervalValue()
    {
        return defaultMultipleguidesintervalValue_helper();
    }

    /**
      Set Display markers thumbnails in guide dialog.
    */
    static
    void setGuidesShowThumbs( bool v )
    {
      if (v != self()->mGuidesShowThumbs && !self()->isGuidesShowThumbsImmutable()) {
        self()->mGuidesShowThumbs = v;
        Q_EMIT self()->guidesShowThumbsChanged();
      }
    }

    Q_PROPERTY(bool guidesShowThumbs READ guidesShowThumbs WRITE setGuidesShowThumbs NOTIFY guidesShowThumbsChanged)
    Q_PROPERTY(bool isGuidesShowThumbsImmutable READ isGuidesShowThumbsImmutable CONSTANT)
    Q_PROPERTY(bool defaultGuidesShowThumbsValue READ defaultGuidesShowThumbsValue CONSTANT)
    /**
      Get Display markers thumbnails in guide dialog.
    */
    static
    bool guidesShowThumbs()
    {
      return self()->mGuidesShowThumbs;
    }

    /**
      Is Display markers thumbnails in guide dialog. Immutable
    */
    static
    bool isGuidesShowThumbsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "guidesShowThumbs" ) );
    }

    /**
      Get Display markers thumbnails in guide dialog. default value
    */
    static
    bool defaultGuidesShowThumbsValue()
    {
        return defaultGuidesShowThumbsValue_helper();
    }

    /**
      Set Select zone when selecting a range marker.
    */
    static
    void setGuidesSelectZone( bool v )
    {
      if (v != self()->mGuidesSelectZone && !self()->isGuidesSelectZoneImmutable()) {
        self()->mGuidesSelectZone = v;
        Q_EMIT self()->guidesSelectZoneChanged();
      }
    }

    Q_PROPERTY(bool guidesSelectZone READ guidesSelectZone WRITE setGuidesSelectZone NOTIFY guidesSelectZoneChanged)
    Q_PROPERTY(bool isGuidesSelectZoneImmutable READ isGuidesSelectZoneImmutable CONSTANT)
    Q_PROPERTY(bool defaultGuidesSelectZoneValue READ defaultGuidesSelectZoneValue CONSTANT)
    /**
      Get Select zone when selecting a range marker.
    */
    static
    bool guidesSelectZone()
    {
      return self()->mGuidesSelectZone;
    }

    /**
      Is Select zone when selecting a range marker. Immutable
    */
    static
    bool isGuidesSelectZoneImmutable()
    {
      return self()->isImmutable( QStringLiteral( "guidesSelectZone" ) );
    }

    /**
      Get Select zone when selecting a range marker. default value
    */
    static
    bool defaultGuidesSelectZoneValue()
    {
        return defaultGuidesSelectZoneValue_helper();
    }

    /**
      Set Default audio capture system.
    */
    static
    void setDefaultaudiocapture( const QString & v )
    {
      if (v != self()->mDefaultaudiocapture && !self()->isDefaultaudiocaptureImmutable()) {
        self()->mDefaultaudiocapture = v;
        Q_EMIT self()->defaultaudiocaptureChanged();
      }
    }

    Q_PROPERTY(QString defaultaudiocapture READ defaultaudiocapture WRITE setDefaultaudiocapture NOTIFY defaultaudiocaptureChanged)
    Q_PROPERTY(bool isDefaultaudiocaptureImmutable READ isDefaultaudiocaptureImmutable CONSTANT)
    Q_PROPERTY(QString defaultDefaultaudiocaptureValue READ defaultDefaultaudiocaptureValue CONSTANT)
    /**
      Get Default audio capture system.
    */
    static
    QString defaultaudiocapture()
    {
      return self()->mDefaultaudiocapture;
    }

    /**
      Is Default audio capture system. Immutable
    */
    static
    bool isDefaultaudiocaptureImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultaudiocapture" ) );
    }

    /**
      Get Default audio capture system. default value
    */
    static
    QString defaultDefaultaudiocaptureValue()
    {
        return defaultDefaultaudiocaptureValue_helper();
    }

    /**
      Set Audio capture volume
    */
    static
    void setAudiocapturevolume( int v )
    {
      if (v != self()->mAudiocapturevolume && !self()->isAudiocapturevolumeImmutable()) {
        self()->mAudiocapturevolume = v;
        Q_EMIT self()->audiocapturevolumeChanged();
      }
    }

    Q_PROPERTY(int audiocapturevolume READ audiocapturevolume WRITE setAudiocapturevolume NOTIFY audiocapturevolumeChanged)
    Q_PROPERTY(bool isAudiocapturevolumeImmutable READ isAudiocapturevolumeImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiocapturevolumeValue READ defaultAudiocapturevolumeValue CONSTANT)
    /**
      Get Audio capture volume
    */
    static
    int audiocapturevolume()
    {
      return self()->mAudiocapturevolume;
    }

    /**
      Is Audio capture volume Immutable
    */
    static
    bool isAudiocapturevolumeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiocapturevolume" ) );
    }

    /**
      Get Audio capture volume default value
    */
    static
    int defaultAudiocapturevolumeValue()
    {
        return defaultAudiocapturevolumeValue_helper();
    }

    /**
      Set Audio capture channels
    */
    static
    void setAudiocapturechannels( int v )
    {
      if (v != self()->mAudiocapturechannels && !self()->isAudiocapturechannelsImmutable()) {
        self()->mAudiocapturechannels = v;
        Q_EMIT self()->audiocapturechannelsChanged();
      }
    }

    Q_PROPERTY(int audiocapturechannels READ audiocapturechannels WRITE setAudiocapturechannels NOTIFY audiocapturechannelsChanged)
    Q_PROPERTY(bool isAudiocapturechannelsImmutable READ isAudiocapturechannelsImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiocapturechannelsValue READ defaultAudiocapturechannelsValue CONSTANT)
    /**
      Get Audio capture channels
    */
    static
    int audiocapturechannels()
    {
      return self()->mAudiocapturechannels;
    }

    /**
      Is Audio capture channels Immutable
    */
    static
    bool isAudiocapturechannelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiocapturechannels" ) );
    }

    /**
      Get Audio capture channels default value
    */
    static
    int defaultAudiocapturechannelsValue()
    {
        return defaultAudiocapturechannelsValue_helper();
    }

    /**
      Set Audio capture sample rate
    */
    static
    void setAudiocapturesamplerate( int v )
    {
      if (v != self()->mAudiocapturesamplerate && !self()->isAudiocapturesamplerateImmutable()) {
        self()->mAudiocapturesamplerate = v;
        Q_EMIT self()->audiocapturesamplerateChanged();
      }
    }

    Q_PROPERTY(int audiocapturesamplerate READ audiocapturesamplerate WRITE setAudiocapturesamplerate NOTIFY audiocapturesamplerateChanged)
    Q_PROPERTY(bool isAudiocapturesamplerateImmutable READ isAudiocapturesamplerateImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiocapturesamplerateValue READ defaultAudiocapturesamplerateValue CONSTANT)
    /**
      Get Audio capture sample rate
    */
    static
    int audiocapturesamplerate()
    {
      return self()->mAudiocapturesamplerate;
    }

    /**
      Is Audio capture sample rate Immutable
    */
    static
    bool isAudiocapturesamplerateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiocapturesamplerate" ) );
    }

    /**
      Get Audio capture sample rate default value
    */
    static
    int defaultAudiocapturesamplerateValue()
    {
        return defaultAudiocapturesamplerateValue_helper();
    }

    /**
      Set Audio capture sample format
    */
    static
    void setAudiocapturesampleformat( int v )
    {
      if (v != self()->mAudiocapturesampleformat && !self()->isAudiocapturesampleformatImmutable()) {
        self()->mAudiocapturesampleformat = v;
        Q_EMIT self()->audiocapturesampleformatChanged();
      }
    }

    Q_PROPERTY(int audiocapturesampleformat READ audiocapturesampleformat WRITE setAudiocapturesampleformat NOTIFY audiocapturesampleformatChanged)
    Q_PROPERTY(bool isAudiocapturesampleformatImmutable READ isAudiocapturesampleformatImmutable CONSTANT)
    Q_PROPERTY(int defaultAudiocapturesampleformatValue READ defaultAudiocapturesampleformatValue CONSTANT)
    /**
      Get Audio capture sample format
    */
    static
    int audiocapturesampleformat()
    {
      return self()->mAudiocapturesampleformat;
    }

    /**
      Is Audio capture sample format Immutable
    */
    static
    bool isAudiocapturesampleformatImmutable()
    {
      return self()->isImmutable( QStringLiteral( "audiocapturesampleformat" ) );
    }

    /**
      Get Audio capture sample format default value
    */
    static
    int defaultAudiocapturesampleformatValue()
    {
        return defaultAudiocapturesampleformatValue_helper();
    }

    /**
      Set Default video capture system.
    */
    static
    void setDefaultcapture( int v )
    {
      if (v != self()->mDefaultcapture && !self()->isDefaultcaptureImmutable()) {
        self()->mDefaultcapture = v;
        Q_EMIT self()->defaultcaptureChanged();
      }
    }

    Q_PROPERTY(int defaultcapture READ defaultcapture WRITE setDefaultcapture NOTIFY defaultcaptureChanged)
    Q_PROPERTY(bool isDefaultcaptureImmutable READ isDefaultcaptureImmutable CONSTANT)
    Q_PROPERTY(int defaultDefaultcaptureValue READ defaultDefaultcaptureValue CONSTANT)
    /**
      Get Default video capture system.
    */
    static
    int defaultcapture()
    {
      return self()->mDefaultcapture;
    }

    /**
      Is Default video capture system. Immutable
    */
    static
    bool isDefaultcaptureImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultcapture" ) );
    }

    /**
      Get Default video capture system. default value
    */
    static
    int defaultDefaultcaptureValue()
    {
        return defaultDefaultcaptureValue_helper();
    }

    /**
      Set Number of audio channels.
    */
    static
    void setAlsachannels( uint v )
    {
      if (v != self()->mAlsachannels && !self()->isAlsachannelsImmutable()) {
        self()->mAlsachannels = v;
        Q_EMIT self()->alsachannelsChanged();
      }
    }

    Q_PROPERTY(uint alsachannels READ alsachannels WRITE setAlsachannels NOTIFY alsachannelsChanged)
    Q_PROPERTY(bool isAlsachannelsImmutable READ isAlsachannelsImmutable CONSTANT)
    Q_PROPERTY(uint defaultAlsachannelsValue READ defaultAlsachannelsValue CONSTANT)
    /**
      Get Number of audio channels.
    */
    static
    uint alsachannels()
    {
      return self()->mAlsachannels;
    }

    /**
      Is Number of audio channels. Immutable
    */
    static
    bool isAlsachannelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "alsachannels" ) );
    }

    /**
      Get Number of audio channels. default value
    */
    static
    uint defaultAlsachannelsValue()
    {
        return defaultAlsachannelsValue_helper();
    }

    /**
      Set default screen grab encoding profile.
    */
    static
    void setGrab_profile( int v )
    {
      if (v != self()->mGrab_profile && !self()->isGrab_profileImmutable()) {
        self()->mGrab_profile = v;
        Q_EMIT self()->grab_profileChanged();
      }
    }

    Q_PROPERTY(int grab_profile READ grab_profile WRITE setGrab_profile NOTIFY grab_profileChanged)
    Q_PROPERTY(bool isGrab_profileImmutable READ isGrab_profileImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_profileValue READ defaultGrab_profileValue CONSTANT)
    /**
      Get default screen grab encoding profile.
    */
    static
    int grab_profile()
    {
      return self()->mGrab_profile;
    }

    /**
      Is default screen grab encoding profile. Immutable
    */
    static
    bool isGrab_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_profile" ) );
    }

    /**
      Get default screen grab encoding profile. default value
    */
    static
    int defaultGrab_profileValue()
    {
        return defaultGrab_profileValue_helper();
    }

    /**
      Set Default video4linux format.
    */
    static
    void setGrab_parameters( const QString & v )
    {
      if (v != self()->mGrab_parameters && !self()->isGrab_parametersImmutable()) {
        self()->mGrab_parameters = v;
        Q_EMIT self()->grab_parametersChanged();
      }
    }

    Q_PROPERTY(QString grab_parameters READ grab_parameters WRITE setGrab_parameters NOTIFY grab_parametersChanged)
    Q_PROPERTY(bool isGrab_parametersImmutable READ isGrab_parametersImmutable CONSTANT)
    /**
      Get Default video4linux format.
    */
    static
    QString grab_parameters()
    {
      return self()->mGrab_parameters;
    }

    /**
      Is Default video4linux format. Immutable
    */
    static
    bool isGrab_parametersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_parameters" ) );
    }

    /**
      Set Default screen grab file extension.
    */
    static
    void setGrab_extension( const QString & v )
    {
      if (v != self()->mGrab_extension && !self()->isGrab_extensionImmutable()) {
        self()->mGrab_extension = v;
        Q_EMIT self()->grab_extensionChanged();
      }
    }

    Q_PROPERTY(QString grab_extension READ grab_extension WRITE setGrab_extension NOTIFY grab_extensionChanged)
    Q_PROPERTY(bool isGrab_extensionImmutable READ isGrab_extensionImmutable CONSTANT)
    /**
      Get Default screen grab file extension.
    */
    static
    QString grab_extension()
    {
      return self()->mGrab_extension;
    }

    /**
      Is Default screen grab file extension. Immutable
    */
    static
    bool isGrab_extensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_extension" ) );
    }

    /**
      Set capture type.
    */
    static
    void setGrab_capture_type( int v )
    {
      if (v != self()->mGrab_capture_type && !self()->isGrab_capture_typeImmutable()) {
        self()->mGrab_capture_type = v;
        Q_EMIT self()->grab_capture_typeChanged();
      }
    }

    Q_PROPERTY(int grab_capture_type READ grab_capture_type WRITE setGrab_capture_type NOTIFY grab_capture_typeChanged)
    Q_PROPERTY(bool isGrab_capture_typeImmutable READ isGrab_capture_typeImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_capture_typeValue READ defaultGrab_capture_typeValue CONSTANT)
    /**
      Get capture type.
    */
    static
    int grab_capture_type()
    {
      return self()->mGrab_capture_type;
    }

    /**
      Is capture type. Immutable
    */
    static
    bool isGrab_capture_typeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_capture_type" ) );
    }

    /**
      Get capture type. default value
    */
    static
    int defaultGrab_capture_typeValue()
    {
        return defaultGrab_capture_typeValue_helper();
    }

    /**
      Set follow mouse in region capture.
    */
    static
    void setGrab_follow_mouse( bool v )
    {
      if (v != self()->mGrab_follow_mouse && !self()->isGrab_follow_mouseImmutable()) {
        self()->mGrab_follow_mouse = v;
        Q_EMIT self()->grab_follow_mouseChanged();
      }
    }

    Q_PROPERTY(bool grab_follow_mouse READ grab_follow_mouse WRITE setGrab_follow_mouse NOTIFY grab_follow_mouseChanged)
    Q_PROPERTY(bool isGrab_follow_mouseImmutable READ isGrab_follow_mouseImmutable CONSTANT)
    Q_PROPERTY(bool defaultGrab_follow_mouseValue READ defaultGrab_follow_mouseValue CONSTANT)
    /**
      Get follow mouse in region capture.
    */
    static
    bool grab_follow_mouse()
    {
      return self()->mGrab_follow_mouse;
    }

    /**
      Is follow mouse in region capture. Immutable
    */
    static
    bool isGrab_follow_mouseImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_follow_mouse" ) );
    }

    /**
      Get follow mouse in region capture. default value
    */
    static
    bool defaultGrab_follow_mouseValue()
    {
        return defaultGrab_follow_mouseValue_helper();
    }

    /**
      Set x offset for video capture.
    */
    static
    void setGrab_offsetx( int v )
    {
      if (v != self()->mGrab_offsetx && !self()->isGrab_offsetxImmutable()) {
        self()->mGrab_offsetx = v;
        Q_EMIT self()->grab_offsetxChanged();
      }
    }

    Q_PROPERTY(int grab_offsetx READ grab_offsetx WRITE setGrab_offsetx NOTIFY grab_offsetxChanged)
    Q_PROPERTY(bool isGrab_offsetxImmutable READ isGrab_offsetxImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_offsetxValue READ defaultGrab_offsetxValue CONSTANT)
    /**
      Get x offset for video capture.
    */
    static
    int grab_offsetx()
    {
      return self()->mGrab_offsetx;
    }

    /**
      Is x offset for video capture. Immutable
    */
    static
    bool isGrab_offsetxImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_offsetx" ) );
    }

    /**
      Get x offset for video capture. default value
    */
    static
    int defaultGrab_offsetxValue()
    {
        return defaultGrab_offsetxValue_helper();
    }

    /**
      Set y offset for video capture.
    */
    static
    void setGrab_offsety( int v )
    {
      if (v != self()->mGrab_offsety && !self()->isGrab_offsetyImmutable()) {
        self()->mGrab_offsety = v;
        Q_EMIT self()->grab_offsetyChanged();
      }
    }

    Q_PROPERTY(int grab_offsety READ grab_offsety WRITE setGrab_offsety NOTIFY grab_offsetyChanged)
    Q_PROPERTY(bool isGrab_offsetyImmutable READ isGrab_offsetyImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_offsetyValue READ defaultGrab_offsetyValue CONSTANT)
    /**
      Get y offset for video capture.
    */
    static
    int grab_offsety()
    {
      return self()->mGrab_offsety;
    }

    /**
      Is y offset for video capture. Immutable
    */
    static
    bool isGrab_offsetyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_offsety" ) );
    }

    /**
      Get y offset for video capture. default value
    */
    static
    int defaultGrab_offsetyValue()
    {
        return defaultGrab_offsetyValue_helper();
    }

    /**
      Set default width for video capture.
    */
    static
    void setGrab_width( int v )
    {
      if (v != self()->mGrab_width && !self()->isGrab_widthImmutable()) {
        self()->mGrab_width = v;
        Q_EMIT self()->grab_widthChanged();
      }
    }

    Q_PROPERTY(int grab_width READ grab_width WRITE setGrab_width NOTIFY grab_widthChanged)
    Q_PROPERTY(bool isGrab_widthImmutable READ isGrab_widthImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_widthValue READ defaultGrab_widthValue CONSTANT)
    /**
      Get default width for video capture.
    */
    static
    int grab_width()
    {
      return self()->mGrab_width;
    }

    /**
      Is default width for video capture. Immutable
    */
    static
    bool isGrab_widthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_width" ) );
    }

    /**
      Get default width for video capture. default value
    */
    static
    int defaultGrab_widthValue()
    {
        return defaultGrab_widthValue_helper();
    }

    /**
      Set default height for video capture.
    */
    static
    void setGrab_height( int v )
    {
      if (v != self()->mGrab_height && !self()->isGrab_heightImmutable()) {
        self()->mGrab_height = v;
        Q_EMIT self()->grab_heightChanged();
      }
    }

    Q_PROPERTY(int grab_height READ grab_height WRITE setGrab_height NOTIFY grab_heightChanged)
    Q_PROPERTY(bool isGrab_heightImmutable READ isGrab_heightImmutable CONSTANT)
    Q_PROPERTY(int defaultGrab_heightValue READ defaultGrab_heightValue CONSTANT)
    /**
      Get default height for video capture.
    */
    static
    int grab_height()
    {
      return self()->mGrab_height;
    }

    /**
      Is default height for video capture. Immutable
    */
    static
    bool isGrab_heightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_height" ) );
    }

    /**
      Get default height for video capture. default value
    */
    static
    int defaultGrab_heightValue()
    {
        return defaultGrab_heightValue_helper();
    }

    /**
      Set fps for video rec.
    */
    static
    void setGrab_fps( double v )
    {
      if (v != self()->mGrab_fps && !self()->isGrab_fpsImmutable()) {
        self()->mGrab_fps = v;
        Q_EMIT self()->grab_fpsChanged();
      }
    }

    Q_PROPERTY(double grab_fps READ grab_fps WRITE setGrab_fps NOTIFY grab_fpsChanged)
    Q_PROPERTY(bool isGrab_fpsImmutable READ isGrab_fpsImmutable CONSTANT)
    Q_PROPERTY(double defaultGrab_fpsValue READ defaultGrab_fpsValue CONSTANT)
    /**
      Get fps for video rec.
    */
    static
    double grab_fps()
    {
      return self()->mGrab_fps;
    }

    /**
      Is fps for video rec. Immutable
    */
    static
    bool isGrab_fpsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_fps" ) );
    }

    /**
      Get fps for video rec. default value
    */
    static
    double defaultGrab_fpsValue()
    {
        return defaultGrab_fpsValue_helper();
    }

    /**
      Set Hide frame around capture zone.
    */
    static
    void setGrab_hide_frame( bool v )
    {
      if (v != self()->mGrab_hide_frame && !self()->isGrab_hide_frameImmutable()) {
        self()->mGrab_hide_frame = v;
        Q_EMIT self()->grab_hide_frameChanged();
      }
    }

    Q_PROPERTY(bool grab_hide_frame READ grab_hide_frame WRITE setGrab_hide_frame NOTIFY grab_hide_frameChanged)
    Q_PROPERTY(bool isGrab_hide_frameImmutable READ isGrab_hide_frameImmutable CONSTANT)
    Q_PROPERTY(bool defaultGrab_hide_frameValue READ defaultGrab_hide_frameValue CONSTANT)
    /**
      Get Hide frame around capture zone.
    */
    static
    bool grab_hide_frame()
    {
      return self()->mGrab_hide_frame;
    }

    /**
      Is Hide frame around capture zone. Immutable
    */
    static
    bool isGrab_hide_frameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_hide_frame" ) );
    }

    /**
      Get Hide frame around capture zone. default value
    */
    static
    bool defaultGrab_hide_frameValue()
    {
        return defaultGrab_hide_frameValue_helper();
    }

    /**
      Set Hide mouse cursor.
    */
    static
    void setGrab_hide_mouse( bool v )
    {
      if (v != self()->mGrab_hide_mouse && !self()->isGrab_hide_mouseImmutable()) {
        self()->mGrab_hide_mouse = v;
        Q_EMIT self()->grab_hide_mouseChanged();
      }
    }

    Q_PROPERTY(bool grab_hide_mouse READ grab_hide_mouse WRITE setGrab_hide_mouse NOTIFY grab_hide_mouseChanged)
    Q_PROPERTY(bool isGrab_hide_mouseImmutable READ isGrab_hide_mouseImmutable CONSTANT)
    Q_PROPERTY(bool defaultGrab_hide_mouseValue READ defaultGrab_hide_mouseValue CONSTANT)
    /**
      Get Hide mouse cursor.
    */
    static
    bool grab_hide_mouse()
    {
      return self()->mGrab_hide_mouse;
    }

    /**
      Is Hide mouse cursor. Immutable
    */
    static
    bool isGrab_hide_mouseImmutable()
    {
      return self()->isImmutable( QStringLiteral( "grab_hide_mouse" ) );
    }

    /**
      Get Hide mouse cursor. default value
    */
    static
    bool defaultGrab_hide_mouseValue()
    {
        return defaultGrab_hide_mouseValue_helper();
    }

    /**
      Set Enable Blackmagic decklink support.
    */
    static
    void setDecklink_device_found( bool v )
    {
      if (v != self()->mDecklink_device_found && !self()->isDecklink_device_foundImmutable()) {
        self()->mDecklink_device_found = v;
        Q_EMIT self()->decklink_device_foundChanged();
      }
    }

    Q_PROPERTY(bool decklink_device_found READ decklink_device_found WRITE setDecklink_device_found NOTIFY decklink_device_foundChanged)
    Q_PROPERTY(bool isDecklink_device_foundImmutable READ isDecklink_device_foundImmutable CONSTANT)
    Q_PROPERTY(bool defaultDecklink_device_foundValue READ defaultDecklink_device_foundValue CONSTANT)
    /**
      Get Enable Blackmagic decklink support.
    */
    static
    bool decklink_device_found()
    {
      return self()->mDecklink_device_found;
    }

    /**
      Is Enable Blackmagic decklink support. Immutable
    */
    static
    bool isDecklink_device_foundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_device_found" ) );
    }

    /**
      Get Enable Blackmagic decklink support. default value
    */
    static
    bool defaultDecklink_device_foundValue()
    {
        return defaultDecklink_device_foundValue_helper();
    }

    /**
      Set default HDMI capture device.
    */
    static
    void setDecklink_capturedevice( uint v )
    {
      if (v != self()->mDecklink_capturedevice && !self()->isDecklink_capturedeviceImmutable()) {
        self()->mDecklink_capturedevice = v;
        Q_EMIT self()->decklink_capturedeviceChanged();
      }
    }

    Q_PROPERTY(uint decklink_capturedevice READ decklink_capturedevice WRITE setDecklink_capturedevice NOTIFY decklink_capturedeviceChanged)
    Q_PROPERTY(bool isDecklink_capturedeviceImmutable READ isDecklink_capturedeviceImmutable CONSTANT)
    Q_PROPERTY(uint defaultDecklink_capturedeviceValue READ defaultDecklink_capturedeviceValue CONSTANT)
    /**
      Get default HDMI capture device.
    */
    static
    uint decklink_capturedevice()
    {
      return self()->mDecklink_capturedevice;
    }

    /**
      Is default HDMI capture device. Immutable
    */
    static
    bool isDecklink_capturedeviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_capturedevice" ) );
    }

    /**
      Get default HDMI capture device. default value
    */
    static
    uint defaultDecklink_capturedeviceValue()
    {
        return defaultDecklink_capturedeviceValue_helper();
    }

    /**
      Set default HDMI encoding profile.
    */
    static
    void setDecklink_profile( int v )
    {
      if (v != self()->mDecklink_profile && !self()->isDecklink_profileImmutable()) {
        self()->mDecklink_profile = v;
        Q_EMIT self()->decklink_profileChanged();
      }
    }

    Q_PROPERTY(int decklink_profile READ decklink_profile WRITE setDecklink_profile NOTIFY decklink_profileChanged)
    Q_PROPERTY(bool isDecklink_profileImmutable READ isDecklink_profileImmutable CONSTANT)
    Q_PROPERTY(int defaultDecklink_profileValue READ defaultDecklink_profileValue CONSTANT)
    /**
      Get default HDMI encoding profile.
    */
    static
    int decklink_profile()
    {
      return self()->mDecklink_profile;
    }

    /**
      Is default HDMI encoding profile. Immutable
    */
    static
    bool isDecklink_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_profile" ) );
    }

    /**
      Get default HDMI encoding profile. default value
    */
    static
    int defaultDecklink_profileValue()
    {
        return defaultDecklink_profileValue_helper();
    }

    /**
      Set default HDMI capture filename.
    */
    static
    void setDecklink_filename( const QString & v )
    {
      if (v != self()->mDecklink_filename && !self()->isDecklink_filenameImmutable()) {
        self()->mDecklink_filename = v;
        Q_EMIT self()->decklink_filenameChanged();
      }
    }

    Q_PROPERTY(QString decklink_filename READ decklink_filename WRITE setDecklink_filename NOTIFY decklink_filenameChanged)
    Q_PROPERTY(bool isDecklink_filenameImmutable READ isDecklink_filenameImmutable CONSTANT)
    Q_PROPERTY(QString defaultDecklink_filenameValue READ defaultDecklink_filenameValue CONSTANT)
    /**
      Get default HDMI capture filename.
    */
    static
    QString decklink_filename()
    {
      return self()->mDecklink_filename;
    }

    /**
      Is default HDMI capture filename. Immutable
    */
    static
    bool isDecklink_filenameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_filename" ) );
    }

    /**
      Get default HDMI capture filename. default value
    */
    static
    QString defaultDecklink_filenameValue()
    {
        return defaultDecklink_filenameValue_helper();
    }

    /**
      Set Default Decklink encoding parameters.
    */
    static
    void setDecklink_parameters( const QString & v )
    {
      if (v != self()->mDecklink_parameters && !self()->isDecklink_parametersImmutable()) {
        self()->mDecklink_parameters = v;
        Q_EMIT self()->decklink_parametersChanged();
      }
    }

    Q_PROPERTY(QString decklink_parameters READ decklink_parameters WRITE setDecklink_parameters NOTIFY decklink_parametersChanged)
    Q_PROPERTY(bool isDecklink_parametersImmutable READ isDecklink_parametersImmutable CONSTANT)
    /**
      Get Default Decklink encoding parameters.
    */
    static
    QString decklink_parameters()
    {
      return self()->mDecklink_parameters;
    }

    /**
      Is Default Decklink encoding parameters. Immutable
    */
    static
    bool isDecklink_parametersImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_parameters" ) );
    }

    /**
      Set Default Decklink capture file extension.
    */
    static
    void setDecklink_extension( const QString & v )
    {
      if (v != self()->mDecklink_extension && !self()->isDecklink_extensionImmutable()) {
        self()->mDecklink_extension = v;
        Q_EMIT self()->decklink_extensionChanged();
      }
    }

    Q_PROPERTY(QString decklink_extension READ decklink_extension WRITE setDecklink_extension NOTIFY decklink_extensionChanged)
    Q_PROPERTY(bool isDecklink_extensionImmutable READ isDecklink_extensionImmutable CONSTANT)
    /**
      Get Default Decklink capture file extension.
    */
    static
    QString decklink_extension()
    {
      return self()->mDecklink_extension;
    }

    /**
      Is Default Decklink capture file extension. Immutable
    */
    static
    bool isDecklink_extensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "decklink_extension" ) );
    }

    /**
      Set Enable jog shuttle device.
    */
    static
    void setEnableshuttle( bool v )
    {
      if (v != self()->mEnableshuttle && !self()->isEnableshuttleImmutable()) {
        self()->mEnableshuttle = v;
        Q_EMIT self()->enableshuttleChanged();
      }
    }

    Q_PROPERTY(bool enableshuttle READ enableshuttle WRITE setEnableshuttle NOTIFY enableshuttleChanged)
    Q_PROPERTY(bool isEnableshuttleImmutable READ isEnableshuttleImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableshuttleValue READ defaultEnableshuttleValue CONSTANT)
    /**
      Get Enable jog shuttle device.
    */
    static
    bool enableshuttle()
    {
      return self()->mEnableshuttle;
    }

    /**
      Is Enable jog shuttle device. Immutable
    */
    static
    bool isEnableshuttleImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableshuttle" ) );
    }

    /**
      Get Enable jog shuttle device. default value
    */
    static
    bool defaultEnableshuttleValue()
    {
        return defaultEnableshuttleValue_helper();
    }

    /**
      Set Path to shuttle device.
    */
    static
    void setShuttledevice( const QString & v )
    {
      if (v != self()->mShuttledevice && !self()->isShuttledeviceImmutable()) {
        self()->mShuttledevice = v;
        Q_EMIT self()->shuttledeviceChanged();
      }
    }

    Q_PROPERTY(QString shuttledevice READ shuttledevice WRITE setShuttledevice NOTIFY shuttledeviceChanged)
    Q_PROPERTY(bool isShuttledeviceImmutable READ isShuttledeviceImmutable CONSTANT)
    /**
      Get Path to shuttle device.
    */
    static
    QString shuttledevice()
    {
      return self()->mShuttledevice;
    }

    /**
      Is Path to shuttle device. Immutable
    */
    static
    bool isShuttledeviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "shuttledevice" ) );
    }

    /**
      Set Available shuttle device names.
    */
    static
    void setShuttledevicenames( const QStringList & v )
    {
      if (v != self()->mShuttledevicenames && !self()->isShuttledevicenamesImmutable()) {
        self()->mShuttledevicenames = v;
        Q_EMIT self()->shuttledevicenamesChanged();
      }
    }

    Q_PROPERTY(QStringList shuttledevicenames READ shuttledevicenames WRITE setShuttledevicenames NOTIFY shuttledevicenamesChanged)
    Q_PROPERTY(bool isShuttledevicenamesImmutable READ isShuttledevicenamesImmutable CONSTANT)
    /**
      Get Available shuttle device names.
    */
    static
    QStringList shuttledevicenames()
    {
      return self()->mShuttledevicenames;
    }

    /**
      Is Available shuttle device names. Immutable
    */
    static
    bool isShuttledevicenamesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "shuttledevicenames" ) );
    }

    /**
      Set Available shuttle device paths.
    */
    static
    void setShuttledevicepaths( const QStringList & v )
    {
      if (v != self()->mShuttledevicepaths && !self()->isShuttledevicepathsImmutable()) {
        self()->mShuttledevicepaths = v;
        Q_EMIT self()->shuttledevicepathsChanged();
      }
    }

    Q_PROPERTY(QStringList shuttledevicepaths READ shuttledevicepaths WRITE setShuttledevicepaths NOTIFY shuttledevicepathsChanged)
    Q_PROPERTY(bool isShuttledevicepathsImmutable READ isShuttledevicepathsImmutable CONSTANT)
    /**
      Get Available shuttle device paths.
    */
    static
    QStringList shuttledevicepaths()
    {
      return self()->mShuttledevicepaths;
    }

    /**
      Is Available shuttle device paths. Immutable
    */
    static
    bool isShuttledevicepathsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "shuttledevicepaths" ) );
    }

    /**
      Set JogShuttle button to actions mappings.
    */
    static
    void setShuttlebuttons( const QString & v )
    {
      if (v != self()->mShuttlebuttons && !self()->isShuttlebuttonsImmutable()) {
        self()->mShuttlebuttons = v;
        Q_EMIT self()->shuttlebuttonsChanged();
      }
    }

    Q_PROPERTY(QString shuttlebuttons READ shuttlebuttons WRITE setShuttlebuttons NOTIFY shuttlebuttonsChanged)
    Q_PROPERTY(bool isShuttlebuttonsImmutable READ isShuttlebuttonsImmutable CONSTANT)
    /**
      Get JogShuttle button to actions mappings.
    */
    static
    QString shuttlebuttons()
    {
      return self()->mShuttlebuttons;
    }

    /**
      Is JogShuttle button to actions mappings. Immutable
    */
    static
    bool isShuttlebuttonsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "shuttlebuttons" ) );
    }

    /**
      Set Number of lines to use for the grid.
    */
    static
    void setBezier_gridlines( int v )
    {
      if (v != self()->mBezier_gridlines && !self()->isBezier_gridlinesImmutable()) {
        self()->mBezier_gridlines = v;
        Q_EMIT self()->bezier_gridlinesChanged();
      }
    }

    Q_PROPERTY(int bezier_gridlines READ bezier_gridlines WRITE setBezier_gridlines NOTIFY bezier_gridlinesChanged)
    Q_PROPERTY(bool isBezier_gridlinesImmutable READ isBezier_gridlinesImmutable CONSTANT)
    Q_PROPERTY(int defaultBezier_gridlinesValue READ defaultBezier_gridlinesValue CONSTANT)
    /**
      Get Number of lines to use for the grid.
    */
    static
    int bezier_gridlines()
    {
      return self()->mBezier_gridlines;
    }

    /**
      Is Number of lines to use for the grid. Immutable
    */
    static
    bool isBezier_gridlinesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "bezier_gridlines" ) );
    }

    /**
      Get Number of lines to use for the grid. default value
    */
    static
    int defaultBezier_gridlinesValue()
    {
        return defaultBezier_gridlinesValue_helper();
    }

    /**
      Set Should a background indicating the changes caused by curve manipulation be shown.
    */
    static
    void setBezier_showpixmap( bool v )
    {
      if (v != self()->mBezier_showpixmap && !self()->isBezier_showpixmapImmutable()) {
        self()->mBezier_showpixmap = v;
        Q_EMIT self()->bezier_showpixmapChanged();
      }
    }

    Q_PROPERTY(bool bezier_showpixmap READ bezier_showpixmap WRITE setBezier_showpixmap NOTIFY bezier_showpixmapChanged)
    Q_PROPERTY(bool isBezier_showpixmapImmutable READ isBezier_showpixmapImmutable CONSTANT)
    Q_PROPERTY(bool defaultBezier_showpixmapValue READ defaultBezier_showpixmapValue CONSTANT)
    /**
      Get Should a background indicating the changes caused by curve manipulation be shown.
    */
    static
    bool bezier_showpixmap()
    {
      return self()->mBezier_showpixmap;
    }

    /**
      Is Should a background indicating the changes caused by curve manipulation be shown. Immutable
    */
    static
    bool isBezier_showpixmapImmutable()
    {
      return self()->isImmutable( QStringLiteral( "bezier_showpixmap" ) );
    }

    /**
      Get Should a background indicating the changes caused by curve manipulation be shown. default value
    */
    static
    bool defaultBezier_showpixmapValue()
    {
        return defaultBezier_showpixmapValue_helper();
    }

    /**
      Set Show handles for all points or only for the selected one.
    */
    static
    void setBezier_showallhandles( bool v )
    {
      if (v != self()->mBezier_showallhandles && !self()->isBezier_showallhandlesImmutable()) {
        self()->mBezier_showallhandles = v;
        Q_EMIT self()->bezier_showallhandlesChanged();
      }
    }

    Q_PROPERTY(bool bezier_showallhandles READ bezier_showallhandles WRITE setBezier_showallhandles NOTIFY bezier_showallhandlesChanged)
    Q_PROPERTY(bool isBezier_showallhandlesImmutable READ isBezier_showallhandlesImmutable CONSTANT)
    Q_PROPERTY(bool defaultBezier_showallhandlesValue READ defaultBezier_showallhandlesValue CONSTANT)
    /**
      Get Show handles for all points or only for the selected one.
    */
    static
    bool bezier_showallhandles()
    {
      return self()->mBezier_showallhandles;
    }

    /**
      Is Show handles for all points or only for the selected one. Immutable
    */
    static
    bool isBezier_showallhandlesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "bezier_showallhandles" ) );
    }

    /**
      Get Show handles for all points or only for the selected one. default value
    */
    static
    bool defaultBezier_showallhandlesValue()
    {
        return defaultBezier_showallhandlesValue_helper();
    }

    /**
      Set ...
    */
    static
    void setDragvalue_mode( int v )
    {
      if (v != self()->mDragvalue_mode && !self()->isDragvalue_modeImmutable()) {
        self()->mDragvalue_mode = v;
        Q_EMIT self()->dragvalue_modeChanged();
      }
    }

    Q_PROPERTY(int dragvalue_mode READ dragvalue_mode WRITE setDragvalue_mode NOTIFY dragvalue_modeChanged)
    Q_PROPERTY(bool isDragvalue_modeImmutable READ isDragvalue_modeImmutable CONSTANT)
    Q_PROPERTY(int defaultDragvalue_modeValue READ defaultDragvalue_modeValue CONSTANT)
    /**
      Get ...
    */
    static
    int dragvalue_mode()
    {
      return self()->mDragvalue_mode;
    }

    /**
      Is ... Immutable
    */
    static
    bool isDragvalue_modeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "dragvalue_mode" ) );
    }

    /**
      Get ... default value
    */
    static
    int defaultDragvalue_modeValue()
    {
        return defaultDragvalue_modeValue_helper();
    }

    /**
      Set ...
    */
    static
    void setDragvalue_directupdate( bool v )
    {
      if (v != self()->mDragvalue_directupdate && !self()->isDragvalue_directupdateImmutable()) {
        self()->mDragvalue_directupdate = v;
        Q_EMIT self()->dragvalue_directupdateChanged();
      }
    }

    Q_PROPERTY(bool dragvalue_directupdate READ dragvalue_directupdate WRITE setDragvalue_directupdate NOTIFY dragvalue_directupdateChanged)
    Q_PROPERTY(bool isDragvalue_directupdateImmutable READ isDragvalue_directupdateImmutable CONSTANT)
    Q_PROPERTY(bool defaultDragvalue_directupdateValue READ defaultDragvalue_directupdateValue CONSTANT)
    /**
      Get ...
    */
    static
    bool dragvalue_directupdate()
    {
      return self()->mDragvalue_directupdate;
    }

    /**
      Is ... Immutable
    */
    static
    bool isDragvalue_directupdateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "dragvalue_directupdate" ) );
    }

    /**
      Get ... default value
    */
    static
    bool defaultDragvalue_directupdateValue()
    {
        return defaultDragvalue_directupdateValue_helper();
    }

    /**
      Set List of recently used profile ids
    */
    static
    void setRecentProfiles( const QStringList & v )
    {
      if (v != self()->mRecentProfiles && !self()->isRecentProfilesImmutable()) {
        self()->mRecentProfiles = v;
        Q_EMIT self()->recentProfilesChanged();
      }
    }

    Q_PROPERTY(QStringList recentProfiles READ recentProfiles WRITE setRecentProfiles NOTIFY recentProfilesChanged)
    Q_PROPERTY(bool isRecentProfilesImmutable READ isRecentProfilesImmutable CONSTANT)
    /**
      Get List of recently used profile ids
    */
    static
    QStringList recentProfiles()
    {
      return self()->mRecentProfiles;
    }

    /**
      Is List of recently used profile ids Immutable
    */
    static
    bool isRecentProfilesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "recentProfiles" ) );
    }

    /**
      Set List of recently used profile display names
    */
    static
    void setRecentProfileNames( const QStringList & v )
    {
      if (v != self()->mRecentProfileNames && !self()->isRecentProfileNamesImmutable()) {
        self()->mRecentProfileNames = v;
        Q_EMIT self()->recentProfileNamesChanged();
      }
    }

    Q_PROPERTY(QStringList recentProfileNames READ recentProfileNames WRITE setRecentProfileNames NOTIFY recentProfileNamesChanged)
    Q_PROPERTY(bool isRecentProfileNamesImmutable READ isRecentProfileNamesImmutable CONSTANT)
    /**
      Get List of recently used profile display names
    */
    static
    QStringList recentProfileNames()
    {
      return self()->mRecentProfileNames;
    }

    /**
      Is List of recently used profile display names Immutable
    */
    static
    bool isRecentProfileNamesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "recentProfileNames" ) );
    }

    /**
      Set Currently displayed page in properties panel
    */
    static
    void setProperties_panel_page( int v )
    {
      if (v != self()->mProperties_panel_page && !self()->isProperties_panel_pageImmutable()) {
        self()->mProperties_panel_page = v;
        Q_EMIT self()->properties_panel_pageChanged();
      }
    }

    Q_PROPERTY(int properties_panel_page READ properties_panel_page WRITE setProperties_panel_page NOTIFY properties_panel_pageChanged)
    Q_PROPERTY(bool isProperties_panel_pageImmutable READ isProperties_panel_pageImmutable CONSTANT)
    Q_PROPERTY(int defaultProperties_panel_pageValue READ defaultProperties_panel_pageValue CONSTANT)
    /**
      Get Currently displayed page in properties panel
    */
    static
    int properties_panel_page()
    {
      return self()->mProperties_panel_page;
    }

    /**
      Is Currently displayed page in properties panel Immutable
    */
    static
    bool isProperties_panel_pageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "properties_panel_page" ) );
    }

    /**
      Get Currently displayed page in properties panel default value
    */
    static
    int defaultProperties_panel_pageValue()
    {
        return defaultProperties_panel_pageValue_helper();
    }

    /**
      Set Current project fps.
    */
    static
    void setProject_fps( double v )
    {
      if (v != self()->mProject_fps && !self()->isProject_fpsImmutable()) {
        self()->mProject_fps = v;
        Q_EMIT self()->project_fpsChanged();
      }
    }

    Q_PROPERTY(double project_fps READ project_fps WRITE setProject_fps NOTIFY project_fpsChanged)
    Q_PROPERTY(bool isProject_fpsImmutable READ isProject_fpsImmutable CONSTANT)
    Q_PROPERTY(double defaultProject_fpsValue READ defaultProject_fpsValue CONSTANT)
    /**
      Get Current project fps.
    */
    static
    double project_fps()
    {
      return self()->mProject_fps;
    }

    /**
      Is Current project fps. Immutable
    */
    static
    bool isProject_fpsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "project_fps" ) );
    }

    /**
      Get Current project fps. default value
    */
    static
    double defaultProject_fpsValue()
    {
        return defaultProject_fpsValue_helper();
    }

    /**
      Set Default project format.
    */
    static
    void setDefault_profile( const QString & v )
    {
      if (v != self()->mDefault_profile && !self()->isDefault_profileImmutable()) {
        self()->mDefault_profile = v;
        Q_EMIT self()->default_profileChanged();
      }
    }

    Q_PROPERTY(QString default_profile READ default_profile WRITE setDefault_profile NOTIFY default_profileChanged)
    Q_PROPERTY(bool isDefault_profileImmutable READ isDefault_profileImmutable CONSTANT)
    /**
      Get Default project format.
    */
    static
    QString default_profile()
    {
      return self()->mDefault_profile;
    }

    /**
      Is Default project format. Immutable
    */
    static
    bool isDefault_profileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "default_profile" ) );
    }

    /**
      Set Default project layout.
    */
    static
    void setKdockLayout( const QString & v )
    {
      if (v != self()->mKdockLayout && !self()->isKdockLayoutImmutable()) {
        self()->mKdockLayout = v;
        Q_EMIT self()->kdockLayoutChanged();
      }
    }

    Q_PROPERTY(QString kdockLayout READ kdockLayout WRITE setKdockLayout NOTIFY kdockLayoutChanged)
    Q_PROPERTY(bool isKdockLayoutImmutable READ isKdockLayoutImmutable CONSTANT)
    /**
      Get Default project layout.
    */
    static
    QString kdockLayout()
    {
      return self()->mKdockLayout;
    }

    /**
      Is Default project layout. Immutable
    */
    static
    bool isKdockLayoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "kdockLayout" ) );
    }

    /**
      Set Project layout order
    */
    static
    void setLayoutsOrder( const QStringList & v )
    {
      if (v != self()->mLayoutsOrder && !self()->isLayoutsOrderImmutable()) {
        self()->mLayoutsOrder = v;
        Q_EMIT self()->layoutsOrderChanged();
      }
    }

    Q_PROPERTY(QStringList layoutsOrder READ layoutsOrder WRITE setLayoutsOrder NOTIFY layoutsOrderChanged)
    Q_PROPERTY(bool isLayoutsOrderImmutable READ isLayoutsOrderImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultLayoutsOrderValue READ defaultLayoutsOrderValue CONSTANT)
    /**
      Get Project layout order
    */
    static
    QStringList layoutsOrder()
    {
      return self()->mLayoutsOrder;
    }

    /**
      Is Project layout order Immutable
    */
    static
    bool isLayoutsOrderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "layoutsOrder" ) );
    }

    /**
      Get Project layout order default value
    */
    static
    QStringList defaultLayoutsOrderValue()
    {
        return defaultLayoutsOrderValue_helper();
    }

    /**
      Set Show descriptions in project tree view.
    */
    static
    void setShowdescriptioncolumn( bool v )
    {
      if (v != self()->mShowdescriptioncolumn && !self()->isShowdescriptioncolumnImmutable()) {
        self()->mShowdescriptioncolumn = v;
        Q_EMIT self()->showdescriptioncolumnChanged();
      }
    }

    Q_PROPERTY(bool showdescriptioncolumn READ showdescriptioncolumn WRITE setShowdescriptioncolumn NOTIFY showdescriptioncolumnChanged)
    Q_PROPERTY(bool isShowdescriptioncolumnImmutable READ isShowdescriptioncolumnImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowdescriptioncolumnValue READ defaultShowdescriptioncolumnValue CONSTANT)
    /**
      Get Show descriptions in project tree view.
    */
    static
    bool showdescriptioncolumn()
    {
      return self()->mShowdescriptioncolumn;
    }

    /**
      Is Show descriptions in project tree view. Immutable
    */
    static
    bool isShowdescriptioncolumnImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showdescriptioncolumn" ) );
    }

    /**
      Get Show descriptions in project tree view. default value
    */
    static
    bool defaultShowdescriptioncolumnValue()
    {
        return defaultShowdescriptioncolumnValue_helper();
    }

    /**
      Set Show ratings in project tree view.
    */
    static
    void setShowratingcolumn( bool v )
    {
      if (v != self()->mShowratingcolumn && !self()->isShowratingcolumnImmutable()) {
        self()->mShowratingcolumn = v;
        Q_EMIT self()->showratingcolumnChanged();
      }
    }

    Q_PROPERTY(bool showratingcolumn READ showratingcolumn WRITE setShowratingcolumn NOTIFY showratingcolumnChanged)
    Q_PROPERTY(bool isShowratingcolumnImmutable READ isShowratingcolumnImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowratingcolumnValue READ defaultShowratingcolumnValue CONSTANT)
    /**
      Get Show ratings in project tree view.
    */
    static
    bool showratingcolumn()
    {
      return self()->mShowratingcolumn;
    }

    /**
      Is Show ratings in project tree view. Immutable
    */
    static
    bool isShowratingcolumnImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showratingcolumn" ) );
    }

    /**
      Get Show ratings in project tree view. default value
    */
    static
    bool defaultShowratingcolumnValue()
    {
        return defaultShowratingcolumnValue_helper();
    }

    /**
      Set Show dates in project tree view.
    */
    static
    void setShowdatecolumn( bool v )
    {
      if (v != self()->mShowdatecolumn && !self()->isShowdatecolumnImmutable()) {
        self()->mShowdatecolumn = v;
        Q_EMIT self()->showdatecolumnChanged();
      }
    }

    Q_PROPERTY(bool showdatecolumn READ showdatecolumn WRITE setShowdatecolumn NOTIFY showdatecolumnChanged)
    Q_PROPERTY(bool isShowdatecolumnImmutable READ isShowdatecolumnImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowdatecolumnValue READ defaultShowdatecolumnValue CONSTANT)
    /**
      Get Show dates in project tree view.
    */
    static
    bool showdatecolumn()
    {
      return self()->mShowdatecolumn;
    }

    /**
      Is Show dates in project tree view. Immutable
    */
    static
    bool isShowdatecolumnImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showdatecolumn" ) );
    }

    /**
      Get Show dates in project tree view. default value
    */
    static
    bool defaultShowdatecolumnValue()
    {
        return defaultShowdatecolumnValue_helper();
    }

    /**
      Set Show timecodes as frame number instead of hh:mm:ss:ff.
    */
    static
    void setFrametimecode( bool v )
    {
      if (v != self()->mFrametimecode && !self()->isFrametimecodeImmutable()) {
        self()->mFrametimecode = v;
        Q_EMIT self()->frametimecodeChanged();
      }
    }

    Q_PROPERTY(bool frametimecode READ frametimecode WRITE setFrametimecode NOTIFY frametimecodeChanged)
    Q_PROPERTY(bool isFrametimecodeImmutable READ isFrametimecodeImmutable CONSTANT)
    Q_PROPERTY(bool defaultFrametimecodeValue READ defaultFrametimecodeValue CONSTANT)
    /**
      Get Show timecodes as frame number instead of hh:mm:ss:ff.
    */
    static
    bool frametimecode()
    {
      return self()->mFrametimecode;
    }

    /**
      Is Show timecodes as frame number instead of hh:mm:ss:ff. Immutable
    */
    static
    bool isFrametimecodeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "frametimecode" ) );
    }

    /**
      Get Show timecodes as frame number instead of hh:mm:ss:ff. default value
    */
    static
    bool defaultFrametimecodeValue()
    {
        return defaultFrametimecodeValue_helper();
    }

    /**
      Set Show recorded timecode in clip monitor, in format hh:mm:ss:ff.
    */
    static
    void setRectimecode( bool v )
    {
      if (v != self()->mRectimecode && !self()->isRectimecodeImmutable()) {
        self()->mRectimecode = v;
        Q_EMIT self()->rectimecodeChanged();
      }
    }

    Q_PROPERTY(bool rectimecode READ rectimecode WRITE setRectimecode NOTIFY rectimecodeChanged)
    Q_PROPERTY(bool isRectimecodeImmutable READ isRectimecodeImmutable CONSTANT)
    Q_PROPERTY(bool defaultRectimecodeValue READ defaultRectimecodeValue CONSTANT)
    /**
      Get Show recorded timecode in clip monitor, in format hh:mm:ss:ff.
    */
    static
    bool rectimecode()
    {
      return self()->mRectimecode;
    }

    /**
      Is Show recorded timecode in clip monitor, in format hh:mm:ss:ff. Immutable
    */
    static
    bool isRectimecodeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "rectimecode" ) );
    }

    /**
      Get Show recorded timecode in clip monitor, in format hh:mm:ss:ff. default value
    */
    static
    bool defaultRectimecodeValue()
    {
        return defaultRectimecodeValue_helper();
    }

    /**
      Set Snap movements to clips, guides and markers.
    */
    static
    void setSnaptopoints( bool v )
    {
      if (v != self()->mSnaptopoints && !self()->isSnaptopointsImmutable()) {
        self()->mSnaptopoints = v;
        Q_EMIT self()->snaptopointsChanged();
      }
    }

    Q_PROPERTY(bool snaptopoints READ snaptopoints WRITE setSnaptopoints NOTIFY snaptopointsChanged)
    Q_PROPERTY(bool isSnaptopointsImmutable READ isSnaptopointsImmutable CONSTANT)
    Q_PROPERTY(bool defaultSnaptopointsValue READ defaultSnaptopointsValue CONSTANT)
    /**
      Get Snap movements to clips, guides and markers.
    */
    static
    bool snaptopoints()
    {
      return self()->mSnaptopoints;
    }

    /**
      Is Snap movements to clips, guides and markers. Immutable
    */
    static
    bool isSnaptopointsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "snaptopoints" ) );
    }

    /**
      Get Snap movements to clips, guides and markers. default value
    */
    static
    bool defaultSnaptopointsValue()
    {
        return defaultSnaptopointsValue_helper();
    }

    /**
      Set Show clip name and infos in timeline.
    */
    static
    void setShowClipOverlays( bool v )
    {
      if (v != self()->mShowClipOverlays && !self()->isShowClipOverlaysImmutable()) {
        self()->mShowClipOverlays = v;
        Q_EMIT self()->showClipOverlaysChanged();
      }
    }

    Q_PROPERTY(bool showClipOverlays READ showClipOverlays WRITE setShowClipOverlays NOTIFY showClipOverlaysChanged)
    Q_PROPERTY(bool isShowClipOverlaysImmutable READ isShowClipOverlaysImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowClipOverlaysValue READ defaultShowClipOverlaysValue CONSTANT)
    /**
      Get Show clip name and infos in timeline.
    */
    static
    bool showClipOverlays()
    {
      return self()->mShowClipOverlays;
    }

    /**
      Is Show clip name and infos in timeline. Immutable
    */
    static
    bool isShowClipOverlaysImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showClipOverlays" ) );
    }

    /**
      Get Show clip name and infos in timeline. default value
    */
    static
    bool defaultShowClipOverlaysValue()
    {
        return defaultShowClipOverlaysValue_helper();
    }

    /**
      Set Enable Ripple edit when changing multiple clips duration.
    */
    static
    void setRippleResize( bool v )
    {
      if (v != self()->mRippleResize && !self()->isRippleResizeImmutable()) {
        self()->mRippleResize = v;
        Q_EMIT self()->rippleResizeChanged();
      }
    }

    Q_PROPERTY(bool rippleResize READ rippleResize WRITE setRippleResize NOTIFY rippleResizeChanged)
    Q_PROPERTY(bool isRippleResizeImmutable READ isRippleResizeImmutable CONSTANT)
    Q_PROPERTY(bool defaultRippleResizeValue READ defaultRippleResizeValue CONSTANT)
    /**
      Get Enable Ripple edit when changing multiple clips duration.
    */
    static
    bool rippleResize()
    {
      return self()->mRippleResize;
    }

    /**
      Is Enable Ripple edit when changing multiple clips duration. Immutable
    */
    static
    bool isRippleResizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "rippleResize" ) );
    }

    /**
      Get Enable Ripple edit when changing multiple clips duration. default value
    */
    static
    bool defaultRippleResizeValue()
    {
        return defaultRippleResizeValue_helper();
    }

    /**
      Set Lock guides on spacer movements (insert/remove space).
    */
    static
    void setLockedGuides( bool v )
    {
      if (v != self()->mLockedGuides && !self()->isLockedGuidesImmutable()) {
        self()->mLockedGuides = v;
        Q_EMIT self()->lockedGuidesChanged();
      }
    }

    Q_PROPERTY(bool lockedGuides READ lockedGuides WRITE setLockedGuides NOTIFY lockedGuidesChanged)
    Q_PROPERTY(bool isLockedGuidesImmutable READ isLockedGuidesImmutable CONSTANT)
    Q_PROPERTY(bool defaultLockedGuidesValue READ defaultLockedGuidesValue CONSTANT)
    /**
      Get Lock guides on spacer movements (insert/remove space).
    */
    static
    bool lockedGuides()
    {
      return self()->mLockedGuides;
    }

    /**
      Is Lock guides on spacer movements (insert/remove space). Immutable
    */
    static
    bool isLockedGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lockedGuides" ) );
    }

    /**
      Get Lock guides on spacer movements (insert/remove space). default value
    */
    static
    bool defaultLockedGuidesValue()
    {
        return defaultLockedGuidesValue_helper();
    }

    /**
      Set The default guide categories.
    */
    static
    void setGuidesCategories( const QStringList & v )
    {
      if (v != self()->mGuidesCategories && !self()->isGuidesCategoriesImmutable()) {
        self()->mGuidesCategories = v;
        Q_EMIT self()->guidesCategoriesChanged();
      }
    }

    Q_PROPERTY(QStringList guidesCategories READ guidesCategories WRITE setGuidesCategories NOTIFY guidesCategoriesChanged)
    Q_PROPERTY(bool isGuidesCategoriesImmutable READ isGuidesCategoriesImmutable CONSTANT)
    /**
      Get The default guide categories.
    */
    static
    QStringList guidesCategories()
    {
      return self()->mGuidesCategories;
    }

    /**
      Is The default guide categories. Immutable
    */
    static
    bool isGuidesCategoriesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "guidesCategories" ) );
    }

    /**
      Set Show color tags in timeline.
    */
    static
    void setTagsintimeline( bool v )
    {
      if (v != self()->mTagsintimeline && !self()->isTagsintimelineImmutable()) {
        self()->mTagsintimeline = v;
        Q_EMIT self()->tagsintimelineChanged();
      }
    }

    Q_PROPERTY(bool tagsintimeline READ tagsintimeline WRITE setTagsintimeline NOTIFY tagsintimelineChanged)
    Q_PROPERTY(bool isTagsintimelineImmutable READ isTagsintimelineImmutable CONSTANT)
    Q_PROPERTY(bool defaultTagsintimelineValue READ defaultTagsintimelineValue CONSTANT)
    /**
      Get Show color tags in timeline.
    */
    static
    bool tagsintimeline()
    {
      return self()->mTagsintimeline;
    }

    /**
      Is Show color tags in timeline. Immutable
    */
    static
    bool isTagsintimelineImmutable()
    {
      return self()->isImmutable( QStringLiteral( "tagsintimeline" ) );
    }

    /**
      Get Show color tags in timeline. default value
    */
    static
    bool defaultTagsintimelineValue()
    {
        return defaultTagsintimelineValue_helper();
    }

    /**
      Set Mouse zoom on timeline based on playhead position, not mouse position.
    */
    static
    void setTimelinemousezoomonplayhead( bool v )
    {
      if (v != self()->mTimelinemousezoomonplayhead && !self()->isTimelinemousezoomonplayheadImmutable()) {
        self()->mTimelinemousezoomonplayhead = v;
        Q_EMIT self()->timelinemousezoomonplayheadChanged();
      }
    }

    Q_PROPERTY(bool timelinemousezoomonplayhead READ timelinemousezoomonplayhead WRITE setTimelinemousezoomonplayhead NOTIFY timelinemousezoomonplayheadChanged)
    Q_PROPERTY(bool isTimelinemousezoomonplayheadImmutable READ isTimelinemousezoomonplayheadImmutable CONSTANT)
    Q_PROPERTY(bool defaultTimelinemousezoomonplayheadValue READ defaultTimelinemousezoomonplayheadValue CONSTANT)
    /**
      Get Mouse zoom on timeline based on playhead position, not mouse position.
    */
    static
    bool timelinemousezoomonplayhead()
    {
      return self()->mTimelinemousezoomonplayhead;
    }

    /**
      Is Mouse zoom on timeline based on playhead position, not mouse position. Immutable
    */
    static
    bool isTimelinemousezoomonplayheadImmutable()
    {
      return self()->isImmutable( QStringLiteral( "timelinemousezoomonplayhead" ) );
    }

    /**
      Get Mouse zoom on timeline based on playhead position, not mouse position. default value
    */
    static
    bool defaultTimelinemousezoomonplayheadValue()
    {
        return defaultTimelinemousezoomonplayheadValue_helper();
    }

    /**
      Set When editing a composite transition, move timeline cursor for better preview.
    */
    static
    void setTransitionfollowcursor( bool v )
    {
      if (v != self()->mTransitionfollowcursor && !self()->isTransitionfollowcursorImmutable()) {
        self()->mTransitionfollowcursor = v;
        Q_EMIT self()->transitionfollowcursorChanged();
      }
    }

    Q_PROPERTY(bool transitionfollowcursor READ transitionfollowcursor WRITE setTransitionfollowcursor NOTIFY transitionfollowcursorChanged)
    Q_PROPERTY(bool isTransitionfollowcursorImmutable READ isTransitionfollowcursorImmutable CONSTANT)
    Q_PROPERTY(bool defaultTransitionfollowcursorValue READ defaultTransitionfollowcursorValue CONSTANT)
    /**
      Get When editing a composite transition, move timeline cursor for better preview.
    */
    static
    bool transitionfollowcursor()
    {
      return self()->mTransitionfollowcursor;
    }

    /**
      Is When editing a composite transition, move timeline cursor for better preview. Immutable
    */
    static
    bool isTransitionfollowcursorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transitionfollowcursor" ) );
    }

    /**
      Get When editing a composite transition, move timeline cursor for better preview. default value
    */
    static
    bool defaultTransitionfollowcursorValue()
    {
        return defaultTransitionfollowcursorValue_helper();
    }

    /**
      Set When editing an effect with position, seek to the keyframe pos.
    */
    static
    void setKeyframeseek( bool v )
    {
      if (v != self()->mKeyframeseek && !self()->isKeyframeseekImmutable()) {
        self()->mKeyframeseek = v;
        Q_EMIT self()->keyframeseekChanged();
      }
    }

    Q_PROPERTY(bool keyframeseek READ keyframeseek WRITE setKeyframeseek NOTIFY keyframeseekChanged)
    Q_PROPERTY(bool isKeyframeseekImmutable READ isKeyframeseekImmutable CONSTANT)
    Q_PROPERTY(bool defaultKeyframeseekValue READ defaultKeyframeseekValue CONSTANT)
    /**
      Get When editing an effect with position, seek to the keyframe pos.
    */
    static
    bool keyframeseek()
    {
      return self()->mKeyframeseek;
    }

    /**
      Is When editing an effect with position, seek to the keyframe pos. Immutable
    */
    static
    bool isKeyframeseekImmutable()
    {
      return self()->isImmutable( QStringLiteral( "keyframeseek" ) );
    }

    /**
      Get When editing an effect with position, seek to the keyframe pos. default value
    */
    static
    bool defaultKeyframeseekValue()
    {
        return defaultKeyframeseekValue_helper();
    }

    /**
      Set Show small effect description in effects list.
    */
    static
    void setShoweffectinfo( bool v )
    {
      if (v != self()->mShoweffectinfo && !self()->isShoweffectinfoImmutable()) {
        self()->mShoweffectinfo = v;
        Q_EMIT self()->showeffectinfoChanged();
      }
    }

    Q_PROPERTY(bool showeffectinfo READ showeffectinfo WRITE setShoweffectinfo NOTIFY showeffectinfoChanged)
    Q_PROPERTY(bool isShoweffectinfoImmutable READ isShoweffectinfoImmutable CONSTANT)
    Q_PROPERTY(bool defaultShoweffectinfoValue READ defaultShoweffectinfoValue CONSTANT)
    /**
      Get Show small effect description in effects list.
    */
    static
    bool showeffectinfo()
    {
      return self()->mShoweffectinfo;
    }

    /**
      Is Show small effect description in effects list. Immutable
    */
    static
    bool isShoweffectinfoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showeffectinfo" ) );
    }

    /**
      Get Show small effect description in effects list. default value
    */
    static
    bool defaultShoweffectinfoValue()
    {
        return defaultShoweffectinfoValue_helper();
    }

    /**
      Set Apply effect param change to all clips in the group.
    */
    static
    void setApplyEffectParamsToGroup( bool v )
    {
      if (v != self()->mApplyEffectParamsToGroup && !self()->isApplyEffectParamsToGroupImmutable()) {
        self()->mApplyEffectParamsToGroup = v;
        Q_EMIT self()->applyEffectParamsToGroupChanged();
      }
    }

    Q_PROPERTY(bool applyEffectParamsToGroup READ applyEffectParamsToGroup WRITE setApplyEffectParamsToGroup NOTIFY applyEffectParamsToGroupChanged)
    Q_PROPERTY(bool isApplyEffectParamsToGroupImmutable READ isApplyEffectParamsToGroupImmutable CONSTANT)
    Q_PROPERTY(bool defaultApplyEffectParamsToGroupValue READ defaultApplyEffectParamsToGroupValue CONSTANT)
    /**
      Get Apply effect param change to all clips in the group.
    */
    static
    bool applyEffectParamsToGroup()
    {
      return self()->mApplyEffectParamsToGroup;
    }

    /**
      Is Apply effect param change to all clips in the group. Immutable
    */
    static
    bool isApplyEffectParamsToGroupImmutable()
    {
      return self()->isImmutable( QStringLiteral( "applyEffectParamsToGroup" ) );
    }

    /**
      Get Apply effect param change to all clips in the group. default value
    */
    static
    bool defaultApplyEffectParamsToGroupValue()
    {
        return defaultApplyEffectParamsToGroupValue_helper();
    }

    /**
      Set Apply group effect param change only to effects having the same param value.
    */
    static
    void setApplyEffectParamsToGroupWithSameValue( bool v )
    {
      if (v != self()->mApplyEffectParamsToGroupWithSameValue && !self()->isApplyEffectParamsToGroupWithSameValueImmutable()) {
        self()->mApplyEffectParamsToGroupWithSameValue = v;
        Q_EMIT self()->applyEffectParamsToGroupWithSameValueChanged();
      }
    }

    Q_PROPERTY(bool applyEffectParamsToGroupWithSameValue READ applyEffectParamsToGroupWithSameValue WRITE setApplyEffectParamsToGroupWithSameValue NOTIFY applyEffectParamsToGroupWithSameValueChanged)
    Q_PROPERTY(bool isApplyEffectParamsToGroupWithSameValueImmutable READ isApplyEffectParamsToGroupWithSameValueImmutable CONSTANT)
    Q_PROPERTY(bool defaultApplyEffectParamsToGroupWithSameValueValue READ defaultApplyEffectParamsToGroupWithSameValueValue CONSTANT)
    /**
      Get Apply group effect param change only to effects having the same param value.
    */
    static
    bool applyEffectParamsToGroupWithSameValue()
    {
      return self()->mApplyEffectParamsToGroupWithSameValue;
    }

    /**
      Is Apply group effect param change only to effects having the same param value. Immutable
    */
    static
    bool isApplyEffectParamsToGroupWithSameValueImmutable()
    {
      return self()->isImmutable( QStringLiteral( "applyEffectParamsToGroupWithSameValue" ) );
    }

    /**
      Get Apply group effect param change only to effects having the same param value. default value
    */
    static
    bool defaultApplyEffectParamsToGroupWithSameValueValue()
    {
        return defaultApplyEffectParamsToGroupWithSameValueValue_helper();
    }

    /**
      Set Default render profile.
    */
    static
    void setRenderProfile( const QString & v )
    {
      if (v != self()->mRenderProfile && !self()->isRenderProfileImmutable()) {
        self()->mRenderProfile = v;
        Q_EMIT self()->renderProfileChanged();
      }
    }

    Q_PROPERTY(QString renderProfile READ renderProfile WRITE setRenderProfile NOTIFY renderProfileChanged)
    Q_PROPERTY(bool isRenderProfileImmutable READ isRenderProfileImmutable CONSTANT)
    Q_PROPERTY(QString defaultRenderProfileValue READ defaultRenderProfileValue CONSTANT)
    /**
      Get Default render profile.
    */
    static
    QString renderProfile()
    {
      return self()->mRenderProfile;
    }

    /**
      Is Default render profile. Immutable
    */
    static
    bool isRenderProfileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "renderProfile" ) );
    }

    /**
      Get Default render profile. default value
    */
    static
    QString defaultRenderProfileValue()
    {
        return defaultRenderProfileValue_helper();
    }

    /**
      Set Should we delete log files after successful render.
    */
    static
    void setKeepRenderLogFiles( bool v )
    {
      if (v != self()->mKeepRenderLogFiles && !self()->isKeepRenderLogFilesImmutable()) {
        self()->mKeepRenderLogFiles = v;
        Q_EMIT self()->keepRenderLogFilesChanged();
      }
    }

    Q_PROPERTY(bool keepRenderLogFiles READ keepRenderLogFiles WRITE setKeepRenderLogFiles NOTIFY keepRenderLogFilesChanged)
    Q_PROPERTY(bool isKeepRenderLogFilesImmutable READ isKeepRenderLogFilesImmutable CONSTANT)
    Q_PROPERTY(bool defaultKeepRenderLogFilesValue READ defaultKeepRenderLogFilesValue CONSTANT)
    /**
      Get Should we delete log files after successful render.
    */
    static
    bool keepRenderLogFiles()
    {
      return self()->mKeepRenderLogFiles;
    }

    /**
      Is Should we delete log files after successful render. Immutable
    */
    static
    bool isKeepRenderLogFilesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "keepRenderLogFiles" ) );
    }

    /**
      Get Should we delete log files after successful render. default value
    */
    static
    bool defaultKeepRenderLogFilesValue()
    {
        return defaultKeepRenderLogFilesValue_helper();
    }

    /**
      Set The paths of lut files that have been validated.
    */
    static
    void setValidated_luts( const QStringList & v )
    {
      if (v != self()->mValidated_luts && !self()->isValidated_lutsImmutable()) {
        self()->mValidated_luts = v;
        Q_EMIT self()->validated_lutsChanged();
      }
    }

    Q_PROPERTY(QStringList validated_luts READ validated_luts WRITE setValidated_luts NOTIFY validated_lutsChanged)
    Q_PROPERTY(bool isValidated_lutsImmutable READ isValidated_lutsImmutable CONSTANT)
    /**
      Get The paths of lut files that have been validated.
    */
    static
    QStringList validated_luts()
    {
      return self()->mValidated_luts;
    }

    /**
      Is The paths of lut files that have been validated. Immutable
    */
    static
    bool isValidated_lutsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "validated_luts" ) );
    }

    /**
      Set Show overlay info on monitor (in / out points, markers,...).
    */
    static
    void setDisplayClipMonitorInfo( int v )
    {
      if (v != self()->mDisplayClipMonitorInfo && !self()->isDisplayClipMonitorInfoImmutable()) {
        self()->mDisplayClipMonitorInfo = v;
        Q_EMIT self()->displayClipMonitorInfoChanged();
      }
    }

    Q_PROPERTY(int displayClipMonitorInfo READ displayClipMonitorInfo WRITE setDisplayClipMonitorInfo NOTIFY displayClipMonitorInfoChanged)
    Q_PROPERTY(bool isDisplayClipMonitorInfoImmutable READ isDisplayClipMonitorInfoImmutable CONSTANT)
    Q_PROPERTY(int defaultDisplayClipMonitorInfoValue READ defaultDisplayClipMonitorInfoValue CONSTANT)
    /**
      Get Show overlay info on monitor (in / out points, markers,...).
    */
    static
    int displayClipMonitorInfo()
    {
      return self()->mDisplayClipMonitorInfo;
    }

    /**
      Is Show overlay info on monitor (in / out points, markers,...). Immutable
    */
    static
    bool isDisplayClipMonitorInfoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "displayClipMonitorInfo" ) );
    }

    /**
      Get Show overlay info on monitor (in / out points, markers,...). default value
    */
    static
    int defaultDisplayClipMonitorInfoValue()
    {
        return defaultDisplayClipMonitorInfoValue_helper();
    }

    /**
      Set Show monitor safe zones.
    */
    static
    void setShowClipMonitorSafeZone( bool v )
    {
      if (v != self()->mShowClipMonitorSafeZone && !self()->isShowClipMonitorSafeZoneImmutable()) {
        self()->mShowClipMonitorSafeZone = v;
        Q_EMIT self()->showClipMonitorSafeZoneChanged();
      }
    }

    Q_PROPERTY(bool showClipMonitorSafeZone READ showClipMonitorSafeZone WRITE setShowClipMonitorSafeZone NOTIFY showClipMonitorSafeZoneChanged)
    Q_PROPERTY(bool isShowClipMonitorSafeZoneImmutable READ isShowClipMonitorSafeZoneImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowClipMonitorSafeZoneValue READ defaultShowClipMonitorSafeZoneValue CONSTANT)
    /**
      Get Show monitor safe zones.
    */
    static
    bool showClipMonitorSafeZone()
    {
      return self()->mShowClipMonitorSafeZone;
    }

    /**
      Is Show monitor safe zones. Immutable
    */
    static
    bool isShowClipMonitorSafeZoneImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showClipMonitorSafeZone" ) );
    }

    /**
      Get Show monitor safe zones. default value
    */
    static
    bool defaultShowClipMonitorSafeZoneValue()
    {
        return defaultShowClipMonitorSafeZoneValue_helper();
    }

    /**
      Set Show monitor safe zones.
    */
    static
    void setShowProjectMonitorSafeZone( bool v )
    {
      if (v != self()->mShowProjectMonitorSafeZone && !self()->isShowProjectMonitorSafeZoneImmutable()) {
        self()->mShowProjectMonitorSafeZone = v;
        Q_EMIT self()->showProjectMonitorSafeZoneChanged();
      }
    }

    Q_PROPERTY(bool showProjectMonitorSafeZone READ showProjectMonitorSafeZone WRITE setShowProjectMonitorSafeZone NOTIFY showProjectMonitorSafeZoneChanged)
    Q_PROPERTY(bool isShowProjectMonitorSafeZoneImmutable READ isShowProjectMonitorSafeZoneImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowProjectMonitorSafeZoneValue READ defaultShowProjectMonitorSafeZoneValue CONSTANT)
    /**
      Get Show monitor safe zones.
    */
    static
    bool showProjectMonitorSafeZone()
    {
      return self()->mShowProjectMonitorSafeZone;
    }

    /**
      Is Show monitor safe zones. Immutable
    */
    static
    bool isShowProjectMonitorSafeZoneImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showProjectMonitorSafeZone" ) );
    }

    /**
      Get Show monitor safe zones. default value
    */
    static
    bool defaultShowProjectMonitorSafeZoneValue()
    {
        return defaultShowProjectMonitorSafeZoneValue_helper();
    }

    /**
      Set Show overlay info on monitor (in / out points, markers,...).
    */
    static
    void setDisplayProjectMonitorInfo( int v )
    {
      if (v != self()->mDisplayProjectMonitorInfo && !self()->isDisplayProjectMonitorInfoImmutable()) {
        self()->mDisplayProjectMonitorInfo = v;
        Q_EMIT self()->displayProjectMonitorInfoChanged();
      }
    }

    Q_PROPERTY(int displayProjectMonitorInfo READ displayProjectMonitorInfo WRITE setDisplayProjectMonitorInfo NOTIFY displayProjectMonitorInfoChanged)
    Q_PROPERTY(bool isDisplayProjectMonitorInfoImmutable READ isDisplayProjectMonitorInfoImmutable CONSTANT)
    Q_PROPERTY(int defaultDisplayProjectMonitorInfoValue READ defaultDisplayProjectMonitorInfoValue CONSTANT)
    /**
      Get Show overlay info on monitor (in / out points, markers,...).
    */
    static
    int displayProjectMonitorInfo()
    {
      return self()->mDisplayProjectMonitorInfo;
    }

    /**
      Is Show overlay info on monitor (in / out points, markers,...). Immutable
    */
    static
    bool isDisplayProjectMonitorInfoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "displayProjectMonitorInfo" ) );
    }

    /**
      Get Show overlay info on monitor (in / out points, markers,...). default value
    */
    static
    int defaultDisplayProjectMonitorInfoValue()
    {
        return defaultDisplayProjectMonitorInfoValue_helper();
    }

    /**
      Set Divide monitor resolution by this factor to speedup preview.
    */
    static
    void setPreviewScaling( int v )
    {
      if (v != self()->mPreviewScaling && !self()->isPreviewScalingImmutable()) {
        self()->mPreviewScaling = v;
        Q_EMIT self()->previewScalingChanged();
      }
    }

    Q_PROPERTY(int previewScaling READ previewScaling WRITE setPreviewScaling NOTIFY previewScalingChanged)
    Q_PROPERTY(bool isPreviewScalingImmutable READ isPreviewScalingImmutable CONSTANT)
    Q_PROPERTY(int defaultPreviewScalingValue READ defaultPreviewScalingValue CONSTANT)
    /**
      Get Divide monitor resolution by this factor to speedup preview.
    */
    static
    int previewScaling()
    {
      return self()->mPreviewScaling;
    }

    /**
      Is Divide monitor resolution by this factor to speedup preview. Immutable
    */
    static
    bool isPreviewScalingImmutable()
    {
      return self()->isImmutable( QStringLiteral( "previewScaling" ) );
    }

    /**
      Get Divide monitor resolution by this factor to speedup preview. default value
    */
    static
    int defaultPreviewScalingValue()
    {
        return defaultPreviewScalingValue_helper();
    }

    /**
      Set Automatically create a new keyframe on keyframe move.
    */
    static
    void setAutoKeyframe( bool v )
    {
      if (v != self()->mAutoKeyframe && !self()->isAutoKeyframeImmutable()) {
        self()->mAutoKeyframe = v;
        Q_EMIT self()->autoKeyframeChanged();
      }
    }

    Q_PROPERTY(bool autoKeyframe READ autoKeyframe WRITE setAutoKeyframe NOTIFY autoKeyframeChanged)
    Q_PROPERTY(bool isAutoKeyframeImmutable READ isAutoKeyframeImmutable CONSTANT)
    Q_PROPERTY(bool defaultAutoKeyframeValue READ defaultAutoKeyframeValue CONSTANT)
    /**
      Get Automatically create a new keyframe on keyframe move.
    */
    static
    bool autoKeyframe()
    {
      return self()->mAutoKeyframe;
    }

    /**
      Is Automatically create a new keyframe on keyframe move. Immutable
    */
    static
    bool isAutoKeyframeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autoKeyframe" ) );
    }

    /**
      Get Automatically create a new keyframe on keyframe move. default value
    */
    static
    bool defaultAutoKeyframeValue()
    {
        return defaultAutoKeyframeValue_helper();
    }

    /**
      Set Limit the frequency of created keyframes when playing.
    */
    static
    void setLimitAutoKeyframes( int v )
    {
      if (v != self()->mLimitAutoKeyframes && !self()->isLimitAutoKeyframesImmutable()) {
        self()->mLimitAutoKeyframes = v;
        Q_EMIT self()->limitAutoKeyframesChanged();
      }
    }

    Q_PROPERTY(int limitAutoKeyframes READ limitAutoKeyframes WRITE setLimitAutoKeyframes NOTIFY limitAutoKeyframesChanged)
    Q_PROPERTY(bool isLimitAutoKeyframesImmutable READ isLimitAutoKeyframesImmutable CONSTANT)
    Q_PROPERTY(int defaultLimitAutoKeyframesValue READ defaultLimitAutoKeyframesValue CONSTANT)
    /**
      Get Limit the frequency of created keyframes when playing.
    */
    static
    int limitAutoKeyframes()
    {
      return self()->mLimitAutoKeyframes;
    }

    /**
      Is Limit the frequency of created keyframes when playing. Immutable
    */
    static
    bool isLimitAutoKeyframesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "limitAutoKeyframes" ) );
    }

    /**
      Get Limit the frequency of created keyframes when playing. default value
    */
    static
    int defaultLimitAutoKeyframesValue()
    {
        return defaultLimitAutoKeyframesValue_helper();
    }

    /**
      Set Default interval for auto keyframes limit when playing.
    */
    static
    void setLimitAutoKeyframesInterval( int v )
    {
      if (v != self()->mLimitAutoKeyframesInterval && !self()->isLimitAutoKeyframesIntervalImmutable()) {
        self()->mLimitAutoKeyframesInterval = v;
        Q_EMIT self()->limitAutoKeyframesIntervalChanged();
      }
    }

    Q_PROPERTY(int limitAutoKeyframesInterval READ limitAutoKeyframesInterval WRITE setLimitAutoKeyframesInterval NOTIFY limitAutoKeyframesIntervalChanged)
    Q_PROPERTY(bool isLimitAutoKeyframesIntervalImmutable READ isLimitAutoKeyframesIntervalImmutable CONSTANT)
    Q_PROPERTY(int defaultLimitAutoKeyframesIntervalValue READ defaultLimitAutoKeyframesIntervalValue CONSTANT)
    /**
      Get Default interval for auto keyframes limit when playing.
    */
    static
    int limitAutoKeyframesInterval()
    {
      return self()->mLimitAutoKeyframesInterval;
    }

    /**
      Is Default interval for auto keyframes limit when playing. Immutable
    */
    static
    bool isLimitAutoKeyframesIntervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "limitAutoKeyframesInterval" ) );
    }

    /**
      Get Default interval for auto keyframes limit when playing. default value
    */
    static
    int defaultLimitAutoKeyframesIntervalValue()
    {
        return defaultLimitAutoKeyframesIntervalValue_helper();
    }

    /**
      Set Opacity of object masks on monitor.
    */
    static
    void setMaskOpacity( int v )
    {
      if (v != self()->mMaskOpacity && !self()->isMaskOpacityImmutable()) {
        self()->mMaskOpacity = v;
        Q_EMIT self()->maskOpacityChanged();
      }
    }

    Q_PROPERTY(int maskOpacity READ maskOpacity WRITE setMaskOpacity NOTIFY maskOpacityChanged)
    Q_PROPERTY(bool isMaskOpacityImmutable READ isMaskOpacityImmutable CONSTANT)
    Q_PROPERTY(int defaultMaskOpacityValue READ defaultMaskOpacityValue CONSTANT)
    /**
      Get Opacity of object masks on monitor.
    */
    static
    int maskOpacity()
    {
      return self()->mMaskOpacity;
    }

    /**
      Is Opacity of object masks on monitor. Immutable
    */
    static
    bool isMaskOpacityImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maskOpacity" ) );
    }

    /**
      Get Opacity of object masks on monitor. default value
    */
    static
    int defaultMaskOpacityValue()
    {
        return defaultMaskOpacityValue_helper();
    }

    /**
      Set Invert alpha mask display.
    */
    static
    void setMaskInverted( bool v )
    {
      if (v != self()->mMaskInverted && !self()->isMaskInvertedImmutable()) {
        self()->mMaskInverted = v;
        Q_EMIT self()->maskInvertedChanged();
      }
    }

    Q_PROPERTY(bool maskInverted READ maskInverted WRITE setMaskInverted NOTIFY maskInvertedChanged)
    Q_PROPERTY(bool isMaskInvertedImmutable READ isMaskInvertedImmutable CONSTANT)
    Q_PROPERTY(bool defaultMaskInvertedValue READ defaultMaskInvertedValue CONSTANT)
    /**
      Get Invert alpha mask display.
    */
    static
    bool maskInverted()
    {
      return self()->mMaskInverted;
    }

    /**
      Is Invert alpha mask display. Immutable
    */
    static
    bool isMaskInvertedImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maskInverted" ) );
    }

    /**
      Get Invert alpha mask display. default value
    */
    static
    bool defaultMaskInvertedValue()
    {
        return defaultMaskInvertedValue_helper();
    }

    /**
      Set index of current guides overlay for clip monitor.
    */
    static
    void setClipMonitorOverlayGuides( int v )
    {
      if (v != self()->mClipMonitorOverlayGuides && !self()->isClipMonitorOverlayGuidesImmutable()) {
        self()->mClipMonitorOverlayGuides = v;
        Q_EMIT self()->clipMonitorOverlayGuidesChanged();
      }
    }

    Q_PROPERTY(int clipMonitorOverlayGuides READ clipMonitorOverlayGuides WRITE setClipMonitorOverlayGuides NOTIFY clipMonitorOverlayGuidesChanged)
    Q_PROPERTY(bool isClipMonitorOverlayGuidesImmutable READ isClipMonitorOverlayGuidesImmutable CONSTANT)
    Q_PROPERTY(int defaultClipMonitorOverlayGuidesValue READ defaultClipMonitorOverlayGuidesValue CONSTANT)
    /**
      Get index of current guides overlay for clip monitor.
    */
    static
    int clipMonitorOverlayGuides()
    {
      return self()->mClipMonitorOverlayGuides;
    }

    /**
      Is index of current guides overlay for clip monitor. Immutable
    */
    static
    bool isClipMonitorOverlayGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "clipMonitorOverlayGuides" ) );
    }

    /**
      Get index of current guides overlay for clip monitor. default value
    */
    static
    int defaultClipMonitorOverlayGuidesValue()
    {
        return defaultClipMonitorOverlayGuidesValue_helper();
    }

    /**
      Set index of current guides overlay for project monitor.
    */
    static
    void setProjectMonitorOverlayGuides( int v )
    {
      if (v != self()->mProjectMonitorOverlayGuides && !self()->isProjectMonitorOverlayGuidesImmutable()) {
        self()->mProjectMonitorOverlayGuides = v;
        Q_EMIT self()->projectMonitorOverlayGuidesChanged();
      }
    }

    Q_PROPERTY(int projectMonitorOverlayGuides READ projectMonitorOverlayGuides WRITE setProjectMonitorOverlayGuides NOTIFY projectMonitorOverlayGuidesChanged)
    Q_PROPERTY(bool isProjectMonitorOverlayGuidesImmutable READ isProjectMonitorOverlayGuidesImmutable CONSTANT)
    Q_PROPERTY(int defaultProjectMonitorOverlayGuidesValue READ defaultProjectMonitorOverlayGuidesValue CONSTANT)
    /**
      Get index of current guides overlay for project monitor.
    */
    static
    int projectMonitorOverlayGuides()
    {
      return self()->mProjectMonitorOverlayGuides;
    }

    /**
      Is index of current guides overlay for project monitor. Immutable
    */
    static
    bool isProjectMonitorOverlayGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "projectMonitorOverlayGuides" ) );
    }

    /**
      Get index of current guides overlay for project monitor. default value
    */
    static
    int defaultProjectMonitorOverlayGuidesValue()
    {
        return defaultProjectMonitorOverlayGuidesValue_helper();
    }

    /**
      Set Always display audio thumbs in clip monitor.
    */
    static
    void setAlwaysShowMonitorAudio( bool v )
    {
      if (v != self()->mAlwaysShowMonitorAudio && !self()->isAlwaysShowMonitorAudioImmutable()) {
        self()->mAlwaysShowMonitorAudio = v;
        Q_EMIT self()->alwaysShowMonitorAudioChanged();
      }
    }

    Q_PROPERTY(bool alwaysShowMonitorAudio READ alwaysShowMonitorAudio WRITE setAlwaysShowMonitorAudio NOTIFY alwaysShowMonitorAudioChanged)
    Q_PROPERTY(bool isAlwaysShowMonitorAudioImmutable READ isAlwaysShowMonitorAudioImmutable CONSTANT)
    Q_PROPERTY(bool defaultAlwaysShowMonitorAudioValue READ defaultAlwaysShowMonitorAudioValue CONSTANT)
    /**
      Get Always display audio thumbs in clip monitor.
    */
    static
    bool alwaysShowMonitorAudio()
    {
      return self()->mAlwaysShowMonitorAudio;
    }

    /**
      Is Always display audio thumbs in clip monitor. Immutable
    */
    static
    bool isAlwaysShowMonitorAudioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "alwaysShowMonitorAudio" ) );
    }

    /**
      Get Always display audio thumbs in clip monitor. default value
    */
    static
    bool defaultAlwaysShowMonitorAudioValue()
    {
        return defaultAlwaysShowMonitorAudioValue_helper();
    }

    /**
      Set Show audio overlay info on monitor.
    */
    static
    void setDisplayAudioOverlay( bool v )
    {
      if (v != self()->mDisplayAudioOverlay && !self()->isDisplayAudioOverlayImmutable()) {
        self()->mDisplayAudioOverlay = v;
        Q_EMIT self()->displayAudioOverlayChanged();
      }
    }

    Q_PROPERTY(bool displayAudioOverlay READ displayAudioOverlay WRITE setDisplayAudioOverlay NOTIFY displayAudioOverlayChanged)
    Q_PROPERTY(bool isDisplayAudioOverlayImmutable READ isDisplayAudioOverlayImmutable CONSTANT)
    Q_PROPERTY(bool defaultDisplayAudioOverlayValue READ defaultDisplayAudioOverlayValue CONSTANT)
    /**
      Get Show audio overlay info on monitor.
    */
    static
    bool displayAudioOverlay()
    {
      return self()->mDisplayAudioOverlay;
    }

    /**
      Is Show audio overlay info on monitor. Immutable
    */
    static
    bool isDisplayAudioOverlayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "displayAudioOverlay" ) );
    }

    /**
      Get Show audio overlay info on monitor. default value
    */
    static
    bool defaultDisplayAudioOverlayValue()
    {
        return defaultDisplayAudioOverlayValue_helper();
    }

    /**
      Set Show monitor's audio level widget.
    */
    static
    void setMonitoraudio( int v )
    {
      if (v != self()->mMonitoraudio && !self()->isMonitoraudioImmutable()) {
        self()->mMonitoraudio = v;
        Q_EMIT self()->monitoraudioChanged();
      }
    }

    Q_PROPERTY(int monitoraudio READ monitoraudio WRITE setMonitoraudio NOTIFY monitoraudioChanged)
    Q_PROPERTY(bool isMonitoraudioImmutable READ isMonitoraudioImmutable CONSTANT)
    Q_PROPERTY(int defaultMonitoraudioValue READ defaultMonitoraudioValue CONSTANT)
    /**
      Get Show monitor's audio level widget.
    */
    static
    int monitoraudio()
    {
      return self()->mMonitoraudio;
    }

    /**
      Is Show monitor's audio level widget. Immutable
    */
    static
    bool isMonitoraudioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitoraudio" ) );
    }

    /**
      Get Show monitor's audio level widget. default value
    */
    static
    int defaultMonitoraudioValue()
    {
        return defaultMonitoraudioValue_helper();
    }

    /**
      Set Show on monitor adjustable effect parameter (geometry, ..).
    */
    static
    void setShowOnMonitorScene( bool v )
    {
      if (v != self()->mShowOnMonitorScene && !self()->isShowOnMonitorSceneImmutable()) {
        self()->mShowOnMonitorScene = v;
        Q_EMIT self()->showOnMonitorSceneChanged();
      }
    }

    Q_PROPERTY(bool showOnMonitorScene READ showOnMonitorScene WRITE setShowOnMonitorScene NOTIFY showOnMonitorSceneChanged)
    Q_PROPERTY(bool isShowOnMonitorSceneImmutable READ isShowOnMonitorSceneImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowOnMonitorSceneValue READ defaultShowOnMonitorSceneValue CONSTANT)
    /**
      Get Show on monitor adjustable effect parameter (geometry, ..).
    */
    static
    bool showOnMonitorScene()
    {
      return self()->mShowOnMonitorScene;
    }

    /**
      Is Show on monitor adjustable effect parameter (geometry, ..). Immutable
    */
    static
    bool isShowOnMonitorSceneImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showOnMonitorScene" ) );
    }

    /**
      Get Show on monitor adjustable effect parameter (geometry, ..). default value
    */
    static
    bool defaultShowOnMonitorSceneValue()
    {
        return defaultShowOnMonitorSceneValue_helper();
    }

    /**
      Set Audio driver selected automatically.
    */
    static
    void setAutoaudiodrivername( const QString & v )
    {
      if (v != self()->mAutoaudiodrivername && !self()->isAutoaudiodrivernameImmutable()) {
        self()->mAutoaudiodrivername = v;
        Q_EMIT self()->autoaudiodrivernameChanged();
      }
    }

    Q_PROPERTY(QString autoaudiodrivername READ autoaudiodrivername WRITE setAutoaudiodrivername NOTIFY autoaudiodrivernameChanged)
    Q_PROPERTY(bool isAutoaudiodrivernameImmutable READ isAutoaudiodrivernameImmutable CONSTANT)
    /**
      Get Audio driver selected automatically.
    */
    static
    QString autoaudiodrivername()
    {
      return self()->mAutoaudiodrivername;
    }

    /**
      Is Audio driver selected automatically. Immutable
    */
    static
    bool isAutoaudiodrivernameImmutable()
    {
      return self()->isImmutable( QStringLiteral( "autoaudiodrivername" ) );
    }

    /**
      Set Collapse audio mixer (only show master channel).
    */
    static
    void setMixerCollapse( bool v )
    {
      if (v != self()->mMixerCollapse && !self()->isMixerCollapseImmutable()) {
        self()->mMixerCollapse = v;
        Q_EMIT self()->mixerCollapseChanged();
      }
    }

    Q_PROPERTY(bool mixerCollapse READ mixerCollapse WRITE setMixerCollapse NOTIFY mixerCollapseChanged)
    Q_PROPERTY(bool isMixerCollapseImmutable READ isMixerCollapseImmutable CONSTANT)
    Q_PROPERTY(bool defaultMixerCollapseValue READ defaultMixerCollapseValue CONSTANT)
    /**
      Get Collapse audio mixer (only show master channel).
    */
    static
    bool mixerCollapse()
    {
      return self()->mMixerCollapse;
    }

    /**
      Is Collapse audio mixer (only show master channel). Immutable
    */
    static
    bool isMixerCollapseImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mixerCollapse" ) );
    }

    /**
      Get Collapse audio mixer (only show master channel). default value
    */
    static
    bool defaultMixerCollapseValue()
    {
        return defaultMixerCollapseValue_helper();
    }

    /**
      Set Detected MLT consumers.
    */
    static
    void setConsumerslist( const QStringList & v )
    {
      if (v != self()->mConsumerslist && !self()->isConsumerslistImmutable()) {
        self()->mConsumerslist = v;
        Q_EMIT self()->consumerslistChanged();
      }
    }

    Q_PROPERTY(QStringList consumerslist READ consumerslist WRITE setConsumerslist NOTIFY consumerslistChanged)
    Q_PROPERTY(bool isConsumerslistImmutable READ isConsumerslistImmutable CONSTANT)
    /**
      Get Detected MLT consumers.
    */
    static
    QStringList consumerslist()
    {
      return self()->mConsumerslist;
    }

    /**
      Is Detected MLT consumers. Immutable
    */
    static
    bool isConsumerslistImmutable()
    {
      return self()->isImmutable( QStringLiteral( "consumerslist" ) );
    }

    /**
      Set List of available MLT producers.
    */
    static
    void setProducerslist( const QStringList & v )
    {
      if (v != self()->mProducerslist && !self()->isProducerslistImmutable()) {
        self()->mProducerslist = v;
        Q_EMIT self()->producerslistChanged();
      }
    }

    Q_PROPERTY(QStringList producerslist READ producerslist WRITE setProducerslist NOTIFY producerslistChanged)
    Q_PROPERTY(bool isProducerslistImmutable READ isProducerslistImmutable CONSTANT)
    /**
      Get List of available MLT producers.
    */
    static
    QStringList producerslist()
    {
      return self()->mProducerslist;
    }

    /**
      Is List of available MLT producers. Immutable
    */
    static
    bool isProducerslistImmutable()
    {
      return self()->isImmutable( QStringLiteral( "producerslist" ) );
    }

    /**
      Set Name of the chosen widget style.
    */
    static
    void setWidgetstyle( const QString & v )
    {
      if (v != self()->mWidgetstyle && !self()->isWidgetstyleImmutable()) {
        self()->mWidgetstyle = v;
        Q_EMIT self()->widgetstyleChanged();
      }
    }

    Q_PROPERTY(QString widgetstyle READ widgetstyle WRITE setWidgetstyle NOTIFY widgetstyleChanged)
    Q_PROPERTY(bool isWidgetstyleImmutable READ isWidgetstyleImmutable CONSTANT)
    /**
      Get Name of the chosen widget style.
    */
    static
    QString widgetstyle()
    {
      return self()->mWidgetstyle;
    }

    /**
      Is Name of the chosen widget style. Immutable
    */
    static
    bool isWidgetstyleImmutable()
    {
      return self()->isImmutable( QStringLiteral( "widgetstyle" ) );
    }

    /**
      Set Show thumbnails in slideshow dialog.
    */
    static
    void setShowslideshowthumbs( bool v )
    {
      if (v != self()->mShowslideshowthumbs && !self()->isShowslideshowthumbsImmutable()) {
        self()->mShowslideshowthumbs = v;
        Q_EMIT self()->showslideshowthumbsChanged();
      }
    }

    Q_PROPERTY(bool showslideshowthumbs READ showslideshowthumbs WRITE setShowslideshowthumbs NOTIFY showslideshowthumbsChanged)
    Q_PROPERTY(bool isShowslideshowthumbsImmutable READ isShowslideshowthumbsImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowslideshowthumbsValue READ defaultShowslideshowthumbsValue CONSTANT)
    /**
      Get Show thumbnails in slideshow dialog.
    */
    static
    bool showslideshowthumbs()
    {
      return self()->mShowslideshowthumbs;
    }

    /**
      Is Show thumbnails in slideshow dialog. Immutable
    */
    static
    bool isShowslideshowthumbsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showslideshowthumbs" ) );
    }

    /**
      Get Show thumbnails in slideshow dialog. default value
    */
    static
    bool defaultShowslideshowthumbsValue()
    {
        return defaultShowslideshowthumbsValue_helper();
    }

    /**
      Set Show dock widget titlebars to allow un/docking.
    */
    static
    void setShowtitlebars( bool v )
    {
      if (v != self()->mShowtitlebars && !self()->isShowtitlebarsImmutable()) {
        self()->mShowtitlebars = v;
        Q_EMIT self()->showtitlebarsChanged();
      }
    }

    Q_PROPERTY(bool showtitlebars READ showtitlebars WRITE setShowtitlebars NOTIFY showtitlebarsChanged)
    Q_PROPERTY(bool isShowtitlebarsImmutable READ isShowtitlebarsImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowtitlebarsValue READ defaultShowtitlebarsValue CONSTANT)
    /**
      Get Show dock widget titlebars to allow un/docking.
    */
    static
    bool showtitlebars()
    {
      return self()->mShowtitlebars;
    }

    /**
      Is Show dock widget titlebars to allow un/docking. Immutable
    */
    static
    bool isShowtitlebarsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showtitlebars" ) );
    }

    /**
      Get Show dock widget titlebars to allow un/docking. default value
    */
    static
    bool defaultShowtitlebarsValue()
    {
        return defaultShowtitlebarsValue_helper();
    }

    /**
      Set Color to preselect in the color clip dialog.
    */
    static
    void setColorclipcolor( const QColor & v )
    {
      if (v != self()->mColorclipcolor && !self()->isColorclipcolorImmutable()) {
        self()->mColorclipcolor = v;
        Q_EMIT self()->colorclipcolorChanged();
      }
    }

    Q_PROPERTY(QColor colorclipcolor READ colorclipcolor WRITE setColorclipcolor NOTIFY colorclipcolorChanged)
    Q_PROPERTY(bool isColorclipcolorImmutable READ isColorclipcolorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultColorclipcolorValue READ defaultColorclipcolorValue CONSTANT)
    /**
      Get Color to preselect in the color clip dialog.
    */
    static
    QColor colorclipcolor()
    {
      return self()->mColorclipcolor;
    }

    /**
      Is Color to preselect in the color clip dialog. Immutable
    */
    static
    bool isColorclipcolorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "colorclipcolor" ) );
    }

    /**
      Get Color to preselect in the color clip dialog. default value
    */
    static
    QColor defaultColorclipcolorValue()
    {
        return defaultColorclipcolorValue_helper();
    }

    /**
      Set Show subtitle track.
    */
    static
    void setShowSubtitles( bool v )
    {
      if (v != self()->mShowSubtitles && !self()->isShowSubtitlesImmutable()) {
        self()->mShowSubtitles = v;
        Q_EMIT self()->showSubtitlesChanged();
      }
    }

    Q_PROPERTY(bool showSubtitles READ showSubtitles WRITE setShowSubtitles NOTIFY showSubtitlesChanged)
    Q_PROPERTY(bool isShowSubtitlesImmutable READ isShowSubtitlesImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowSubtitlesValue READ defaultShowSubtitlesValue CONSTANT)
    /**
      Get Show subtitle track.
    */
    static
    bool showSubtitles()
    {
      return self()->mShowSubtitles;
    }

    /**
      Is Show subtitle track. Immutable
    */
    static
    bool isShowSubtitlesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showSubtitles" ) );
    }

    /**
      Get Show subtitle track. default value
    */
    static
    bool defaultShowSubtitlesValue()
    {
        return defaultShowSubtitlesValue_helper();
    }

    /**
      Set Default font size for edit subtitle text widget.
    */
    static
    void setSubtitleEditFontSize( double v )
    {
      if (v != self()->mSubtitleEditFontSize && !self()->isSubtitleEditFontSizeImmutable()) {
        self()->mSubtitleEditFontSize = v;
        Q_EMIT self()->subtitleEditFontSizeChanged();
      }
    }

    Q_PROPERTY(double subtitleEditFontSize READ subtitleEditFontSize WRITE setSubtitleEditFontSize NOTIFY subtitleEditFontSizeChanged)
    Q_PROPERTY(bool isSubtitleEditFontSizeImmutable READ isSubtitleEditFontSizeImmutable CONSTANT)
    Q_PROPERTY(double defaultSubtitleEditFontSizeValue READ defaultSubtitleEditFontSizeValue CONSTANT)
    /**
      Get Default font size for edit subtitle text widget.
    */
    static
    double subtitleEditFontSize()
    {
      return self()->mSubtitleEditFontSize;
    }

    /**
      Is Default font size for edit subtitle text widget. Immutable
    */
    static
    bool isSubtitleEditFontSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "subtitleEditFontSize" ) );
    }

    /**
      Get Default font size for edit subtitle text widget. default value
    */
    static
    double defaultSubtitleEditFontSizeValue()
    {
        return defaultSubtitleEditFontSizeValue_helper();
    }

    /**
      Set Color to draw even audio channels.
    */
    static
    void setThumbColor1( const QColor & v )
    {
      if (v != self()->mThumbColor1 && !self()->isThumbColor1Immutable()) {
        self()->mThumbColor1 = v;
        Q_EMIT self()->thumbColor1Changed();
      }
    }

    Q_PROPERTY(QColor thumbColor1 READ thumbColor1 WRITE setThumbColor1 NOTIFY thumbColor1Changed)
    Q_PROPERTY(bool isThumbColor1Immutable READ isThumbColor1Immutable CONSTANT)
    Q_PROPERTY(QColor defaultThumbColor1Value READ defaultThumbColor1Value CONSTANT)
    /**
      Get Color to draw even audio channels.
    */
    static
    QColor thumbColor1()
    {
      return self()->mThumbColor1;
    }

    /**
      Is Color to draw even audio channels. Immutable
    */
    static
    bool isThumbColor1Immutable()
    {
      return self()->isImmutable( QStringLiteral( "thumbColor1" ) );
    }

    /**
      Get Color to draw even audio channels. default value
    */
    static
    QColor defaultThumbColor1Value()
    {
        return defaultThumbColor1Value_helper();
    }

    /**
      Set Color to draw odd audio channels.
    */
    static
    void setThumbColor2( const QColor & v )
    {
      if (v != self()->mThumbColor2 && !self()->isThumbColor2Immutable()) {
        self()->mThumbColor2 = v;
        Q_EMIT self()->thumbColor2Changed();
      }
    }

    Q_PROPERTY(QColor thumbColor2 READ thumbColor2 WRITE setThumbColor2 NOTIFY thumbColor2Changed)
    Q_PROPERTY(bool isThumbColor2Immutable READ isThumbColor2Immutable CONSTANT)
    Q_PROPERTY(QColor defaultThumbColor2Value READ defaultThumbColor2Value CONSTANT)
    /**
      Get Color to draw odd audio channels.
    */
    static
    QColor thumbColor2()
    {
      return self()->mThumbColor2;
    }

    /**
      Is Color to draw odd audio channels. Immutable
    */
    static
    bool isThumbColor2Immutable()
    {
      return self()->isImmutable( QStringLiteral( "thumbColor2" ) );
    }

    /**
      Get Color to draw odd audio channels. default value
    */
    static
    QColor defaultThumbColor2Value()
    {
        return defaultThumbColor2Value_helper();
    }

    /**
      Set Color to draw the monitor overlay guides.
    */
    static
    void setOverlayColor( const QColor & v )
    {
      if (v != self()->mOverlayColor && !self()->isOverlayColorImmutable()) {
        self()->mOverlayColor = v;
        Q_EMIT self()->overlayColorChanged();
      }
    }

    Q_PROPERTY(QColor overlayColor READ overlayColor WRITE setOverlayColor NOTIFY overlayColorChanged)
    Q_PROPERTY(bool isOverlayColorImmutable READ isOverlayColorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultOverlayColorValue READ defaultOverlayColorValue CONSTANT)
    /**
      Get Color to draw the monitor overlay guides.
    */
    static
    QColor overlayColor()
    {
      return self()->mOverlayColor;
    }

    /**
      Is Color to draw the monitor overlay guides. Immutable
    */
    static
    bool isOverlayColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "overlayColor" ) );
    }

    /**
      Get Color to draw the monitor overlay guides. default value
    */
    static
    QColor defaultOverlayColorValue()
    {
        return defaultOverlayColorValue_helper();
    }

    /**
      Set Color to draw the safe zone.
    */
    static
    void setSafeColor( const QColor & v )
    {
      if (v != self()->mSafeColor && !self()->isSafeColorImmutable()) {
        self()->mSafeColor = v;
        Q_EMIT self()->safeColorChanged();
      }
    }

    Q_PROPERTY(QColor safeColor READ safeColor WRITE setSafeColor NOTIFY safeColorChanged)
    Q_PROPERTY(bool isSafeColorImmutable READ isSafeColorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultSafeColorValue READ defaultSafeColorValue CONSTANT)
    /**
      Get Color to draw the safe zone.
    */
    static
    QColor safeColor()
    {
      return self()->mSafeColor;
    }

    /**
      Is Color to draw the safe zone. Immutable
    */
    static
    bool isSafeColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "safeColor" ) );
    }

    /**
      Get Color to draw the safe zone. default value
    */
    static
    QColor defaultSafeColorValue()
    {
        return defaultSafeColorValue_helper();
    }

    /**
      Set default width for rendering rescale.
    */
    static
    void setDefaultrescalewidth( int v )
    {
      if (v != self()->mDefaultrescalewidth && !self()->isDefaultrescalewidthImmutable()) {
        self()->mDefaultrescalewidth = v;
        Q_EMIT self()->defaultrescalewidthChanged();
      }
    }

    Q_PROPERTY(int defaultrescalewidth READ defaultrescalewidth WRITE setDefaultrescalewidth NOTIFY defaultrescalewidthChanged)
    Q_PROPERTY(bool isDefaultrescalewidthImmutable READ isDefaultrescalewidthImmutable CONSTANT)
    Q_PROPERTY(int defaultDefaultrescalewidthValue READ defaultDefaultrescalewidthValue CONSTANT)
    /**
      Get default width for rendering rescale.
    */
    static
    int defaultrescalewidth()
    {
      return self()->mDefaultrescalewidth;
    }

    /**
      Is default width for rendering rescale. Immutable
    */
    static
    bool isDefaultrescalewidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultrescalewidth" ) );
    }

    /**
      Get default width for rendering rescale. default value
    */
    static
    int defaultDefaultrescalewidthValue()
    {
        return defaultDefaultrescalewidthValue_helper();
    }

    /**
      Set default width for rendering rescale.
    */
    static
    void setDefaultrescaleheight( int v )
    {
      if (v != self()->mDefaultrescaleheight && !self()->isDefaultrescaleheightImmutable()) {
        self()->mDefaultrescaleheight = v;
        Q_EMIT self()->defaultrescaleheightChanged();
      }
    }

    Q_PROPERTY(int defaultrescaleheight READ defaultrescaleheight WRITE setDefaultrescaleheight NOTIFY defaultrescaleheightChanged)
    Q_PROPERTY(bool isDefaultrescaleheightImmutable READ isDefaultrescaleheightImmutable CONSTANT)
    Q_PROPERTY(int defaultDefaultrescaleheightValue READ defaultDefaultrescaleheightValue CONSTANT)
    /**
      Get default width for rendering rescale.
    */
    static
    int defaultrescaleheight()
    {
      return self()->mDefaultrescaleheight;
    }

    /**
      Is default width for rendering rescale. Immutable
    */
    static
    bool isDefaultrescaleheightImmutable()
    {
      return self()->isImmutable( QStringLiteral( "defaultrescaleheight" ) );
    }

    /**
      Get default width for rendering rescale. default value
    */
    static
    int defaultDefaultrescaleheightValue()
    {
        return defaultDefaultrescaleheightValue_helper();
    }

    /**
      Set True if slideshow default method is MIME type.
    */
    static
    void setSlideshowbymime( bool v )
    {
      if (v != self()->mSlideshowbymime && !self()->isSlideshowbymimeImmutable()) {
        self()->mSlideshowbymime = v;
        Q_EMIT self()->slideshowbymimeChanged();
      }
    }

    Q_PROPERTY(bool slideshowbymime READ slideshowbymime WRITE setSlideshowbymime NOTIFY slideshowbymimeChanged)
    Q_PROPERTY(bool isSlideshowbymimeImmutable READ isSlideshowbymimeImmutable CONSTANT)
    Q_PROPERTY(bool defaultSlideshowbymimeValue READ defaultSlideshowbymimeValue CONSTANT)
    /**
      Get True if slideshow default method is MIME type.
    */
    static
    bool slideshowbymime()
    {
      return self()->mSlideshowbymime;
    }

    /**
      Is True if slideshow default method is MIME type. Immutable
    */
    static
    bool isSlideshowbymimeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "slideshowbymime" ) );
    }

    /**
      Get True if slideshow default method is MIME type. default value
    */
    static
    bool defaultSlideshowbymimeValue()
    {
        return defaultSlideshowbymimeValue_helper();
    }

    /**
      Set The default image extension for slideshows.
    */
    static
    void setSlideshowmimeextension( const QString & v )
    {
      if (v != self()->mSlideshowmimeextension && !self()->isSlideshowmimeextensionImmutable()) {
        self()->mSlideshowmimeextension = v;
        Q_EMIT self()->slideshowmimeextensionChanged();
      }
    }

    Q_PROPERTY(QString slideshowmimeextension READ slideshowmimeextension WRITE setSlideshowmimeextension NOTIFY slideshowmimeextensionChanged)
    Q_PROPERTY(bool isSlideshowmimeextensionImmutable READ isSlideshowmimeextensionImmutable CONSTANT)
    /**
      Get The default image extension for slideshows.
    */
    static
    QString slideshowmimeextension()
    {
      return self()->mSlideshowmimeextension;
    }

    /**
      Is The default image extension for slideshows. Immutable
    */
    static
    bool isSlideshowmimeextensionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "slideshowmimeextension" ) );
    }

    /**
      Set Update parameters while monitor scene changes.
    */
    static
    void setMonitorscene_directupdate( bool v )
    {
      if (v != self()->mMonitorscene_directupdate && !self()->isMonitorscene_directupdateImmutable()) {
        self()->mMonitorscene_directupdate = v;
        Q_EMIT self()->monitorscene_directupdateChanged();
      }
    }

    Q_PROPERTY(bool monitorscene_directupdate READ monitorscene_directupdate WRITE setMonitorscene_directupdate NOTIFY monitorscene_directupdateChanged)
    Q_PROPERTY(bool isMonitorscene_directupdateImmutable READ isMonitorscene_directupdateImmutable CONSTANT)
    Q_PROPERTY(bool defaultMonitorscene_directupdateValue READ defaultMonitorscene_directupdateValue CONSTANT)
    /**
      Get Update parameters while monitor scene changes.
    */
    static
    bool monitorscene_directupdate()
    {
      return self()->mMonitorscene_directupdate;
    }

    /**
      Is Update parameters while monitor scene changes. Immutable
    */
    static
    bool isMonitorscene_directupdateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitorscene_directupdate" ) );
    }

    /**
      Get Update parameters while monitor scene changes. default value
    */
    static
    bool defaultMonitorscene_directupdateValue()
    {
        return defaultMonitorscene_directupdateValue_helper();
    }

    /**
      Set Send stopmotion frames to scopes for live analysis.
    */
    static
    void setAnalyse_stopmotion( bool v )
    {
      if (v != self()->mAnalyse_stopmotion && !self()->isAnalyse_stopmotionImmutable()) {
        self()->mAnalyse_stopmotion = v;
        Q_EMIT self()->analyse_stopmotionChanged();
      }
    }

    Q_PROPERTY(bool analyse_stopmotion READ analyse_stopmotion WRITE setAnalyse_stopmotion NOTIFY analyse_stopmotionChanged)
    Q_PROPERTY(bool isAnalyse_stopmotionImmutable READ isAnalyse_stopmotionImmutable CONSTANT)
    Q_PROPERTY(bool defaultAnalyse_stopmotionValue READ defaultAnalyse_stopmotionValue CONSTANT)
    /**
      Get Send stopmotion frames to scopes for live analysis.
    */
    static
    bool analyse_stopmotion()
    {
      return self()->mAnalyse_stopmotion;
    }

    /**
      Is Send stopmotion frames to scopes for live analysis. Immutable
    */
    static
    bool isAnalyse_stopmotionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "analyse_stopmotion" ) );
    }

    /**
      Get Send stopmotion frames to scopes for live analysis. default value
    */
    static
    bool defaultAnalyse_stopmotionValue()
    {
        return defaultAnalyse_stopmotionValue_helper();
    }

    /**
      Set Send frames to audiospectrum scope for live analysis.
    */
    static
    void setEnableaudiospectrum( bool v )
    {
      if (v != self()->mEnableaudiospectrum && !self()->isEnableaudiospectrumImmutable()) {
        self()->mEnableaudiospectrum = v;
        Q_EMIT self()->enableaudiospectrumChanged();
      }
    }

    Q_PROPERTY(bool enableaudiospectrum READ enableaudiospectrum WRITE setEnableaudiospectrum NOTIFY enableaudiospectrumChanged)
    Q_PROPERTY(bool isEnableaudiospectrumImmutable READ isEnableaudiospectrumImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableaudiospectrumValue READ defaultEnableaudiospectrumValue CONSTANT)
    /**
      Get Send frames to audiospectrum scope for live analysis.
    */
    static
    bool enableaudiospectrum()
    {
      return self()->mEnableaudiospectrum;
    }

    /**
      Is Send frames to audiospectrum scope for live analysis. Immutable
    */
    static
    bool isEnableaudiospectrumImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableaudiospectrum" ) );
    }

    /**
      Get Send frames to audiospectrum scope for live analysis. default value
    */
    static
    bool defaultEnableaudiospectrumValue()
    {
        return defaultEnableaudiospectrumValue_helper();
    }

    /**
      Set Show sequence thumbnails in stopmotion widget.
    */
    static
    void setShowstopmotionthumbs( bool v )
    {
      if (v != self()->mShowstopmotionthumbs && !self()->isShowstopmotionthumbsImmutable()) {
        self()->mShowstopmotionthumbs = v;
        Q_EMIT self()->showstopmotionthumbsChanged();
      }
    }

    Q_PROPERTY(bool showstopmotionthumbs READ showstopmotionthumbs WRITE setShowstopmotionthumbs NOTIFY showstopmotionthumbsChanged)
    Q_PROPERTY(bool isShowstopmotionthumbsImmutable READ isShowstopmotionthumbsImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowstopmotionthumbsValue READ defaultShowstopmotionthumbsValue CONSTANT)
    /**
      Get Show sequence thumbnails in stopmotion widget.
    */
    static
    bool showstopmotionthumbs()
    {
      return self()->mShowstopmotionthumbs;
    }

    /**
      Is Show sequence thumbnails in stopmotion widget. Immutable
    */
    static
    bool isShowstopmotionthumbsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showstopmotionthumbs" ) );
    }

    /**
      Get Show sequence thumbnails in stopmotion widget. default value
    */
    static
    bool defaultShowstopmotionthumbsValue()
    {
        return defaultShowstopmotionthumbsValue_helper();
    }

    /**
      Set Interval between each capture (in seconds).
    */
    static
    void setCaptureinterval( int v )
    {
      if (v != self()->mCaptureinterval && !self()->isCaptureintervalImmutable()) {
        self()->mCaptureinterval = v;
        Q_EMIT self()->captureintervalChanged();
      }
    }

    Q_PROPERTY(int captureinterval READ captureinterval WRITE setCaptureinterval NOTIFY captureintervalChanged)
    Q_PROPERTY(bool isCaptureintervalImmutable READ isCaptureintervalImmutable CONSTANT)
    Q_PROPERTY(int defaultCaptureintervalValue READ defaultCaptureintervalValue CONSTANT)
    /**
      Get Interval between each capture (in seconds).
    */
    static
    int captureinterval()
    {
      return self()->mCaptureinterval;
    }

    /**
      Is Interval between each capture (in seconds). Immutable
    */
    static
    bool isCaptureintervalImmutable()
    {
      return self()->isImmutable( QStringLiteral( "captureinterval" ) );
    }

    /**
      Get Interval between each capture (in seconds). default value
    */
    static
    int defaultCaptureintervalValue()
    {
        return defaultCaptureintervalValue_helper();
    }

    /**
      Set Seconds before triggering a capture notification.
    */
    static
    void setSm_notifytime( int v )
    {
      if (v != self()->mSm_notifytime && !self()->isSm_notifytimeImmutable()) {
        self()->mSm_notifytime = v;
        Q_EMIT self()->sm_notifytimeChanged();
      }
    }

    Q_PROPERTY(int sm_notifytime READ sm_notifytime WRITE setSm_notifytime NOTIFY sm_notifytimeChanged)
    Q_PROPERTY(bool isSm_notifytimeImmutable READ isSm_notifytimeImmutable CONSTANT)
    Q_PROPERTY(int defaultSm_notifytimeValue READ defaultSm_notifytimeValue CONSTANT)
    /**
      Get Seconds before triggering a capture notification.
    */
    static
    int sm_notifytime()
    {
      return self()->mSm_notifytime;
    }

    /**
      Is Seconds before triggering a capture notification. Immutable
    */
    static
    bool isSm_notifytimeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sm_notifytime" ) );
    }

    /**
      Get Seconds before triggering a capture notification. default value
    */
    static
    int defaultSm_notifytimeValue()
    {
        return defaultSm_notifytimeValue_helper();
    }

    /**
      Set Send a notification a few seconds before capture.
    */
    static
    void setSm_prenotify( bool v )
    {
      if (v != self()->mSm_prenotify && !self()->isSm_prenotifyImmutable()) {
        self()->mSm_prenotify = v;
        Q_EMIT self()->sm_prenotifyChanged();
      }
    }

    Q_PROPERTY(bool sm_prenotify READ sm_prenotify WRITE setSm_prenotify NOTIFY sm_prenotifyChanged)
    Q_PROPERTY(bool isSm_prenotifyImmutable READ isSm_prenotifyImmutable CONSTANT)
    Q_PROPERTY(bool defaultSm_prenotifyValue READ defaultSm_prenotifyValue CONSTANT)
    /**
      Get Send a notification a few seconds before capture.
    */
    static
    bool sm_prenotify()
    {
      return self()->mSm_prenotify;
    }

    /**
      Is Send a notification a few seconds before capture. Immutable
    */
    static
    bool isSm_prenotifyImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sm_prenotify" ) );
    }

    /**
      Get Send a notification a few seconds before capture. default value
    */
    static
    bool defaultSm_prenotifyValue()
    {
        return defaultSm_prenotifyValue_helper();
    }

    /**
      Set Should we loop in stop motion playback.
    */
    static
    void setSm_loop( bool v )
    {
      if (v != self()->mSm_loop && !self()->isSm_loopImmutable()) {
        self()->mSm_loop = v;
        Q_EMIT self()->sm_loopChanged();
      }
    }

    Q_PROPERTY(bool sm_loop READ sm_loop WRITE setSm_loop NOTIFY sm_loopChanged)
    Q_PROPERTY(bool isSm_loopImmutable READ isSm_loopImmutable CONSTANT)
    Q_PROPERTY(bool defaultSm_loopValue READ defaultSm_loopValue CONSTANT)
    /**
      Get Should we loop in stop motion playback.
    */
    static
    bool sm_loop()
    {
      return self()->mSm_loop;
    }

    /**
      Is Should we loop in stop motion playback. Immutable
    */
    static
    bool isSm_loopImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sm_loop" ) );
    }

    /**
      Get Should we loop in stop motion playback. default value
    */
    static
    bool defaultSm_loopValue()
    {
        return defaultSm_loopValue_helper();
    }

    /**
      Set Should we play a sound to notify of captured frame in stop motion.
    */
    static
    void setSm_playsound( bool v )
    {
      if (v != self()->mSm_playsound && !self()->isSm_playsoundImmutable()) {
        self()->mSm_playsound = v;
        Q_EMIT self()->sm_playsoundChanged();
      }
    }

    Q_PROPERTY(bool sm_playsound READ sm_playsound WRITE setSm_playsound NOTIFY sm_playsoundChanged)
    Q_PROPERTY(bool isSm_playsoundImmutable READ isSm_playsoundImmutable CONSTANT)
    Q_PROPERTY(bool defaultSm_playsoundValue READ defaultSm_playsoundValue CONSTANT)
    /**
      Get Should we play a sound to notify of captured frame in stop motion.
    */
    static
    bool sm_playsound()
    {
      return self()->mSm_playsound;
    }

    /**
      Is Should we play a sound to notify of captured frame in stop motion. Immutable
    */
    static
    bool isSm_playsoundImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sm_playsound" ) );
    }

    /**
      Get Should we play a sound to notify of captured frame in stop motion. default value
    */
    static
    bool defaultSm_playsoundValue()
    {
        return defaultSm_playsoundValue_helper();
    }

    /**
      Set Number of frames to play back in stop motion playback.
    */
    static
    void setSm_framesplayback( int v )
    {
      if (v != self()->mSm_framesplayback && !self()->isSm_framesplaybackImmutable()) {
        self()->mSm_framesplayback = v;
        Q_EMIT self()->sm_framesplaybackChanged();
      }
    }

    Q_PROPERTY(int sm_framesplayback READ sm_framesplayback WRITE setSm_framesplayback NOTIFY sm_framesplaybackChanged)
    Q_PROPERTY(bool isSm_framesplaybackImmutable READ isSm_framesplaybackImmutable CONSTANT)
    Q_PROPERTY(int defaultSm_framesplaybackValue READ defaultSm_framesplaybackValue CONSTANT)
    /**
      Get Number of frames to play back in stop motion playback.
    */
    static
    int sm_framesplayback()
    {
      return self()->mSm_framesplayback;
    }

    /**
      Is Number of frames to play back in stop motion playback. Immutable
    */
    static
    bool isSm_framesplaybackImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sm_framesplayback" ) );
    }

    /**
      Get Number of frames to play back in stop motion playback. default value
    */
    static
    int defaultSm_framesplaybackValue()
    {
        return defaultSm_framesplaybackValue_helper();
    }

    /**
      Set Effect applied to stopmotion frame overlay.
    */
    static
    void setStopmotioneffect( int v )
    {
      if (v != self()->mStopmotioneffect && !self()->isStopmotioneffectImmutable()) {
        self()->mStopmotioneffect = v;
        Q_EMIT self()->stopmotioneffectChanged();
      }
    }

    Q_PROPERTY(int stopmotioneffect READ stopmotioneffect WRITE setStopmotioneffect NOTIFY stopmotioneffectChanged)
    Q_PROPERTY(bool isStopmotioneffectImmutable READ isStopmotioneffectImmutable CONSTANT)
    Q_PROPERTY(int defaultStopmotioneffectValue READ defaultStopmotioneffectValue CONSTANT)
    /**
      Get Effect applied to stopmotion frame overlay.
    */
    static
    int stopmotioneffect()
    {
      return self()->mStopmotioneffect;
    }

    /**
      Is Effect applied to stopmotion frame overlay. Immutable
    */
    static
    bool isStopmotioneffectImmutable()
    {
      return self()->isImmutable( QStringLiteral( "stopmotioneffect" ) );
    }

    /**
      Get Effect applied to stopmotion frame overlay. default value
    */
    static
    int defaultStopmotioneffectValue()
    {
        return defaultStopmotioneffectValue_helper();
    }

    /**
      Set Connect the corners in the widget for the c0rners effect with lines.
    */
    static
    void setOnmonitoreffects_cornersshowlines( bool v )
    {
      if (v != self()->mOnmonitoreffects_cornersshowlines && !self()->isOnmonitoreffects_cornersshowlinesImmutable()) {
        self()->mOnmonitoreffects_cornersshowlines = v;
        Q_EMIT self()->onmonitoreffects_cornersshowlinesChanged();
      }
    }

    Q_PROPERTY(bool onmonitoreffects_cornersshowlines READ onmonitoreffects_cornersshowlines WRITE setOnmonitoreffects_cornersshowlines NOTIFY onmonitoreffects_cornersshowlinesChanged)
    Q_PROPERTY(bool isOnmonitoreffects_cornersshowlinesImmutable READ isOnmonitoreffects_cornersshowlinesImmutable CONSTANT)
    Q_PROPERTY(bool defaultOnmonitoreffects_cornersshowlinesValue READ defaultOnmonitoreffects_cornersshowlinesValue CONSTANT)
    /**
      Get Connect the corners in the widget for the c0rners effect with lines.
    */
    static
    bool onmonitoreffects_cornersshowlines()
    {
      return self()->mOnmonitoreffects_cornersshowlines;
    }

    /**
      Is Connect the corners in the widget for the c0rners effect with lines. Immutable
    */
    static
    bool isOnmonitoreffects_cornersshowlinesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "onmonitoreffects_cornersshowlines" ) );
    }

    /**
      Get Connect the corners in the widget for the c0rners effect with lines. default value
    */
    static
    bool defaultOnmonitoreffects_cornersshowlinesValue()
    {
        return defaultOnmonitoreffects_cornersshowlinesValue_helper();
    }

    /**
      Set Show previous keyframe in monitor.
    */
    static
    void setOnmonitoreffects_geometryshowprevious( bool v )
    {
      if (v != self()->mOnmonitoreffects_geometryshowprevious && !self()->isOnmonitoreffects_geometryshowpreviousImmutable()) {
        self()->mOnmonitoreffects_geometryshowprevious = v;
        Q_EMIT self()->onmonitoreffects_geometryshowpreviousChanged();
      }
    }

    Q_PROPERTY(bool onmonitoreffects_geometryshowprevious READ onmonitoreffects_geometryshowprevious WRITE setOnmonitoreffects_geometryshowprevious NOTIFY onmonitoreffects_geometryshowpreviousChanged)
    Q_PROPERTY(bool isOnmonitoreffects_geometryshowpreviousImmutable READ isOnmonitoreffects_geometryshowpreviousImmutable CONSTANT)
    Q_PROPERTY(bool defaultOnmonitoreffects_geometryshowpreviousValue READ defaultOnmonitoreffects_geometryshowpreviousValue CONSTANT)
    /**
      Get Show previous keyframe in monitor.
    */
    static
    bool onmonitoreffects_geometryshowprevious()
    {
      return self()->mOnmonitoreffects_geometryshowprevious;
    }

    /**
      Is Show previous keyframe in monitor. Immutable
    */
    static
    bool isOnmonitoreffects_geometryshowpreviousImmutable()
    {
      return self()->isImmutable( QStringLiteral( "onmonitoreffects_geometryshowprevious" ) );
    }

    /**
      Get Show previous keyframe in monitor. default value
    */
    static
    bool defaultOnmonitoreffects_geometryshowpreviousValue()
    {
        return defaultOnmonitoreffects_geometryshowpreviousValue_helper();
    }

    /**
      Set Show keyframe path in monitor.
    */
    static
    void setOnmonitoreffects_geometryshowpath( bool v )
    {
      if (v != self()->mOnmonitoreffects_geometryshowpath && !self()->isOnmonitoreffects_geometryshowpathImmutable()) {
        self()->mOnmonitoreffects_geometryshowpath = v;
        Q_EMIT self()->onmonitoreffects_geometryshowpathChanged();
      }
    }

    Q_PROPERTY(bool onmonitoreffects_geometryshowpath READ onmonitoreffects_geometryshowpath WRITE setOnmonitoreffects_geometryshowpath NOTIFY onmonitoreffects_geometryshowpathChanged)
    Q_PROPERTY(bool isOnmonitoreffects_geometryshowpathImmutable READ isOnmonitoreffects_geometryshowpathImmutable CONSTANT)
    Q_PROPERTY(bool defaultOnmonitoreffects_geometryshowpathValue READ defaultOnmonitoreffects_geometryshowpathValue CONSTANT)
    /**
      Get Show keyframe path in monitor.
    */
    static
    bool onmonitoreffects_geometryshowpath()
    {
      return self()->mOnmonitoreffects_geometryshowpath;
    }

    /**
      Is Show keyframe path in monitor. Immutable
    */
    static
    bool isOnmonitoreffects_geometryshowpathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "onmonitoreffects_geometryshowpath" ) );
    }

    /**
      Get Show keyframe path in monitor. default value
    */
    static
    bool defaultOnmonitoreffects_geometryshowpathValue()
    {
        return defaultOnmonitoreffects_geometryshowpathValue_helper();
    }

    /**
      Set Show additional controls in the c0rners on-monitor widget.
    */
    static
    void setOnmonitoreffects_cornersshowcontrols( bool v )
    {
      if (v != self()->mOnmonitoreffects_cornersshowcontrols && !self()->isOnmonitoreffects_cornersshowcontrolsImmutable()) {
        self()->mOnmonitoreffects_cornersshowcontrols = v;
        Q_EMIT self()->onmonitoreffects_cornersshowcontrolsChanged();
      }
    }

    Q_PROPERTY(bool onmonitoreffects_cornersshowcontrols READ onmonitoreffects_cornersshowcontrols WRITE setOnmonitoreffects_cornersshowcontrols NOTIFY onmonitoreffects_cornersshowcontrolsChanged)
    Q_PROPERTY(bool isOnmonitoreffects_cornersshowcontrolsImmutable READ isOnmonitoreffects_cornersshowcontrolsImmutable CONSTANT)
    Q_PROPERTY(bool defaultOnmonitoreffects_cornersshowcontrolsValue READ defaultOnmonitoreffects_cornersshowcontrolsValue CONSTANT)
    /**
      Get Show additional controls in the c0rners on-monitor widget.
    */
    static
    bool onmonitoreffects_cornersshowcontrols()
    {
      return self()->mOnmonitoreffects_cornersshowcontrols;
    }

    /**
      Is Show additional controls in the c0rners on-monitor widget. Immutable
    */
    static
    bool isOnmonitoreffects_cornersshowcontrolsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "onmonitoreffects_cornersshowcontrols" ) );
    }

    /**
      Get Show additional controls in the c0rners on-monitor widget. default value
    */
    static
    bool defaultOnmonitoreffects_cornersshowcontrolsValue()
    {
        return defaultOnmonitoreffects_cornersshowcontrolsValue_helper();
    }

    /**
      Set Do not validate the video files when loading a project for the sake of speed.
    */
    static
    void setProjectloading_avformatnovalidate( bool v )
    {
      if (v != self()->mProjectloading_avformatnovalidate && !self()->isProjectloading_avformatnovalidateImmutable()) {
        self()->mProjectloading_avformatnovalidate = v;
        Q_EMIT self()->projectloading_avformatnovalidateChanged();
      }
    }

    Q_PROPERTY(bool projectloading_avformatnovalidate READ projectloading_avformatnovalidate WRITE setProjectloading_avformatnovalidate NOTIFY projectloading_avformatnovalidateChanged)
    Q_PROPERTY(bool isProjectloading_avformatnovalidateImmutable READ isProjectloading_avformatnovalidateImmutable CONSTANT)
    Q_PROPERTY(bool defaultProjectloading_avformatnovalidateValue READ defaultProjectloading_avformatnovalidateValue CONSTANT)
    /**
      Get Do not validate the video files when loading a project for the sake of speed.
    */
    static
    bool projectloading_avformatnovalidate()
    {
      return self()->mProjectloading_avformatnovalidate;
    }

    /**
      Is Do not validate the video files when loading a project for the sake of speed. Immutable
    */
    static
    bool isProjectloading_avformatnovalidateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "projectloading_avformatnovalidate" ) );
    }

    /**
      Get Do not validate the video files when loading a project for the sake of speed. default value
    */
    static
    bool defaultProjectloading_avformatnovalidateValue()
    {
        return defaultProjectloading_avformatnovalidateValue_helper();
    }

    /**
      Set Display audio levels.
    */
    static
    void setMonitor_audio( bool v )
    {
      if (v != self()->mMonitor_audio && !self()->isMonitor_audioImmutable()) {
        self()->mMonitor_audio = v;
        Q_EMIT self()->monitor_audioChanged();
      }
    }

    Q_PROPERTY(bool monitor_audio READ monitor_audio WRITE setMonitor_audio NOTIFY monitor_audioChanged)
    Q_PROPERTY(bool isMonitor_audioImmutable READ isMonitor_audioImmutable CONSTANT)
    Q_PROPERTY(bool defaultMonitor_audioValue READ defaultMonitor_audioValue CONSTANT)
    /**
      Get Display audio levels.
    */
    static
    bool monitor_audio()
    {
      return self()->mMonitor_audio;
    }

    /**
      Is Display audio levels. Immutable
    */
    static
    bool isMonitor_audioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "monitor_audio" ) );
    }

    /**
      Get Display audio levels. default value
    */
    static
    bool defaultMonitor_audioValue()
    {
        return defaultMonitor_audioValue_helper();
    }

    /**
      Set Should we display video frames while capturing.
    */
    static
    void setEnable_recording_preview( bool v )
    {
      if (v != self()->mEnable_recording_preview && !self()->isEnable_recording_previewImmutable()) {
        self()->mEnable_recording_preview = v;
        Q_EMIT self()->enable_recording_previewChanged();
      }
    }

    Q_PROPERTY(bool enable_recording_preview READ enable_recording_preview WRITE setEnable_recording_preview NOTIFY enable_recording_previewChanged)
    Q_PROPERTY(bool isEnable_recording_previewImmutable READ isEnable_recording_previewImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnable_recording_previewValue READ defaultEnable_recording_previewValue CONSTANT)
    /**
      Get Should we display video frames while capturing.
    */
    static
    bool enable_recording_preview()
    {
      return self()->mEnable_recording_preview;
    }

    /**
      Is Should we display video frames while capturing. Immutable
    */
    static
    bool isEnable_recording_previewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enable_recording_preview" ) );
    }

    /**
      Get Should we display video frames while capturing. default value
    */
    static
    bool defaultEnable_recording_previewValue()
    {
        return defaultEnable_recording_previewValue_helper();
    }

    /**
      Set Add task clips to project after processing.
    */
    static
    void setAdd_new_clip( bool v )
    {
      if (v != self()->mAdd_new_clip && !self()->isAdd_new_clipImmutable()) {
        self()->mAdd_new_clip = v;
        Q_EMIT self()->add_new_clipChanged();
      }
    }

    Q_PROPERTY(bool add_new_clip READ add_new_clip WRITE setAdd_new_clip NOTIFY add_new_clipChanged)
    Q_PROPERTY(bool isAdd_new_clipImmutable READ isAdd_new_clipImmutable CONSTANT)
    Q_PROPERTY(bool defaultAdd_new_clipValue READ defaultAdd_new_clipValue CONSTANT)
    /**
      Get Add task clips to project after processing.
    */
    static
    bool add_new_clip()
    {
      return self()->mAdd_new_clip;
    }

    /**
      Is Add task clips to project after processing. Immutable
    */
    static
    bool isAdd_new_clipImmutable()
    {
      return self()->isImmutable( QStringLiteral( "add_new_clip" ) );
    }

    /**
      Get Add task clips to project after processing. default value
    */
    static
    bool defaultAdd_new_clipValue()
    {
        return defaultAdd_new_clipValue_helper();
    }

    /**
      Set Add task clips in a specific folder after processing.
    */
    static
    void setAdd_new_clip_to_folder( bool v )
    {
      if (v != self()->mAdd_new_clip_to_folder && !self()->isAdd_new_clip_to_folderImmutable()) {
        self()->mAdd_new_clip_to_folder = v;
        Q_EMIT self()->add_new_clip_to_folderChanged();
      }
    }

    Q_PROPERTY(bool add_new_clip_to_folder READ add_new_clip_to_folder WRITE setAdd_new_clip_to_folder NOTIFY add_new_clip_to_folderChanged)
    Q_PROPERTY(bool isAdd_new_clip_to_folderImmutable READ isAdd_new_clip_to_folderImmutable CONSTANT)
    Q_PROPERTY(bool defaultAdd_new_clip_to_folderValue READ defaultAdd_new_clip_to_folderValue CONSTANT)
    /**
      Get Add task clips in a specific folder after processing.
    */
    static
    bool add_new_clip_to_folder()
    {
      return self()->mAdd_new_clip_to_folder;
    }

    /**
      Is Add task clips in a specific folder after processing. Immutable
    */
    static
    bool isAdd_new_clip_to_folderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "add_new_clip_to_folder" ) );
    }

    /**
      Get Add task clips in a specific folder after processing. default value
    */
    static
    bool defaultAdd_new_clip_to_folderValue()
    {
        return defaultAdd_new_clip_to_folderValue_helper();
    }

    /**
      Set Default category for newly created clip markers.
    */
    static
    void setDefault_marker_type( int v )
    {
      if (v != self()->mDefault_marker_type && !self()->isDefault_marker_typeImmutable()) {
        self()->mDefault_marker_type = v;
        Q_EMIT self()->default_marker_typeChanged();
      }
    }

    Q_PROPERTY(int default_marker_type READ default_marker_type WRITE setDefault_marker_type NOTIFY default_marker_typeChanged)
    Q_PROPERTY(bool isDefault_marker_typeImmutable READ isDefault_marker_typeImmutable CONSTANT)
    Q_PROPERTY(int defaultDefault_marker_typeValue READ defaultDefault_marker_typeValue CONSTANT)
    /**
      Get Default category for newly created clip markers.
    */
    static
    int default_marker_type()
    {
      return self()->mDefault_marker_type;
    }

    /**
      Is Default category for newly created clip markers. Immutable
    */
    static
    bool isDefault_marker_typeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "default_marker_type" ) );
    }

    /**
      Get Default category for newly created clip markers. default value
    */
    static
    int defaultDefault_marker_typeValue()
    {
        return defaultDefault_marker_typeValue_helper();
    }

    /**
      Set Name of the chosen deinterlacer.
    */
    static
    void setMltdeinterlacer( const QString & v )
    {
      if (v != self()->mMltdeinterlacer && !self()->isMltdeinterlacerImmutable()) {
        self()->mMltdeinterlacer = v;
        Q_EMIT self()->mltdeinterlacerChanged();
      }
    }

    Q_PROPERTY(QString mltdeinterlacer READ mltdeinterlacer WRITE setMltdeinterlacer NOTIFY mltdeinterlacerChanged)
    Q_PROPERTY(bool isMltdeinterlacerImmutable READ isMltdeinterlacerImmutable CONSTANT)
    Q_PROPERTY(QString defaultMltdeinterlacerValue READ defaultMltdeinterlacerValue CONSTANT)
    /**
      Get Name of the chosen deinterlacer.
    */
    static
    QString mltdeinterlacer()
    {
      return self()->mMltdeinterlacer;
    }

    /**
      Is Name of the chosen deinterlacer. Immutable
    */
    static
    bool isMltdeinterlacerImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mltdeinterlacer" ) );
    }

    /**
      Get Name of the chosen deinterlacer. default value
    */
    static
    QString defaultMltdeinterlacerValue()
    {
        return defaultMltdeinterlacerValue_helper();
    }

    /**
      Set Name of the chosen interpol method.
    */
    static
    void setMltinterpolation( const QString & v )
    {
      if (v != self()->mMltinterpolation && !self()->isMltinterpolationImmutable()) {
        self()->mMltinterpolation = v;
        Q_EMIT self()->mltinterpolationChanged();
      }
    }

    Q_PROPERTY(QString mltinterpolation READ mltinterpolation WRITE setMltinterpolation NOTIFY mltinterpolationChanged)
    Q_PROPERTY(bool isMltinterpolationImmutable READ isMltinterpolationImmutable CONSTANT)
    Q_PROPERTY(QString defaultMltinterpolationValue READ defaultMltinterpolationValue CONSTANT)
    /**
      Get Name of the chosen interpol method.
    */
    static
    QString mltinterpolation()
    {
      return self()->mMltinterpolation;
    }

    /**
      Is Name of the chosen interpol method. Immutable
    */
    static
    bool isMltinterpolationImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mltinterpolation" ) );
    }

    /**
      Get Name of the chosen interpol method. default value
    */
    static
    QString defaultMltinterpolationValue()
    {
        return defaultMltinterpolationValue_helper();
    }

    /**
      Set List of favorite effects ids.
    */
    static
    void setFavorite_effects( const QStringList & v )
    {
      if (v != self()->mFavorite_effects && !self()->isFavorite_effectsImmutable()) {
        self()->mFavorite_effects = v;
        Q_EMIT self()->favorite_effectsChanged();
      }
    }

    Q_PROPERTY(QStringList favorite_effects READ favorite_effects WRITE setFavorite_effects NOTIFY favorite_effectsChanged)
    Q_PROPERTY(bool isFavorite_effectsImmutable READ isFavorite_effectsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultFavorite_effectsValue READ defaultFavorite_effectsValue CONSTANT)
    /**
      Get List of favorite effects ids.
    */
    static
    QStringList favorite_effects()
    {
      return self()->mFavorite_effects;
    }

    /**
      Is List of favorite effects ids. Immutable
    */
    static
    bool isFavorite_effectsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "favorite_effects" ) );
    }

    /**
      Get List of favorite effects ids. default value
    */
    static
    QStringList defaultFavorite_effectsValue()
    {
        return defaultFavorite_effectsValue_helper();
    }

    /**
      Set List of favorite transitions ids.
    */
    static
    void setFavorite_transitions( const QStringList & v )
    {
      if (v != self()->mFavorite_transitions && !self()->isFavorite_transitionsImmutable()) {
        self()->mFavorite_transitions = v;
        Q_EMIT self()->favorite_transitionsChanged();
      }
    }

    Q_PROPERTY(QStringList favorite_transitions READ favorite_transitions WRITE setFavorite_transitions NOTIFY favorite_transitionsChanged)
    Q_PROPERTY(bool isFavorite_transitionsImmutable READ isFavorite_transitionsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultFavorite_transitionsValue READ defaultFavorite_transitionsValue CONSTANT)
    /**
      Get List of favorite transitions ids.
    */
    static
    QStringList favorite_transitions()
    {
      return self()->mFavorite_transitions;
    }

    /**
      Is List of favorite transitions ids. Immutable
    */
    static
    bool isFavorite_transitionsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "favorite_transitions" ) );
    }

    /**
      Get List of favorite transitions ids. default value
    */
    static
    QStringList defaultFavorite_transitionsValue()
    {
        return defaultFavorite_transitionsValue_helper();
    }

    /**
      Set Last opened tab in effects list.
    */
    static
    void setSelected_effecttab( int v )
    {
      if (v != self()->mSelected_effecttab && !self()->isSelected_effecttabImmutable()) {
        self()->mSelected_effecttab = v;
        Q_EMIT self()->selected_effecttabChanged();
      }
    }

    Q_PROPERTY(int selected_effecttab READ selected_effecttab WRITE setSelected_effecttab NOTIFY selected_effecttabChanged)
    Q_PROPERTY(bool isSelected_effecttabImmutable READ isSelected_effecttabImmutable CONSTANT)
    Q_PROPERTY(int defaultSelected_effecttabValue READ defaultSelected_effecttabValue CONSTANT)
    /**
      Get Last opened tab in effects list.
    */
    static
    int selected_effecttab()
    {
      return self()->mSelected_effecttab;
    }

    /**
      Is Last opened tab in effects list. Immutable
    */
    static
    bool isSelected_effecttabImmutable()
    {
      return self()->isImmutable( QStringLiteral( "selected_effecttab" ) );
    }

    /**
      Get Last opened tab in effects list. default value
    */
    static
    int defaultSelected_effecttabValue()
    {
        return defaultSelected_effecttabValue_helper();
    }

    /**
      Set Show effects as icon list.
    */
    static
    void setEffectViewAsIcon( bool v )
    {
      if (v != self()->mEffectViewAsIcon && !self()->isEffectViewAsIconImmutable()) {
        self()->mEffectViewAsIcon = v;
        Q_EMIT self()->effectViewAsIconChanged();
      }
    }

    Q_PROPERTY(bool effectViewAsIcon READ effectViewAsIcon WRITE setEffectViewAsIcon NOTIFY effectViewAsIconChanged)
    Q_PROPERTY(bool isEffectViewAsIconImmutable READ isEffectViewAsIconImmutable CONSTANT)
    Q_PROPERTY(bool defaultEffectViewAsIconValue READ defaultEffectViewAsIconValue CONSTANT)
    /**
      Get Show effects as icon list.
    */
    static
    bool effectViewAsIcon()
    {
      return self()->mEffectViewAsIcon;
    }

    /**
      Is Show effects as icon list. Immutable
    */
    static
    bool isEffectViewAsIconImmutable()
    {
      return self()->isImmutable( QStringLiteral( "effectViewAsIcon" ) );
    }

    /**
      Get Show effects as icon list. default value
    */
    static
    bool defaultEffectViewAsIconValue()
    {
        return defaultEffectViewAsIconValue_helper();
    }

    /**
      Set Show transitions as icon list.
    */
    static
    void setTransitionViewAsIcon( bool v )
    {
      if (v != self()->mTransitionViewAsIcon && !self()->isTransitionViewAsIconImmutable()) {
        self()->mTransitionViewAsIcon = v;
        Q_EMIT self()->transitionViewAsIconChanged();
      }
    }

    Q_PROPERTY(bool transitionViewAsIcon READ transitionViewAsIcon WRITE setTransitionViewAsIcon NOTIFY transitionViewAsIconChanged)
    Q_PROPERTY(bool isTransitionViewAsIconImmutable READ isTransitionViewAsIconImmutable CONSTANT)
    Q_PROPERTY(bool defaultTransitionViewAsIconValue READ defaultTransitionViewAsIconValue CONSTANT)
    /**
      Get Show transitions as icon list.
    */
    static
    bool transitionViewAsIcon()
    {
      return self()->mTransitionViewAsIcon;
    }

    /**
      Is Show transitions as icon list. Immutable
    */
    static
    bool isTransitionViewAsIconImmutable()
    {
      return self()->isImmutable( QStringLiteral( "transitionViewAsIcon" ) );
    }

    /**
      Get Show transitions as icon list. default value
    */
    static
    bool defaultTransitionViewAsIconValue()
    {
        return defaultTransitionViewAsIconValue_helper();
    }

    /**
      Set Force breeze icon theme for consistent look.
    */
    static
    void setForce_breeze( bool v )
    {
      if (v != self()->mForce_breeze && !self()->isForce_breezeImmutable()) {
        self()->mForce_breeze = v;
        Q_EMIT self()->force_breezeChanged();
      }
    }

    Q_PROPERTY(bool force_breeze READ force_breeze WRITE setForce_breeze NOTIFY force_breezeChanged)
    Q_PROPERTY(bool isForce_breezeImmutable READ isForce_breezeImmutable CONSTANT)
    Q_PROPERTY(bool defaultForce_breezeValue READ defaultForce_breezeValue CONSTANT)
    /**
      Get Force breeze icon theme for consistent look.
    */
    static
    bool force_breeze()
    {
      return self()->mForce_breeze;
    }

    /**
      Is Force breeze icon theme for consistent look. Immutable
    */
    static
    bool isForce_breezeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "force_breeze" ) );
    }

    /**
      Get Force breeze icon theme for consistent look. default value
    */
    static
    bool defaultForce_breezeValue()
    {
        return defaultForce_breezeValue_helper();
    }

    /**
      Set Force breeze icon color theme for consistent look.
    */
    static
    void setUse_dark_breeze( bool v )
    {
      if (v != self()->mUse_dark_breeze && !self()->isUse_dark_breezeImmutable()) {
        self()->mUse_dark_breeze = v;
        Q_EMIT self()->use_dark_breezeChanged();
      }
    }

    Q_PROPERTY(bool use_dark_breeze READ use_dark_breeze WRITE setUse_dark_breeze NOTIFY use_dark_breezeChanged)
    Q_PROPERTY(bool isUse_dark_breezeImmutable READ isUse_dark_breezeImmutable CONSTANT)
    Q_PROPERTY(bool defaultUse_dark_breezeValue READ defaultUse_dark_breezeValue CONSTANT)
    /**
      Get Force breeze icon color theme for consistent look.
    */
    static
    bool use_dark_breeze()
    {
      return self()->mUse_dark_breeze;
    }

    /**
      Is Force breeze icon color theme for consistent look. Immutable
    */
    static
    bool isUse_dark_breezeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "use_dark_breeze" ) );
    }

    /**
      Get Force breeze icon color theme for consistent look. default value
    */
    static
    bool defaultUse_dark_breezeValue()
    {
        return defaultUse_dark_breezeValue_helper();
    }

    /**
      Set Show Welcome page on Start.
    */
    static
    void setShowWelcome( bool v )
    {
      if (v != self()->mShowWelcome && !self()->isShowWelcomeImmutable()) {
        self()->mShowWelcome = v;
        Q_EMIT self()->showWelcomeChanged();
      }
    }

    Q_PROPERTY(bool showWelcome READ showWelcome WRITE setShowWelcome NOTIFY showWelcomeChanged)
    Q_PROPERTY(bool isShowWelcomeImmutable READ isShowWelcomeImmutable CONSTANT)
    Q_PROPERTY(bool defaultShowWelcomeValue READ defaultShowWelcomeValue CONSTANT)
    /**
      Get Show Welcome page on Start.
    */
    static
    bool showWelcome()
    {
      return self()->mShowWelcome;
    }

    /**
      Is Show Welcome page on Start. Immutable
    */
    static
    bool isShowWelcomeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "showWelcome" ) );
    }

    /**
      Get Show Welcome page on Start. default value
    */
    static
    bool defaultShowWelcomeValue()
    {
        return defaultShowWelcomeValue_helper();
    }

    /**
      Set Last used version of Kdenlive - major.
    */
    static
    void setLastSeenVersionMajor( int v )
    {
      if (v != self()->mLastSeenVersionMajor && !self()->isLastSeenVersionMajorImmutable()) {
        self()->mLastSeenVersionMajor = v;
        Q_EMIT self()->lastSeenVersionMajorChanged();
      }
    }

    Q_PROPERTY(int lastSeenVersionMajor READ lastSeenVersionMajor WRITE setLastSeenVersionMajor NOTIFY lastSeenVersionMajorChanged)
    Q_PROPERTY(bool isLastSeenVersionMajorImmutable READ isLastSeenVersionMajorImmutable CONSTANT)
    Q_PROPERTY(int defaultLastSeenVersionMajorValue READ defaultLastSeenVersionMajorValue CONSTANT)
    /**
      Get Last used version of Kdenlive - major.
    */
    static
    int lastSeenVersionMajor()
    {
      return self()->mLastSeenVersionMajor;
    }

    /**
      Is Last used version of Kdenlive - major. Immutable
    */
    static
    bool isLastSeenVersionMajorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastSeenVersionMajor" ) );
    }

    /**
      Get Last used version of Kdenlive - major. default value
    */
    static
    int defaultLastSeenVersionMajorValue()
    {
        return defaultLastSeenVersionMajorValue_helper();
    }

    /**
      Set Last used version of Kdenlive - minor.
    */
    static
    void setLastSeenVersionMinor( int v )
    {
      if (v != self()->mLastSeenVersionMinor && !self()->isLastSeenVersionMinorImmutable()) {
        self()->mLastSeenVersionMinor = v;
        Q_EMIT self()->lastSeenVersionMinorChanged();
      }
    }

    Q_PROPERTY(int lastSeenVersionMinor READ lastSeenVersionMinor WRITE setLastSeenVersionMinor NOTIFY lastSeenVersionMinorChanged)
    Q_PROPERTY(bool isLastSeenVersionMinorImmutable READ isLastSeenVersionMinorImmutable CONSTANT)
    Q_PROPERTY(int defaultLastSeenVersionMinorValue READ defaultLastSeenVersionMinorValue CONSTANT)
    /**
      Get Last used version of Kdenlive - minor.
    */
    static
    int lastSeenVersionMinor()
    {
      return self()->mLastSeenVersionMinor;
    }

    /**
      Is Last used version of Kdenlive - minor. Immutable
    */
    static
    bool isLastSeenVersionMinorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastSeenVersionMinor" ) );
    }

    /**
      Get Last used version of Kdenlive - minor. default value
    */
    static
    int defaultLastSeenVersionMinorValue()
    {
        return defaultLastSeenVersionMinorValue_helper();
    }

    /**
      Set Last used version of Kdenlive - micro.
    */
    static
    void setLastSeenVersionMicro( int v )
    {
      if (v != self()->mLastSeenVersionMicro && !self()->isLastSeenVersionMicroImmutable()) {
        self()->mLastSeenVersionMicro = v;
        Q_EMIT self()->lastSeenVersionMicroChanged();
      }
    }

    Q_PROPERTY(int lastSeenVersionMicro READ lastSeenVersionMicro WRITE setLastSeenVersionMicro NOTIFY lastSeenVersionMicroChanged)
    Q_PROPERTY(bool isLastSeenVersionMicroImmutable READ isLastSeenVersionMicroImmutable CONSTANT)
    Q_PROPERTY(int defaultLastSeenVersionMicroValue READ defaultLastSeenVersionMicroValue CONSTANT)
    /**
      Get Last used version of Kdenlive - micro.
    */
    static
    int lastSeenVersionMicro()
    {
      return self()->mLastSeenVersionMicro;
    }

    /**
      Is Last used version of Kdenlive - micro. Immutable
    */
    static
    bool isLastSeenVersionMicroImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lastSeenVersionMicro" ) );
    }

    /**
      Get Last used version of Kdenlive - micro. default value
    */
    static
    int defaultLastSeenVersionMicroValue()
    {
        return defaultLastSeenVersionMicroValue_helper();
    }

    /**
      Set Lock size ratio in effects.
    */
    static
    void setLock_ratio( bool v )
    {
      if (v != self()->mLock_ratio && !self()->isLock_ratioImmutable()) {
        self()->mLock_ratio = v;
        Q_EMIT self()->lock_ratioChanged();
      }
    }

    Q_PROPERTY(bool lock_ratio READ lock_ratio WRITE setLock_ratio NOTIFY lock_ratioChanged)
    Q_PROPERTY(bool isLock_ratioImmutable READ isLock_ratioImmutable CONSTANT)
    Q_PROPERTY(bool defaultLock_ratioValue READ defaultLock_ratioValue CONSTANT)
    /**
      Get Lock size ratio in effects.
    */
    static
    bool lock_ratio()
    {
      return self()->mLock_ratio;
    }

    /**
      Is Lock size ratio in effects. Immutable
    */
    static
    bool isLock_ratioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "lock_ratio" ) );
    }

    /**
      Get Lock size ratio in effects. default value
    */
    static
    bool defaultLock_ratioValue()
    {
        return defaultLock_ratioValue_helper();
    }

    /**
      Set Name of last selected title template
    */
    static
    void setSelected_template( const QString & v )
    {
      if (v != self()->mSelected_template && !self()->isSelected_templateImmutable()) {
        self()->mSelected_template = v;
        Q_EMIT self()->selected_templateChanged();
      }
    }

    Q_PROPERTY(QString selected_template READ selected_template WRITE setSelected_template NOTIFY selected_templateChanged)
    Q_PROPERTY(bool isSelected_templateImmutable READ isSelected_templateImmutable CONSTANT)
    /**
      Get Name of last selected title template
    */
    static
    QString selected_template()
    {
      return self()->mSelected_template;
    }

    /**
      Is Name of last selected title template Immutable
    */
    static
    bool isSelected_templateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "selected_template" ) );
    }

    /**
      Set Show guides in titler.
    */
    static
    void setTitlerShowGuides( bool v )
    {
      if (v != self()->mTitlerShowGuides && !self()->isTitlerShowGuidesImmutable()) {
        self()->mTitlerShowGuides = v;
        Q_EMIT self()->titlerShowGuidesChanged();
      }
    }

    Q_PROPERTY(bool titlerShowGuides READ titlerShowGuides WRITE setTitlerShowGuides NOTIFY titlerShowGuidesChanged)
    Q_PROPERTY(bool isTitlerShowGuidesImmutable READ isTitlerShowGuidesImmutable CONSTANT)
    Q_PROPERTY(bool defaultTitlerShowGuidesValue READ defaultTitlerShowGuidesValue CONSTANT)
    /**
      Get Show guides in titler.
    */
    static
    bool titlerShowGuides()
    {
      return self()->mTitlerShowGuides;
    }

    /**
      Is Show guides in titler. Immutable
    */
    static
    bool isTitlerShowGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerShowGuides" ) );
    }

    /**
      Get Show guides in titler. default value
    */
    static
    bool defaultTitlerShowGuidesValue()
    {
        return defaultTitlerShowGuidesValue_helper();
    }

    /**
      Set Version of the Kdenlivetitler MLT module.
    */
    static
    void setTitlerVersion( int v )
    {
      if (v != self()->mTitlerVersion && !self()->isTitlerVersionImmutable()) {
        self()->mTitlerVersion = v;
        Q_EMIT self()->titlerVersionChanged();
      }
    }

    Q_PROPERTY(int titlerVersion READ titlerVersion WRITE setTitlerVersion NOTIFY titlerVersionChanged)
    Q_PROPERTY(bool isTitlerVersionImmutable READ isTitlerVersionImmutable CONSTANT)
    Q_PROPERTY(int defaultTitlerVersionValue READ defaultTitlerVersionValue CONSTANT)
    /**
      Get Version of the Kdenlivetitler MLT module.
    */
    static
    int titlerVersion()
    {
      return self()->mTitlerVersion;
    }

    /**
      Is Version of the Kdenlivetitler MLT module. Immutable
    */
    static
    bool isTitlerVersionImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerVersion" ) );
    }

    /**
      Get Version of the Kdenlivetitler MLT module. default value
    */
    static
    int defaultTitlerVersionValue()
    {
        return defaultTitlerVersionValue_helper();
    }

    /**
      Set Number of horizontal guides in titler.
    */
    static
    void setTitlerHGuides( int v )
    {
      if (v != self()->mTitlerHGuides && !self()->isTitlerHGuidesImmutable()) {
        self()->mTitlerHGuides = v;
        Q_EMIT self()->titlerHGuidesChanged();
      }
    }

    Q_PROPERTY(int titlerHGuides READ titlerHGuides WRITE setTitlerHGuides NOTIFY titlerHGuidesChanged)
    Q_PROPERTY(bool isTitlerHGuidesImmutable READ isTitlerHGuidesImmutable CONSTANT)
    Q_PROPERTY(int defaultTitlerHGuidesValue READ defaultTitlerHGuidesValue CONSTANT)
    /**
      Get Number of horizontal guides in titler.
    */
    static
    int titlerHGuides()
    {
      return self()->mTitlerHGuides;
    }

    /**
      Is Number of horizontal guides in titler. Immutable
    */
    static
    bool isTitlerHGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerHGuides" ) );
    }

    /**
      Get Number of horizontal guides in titler. default value
    */
    static
    int defaultTitlerHGuidesValue()
    {
        return defaultTitlerHGuidesValue_helper();
    }

    /**
      Set Number of vertical guides in titler.
    */
    static
    void setTitlerVGuides( int v )
    {
      if (v != self()->mTitlerVGuides && !self()->isTitlerVGuidesImmutable()) {
        self()->mTitlerVGuides = v;
        Q_EMIT self()->titlerVGuidesChanged();
      }
    }

    Q_PROPERTY(int titlerVGuides READ titlerVGuides WRITE setTitlerVGuides NOTIFY titlerVGuidesChanged)
    Q_PROPERTY(bool isTitlerVGuidesImmutable READ isTitlerVGuidesImmutable CONSTANT)
    Q_PROPERTY(int defaultTitlerVGuidesValue READ defaultTitlerVGuidesValue CONSTANT)
    /**
      Get Number of vertical guides in titler.
    */
    static
    int titlerVGuides()
    {
      return self()->mTitlerVGuides;
    }

    /**
      Is Number of vertical guides in titler. Immutable
    */
    static
    bool isTitlerVGuidesImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerVGuides" ) );
    }

    /**
      Get Number of vertical guides in titler. default value
    */
    static
    int defaultTitlerVGuidesValue()
    {
        return defaultTitlerVGuidesValue_helper();
    }

    /**
      Set color titler guides.
    */
    static
    void setTitleGuideColor( const QColor & v )
    {
      if (v != self()->mTitleGuideColor && !self()->isTitleGuideColorImmutable()) {
        self()->mTitleGuideColor = v;
        Q_EMIT self()->titleGuideColorChanged();
      }
    }

    Q_PROPERTY(QColor titleGuideColor READ titleGuideColor WRITE setTitleGuideColor NOTIFY titleGuideColorChanged)
    Q_PROPERTY(bool isTitleGuideColorImmutable READ isTitleGuideColorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultTitleGuideColorValue READ defaultTitleGuideColorValue CONSTANT)
    /**
      Get color titler guides.
    */
    static
    QColor titleGuideColor()
    {
      return self()->mTitleGuideColor;
    }

    /**
      Is color titler guides. Immutable
    */
    static
    bool isTitleGuideColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titleGuideColor" ) );
    }

    /**
      Get color titler guides. default value
    */
    static
    QColor defaultTitleGuideColorValue()
    {
        return defaultTitleGuideColorValue_helper();
    }

    /**
      Set Default background for titler.
    */
    static
    void setTitlerbg( int v )
    {
      if (v != self()->mTitlerbg && !self()->isTitlerbgImmutable()) {
        self()->mTitlerbg = v;
        Q_EMIT self()->titlerbgChanged();
      }
    }

    Q_PROPERTY(int titlerbg READ titlerbg WRITE setTitlerbg NOTIFY titlerbgChanged)
    Q_PROPERTY(bool isTitlerbgImmutable READ isTitlerbgImmutable CONSTANT)
    Q_PROPERTY(int defaultTitlerbgValue READ defaultTitlerbgValue CONSTANT)
    /**
      Get Default background for titler.
    */
    static
    int titlerbg()
    {
      return self()->mTitlerbg;
    }

    /**
      Is Default background for titler. Immutable
    */
    static
    bool isTitlerbgImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerbg" ) );
    }

    /**
      Get Default background for titler. default value
    */
    static
    int defaultTitlerbgValue()
    {
        return defaultTitlerbgValue_helper();
    }

    /**
      Set Show titler background.
    */
    static
    void setTitlerShowbg( bool v )
    {
      if (v != self()->mTitlerShowbg && !self()->isTitlerShowbgImmutable()) {
        self()->mTitlerShowbg = v;
        Q_EMIT self()->titlerShowbgChanged();
      }
    }

    Q_PROPERTY(bool titlerShowbg READ titlerShowbg WRITE setTitlerShowbg NOTIFY titlerShowbgChanged)
    Q_PROPERTY(bool isTitlerShowbgImmutable READ isTitlerShowbgImmutable CONSTANT)
    Q_PROPERTY(bool defaultTitlerShowbgValue READ defaultTitlerShowbgValue CONSTANT)
    /**
      Get Show titler background.
    */
    static
    bool titlerShowbg()
    {
      return self()->mTitlerShowbg;
    }

    /**
      Is Show titler background. Immutable
    */
    static
    bool isTitlerShowbgImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerShowbg" ) );
    }

    /**
      Get Show titler background. default value
    */
    static
    bool defaultTitlerShowbgValue()
    {
        return defaultTitlerShowbgValue_helper();
    }

    /**
      Set Default text align for titler.
    */
    static
    void setTitlerAlign( int v )
    {
      if (v != self()->mTitlerAlign && !self()->isTitlerAlignImmutable()) {
        self()->mTitlerAlign = v;
        Q_EMIT self()->titlerAlignChanged();
      }
    }

    Q_PROPERTY(int titlerAlign READ titlerAlign WRITE setTitlerAlign NOTIFY titlerAlignChanged)
    Q_PROPERTY(bool isTitlerAlignImmutable READ isTitlerAlignImmutable CONSTANT)
    Q_PROPERTY(int defaultTitlerAlignValue READ defaultTitlerAlignValue CONSTANT)
    /**
      Get Default text align for titler.
    */
    static
    int titlerAlign()
    {
      return self()->mTitlerAlign;
    }

    /**
      Is Default text align for titler. Immutable
    */
    static
    bool isTitlerAlignImmutable()
    {
      return self()->isImmutable( QStringLiteral( "titlerAlign" ) );
    }

    /**
      Get Default text align for titler. default value
    */
    static
    int defaultTitlerAlignValue()
    {
        return defaultTitlerAlignValue_helper();
    }

    /**
      Set Path for the chosen sam model.
    */
    static
    void setSamModelFile( const QString & v )
    {
      if (v != self()->mSamModelFile && !self()->isSamModelFileImmutable()) {
        self()->mSamModelFile = v;
        Q_EMIT self()->samModelFileChanged();
      }
    }

    Q_PROPERTY(QString samModelFile READ samModelFile WRITE setSamModelFile NOTIFY samModelFileChanged)
    Q_PROPERTY(bool isSamModelFileImmutable READ isSamModelFileImmutable CONSTANT)
    /**
      Get Path for the chosen sam model.
    */
    static
    QString samModelFile()
    {
      return self()->mSamModelFile;
    }

    /**
      Is Path for the chosen sam model. Immutable
    */
    static
    bool isSamModelFileImmutable()
    {
      return self()->isImmutable( QStringLiteral( "samModelFile" ) );
    }

    /**
      Set Offload video to CPU to reduce memory use.
    */
    static
    void setSam_offload_video( bool v )
    {
      if (v != self()->mSam_offload_video && !self()->isSam_offload_videoImmutable()) {
        self()->mSam_offload_video = v;
        Q_EMIT self()->sam_offload_videoChanged();
      }
    }

    Q_PROPERTY(bool sam_offload_video READ sam_offload_video WRITE setSam_offload_video NOTIFY sam_offload_videoChanged)
    Q_PROPERTY(bool isSam_offload_videoImmutable READ isSam_offload_videoImmutable CONSTANT)
    Q_PROPERTY(bool defaultSam_offload_videoValue READ defaultSam_offload_videoValue CONSTANT)
    /**
      Get Offload video to CPU to reduce memory use.
    */
    static
    bool sam_offload_video()
    {
      return self()->mSam_offload_video;
    }

    /**
      Is Offload video to CPU to reduce memory use. Immutable
    */
    static
    bool isSam_offload_videoImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sam_offload_video" ) );
    }

    /**
      Get Offload video to CPU to reduce memory use. default value
    */
    static
    bool defaultSam_offload_videoValue()
    {
        return defaultSam_offload_videoValue_helper();
    }

    /**
      Set Use system packages for SAM plugin
    */
    static
    void setSam_system_python( bool v )
    {
      if (v != self()->mSam_system_python && !self()->isSam_system_pythonImmutable()) {
        self()->mSam_system_python = v;
        Q_EMIT self()->sam_system_pythonChanged();
      }
    }

    Q_PROPERTY(bool sam_system_python READ sam_system_python WRITE setSam_system_python NOTIFY sam_system_pythonChanged)
    Q_PROPERTY(bool isSam_system_pythonImmutable READ isSam_system_pythonImmutable CONSTANT)
    Q_PROPERTY(bool defaultSam_system_pythonValue READ defaultSam_system_pythonValue CONSTANT)
    /**
      Get Use system packages for SAM plugin
    */
    static
    bool sam_system_python()
    {
      return self()->mSam_system_python;
    }

    /**
      Is Use system packages for SAM plugin Immutable
    */
    static
    bool isSam_system_pythonImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sam_system_python" ) );
    }

    /**
      Get Use system packages for SAM plugin default value
    */
    static
    bool defaultSam_system_pythonValue()
    {
        return defaultSam_system_pythonValue_helper();
    }

    /**
      Set Path to python exec for SAM.
    */
    static
    void setSam_system_python_path( const QString & v )
    {
      if (v != self()->mSam_system_python_path && !self()->isSam_system_python_pathImmutable()) {
        self()->mSam_system_python_path = v;
        Q_EMIT self()->sam_system_python_pathChanged();
      }
    }

    Q_PROPERTY(QString sam_system_python_path READ sam_system_python_path WRITE setSam_system_python_path NOTIFY sam_system_python_pathChanged)
    Q_PROPERTY(bool isSam_system_python_pathImmutable READ isSam_system_python_pathImmutable CONSTANT)
    /**
      Get Path to python exec for SAM.
    */
    static
    QString sam_system_python_path()
    {
      return self()->mSam_system_python_path;
    }

    /**
      Is Path to python exec for SAM. Immutable
    */
    static
    bool isSam_system_python_pathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "sam_system_python_path" ) );
    }

    /**
      Set Default border width for mask.
    */
    static
    void setMaskBorderWidth( int v )
    {
      if (v != self()->mMaskBorderWidth && !self()->isMaskBorderWidthImmutable()) {
        self()->mMaskBorderWidth = v;
        Q_EMIT self()->maskBorderWidthChanged();
      }
    }

    Q_PROPERTY(int maskBorderWidth READ maskBorderWidth WRITE setMaskBorderWidth NOTIFY maskBorderWidthChanged)
    Q_PROPERTY(bool isMaskBorderWidthImmutable READ isMaskBorderWidthImmutable CONSTANT)
    Q_PROPERTY(int defaultMaskBorderWidthValue READ defaultMaskBorderWidthValue CONSTANT)
    /**
      Get Default border width for mask.
    */
    static
    int maskBorderWidth()
    {
      return self()->mMaskBorderWidth;
    }

    /**
      Is Default border width for mask. Immutable
    */
    static
    bool isMaskBorderWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maskBorderWidth" ) );
    }

    /**
      Get Default border width for mask. default value
    */
    static
    int defaultMaskBorderWidthValue()
    {
        return defaultMaskBorderWidthValue_helper();
    }

    /**
      Set Default border color for mask.
    */
    static
    void setMaskBorderColor( const QColor & v )
    {
      if (v != self()->mMaskBorderColor && !self()->isMaskBorderColorImmutable()) {
        self()->mMaskBorderColor = v;
        Q_EMIT self()->maskBorderColorChanged();
      }
    }

    Q_PROPERTY(QColor maskBorderColor READ maskBorderColor WRITE setMaskBorderColor NOTIFY maskBorderColorChanged)
    Q_PROPERTY(bool isMaskBorderColorImmutable READ isMaskBorderColorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultMaskBorderColorValue READ defaultMaskBorderColorValue CONSTANT)
    /**
      Get Default border color for mask.
    */
    static
    QColor maskBorderColor()
    {
      return self()->mMaskBorderColor;
    }

    /**
      Is Default border color for mask. Immutable
    */
    static
    bool isMaskBorderColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maskBorderColor" ) );
    }

    /**
      Get Default border color for mask. default value
    */
    static
    QColor defaultMaskBorderColorValue()
    {
        return defaultMaskBorderColorValue_helper();
    }

    /**
      Set Default color for mask.
    */
    static
    void setMaskColor( const QColor & v )
    {
      if (v != self()->mMaskColor && !self()->isMaskColorImmutable()) {
        self()->mMaskColor = v;
        Q_EMIT self()->maskColorChanged();
      }
    }

    Q_PROPERTY(QColor maskColor READ maskColor WRITE setMaskColor NOTIFY maskColorChanged)
    Q_PROPERTY(bool isMaskColorImmutable READ isMaskColorImmutable CONSTANT)
    Q_PROPERTY(QColor defaultMaskColorValue READ defaultMaskColorValue CONSTANT)
    /**
      Get Default color for mask.
    */
    static
    QColor maskColor()
    {
      return self()->mMaskColor;
    }

    /**
      Is Default color for mask. Immutable
    */
    static
    bool isMaskColorImmutable()
    {
      return self()->isImmutable( QStringLiteral( "maskColor" ) );
    }

    /**
      Get Default color for mask. default value
    */
    static
    QColor defaultMaskColorValue()
    {
        return defaultMaskColorValue_helper();
    }

    /**
      Set Use system packages for STT plugin
    */
    static
    void setSpeech_system_python( bool v )
    {
      if (v != self()->mSpeech_system_python && !self()->isSpeech_system_pythonImmutable()) {
        self()->mSpeech_system_python = v;
        Q_EMIT self()->speech_system_pythonChanged();
      }
    }

    Q_PROPERTY(bool speech_system_python READ speech_system_python WRITE setSpeech_system_python NOTIFY speech_system_pythonChanged)
    Q_PROPERTY(bool isSpeech_system_pythonImmutable READ isSpeech_system_pythonImmutable CONSTANT)
    Q_PROPERTY(bool defaultSpeech_system_pythonValue READ defaultSpeech_system_pythonValue CONSTANT)
    /**
      Get Use system packages for STT plugin
    */
    static
    bool speech_system_python()
    {
      return self()->mSpeech_system_python;
    }

    /**
      Is Use system packages for STT plugin Immutable
    */
    static
    bool isSpeech_system_pythonImmutable()
    {
      return self()->isImmutable( QStringLiteral( "speech_system_python" ) );
    }

    /**
      Get Use system packages for STT plugin default value
    */
    static
    bool defaultSpeech_system_pythonValue()
    {
        return defaultSpeech_system_pythonValue_helper();
    }

    /**
      Set Path to python exec for STT.
    */
    static
    void setSpeech_system_python_path( const QString & v )
    {
      if (v != self()->mSpeech_system_python_path && !self()->isSpeech_system_python_pathImmutable()) {
        self()->mSpeech_system_python_path = v;
        Q_EMIT self()->speech_system_python_pathChanged();
      }
    }

    Q_PROPERTY(QString speech_system_python_path READ speech_system_python_path WRITE setSpeech_system_python_path NOTIFY speech_system_python_pathChanged)
    Q_PROPERTY(bool isSpeech_system_python_pathImmutable READ isSpeech_system_python_pathImmutable CONSTANT)
    /**
      Get Path to python exec for STT.
    */
    static
    QString speech_system_python_path()
    {
      return self()->mSpeech_system_python_path;
    }

    /**
      Is Path to python exec for STT. Immutable
    */
    static
    bool isSpeech_system_python_pathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "speech_system_python_path" ) );
    }

    /**
      Set Custom path for the folder containins the vosk speech models. Uses default XDG location if empty
    */
    static
    void setVosk_folder_path( const QString & v )
    {
      if (v != self()->mVosk_folder_path && !self()->isVosk_folder_pathImmutable()) {
        self()->mVosk_folder_path = v;
        Q_EMIT self()->vosk_folder_pathChanged();
      }
    }

    Q_PROPERTY(QString vosk_folder_path READ vosk_folder_path WRITE setVosk_folder_path NOTIFY vosk_folder_pathChanged)
    Q_PROPERTY(bool isVosk_folder_pathImmutable READ isVosk_folder_pathImmutable CONSTANT)
    /**
      Get Custom path for the folder containins the vosk speech models. Uses default XDG location if empty
    */
    static
    QString vosk_folder_path()
    {
      return self()->mVosk_folder_path;
    }

    /**
      Is Custom path for the folder containins the vosk speech models. Uses default XDG location if empty Immutable
    */
    static
    bool isVosk_folder_pathImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vosk_folder_path" ) );
    }

    /**
      Set Last selected model for speech recognition
    */
    static
    void setVosk_text_model( const QString & v )
    {
      if (v != self()->mVosk_text_model && !self()->isVosk_text_modelImmutable()) {
        self()->mVosk_text_model = v;
        Q_EMIT self()->vosk_text_modelChanged();
      }
    }

    Q_PROPERTY(QString vosk_text_model READ vosk_text_model WRITE setVosk_text_model NOTIFY vosk_text_modelChanged)
    Q_PROPERTY(bool isVosk_text_modelImmutable READ isVosk_text_modelImmutable CONSTANT)
    /**
      Get Last selected model for speech recognition
    */
    static
    QString vosk_text_model()
    {
      return self()->mVosk_text_model;
    }

    /**
      Is Last selected model for speech recognition Immutable
    */
    static
    bool isVosk_text_modelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vosk_text_model" ) );
    }

    /**
      Set Last selected model for automatic subtitling
    */
    static
    void setVosk_srt_model( const QString & v )
    {
      if (v != self()->mVosk_srt_model && !self()->isVosk_srt_modelImmutable()) {
        self()->mVosk_srt_model = v;
        Q_EMIT self()->vosk_srt_modelChanged();
      }
    }

    Q_PROPERTY(QString vosk_srt_model READ vosk_srt_model WRITE setVosk_srt_model NOTIFY vosk_srt_modelChanged)
    Q_PROPERTY(bool isVosk_srt_modelImmutable READ isVosk_srt_modelImmutable CONSTANT)
    /**
      Get Last selected model for automatic subtitling
    */
    static
    QString vosk_srt_model()
    {
      return self()->mVosk_srt_model;
    }

    /**
      Is Last selected model for automatic subtitling Immutable
    */
    static
    bool isVosk_srt_modelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "vosk_srt_model" ) );
    }

    /**
      Set Last selected model for automatic subtitling
    */
    static
    void setSpeech_zone( bool v )
    {
      if (v != self()->mSpeech_zone && !self()->isSpeech_zoneImmutable()) {
        self()->mSpeech_zone = v;
        Q_EMIT self()->speech_zoneChanged();
      }
    }

    Q_PROPERTY(bool speech_zone READ speech_zone WRITE setSpeech_zone NOTIFY speech_zoneChanged)
    Q_PROPERTY(bool isSpeech_zoneImmutable READ isSpeech_zoneImmutable CONSTANT)
    Q_PROPERTY(bool defaultSpeech_zoneValue READ defaultSpeech_zoneValue CONSTANT)
    /**
      Get Last selected model for automatic subtitling
    */
    static
    bool speech_zone()
    {
      return self()->mSpeech_zone;
    }

    /**
      Is Last selected model for automatic subtitling Immutable
    */
    static
    bool isSpeech_zoneImmutable()
    {
      return self()->isImmutable( QStringLiteral( "speech_zone" ) );
    }

    /**
      Get Last selected model for automatic subtitling default value
    */
    static
    bool defaultSpeech_zoneValue()
    {
        return defaultSpeech_zoneValue_helper();
    }

    /**
      Set Last selected model for automatic subtitling
    */
    static
    void setWhisperModel( const QString & v )
    {
      if (v != self()->mWhisperModel && !self()->isWhisperModelImmutable()) {
        self()->mWhisperModel = v;
        Q_EMIT self()->whisperModelChanged();
      }
    }

    Q_PROPERTY(QString whisperModel READ whisperModel WRITE setWhisperModel NOTIFY whisperModelChanged)
    Q_PROPERTY(bool isWhisperModelImmutable READ isWhisperModelImmutable CONSTANT)
    Q_PROPERTY(QString defaultWhisperModelValue READ defaultWhisperModelValue CONSTANT)
    /**
      Get Last selected model for automatic subtitling
    */
    static
    QString whisperModel()
    {
      return self()->mWhisperModel;
    }

    /**
      Is Last selected model for automatic subtitling Immutable
    */
    static
    bool isWhisperModelImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperModel" ) );
    }

    /**
      Get Last selected model for automatic subtitling default value
    */
    static
    QString defaultWhisperModelValue()
    {
        return defaultWhisperModelValue_helper();
    }

    /**
      Set The list of already downloaded models
    */
    static
    void setWhisperInstalledModels( const QStringList & v )
    {
      if (v != self()->mWhisperInstalledModels && !self()->isWhisperInstalledModelsImmutable()) {
        self()->mWhisperInstalledModels = v;
        Q_EMIT self()->whisperInstalledModelsChanged();
      }
    }

    Q_PROPERTY(QStringList whisperInstalledModels READ whisperInstalledModels WRITE setWhisperInstalledModels NOTIFY whisperInstalledModelsChanged)
    Q_PROPERTY(bool isWhisperInstalledModelsImmutable READ isWhisperInstalledModelsImmutable CONSTANT)
    /**
      Get The list of already downloaded models
    */
    static
    QStringList whisperInstalledModels()
    {
      return self()->mWhisperInstalledModels;
    }

    /**
      Is The list of already downloaded models Immutable
    */
    static
    bool isWhisperInstalledModelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperInstalledModels" ) );
    }

    /**
      Set The list of available models, with modelname=filename
    */
    static
    void setWhisperAvailableModels( const QStringList & v )
    {
      if (v != self()->mWhisperAvailableModels && !self()->isWhisperAvailableModelsImmutable()) {
        self()->mWhisperAvailableModels = v;
        Q_EMIT self()->whisperAvailableModelsChanged();
      }
    }

    Q_PROPERTY(QStringList whisperAvailableModels READ whisperAvailableModels WRITE setWhisperAvailableModels NOTIFY whisperAvailableModelsChanged)
    Q_PROPERTY(bool isWhisperAvailableModelsImmutable READ isWhisperAvailableModelsImmutable CONSTANT)
    Q_PROPERTY(QStringList defaultWhisperAvailableModelsValue READ defaultWhisperAvailableModelsValue CONSTANT)
    /**
      Get The list of available models, with modelname=filename
    */
    static
    QStringList whisperAvailableModels()
    {
      return self()->mWhisperAvailableModels;
    }

    /**
      Is The list of available models, with modelname=filename Immutable
    */
    static
    bool isWhisperAvailableModelsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperAvailableModels" ) );
    }

    /**
      Get The list of available models, with modelname=filename default value
    */
    static
    QStringList defaultWhisperAvailableModelsValue()
    {
        return defaultWhisperAvailableModelsValue_helper();
    }

    /**
      Set The list of available models, with filename=hash
    */
    static
    void setWhisperAvailableModelsHash( const QStringList & v )
    {
      if (v != self()->mWhisperAvailableModelsHash && !self()->isWhisperAvailableModelsHashImmutable()) {
        self()->mWhisperAvailableModelsHash = v;
        Q_EMIT self()->whisperAvailableModelsHashChanged();
      }
    }

    Q_PROPERTY(QStringList whisperAvailableModelsHash READ whisperAvailableModelsHash WRITE setWhisperAvailableModelsHash NOTIFY whisperAvailableModelsHashChanged)
    Q_PROPERTY(bool isWhisperAvailableModelsHashImmutable READ isWhisperAvailableModelsHashImmutable CONSTANT)
    /**
      Get The list of available models, with filename=hash
    */
    static
    QStringList whisperAvailableModelsHash()
    {
      return self()->mWhisperAvailableModelsHash;
    }

    /**
      Is The list of available models, with filename=hash Immutable
    */
    static
    bool isWhisperAvailableModelsHashImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperAvailableModelsHash" ) );
    }

    /**
      Set The path to models downloads
    */
    static
    void setWhisperModelFolder( const QString & v )
    {
      if (v != self()->mWhisperModelFolder && !self()->isWhisperModelFolderImmutable()) {
        self()->mWhisperModelFolder = v;
        Q_EMIT self()->whisperModelFolderChanged();
      }
    }

    Q_PROPERTY(QString whisperModelFolder READ whisperModelFolder WRITE setWhisperModelFolder NOTIFY whisperModelFolderChanged)
    Q_PROPERTY(bool isWhisperModelFolderImmutable READ isWhisperModelFolderImmutable CONSTANT)
    /**
      Get The path to models downloads
    */
    static
    QString whisperModelFolder()
    {
      return self()->mWhisperModelFolder;
    }

    /**
      Is The path to models downloads Immutable
    */
    static
    bool isWhisperModelFolderImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperModelFolder" ) );
    }

    /**
      Set Last selected language for speech detection
    */
    static
    void setWhisperLanguage( const QString & v )
    {
      if (v != self()->mWhisperLanguage && !self()->isWhisperLanguageImmutable()) {
        self()->mWhisperLanguage = v;
        Q_EMIT self()->whisperLanguageChanged();
      }
    }

    Q_PROPERTY(QString whisperLanguage READ whisperLanguage WRITE setWhisperLanguage NOTIFY whisperLanguageChanged)
    Q_PROPERTY(bool isWhisperLanguageImmutable READ isWhisperLanguageImmutable CONSTANT)
    /**
      Get Last selected language for speech detection
    */
    static
    QString whisperLanguage()
    {
      return self()->mWhisperLanguage;
    }

    /**
      Is Last selected language for speech detection Immutable
    */
    static
    bool isWhisperLanguageImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperLanguage" ) );
    }

    /**
      Set Enable Subtitles translation through SeamlessM4T llm
    */
    static
    void setEnableSeamless( bool v )
    {
      if (v != self()->mEnableSeamless && !self()->isEnableSeamlessImmutable()) {
        self()->mEnableSeamless = v;
        Q_EMIT self()->enableSeamlessChanged();
      }
    }

    Q_PROPERTY(bool enableSeamless READ enableSeamless WRITE setEnableSeamless NOTIFY enableSeamlessChanged)
    Q_PROPERTY(bool isEnableSeamlessImmutable READ isEnableSeamlessImmutable CONSTANT)
    Q_PROPERTY(bool defaultEnableSeamlessValue READ defaultEnableSeamlessValue CONSTANT)
    /**
      Get Enable Subtitles translation through SeamlessM4T llm
    */
    static
    bool enableSeamless()
    {
      return self()->mEnableSeamless;
    }

    /**
      Is Enable Subtitles translation through SeamlessM4T llm Immutable
    */
    static
    bool isEnableSeamlessImmutable()
    {
      return self()->isImmutable( QStringLiteral( "enableSeamless" ) );
    }

    /**
      Get Enable Subtitles translation through SeamlessM4T llm default value
    */
    static
    bool defaultEnableSeamlessValue()
    {
        return defaultEnableSeamlessValue_helper();
    }

    /**
      Set Translate subtitles with seamless
    */
    static
    void setSrtSeamlessTranslate( bool v )
    {
      if (v != self()->mSrtSeamlessTranslate && !self()->isSrtSeamlessTranslateImmutable()) {
        self()->mSrtSeamlessTranslate = v;
        Q_EMIT self()->srtSeamlessTranslateChanged();
      }
    }

    Q_PROPERTY(bool srtSeamlessTranslate READ srtSeamlessTranslate WRITE setSrtSeamlessTranslate NOTIFY srtSeamlessTranslateChanged)
    Q_PROPERTY(bool isSrtSeamlessTranslateImmutable READ isSrtSeamlessTranslateImmutable CONSTANT)
    Q_PROPERTY(bool defaultSrtSeamlessTranslateValue READ defaultSrtSeamlessTranslateValue CONSTANT)
    /**
      Get Translate subtitles with seamless
    */
    static
    bool srtSeamlessTranslate()
    {
      return self()->mSrtSeamlessTranslate;
    }

    /**
      Is Translate subtitles with seamless Immutable
    */
    static
    bool isSrtSeamlessTranslateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "srtSeamlessTranslate" ) );
    }

    /**
      Get Translate subtitles with seamless default value
    */
    static
    bool defaultSrtSeamlessTranslateValue()
    {
        return defaultSrtSeamlessTranslateValue_helper();
    }

    /**
      Set Default input language for seamless
    */
    static
    void setSeamless_input( const QString & v )
    {
      if (v != self()->mSeamless_input && !self()->isSeamless_inputImmutable()) {
        self()->mSeamless_input = v;
        Q_EMIT self()->seamless_inputChanged();
      }
    }

    Q_PROPERTY(QString seamless_input READ seamless_input WRITE setSeamless_input NOTIFY seamless_inputChanged)
    Q_PROPERTY(bool isSeamless_inputImmutable READ isSeamless_inputImmutable CONSTANT)
    /**
      Get Default input language for seamless
    */
    static
    QString seamless_input()
    {
      return self()->mSeamless_input;
    }

    /**
      Is Default input language for seamless Immutable
    */
    static
    bool isSeamless_inputImmutable()
    {
      return self()->isImmutable( QStringLiteral( "seamless_input" ) );
    }

    /**
      Set Default output language for seamless
    */
    static
    void setSeamless_output( const QString & v )
    {
      if (v != self()->mSeamless_output && !self()->isSeamless_outputImmutable()) {
        self()->mSeamless_output = v;
        Q_EMIT self()->seamless_outputChanged();
      }
    }

    Q_PROPERTY(QString seamless_output READ seamless_output WRITE setSeamless_output NOTIFY seamless_outputChanged)
    Q_PROPERTY(bool isSeamless_outputImmutable READ isSeamless_outputImmutable CONSTANT)
    /**
      Get Default output language for seamless
    */
    static
    QString seamless_output()
    {
      return self()->mSeamless_output;
    }

    /**
      Is Default output language for seamless Immutable
    */
    static
    bool isSeamless_outputImmutable()
    {
      return self()->isImmutable( QStringLiteral( "seamless_output" ) );
    }

    /**
      Set Maximum characters in a Whisper subtitle
    */
    static
    void setWhisperMaxChars( int v )
    {
      if (v != self()->mWhisperMaxChars && !self()->isWhisperMaxCharsImmutable()) {
        self()->mWhisperMaxChars = v;
        Q_EMIT self()->whisperMaxCharsChanged();
      }
    }

    Q_PROPERTY(int whisperMaxChars READ whisperMaxChars WRITE setWhisperMaxChars NOTIFY whisperMaxCharsChanged)
    Q_PROPERTY(bool isWhisperMaxCharsImmutable READ isWhisperMaxCharsImmutable CONSTANT)
    Q_PROPERTY(int defaultWhisperMaxCharsValue READ defaultWhisperMaxCharsValue CONSTANT)
    /**
      Get Maximum characters in a Whisper subtitle
    */
    static
    int whisperMaxChars()
    {
      return self()->mWhisperMaxChars;
    }

    /**
      Is Maximum characters in a Whisper subtitle Immutable
    */
    static
    bool isWhisperMaxCharsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperMaxChars" ) );
    }

    /**
      Get Maximum characters in a Whisper subtitle default value
    */
    static
    int defaultWhisperMaxCharsValue()
    {
        return defaultWhisperMaxCharsValue_helper();
    }

    /**
      Set Default mode for subtitle creation (full timeline=1, zone=2, one track=3, clip=4)
    */
    static
    void setSubtitleMode( int v )
    {
      if (v != self()->mSubtitleMode && !self()->isSubtitleModeImmutable()) {
        self()->mSubtitleMode = v;
        Q_EMIT self()->subtitleModeChanged();
      }
    }

    Q_PROPERTY(int subtitleMode READ subtitleMode WRITE setSubtitleMode NOTIFY subtitleModeChanged)
    Q_PROPERTY(bool isSubtitleModeImmutable READ isSubtitleModeImmutable CONSTANT)
    Q_PROPERTY(int defaultSubtitleModeValue READ defaultSubtitleModeValue CONSTANT)
    /**
      Get Default mode for subtitle creation (full timeline=1, zone=2, one track=3, clip=4)
    */
    static
    int subtitleMode()
    {
      return self()->mSubtitleMode;
    }

    /**
      Is Default mode for subtitle creation (full timeline=1, zone=2, one track=3, clip=4) Immutable
    */
    static
    bool isSubtitleModeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "subtitleMode" ) );
    }

    /**
      Get Default mode for subtitle creation (full timeline=1, zone=2, one track=3, clip=4) default value
    */
    static
    int defaultSubtitleModeValue()
    {
        return defaultSubtitleModeValue_helper();
    }

    /**
      Set Limit maximum characters in a Whisper subtitle
    */
    static
    void setCutWhisperMaxChars( bool v )
    {
      if (v != self()->mCutWhisperMaxChars && !self()->isCutWhisperMaxCharsImmutable()) {
        self()->mCutWhisperMaxChars = v;
        Q_EMIT self()->cutWhisperMaxCharsChanged();
      }
    }

    Q_PROPERTY(bool cutWhisperMaxChars READ cutWhisperMaxChars WRITE setCutWhisperMaxChars NOTIFY cutWhisperMaxCharsChanged)
    Q_PROPERTY(bool isCutWhisperMaxCharsImmutable READ isCutWhisperMaxCharsImmutable CONSTANT)
    Q_PROPERTY(bool defaultCutWhisperMaxCharsValue READ defaultCutWhisperMaxCharsValue CONSTANT)
    /**
      Get Limit maximum characters in a Whisper subtitle
    */
    static
    bool cutWhisperMaxChars()
    {
      return self()->mCutWhisperMaxChars;
    }

    /**
      Is Limit maximum characters in a Whisper subtitle Immutable
    */
    static
    bool isCutWhisperMaxCharsImmutable()
    {
      return self()->isImmutable( QStringLiteral( "cutWhisperMaxChars" ) );
    }

    /**
      Get Limit maximum characters in a Whisper subtitle default value
    */
    static
    bool defaultCutWhisperMaxCharsValue()
    {
        return defaultCutWhisperMaxCharsValue_helper();
    }

    /**
      Set Device for data processing
    */
    static
    void setWhisperDevice( const QString & v )
    {
      if (v != self()->mWhisperDevice && !self()->isWhisperDeviceImmutable()) {
        self()->mWhisperDevice = v;
        Q_EMIT self()->whisperDeviceChanged();
      }
    }

    Q_PROPERTY(QString whisperDevice READ whisperDevice WRITE setWhisperDevice NOTIFY whisperDeviceChanged)
    Q_PROPERTY(bool isWhisperDeviceImmutable READ isWhisperDeviceImmutable CONSTANT)
    Q_PROPERTY(QString defaultWhisperDeviceValue READ defaultWhisperDeviceValue CONSTANT)
    /**
      Get Device for data processing
    */
    static
    QString whisperDevice()
    {
      return self()->mWhisperDevice;
    }

    /**
      Is Device for data processing Immutable
    */
    static
    bool isWhisperDeviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperDevice" ) );
    }

    /**
      Get Device for data processing default value
    */
    static
    QString defaultWhisperDeviceValue()
    {
        return defaultWhisperDeviceValue_helper();
    }

    /**
      Set Device for data processing
    */
    static
    void setSamDevice( const QString & v )
    {
      if (v != self()->mSamDevice && !self()->isSamDeviceImmutable()) {
        self()->mSamDevice = v;
        Q_EMIT self()->samDeviceChanged();
      }
    }

    Q_PROPERTY(QString samDevice READ samDevice WRITE setSamDevice NOTIFY samDeviceChanged)
    Q_PROPERTY(bool isSamDeviceImmutable READ isSamDeviceImmutable CONSTANT)
    Q_PROPERTY(QString defaultSamDeviceValue READ defaultSamDeviceValue CONSTANT)
    /**
      Get Device for data processing
    */
    static
    QString samDevice()
    {
      return self()->mSamDevice;
    }

    /**
      Is Device for data processing Immutable
    */
    static
    bool isSamDeviceImmutable()
    {
      return self()->isImmutable( QStringLiteral( "samDevice" ) );
    }

    /**
      Get Device for data processing default value
    */
    static
    QString defaultSamDeviceValue()
    {
        return defaultSamDeviceValue_helper();
    }

    /**
      Set Translate speech detection to English
    */
    static
    void setWhisperTranslate( bool v )
    {
      if (v != self()->mWhisperTranslate && !self()->isWhisperTranslateImmutable()) {
        self()->mWhisperTranslate = v;
        Q_EMIT self()->whisperTranslateChanged();
      }
    }

    Q_PROPERTY(bool whisperTranslate READ whisperTranslate WRITE setWhisperTranslate NOTIFY whisperTranslateChanged)
    Q_PROPERTY(bool isWhisperTranslateImmutable READ isWhisperTranslateImmutable CONSTANT)
    Q_PROPERTY(bool defaultWhisperTranslateValue READ defaultWhisperTranslateValue CONSTANT)
    /**
      Get Translate speech detection to English
    */
    static
    bool whisperTranslate()
    {
      return self()->mWhisperTranslate;
    }

    /**
      Is Translate speech detection to English Immutable
    */
    static
    bool isWhisperTranslateImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperTranslate" ) );
    }

    /**
      Get Translate speech detection to English default value
    */
    static
    bool defaultWhisperTranslateValue()
    {
        return defaultWhisperTranslateValue_helper();
    }

    /**
      Set Disable FP16 in whisper engine
    */
    static
    void setWhisperDisableFP16( bool v )
    {
      if (v != self()->mWhisperDisableFP16 && !self()->isWhisperDisableFP16Immutable()) {
        self()->mWhisperDisableFP16 = v;
        Q_EMIT self()->whisperDisableFP16Changed();
      }
    }

    Q_PROPERTY(bool whisperDisableFP16 READ whisperDisableFP16 WRITE setWhisperDisableFP16 NOTIFY whisperDisableFP16Changed)
    Q_PROPERTY(bool isWhisperDisableFP16Immutable READ isWhisperDisableFP16Immutable CONSTANT)
    Q_PROPERTY(bool defaultWhisperDisableFP16Value READ defaultWhisperDisableFP16Value CONSTANT)
    /**
      Get Disable FP16 in whisper engine
    */
    static
    bool whisperDisableFP16()
    {
      return self()->mWhisperDisableFP16;
    }

    /**
      Is Disable FP16 in whisper engine Immutable
    */
    static
    bool isWhisperDisableFP16Immutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperDisableFP16" ) );
    }

    /**
      Get Disable FP16 in whisper engine default value
    */
    static
    bool defaultWhisperDisableFP16Value()
    {
        return defaultWhisperDisableFP16Value_helper();
    }

    /**
      Set Extra parameters for Whisper
    */
    static
    void setWhisperExtra( const QString & v )
    {
      if (v != self()->mWhisperExtra && !self()->isWhisperExtraImmutable()) {
        self()->mWhisperExtra = v;
        Q_EMIT self()->whisperExtraChanged();
      }
    }

    Q_PROPERTY(QString whisperExtra READ whisperExtra WRITE setWhisperExtra NOTIFY whisperExtraChanged)
    Q_PROPERTY(bool isWhisperExtraImmutable READ isWhisperExtraImmutable CONSTANT)
    /**
      Get Extra parameters for Whisper
    */
    static
    QString whisperExtra()
    {
      return self()->mWhisperExtra;
    }

    /**
      Is Extra parameters for Whisper Immutable
    */
    static
    bool isWhisperExtraImmutable()
    {
      return self()->isImmutable( QStringLiteral( "whisperExtra" ) );
    }

    /**
      Set Selected model for speech recognition (whisper or vosk)
    */
    static
    void setSpeechEngine( const QString & v )
    {
      if (v != self()->mSpeechEngine && !self()->isSpeechEngineImmutable()) {
        self()->mSpeechEngine = v;
        Q_EMIT self()->speechEngineChanged();
      }
    }

    Q_PROPERTY(QString speechEngine READ speechEngine WRITE setSpeechEngine NOTIFY speechEngineChanged)
    Q_PROPERTY(bool isSpeechEngineImmutable READ isSpeechEngineImmutable CONSTANT)
    Q_PROPERTY(QString defaultSpeechEngineValue READ defaultSpeechEngineValue CONSTANT)
    /**
      Get Selected model for speech recognition (whisper or vosk)
    */
    static
    QString speechEngine()
    {
      return self()->mSpeechEngine;
    }

    /**
      Is Selected model for speech recognition (whisper or vosk) Immutable
    */
    static
    bool isSpeechEngineImmutable()
    {
      return self()->isImmutable( QStringLiteral( "speechEngine" ) );
    }

    /**
      Get Selected model for speech recognition (whisper or vosk) default value
    */
    static
    QString defaultSpeechEngineValue()
    {
        return defaultSpeechEngineValue_helper();
    }

    /**
      Set Default size for media browser icons.
    */
    static
    void setMediaIconSize( int v )
    {
      if (v != self()->mMediaIconSize && !self()->isMediaIconSizeImmutable()) {
        self()->mMediaIconSize = v;
        Q_EMIT self()->mediaIconSizeChanged();
      }
    }

    Q_PROPERTY(int mediaIconSize READ mediaIconSize WRITE setMediaIconSize NOTIFY mediaIconSizeChanged)
    Q_PROPERTY(bool isMediaIconSizeImmutable READ isMediaIconSizeImmutable CONSTANT)
    Q_PROPERTY(int defaultMediaIconSizeValue READ defaultMediaIconSizeValue CONSTANT)
    /**
      Get Default size for media browser icons.
    */
    static
    int mediaIconSize()
    {
      return self()->mMediaIconSize;
    }

    /**
      Is Default size for media browser icons. Immutable
    */
    static
    bool isMediaIconSizeImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaIconSize" ) );
    }

    /**
      Get Default size for media browser icons. default value
    */
    static
    int defaultMediaIconSizeValue()
    {
        return defaultMediaIconSizeValue_helper();
    }

    /**
      Set Show preview panel in browser.
    */
    static
    void setMediaManagerPanelLayout( const QString & v )
    {
      if (v != self()->mMediaManagerPanelLayout && !self()->isMediaManagerPanelLayoutImmutable()) {
        self()->mMediaManagerPanelLayout = v;
        Q_EMIT self()->mediaManagerPanelLayoutChanged();
      }
    }

    Q_PROPERTY(QString mediaManagerPanelLayout READ mediaManagerPanelLayout WRITE setMediaManagerPanelLayout NOTIFY mediaManagerPanelLayoutChanged)
    Q_PROPERTY(bool isMediaManagerPanelLayoutImmutable READ isMediaManagerPanelLayoutImmutable CONSTANT)
    /**
      Get Show preview panel in browser.
    */
    static
    QString mediaManagerPanelLayout()
    {
      return self()->mMediaManagerPanelLayout;
    }

    /**
      Is Show preview panel in browser. Immutable
    */
    static
    bool isMediaManagerPanelLayoutImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaManagerPanelLayout" ) );
    }

    /**
      Set Default width for the preview panel.
    */
    static
    void setMediaManagerPanelWidth( int v )
    {
      if (v != self()->mMediaManagerPanelWidth && !self()->isMediaManagerPanelWidthImmutable()) {
        self()->mMediaManagerPanelWidth = v;
        Q_EMIT self()->mediaManagerPanelWidthChanged();
      }
    }

    Q_PROPERTY(int mediaManagerPanelWidth READ mediaManagerPanelWidth WRITE setMediaManagerPanelWidth NOTIFY mediaManagerPanelWidthChanged)
    Q_PROPERTY(bool isMediaManagerPanelWidthImmutable READ isMediaManagerPanelWidthImmutable CONSTANT)
    Q_PROPERTY(int defaultMediaManagerPanelWidthValue READ defaultMediaManagerPanelWidthValue CONSTANT)
    /**
      Get Default width for the preview panel.
    */
    static
    int mediaManagerPanelWidth()
    {
      return self()->mMediaManagerPanelWidth;
    }

    /**
      Is Default width for the preview panel. Immutable
    */
    static
    bool isMediaManagerPanelWidthImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaManagerPanelWidth" ) );
    }

    /**
      Get Default width for the preview panel. default value
    */
    static
    int defaultMediaManagerPanelWidthValue()
    {
        return defaultMediaManagerPanelWidthValue_helper();
    }

    /**
      Set Autoplay preview in panel.
    */
    static
    void setMediaBrowserAutoPlay( bool v )
    {
      if (v != self()->mMediaBrowserAutoPlay && !self()->isMediaBrowserAutoPlayImmutable()) {
        self()->mMediaBrowserAutoPlay = v;
        Q_EMIT self()->mediaBrowserAutoPlayChanged();
      }
    }

    Q_PROPERTY(bool mediaBrowserAutoPlay READ mediaBrowserAutoPlay WRITE setMediaBrowserAutoPlay NOTIFY mediaBrowserAutoPlayChanged)
    Q_PROPERTY(bool isMediaBrowserAutoPlayImmutable READ isMediaBrowserAutoPlayImmutable CONSTANT)
    Q_PROPERTY(bool defaultMediaBrowserAutoPlayValue READ defaultMediaBrowserAutoPlayValue CONSTANT)
    /**
      Get Autoplay preview in panel.
    */
    static
    bool mediaBrowserAutoPlay()
    {
      return self()->mMediaBrowserAutoPlay;
    }

    /**
      Is Autoplay preview in panel. Immutable
    */
    static
    bool isMediaBrowserAutoPlayImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaBrowserAutoPlay" ) );
    }

    /**
      Get Autoplay preview in panel. default value
    */
    static
    bool defaultMediaBrowserAutoPlayValue()
    {
        return defaultMediaBrowserAutoPlayValue_helper();
    }

    /**
      Set Play audio in browser.
    */
    static
    void setMediaBrowserWithAudio( bool v )
    {
      if (v != self()->mMediaBrowserWithAudio && !self()->isMediaBrowserWithAudioImmutable()) {
        self()->mMediaBrowserWithAudio = v;
        Q_EMIT self()->mediaBrowserWithAudioChanged();
      }
    }

    Q_PROPERTY(bool mediaBrowserWithAudio READ mediaBrowserWithAudio WRITE setMediaBrowserWithAudio NOTIFY mediaBrowserWithAudioChanged)
    Q_PROPERTY(bool isMediaBrowserWithAudioImmutable READ isMediaBrowserWithAudioImmutable CONSTANT)
    Q_PROPERTY(bool defaultMediaBrowserWithAudioValue READ defaultMediaBrowserWithAudioValue CONSTANT)
    /**
      Get Play audio in browser.
    */
    static
    bool mediaBrowserWithAudio()
    {
      return self()->mMediaBrowserWithAudio;
    }

    /**
      Is Play audio in browser. Immutable
    */
    static
    bool isMediaBrowserWithAudioImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaBrowserWithAudio" ) );
    }

    /**
      Get Play audio in browser. default value
    */
    static
    bool defaultMediaBrowserWithAudioValue()
    {
        return defaultMediaBrowserWithAudioValue_helper();
    }

    /**
      Set Double click on a file imports it to the project.
    */
    static
    void setMediaDoubleClickImport( bool v )
    {
      if (v != self()->mMediaDoubleClickImport && !self()->isMediaDoubleClickImportImmutable()) {
        self()->mMediaDoubleClickImport = v;
        Q_EMIT self()->mediaDoubleClickImportChanged();
      }
    }

    Q_PROPERTY(bool mediaDoubleClickImport READ mediaDoubleClickImport WRITE setMediaDoubleClickImport NOTIFY mediaDoubleClickImportChanged)
    Q_PROPERTY(bool isMediaDoubleClickImportImmutable READ isMediaDoubleClickImportImmutable CONSTANT)
    Q_PROPERTY(bool defaultMediaDoubleClickImportValue READ defaultMediaDoubleClickImportValue CONSTANT)
    /**
      Get Double click on a file imports it to the project.
    */
    static
    bool mediaDoubleClickImport()
    {
      return self()->mMediaDoubleClickImport;
    }

    /**
      Is Double click on a file imports it to the project. Immutable
    */
    static
    bool isMediaDoubleClickImportImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaDoubleClickImport" ) );
    }

    /**
      Get Double click on a file imports it to the project. default value
    */
    static
    bool defaultMediaDoubleClickImportValue()
    {
        return defaultMediaDoubleClickImportValue_helper();
    }

    /**
      Set Show inline preview in media browser.
    */
    static
    void setMediaBrowserInlinePreview( bool v )
    {
      if (v != self()->mMediaBrowserInlinePreview && !self()->isMediaBrowserInlinePreviewImmutable()) {
        self()->mMediaBrowserInlinePreview = v;
        Q_EMIT self()->mediaBrowserInlinePreviewChanged();
      }
    }

    Q_PROPERTY(bool mediaBrowserInlinePreview READ mediaBrowserInlinePreview WRITE setMediaBrowserInlinePreview NOTIFY mediaBrowserInlinePreviewChanged)
    Q_PROPERTY(bool isMediaBrowserInlinePreviewImmutable READ isMediaBrowserInlinePreviewImmutable CONSTANT)
    Q_PROPERTY(bool defaultMediaBrowserInlinePreviewValue READ defaultMediaBrowserInlinePreviewValue CONSTANT)
    /**
      Get Show inline preview in media browser.
    */
    static
    bool mediaBrowserInlinePreview()
    {
      return self()->mMediaBrowserInlinePreview;
    }

    /**
      Is Show inline preview in media browser. Immutable
    */
    static
    bool isMediaBrowserInlinePreviewImmutable()
    {
      return self()->isImmutable( QStringLiteral( "mediaBrowserInlinePreview" ) );
    }

    /**
      Get Show inline preview in media browser. default value
    */
    static
    bool defaultMediaBrowserInlinePreviewValue()
    {
        return defaultMediaBrowserInlinePreviewValue_helper();
    }


    enum {
      signalTreeviewheadersChanged = 1,
      signalBinSortingChanged = 2,
      signalBinModeChanged = 3,
      signalBin_zoomChanged = 4,
      signalAddedExtensionsChanged = 5,
      signalHoverPreviewChanged = 6,
      signalBinsCountChanged = 7,
      signalScenesplitthresholdChanged = 8,
      signalScenesplitmarkersChanged = 9,
      signalScenesplitrangemarkersChanged = 10,
      signalScenesplitsubclipsChanged = 11,
      signalCleanCacheMonthsChanged = 12,
      signalOpenlastprojectChanged = 13,
      signalCrashrecoveryChanged = 14,
      signalAutosave_timeChanged = 15,
      signalAutosave_opsChanged = 16,
      signalTabpositionChanged = 17,
      signalCheckfirstprojectclipChanged = 18,
      signalKeep_original_frame_sizeChanged = 19,
      signalExportframe_usingsourceresChanged = 20,
      signalColor_durationChanged = 21,
      signalImage_durationChanged = 22,
      signalSequence_durationChanged = 23,
      signalFade_durationChanged = 24,
      signalMix_durationChanged = 25,
      signalSubtitle_durationChanged = 26,
      signalAutoimagesequenceChanged = 27,
      signalIgnoresubdirstructureChanged = 28,
      signalDisableimagescalingChanged = 29,
      signalAutomultistreamsChanged = 30,
      signalUse_exiftoolChanged = 31,
      signalUse_magicLanternChanged = 32,
      signalTitle_durationChanged = 33,
      signalTransition_durationChanged = 34,
      signalEnableAssetsIncludeListChanged = 35,
      signalEffectsInfoHeightChanged = 36,
      signalShowEffectsInfoChanged = 37,
      signalTransitionsInfoHeightChanged = 38,
      signalShowTransitionsInfoChanged = 39,
      signalDisable_effect_parametersChanged = 40,
      signalProfile_fps_filterChanged = 41,
      signalProfile_scanning_filterChanged = 42,
      signalOpengl_backendChanged = 43,
      signalVideotracksChanged = 44,
      signalAudiotracksChanged = 45,
      signalAudio_channelsChanged = 46,
      signalEnableproxyChanged = 47,
      signalExternalproxyChanged = 48,
      signalGenerateproxyChanged = 49,
      signalExternal_proxy_profileChanged = 50,
      signalExternalProxyProfileChanged = 51,
      signalGenerateimageproxyChanged = 52,
      signalProxyminsizeChanged = 53,
      signalProxyimageminsizeChanged = 54,
      signalProxyimagesizeChanged = 55,
      signalProxyscaleChanged = 56,
      signalEnforceLowerTrackCompositingChanged = 57,
      signalProxyextensionChanged = 58,
      signalProxyparamsChanged = 59,
      signalProxy_profileChanged = 60,
      signalProxyalphaextensionChanged = 61,
      signalProxyalphaparamsChanged = 62,
      signalAlpha_profileChanged = 63,
      signalTranscodeFriendlyChanged = 64,
      signalTranscodingReplaceChanged = 65,
      signalPreviewextensionChanged = 66,
      signalPreview_profileChanged = 67,
      signalPreviewparamsChanged = 68,
      signalParallelrenderChanged = 69,
      signalRenderInterpChanged = 70,
      signalRenderDeinterlacerChanged = 71,
      signalVaapiEnabledChanged = 72,
      signalAmfEnabledChanged = 73,
      signalSupportedHWCodecsChanged = 74,
      signalNvScalingEnabledChanged = 75,
      signalHwDecodingChanged = 76,
      signalShowRenderTextParametersChanged = 77,
      signalHeaderwidthChanged = 78,
      signalDefaultkeyframeinterpChanged = 79,
      signalTimelinechunksChanged = 80,
      signalAutopreviewChanged = 81,
      signalDraginprogressChanged = 82,
      signalProxypreviewChanged = 83,
      signalMultistreamChanged = 84,
      signalMultistream_checktrackChanged = 85,
      signalVideothumbnailsChanged = 86,
      signalAudiothumbnailsChanged = 87,
      signalWaveformScalerChanged = 88,
      signalShowmarkersChanged = 89,
      signalDisplayallchannelsChanged = 90,
      signalNormalizechannelsChanged = 91,
      signalAutotrackheightChanged = 92,
      signalAutoscrollChanged = 93,
      signalCenteredplayheadChanged = 94,
      signalJumptostartChanged = 95,
      signalPauseonseekChanged = 96,
      signalSeekonaddeffectChanged = 97,
      signalEnableBuiltInEffectsChanged = 98,
      signalTenbitpipelineChanged = 99,
      signalEffectsFilterChanged = 100,
      signalTransitionsFilterChanged = 101,
      signalScrollverticallyChanged = 102,
      signalTrackheightChanged = 103,
      signalAudiotracksbelowChanged = 104,
      signalRaisepropsclipsChanged = 105,
      signalRaisepropscompositionsChanged = 106,
      signalRaisepropsmixesChanged = 107,
      signalRaisepropstracksChanged = 108,
      signalUiDebugModeChanged = 109,
      signalGpu_accelChanged = 110,
      signalAudio_scrubChanged = 111,
      signalSdlAudioBackendChanged = 112,
      signalAudio_backendChanged = 113,
      signalAudiobackendChanged = 114,
      signalAudio_driverChanged = 115,
      signalAudiodevicenameChanged = 116,
      signalAudiodrivernameChanged = 117,
      signalDisablereccountdownChanged = 118,
      signalVideodrivernameChanged = 119,
      signalAudio_deviceChanged = 120,
      signalWindow_backgroundChanged = 121,
      signalShowMonitorGridChanged = 122,
      signalMonitorGridHChanged = 123,
      signalMonitorGridVChanged = 124,
      signalMonitor_backgroundChanged = 125,
      signalMonitor_progressiveChanged = 126,
      signalVolumeChanged = 127,
      signalMonitor_dropframesChanged = 128,
      signalExternal_displayChanged = 129,
      signalBlackmagic_output_deviceChanged = 130,
      signalPlay_monitor_on_clickChanged = 131,
      signalMirrorMonitorOnFullscreenChanged = 132,
      signalFullscreen_monitorChanged = 133,
      signalProject_monitor_fullscreenChanged = 134,
      signalClip_monitor_fullscreenChanged = 135,
      signalPreferredcompositeChanged = 136,
      signalCompositingListChanged = 137,
      signalSubtitle_razor_modeChanged = 138,
      signalMltpathChanged = 139,
      signalKdenliverendererpathChanged = 140,
      signalMeltpathChanged = 141,
      signalFfmpegpathChanged = 142,
      signalFfplaypathChanged = 143,
      signalFfprobepathChanged = 144,
      signalProcessingthreadsChanged = 145,
      signalProxythreadsChanged = 146,
      signalEncodethreadsChanged = 147,
      signalCurrenttmpfolderChanged = 148,
      signalMaxcachesizeChanged = 149,
      signalCheckForUpdateChanged = 150,
      signalUsePowerManagementChanged = 151,
      signalLastCacheCheckChanged = 152,
      signalDefaultprojectfolderChanged = 153,
      signalCustomprojectfolderChanged = 154,
      signalSameprojectfolderChanged = 155,
      signalCapturetoprojectfolderChanged = 156,
      signalCapturefolderChanged = 157,
      signalCaptureprojectsubfolderChanged = 158,
      signalLibrarytodefaultfolderChanged = 159,
      signalVideotodefaultfolderChanged = 160,
      signalLibraryfolderChanged = 161,
      signalVideofolderChanged = 162,
      signalDefaultimageappChanged = 163,
      signalDefaultaudioappChanged = 164,
      signalGlaxnimatePathChanged = 165,
      signalDefaultvideoappChanged = 166,
      signalNice_tasksChanged = 167,
      signalExportGuidesFormatChanged = 168,
      signalMultipleguidesintervalChanged = 169,
      signalGuidesShowThumbsChanged = 170,
      signalGuidesSelectZoneChanged = 171,
      signalDefaultaudiocaptureChanged = 172,
      signalAudiocapturevolumeChanged = 173,
      signalAudiocapturechannelsChanged = 174,
      signalAudiocapturesamplerateChanged = 175,
      signalAudiocapturesampleformatChanged = 176,
      signalDefaultcaptureChanged = 177,
      signalAlsachannelsChanged = 178,
      signalGrab_profileChanged = 179,
      signalGrab_parametersChanged = 180,
      signalGrab_extensionChanged = 181,
      signalGrab_capture_typeChanged = 182,
      signalGrab_follow_mouseChanged = 183,
      signalGrab_offsetxChanged = 184,
      signalGrab_offsetyChanged = 185,
      signalGrab_widthChanged = 186,
      signalGrab_heightChanged = 187,
      signalGrab_fpsChanged = 188,
      signalGrab_hide_frameChanged = 189,
      signalGrab_hide_mouseChanged = 190,
      signalDecklink_device_foundChanged = 191,
      signalDecklink_capturedeviceChanged = 192,
      signalDecklink_profileChanged = 193,
      signalDecklink_filenameChanged = 194,
      signalDecklink_parametersChanged = 195,
      signalDecklink_extensionChanged = 196,
      signalEnableshuttleChanged = 197,
      signalShuttledeviceChanged = 198,
      signalShuttledevicenamesChanged = 199,
      signalShuttledevicepathsChanged = 200,
      signalShuttlebuttonsChanged = 201,
      signalBezier_gridlinesChanged = 202,
      signalBezier_showpixmapChanged = 203,
      signalBezier_showallhandlesChanged = 204,
      signalDragvalue_modeChanged = 205,
      signalDragvalue_directupdateChanged = 206,
      signalRecentProfilesChanged = 207,
      signalRecentProfileNamesChanged = 208,
      signalProperties_panel_pageChanged = 209,
      signalProject_fpsChanged = 210,
      signalDefault_profileChanged = 211,
      signalKdockLayoutChanged = 212,
      signalLayoutsOrderChanged = 213,
      signalShowdescriptioncolumnChanged = 214,
      signalShowratingcolumnChanged = 215,
      signalShowdatecolumnChanged = 216,
      signalFrametimecodeChanged = 217,
      signalRectimecodeChanged = 218,
      signalSnaptopointsChanged = 219,
      signalShowClipOverlaysChanged = 220,
      signalRippleResizeChanged = 221,
      signalLockedGuidesChanged = 222,
      signalGuidesCategoriesChanged = 223,
      signalTagsintimelineChanged = 224,
      signalTimelinemousezoomonplayheadChanged = 225,
      signalTransitionfollowcursorChanged = 226,
      signalKeyframeseekChanged = 227,
      signalShoweffectinfoChanged = 228,
      signalApplyEffectParamsToGroupChanged = 229,
      signalApplyEffectParamsToGroupWithSameValueChanged = 230,
      signalRenderProfileChanged = 231,
      signalKeepRenderLogFilesChanged = 232,
      signalValidated_lutsChanged = 233,
      signalDisplayClipMonitorInfoChanged = 234,
      signalShowClipMonitorSafeZoneChanged = 235,
      signalShowProjectMonitorSafeZoneChanged = 236,
      signalDisplayProjectMonitorInfoChanged = 237,
      signalPreviewScalingChanged = 238,
      signalAutoKeyframeChanged = 239,
      signalLimitAutoKeyframesChanged = 240,
      signalLimitAutoKeyframesIntervalChanged = 241,
      signalMaskOpacityChanged = 242,
      signalMaskInvertedChanged = 243,
      signalClipMonitorOverlayGuidesChanged = 244,
      signalProjectMonitorOverlayGuidesChanged = 245,
      signalAlwaysShowMonitorAudioChanged = 246,
      signalDisplayAudioOverlayChanged = 247,
      signalMonitoraudioChanged = 248,
      signalShowOnMonitorSceneChanged = 249,
      signalAutoaudiodrivernameChanged = 250,
      signalMixerCollapseChanged = 251,
      signalConsumerslistChanged = 252,
      signalProducerslistChanged = 253,
      signalWidgetstyleChanged = 254,
      signalShowslideshowthumbsChanged = 255,
      signalShowtitlebarsChanged = 256,
      signalColorclipcolorChanged = 257,
      signalShowSubtitlesChanged = 258,
      signalSubtitleEditFontSizeChanged = 259,
      signalThumbColor1Changed = 260,
      signalThumbColor2Changed = 261,
      signalOverlayColorChanged = 262,
      signalSafeColorChanged = 263,
      signalDefaultrescalewidthChanged = 264,
      signalDefaultrescaleheightChanged = 265,
      signalSlideshowbymimeChanged = 266,
      signalSlideshowmimeextensionChanged = 267,
      signalMonitorscene_directupdateChanged = 268,
      signalAnalyse_stopmotionChanged = 269,
      signalEnableaudiospectrumChanged = 270,
      signalShowstopmotionthumbsChanged = 271,
      signalCaptureintervalChanged = 272,
      signalSm_notifytimeChanged = 273,
      signalSm_prenotifyChanged = 274,
      signalSm_loopChanged = 275,
      signalSm_playsoundChanged = 276,
      signalSm_framesplaybackChanged = 277,
      signalStopmotioneffectChanged = 278,
      signalOnmonitoreffects_cornersshowlinesChanged = 279,
      signalOnmonitoreffects_geometryshowpreviousChanged = 280,
      signalOnmonitoreffects_geometryshowpathChanged = 281,
      signalOnmonitoreffects_cornersshowcontrolsChanged = 282,
      signalProjectloading_avformatnovalidateChanged = 283,
      signalMonitor_audioChanged = 284,
      signalEnable_recording_previewChanged = 285,
      signalAdd_new_clipChanged = 286,
      signalAdd_new_clip_to_folderChanged = 287,
      signalDefault_marker_typeChanged = 288,
      signalMltdeinterlacerChanged = 289,
      signalMltinterpolationChanged = 290,
      signalFavorite_effectsChanged = 291,
      signalFavorite_transitionsChanged = 292,
      signalSelected_effecttabChanged = 293,
      signalEffectViewAsIconChanged = 294,
      signalTransitionViewAsIconChanged = 295,
      signalForce_breezeChanged = 296,
      signalUse_dark_breezeChanged = 297,
      signalShowWelcomeChanged = 298,
      signalLastSeenVersionMajorChanged = 299,
      signalLastSeenVersionMinorChanged = 300,
      signalLastSeenVersionMicroChanged = 301,
      signalLock_ratioChanged = 302,
      signalSelected_templateChanged = 303,
      signalTitlerShowGuidesChanged = 304,
      signalTitlerVersionChanged = 305,
      signalTitlerHGuidesChanged = 306,
      signalTitlerVGuidesChanged = 307,
      signalTitleGuideColorChanged = 308,
      signalTitlerbgChanged = 309,
      signalTitlerShowbgChanged = 310,
      signalTitlerAlignChanged = 311,
      signalSamModelFileChanged = 312,
      signalSam_offload_videoChanged = 313,
      signalSam_system_pythonChanged = 314,
      signalSam_system_python_pathChanged = 315,
      signalMaskBorderWidthChanged = 316,
      signalMaskBorderColorChanged = 317,
      signalMaskColorChanged = 318,
      signalSpeech_system_pythonChanged = 319,
      signalSpeech_system_python_pathChanged = 320,
      signalVosk_folder_pathChanged = 321,
      signalVosk_text_modelChanged = 322,
      signalVosk_srt_modelChanged = 323,
      signalSpeech_zoneChanged = 324,
      signalWhisperModelChanged = 325,
      signalWhisperInstalledModelsChanged = 326,
      signalWhisperAvailableModelsChanged = 327,
      signalWhisperAvailableModelsHashChanged = 328,
      signalWhisperModelFolderChanged = 329,
      signalWhisperLanguageChanged = 330,
      signalEnableSeamlessChanged = 331,
      signalSrtSeamlessTranslateChanged = 332,
      signalSeamless_inputChanged = 333,
      signalSeamless_outputChanged = 334,
      signalWhisperMaxCharsChanged = 335,
      signalSubtitleModeChanged = 336,
      signalCutWhisperMaxCharsChanged = 337,
      signalWhisperDeviceChanged = 338,
      signalSamDeviceChanged = 339,
      signalWhisperTranslateChanged = 340,
      signalWhisperDisableFP16Changed = 341,
      signalWhisperExtraChanged = 342,
      signalSpeechEngineChanged = 343,
      signalMediaIconSizeChanged = 344,
      signalMediaManagerPanelLayoutChanged = 345,
      signalMediaManagerPanelWidthChanged = 346,
      signalMediaBrowserAutoPlayChanged = 347,
      signalMediaBrowserWithAudioChanged = 348,
      signalMediaDoubleClickImportChanged = 349,
      signalMediaBrowserInlinePreviewChanged = 350
    };

  Q_SIGNALS:
    void treeviewheadersChanged();

    void binSortingChanged();

    void binModeChanged();

    void bin_zoomChanged();

    void addedExtensionsChanged();

    void hoverPreviewChanged();

    void binsCountChanged();

    void scenesplitthresholdChanged();

    void scenesplitmarkersChanged();

    void scenesplitrangemarkersChanged();

    void scenesplitsubclipsChanged();

    void cleanCacheMonthsChanged();

    void openlastprojectChanged();

    void crashrecoveryChanged();

    void autosave_timeChanged();

    void autosave_opsChanged();

    void tabpositionChanged();

    void checkfirstprojectclipChanged();

    void keep_original_frame_sizeChanged();

    void exportframe_usingsourceresChanged();

    void color_durationChanged();

    void image_durationChanged();

    void sequence_durationChanged();

    void fade_durationChanged();

    void mix_durationChanged();

    void subtitle_durationChanged();

    void autoimagesequenceChanged();

    void ignoresubdirstructureChanged();

    void disableimagescalingChanged();

    void automultistreamsChanged();

    void use_exiftoolChanged();

    void use_magicLanternChanged();

    void title_durationChanged();

    void transition_durationChanged();

    void enableAssetsIncludeListChanged();

    void effectsInfoHeightChanged();

    void showEffectsInfoChanged();

    void transitionsInfoHeightChanged();

    void showTransitionsInfoChanged();

    void disable_effect_parametersChanged();

    void profile_fps_filterChanged();

    void profile_scanning_filterChanged();

    void opengl_backendChanged();

    void videotracksChanged();

    void audiotracksChanged();

    void audio_channelsChanged();

    void enableproxyChanged();

    void externalproxyChanged();

    void generateproxyChanged();

    void external_proxy_profileChanged();

    void externalProxyProfileChanged();

    void generateimageproxyChanged();

    void proxyminsizeChanged();

    void proxyimageminsizeChanged();

    void proxyimagesizeChanged();

    void proxyscaleChanged();

    void enforceLowerTrackCompositingChanged();

    void proxyextensionChanged();

    void proxyparamsChanged();

    void proxy_profileChanged();

    void proxyalphaextensionChanged();

    void proxyalphaparamsChanged();

    void alpha_profileChanged();

    void transcodeFriendlyChanged();

    void transcodingReplaceChanged();

    void previewextensionChanged();

    void preview_profileChanged();

    void previewparamsChanged();

    void parallelrenderChanged();

    void renderInterpChanged();

    void renderDeinterlacerChanged();

    void vaapiEnabledChanged();

    void amfEnabledChanged();

    void SupportedHWCodecsChanged();

    void nvScalingEnabledChanged();

    void hwDecodingChanged();

    void showRenderTextParametersChanged();

    void headerwidthChanged();

    void defaultkeyframeinterpChanged();

    void timelinechunksChanged();

    void autopreviewChanged();

    void draginprogressChanged();

    void proxypreviewChanged();

    void multistreamChanged();

    void multistream_checktrackChanged();

    void videothumbnailsChanged();

    void audiothumbnailsChanged();

    void waveformScalerChanged();

    void showmarkersChanged();

    void displayallchannelsChanged();

    void normalizechannelsChanged();

    void autotrackheightChanged();

    void autoscrollChanged();

    void centeredplayheadChanged();

    void jumptostartChanged();

    void pauseonseekChanged();

    void seekonaddeffectChanged();

    void enableBuiltInEffectsChanged();

    void tenbitpipelineChanged();

    void effectsFilterChanged();

    void transitionsFilterChanged();

    void scrollverticallyChanged();

    void trackheightChanged();

    void audiotracksbelowChanged();

    void raisepropsclipsChanged();

    void raisepropscompositionsChanged();

    void raisepropsmixesChanged();

    void raisepropstracksChanged();

    void uiDebugModeChanged();

    void gpu_accelChanged();

    void audio_scrubChanged();

    void sdlAudioBackendChanged();

    void audio_backendChanged();

    void audiobackendChanged();

    void audio_driverChanged();

    void audiodevicenameChanged();

    void audiodrivernameChanged();

    void disablereccountdownChanged();

    void videodrivernameChanged();

    void audio_deviceChanged();

    void window_backgroundChanged();

    void showMonitorGridChanged();

    void monitorGridHChanged();

    void monitorGridVChanged();

    void monitor_backgroundChanged();

    void monitor_progressiveChanged();

    void volumeChanged();

    void monitor_dropframesChanged();

    void external_displayChanged();

    void blackmagic_output_deviceChanged();

    void play_monitor_on_clickChanged();

    void mirrorMonitorOnFullscreenChanged();

    void fullscreen_monitorChanged();

    void project_monitor_fullscreenChanged();

    void clip_monitor_fullscreenChanged();

    void preferredcompositeChanged();

    void compositingListChanged();

    void subtitle_razor_modeChanged();

    void mltpathChanged();

    void kdenliverendererpathChanged();

    void meltpathChanged();

    void ffmpegpathChanged();

    void ffplaypathChanged();

    void ffprobepathChanged();

    void processingthreadsChanged();

    void proxythreadsChanged();

    void encodethreadsChanged();

    void currenttmpfolderChanged();

    void maxcachesizeChanged();

    void checkForUpdateChanged();

    void usePowerManagementChanged();

    void lastCacheCheckChanged();

    void defaultprojectfolderChanged();

    void customprojectfolderChanged();

    void sameprojectfolderChanged();

    void capturetoprojectfolderChanged();

    void capturefolderChanged();

    void captureprojectsubfolderChanged();

    void librarytodefaultfolderChanged();

    void videotodefaultfolderChanged();

    void libraryfolderChanged();

    void videofolderChanged();

    void defaultimageappChanged();

    void defaultaudioappChanged();

    void glaxnimatePathChanged();

    void defaultvideoappChanged();

    void nice_tasksChanged();

    void exportGuidesFormatChanged();

    void multipleguidesintervalChanged();

    void guidesShowThumbsChanged();

    void guidesSelectZoneChanged();

    void defaultaudiocaptureChanged();

    void audiocapturevolumeChanged();

    void audiocapturechannelsChanged();

    void audiocapturesamplerateChanged();

    void audiocapturesampleformatChanged();

    void defaultcaptureChanged();

    void alsachannelsChanged();

    void grab_profileChanged();

    void grab_parametersChanged();

    void grab_extensionChanged();

    void grab_capture_typeChanged();

    void grab_follow_mouseChanged();

    void grab_offsetxChanged();

    void grab_offsetyChanged();

    void grab_widthChanged();

    void grab_heightChanged();

    void grab_fpsChanged();

    void grab_hide_frameChanged();

    void grab_hide_mouseChanged();

    void decklink_device_foundChanged();

    void decklink_capturedeviceChanged();

    void decklink_profileChanged();

    void decklink_filenameChanged();

    void decklink_parametersChanged();

    void decklink_extensionChanged();

    void enableshuttleChanged();

    void shuttledeviceChanged();

    void shuttledevicenamesChanged();

    void shuttledevicepathsChanged();

    void shuttlebuttonsChanged();

    void bezier_gridlinesChanged();

    void bezier_showpixmapChanged();

    void bezier_showallhandlesChanged();

    void dragvalue_modeChanged();

    void dragvalue_directupdateChanged();

    void recentProfilesChanged();

    void recentProfileNamesChanged();

    void properties_panel_pageChanged();

    void project_fpsChanged();

    void default_profileChanged();

    void kdockLayoutChanged();

    void layoutsOrderChanged();

    void showdescriptioncolumnChanged();

    void showratingcolumnChanged();

    void showdatecolumnChanged();

    void frametimecodeChanged();

    void rectimecodeChanged();

    void snaptopointsChanged();

    void showClipOverlaysChanged();

    void rippleResizeChanged();

    void lockedGuidesChanged();

    void guidesCategoriesChanged();

    void tagsintimelineChanged();

    void timelinemousezoomonplayheadChanged();

    void transitionfollowcursorChanged();

    void keyframeseekChanged();

    void showeffectinfoChanged();

    void applyEffectParamsToGroupChanged();

    void applyEffectParamsToGroupWithSameValueChanged();

    void renderProfileChanged();

    void keepRenderLogFilesChanged();

    void validated_lutsChanged();

    void displayClipMonitorInfoChanged();

    void showClipMonitorSafeZoneChanged();

    void showProjectMonitorSafeZoneChanged();

    void displayProjectMonitorInfoChanged();

    void previewScalingChanged();

    void autoKeyframeChanged();

    void limitAutoKeyframesChanged();

    void limitAutoKeyframesIntervalChanged();

    void maskOpacityChanged();

    void maskInvertedChanged();

    void clipMonitorOverlayGuidesChanged();

    void projectMonitorOverlayGuidesChanged();

    void alwaysShowMonitorAudioChanged();

    void displayAudioOverlayChanged();

    void monitoraudioChanged();

    void showOnMonitorSceneChanged();

    void autoaudiodrivernameChanged();

    void mixerCollapseChanged();

    void consumerslistChanged();

    void producerslistChanged();

    void widgetstyleChanged();

    void showslideshowthumbsChanged();

    void showtitlebarsChanged();

    void colorclipcolorChanged();

    void showSubtitlesChanged();

    void subtitleEditFontSizeChanged();

    void thumbColor1Changed();

    void thumbColor2Changed();

    void overlayColorChanged();

    void safeColorChanged();

    void defaultrescalewidthChanged();

    void defaultrescaleheightChanged();

    void slideshowbymimeChanged();

    void slideshowmimeextensionChanged();

    void monitorscene_directupdateChanged();

    void analyse_stopmotionChanged();

    void enableaudiospectrumChanged();

    void showstopmotionthumbsChanged();

    void captureintervalChanged();

    void sm_notifytimeChanged();

    void sm_prenotifyChanged();

    void sm_loopChanged();

    void sm_playsoundChanged();

    void sm_framesplaybackChanged();

    void stopmotioneffectChanged();

    void onmonitoreffects_cornersshowlinesChanged();

    void onmonitoreffects_geometryshowpreviousChanged();

    void onmonitoreffects_geometryshowpathChanged();

    void onmonitoreffects_cornersshowcontrolsChanged();

    void projectloading_avformatnovalidateChanged();

    void monitor_audioChanged();

    void enable_recording_previewChanged();

    void add_new_clipChanged();

    void add_new_clip_to_folderChanged();

    void default_marker_typeChanged();

    void mltdeinterlacerChanged();

    void mltinterpolationChanged();

    void favorite_effectsChanged();

    void favorite_transitionsChanged();

    void selected_effecttabChanged();

    void effectViewAsIconChanged();

    void transitionViewAsIconChanged();

    void force_breezeChanged();

    void use_dark_breezeChanged();

    void showWelcomeChanged();

    void lastSeenVersionMajorChanged();

    void lastSeenVersionMinorChanged();

    void lastSeenVersionMicroChanged();

    void lock_ratioChanged();

    void selected_templateChanged();

    void titlerShowGuidesChanged();

    void titlerVersionChanged();

    void titlerHGuidesChanged();

    void titlerVGuidesChanged();

    void titleGuideColorChanged();

    void titlerbgChanged();

    void titlerShowbgChanged();

    void titlerAlignChanged();

    void samModelFileChanged();

    void sam_offload_videoChanged();

    void sam_system_pythonChanged();

    void sam_system_python_pathChanged();

    void maskBorderWidthChanged();

    void maskBorderColorChanged();

    void maskColorChanged();

    void speech_system_pythonChanged();

    void speech_system_python_pathChanged();

    void vosk_folder_pathChanged();

    void vosk_text_modelChanged();

    void vosk_srt_modelChanged();

    void speech_zoneChanged();

    void whisperModelChanged();

    void whisperInstalledModelsChanged();

    void whisperAvailableModelsChanged();

    void whisperAvailableModelsHashChanged();

    void whisperModelFolderChanged();

    void whisperLanguageChanged();

    void enableSeamlessChanged();

    void srtSeamlessTranslateChanged();

    void seamless_inputChanged();

    void seamless_outputChanged();

    void whisperMaxCharsChanged();

    void subtitleModeChanged();

    void cutWhisperMaxCharsChanged();

    void whisperDeviceChanged();

    void samDeviceChanged();

    void whisperTranslateChanged();

    void whisperDisableFP16Changed();

    void whisperExtraChanged();

    void speechEngineChanged();

    void mediaIconSizeChanged();

    void mediaManagerPanelLayoutChanged();

    void mediaManagerPanelWidthChanged();

    void mediaBrowserAutoPlayChanged();

    void mediaBrowserWithAudioChanged();

    void mediaDoubleClickImportChanged();

    void mediaBrowserInlinePreviewChanged();

  private:
    void itemChanged(quint64 signalFlag);

  protected:
    KdenliveSettings();
    friend class KdenliveSettingsHelper;


    // bin
    QString mTreeviewheaders;
    static QString defaultTreeviewheadersValue_helper();
    int mBinSorting;
    static int defaultBinSortingValue_helper();
    int mBinMode;
    static int defaultBinModeValue_helper();
    int mBin_zoom;
    static int defaultBin_zoomValue_helper();
    QString mAddedExtensions;
    static QString defaultAddedExtensionsValue_helper();
    bool mHoverPreview;
    static bool defaultHoverPreviewValue_helper();
    int mBinsCount;
    static int defaultBinsCountValue_helper();

    // jobs
    int mScenesplitthreshold;
    static int defaultScenesplitthresholdValue_helper();
    bool mScenesplitmarkers;
    static bool defaultScenesplitmarkersValue_helper();
    bool mScenesplitrangemarkers;
    static bool defaultScenesplitrangemarkersValue_helper();
    bool mScenesplitsubclips;
    static bool defaultScenesplitsubclipsValue_helper();

    // misc
    int mCleanCacheMonths;
    static int defaultCleanCacheMonthsValue_helper();
    bool mOpenlastproject;
    static bool defaultOpenlastprojectValue_helper();
    bool mCrashrecovery;
    static bool defaultCrashrecoveryValue_helper();
    int mAutosave_time;
    static int defaultAutosave_timeValue_helper();
    int mAutosave_ops;
    static int defaultAutosave_opsValue_helper();
    int mTabposition;
    static int defaultTabpositionValue_helper();
    bool mCheckfirstprojectclip;
    static bool defaultCheckfirstprojectclipValue_helper();
    bool mKeep_original_frame_size;
    static bool defaultKeep_original_frame_sizeValue_helper();
    bool mExportframe_usingsourceres;
    static bool defaultExportframe_usingsourceresValue_helper();
    QString mColor_duration;
    static QString defaultColor_durationValue_helper();
    QString mImage_duration;
    static QString defaultImage_durationValue_helper();
    QString mSequence_duration;
    static QString defaultSequence_durationValue_helper();
    QString mFade_duration;
    static QString defaultFade_durationValue_helper();
    QString mMix_duration;
    static QString defaultMix_durationValue_helper();
    QString mSubtitle_duration;
    static QString defaultSubtitle_durationValue_helper();
    bool mAutoimagesequence;
    static bool defaultAutoimagesequenceValue_helper();
    bool mIgnoresubdirstructure;
    static bool defaultIgnoresubdirstructureValue_helper();
    bool mDisableimagescaling;
    static bool defaultDisableimagescalingValue_helper();
    bool mAutomultistreams;
    static bool defaultAutomultistreamsValue_helper();
    bool mUse_exiftool;
    static bool defaultUse_exiftoolValue_helper();
    bool mUse_magicLantern;
    static bool defaultUse_magicLanternValue_helper();
    QString mTitle_duration;
    static QString defaultTitle_durationValue_helper();
    QString mTransition_duration;
    static QString defaultTransition_durationValue_helper();
    bool mEnableAssetsIncludeList;
    static bool defaultEnableAssetsIncludeListValue_helper();
    QString mEffectsInfoHeight;
    static QString defaultEffectsInfoHeightValue_helper();
    bool mShowEffectsInfo;
    static bool defaultShowEffectsInfoValue_helper();
    QString mTransitionsInfoHeight;
    static QString defaultTransitionsInfoHeightValue_helper();
    bool mShowTransitionsInfo;
    static bool defaultShowTransitionsInfoValue_helper();
    bool mDisable_effect_parameters;
    static bool defaultDisable_effect_parametersValue_helper();
    QString mProfile_fps_filter;
    static QString defaultProfile_fps_filterValue_helper();
    QString mProfile_scanning_filter;
    static QString defaultProfile_scanning_filterValue_helper();
    int mOpengl_backend;
    static int defaultOpengl_backendValue_helper();

    // project
    int mVideotracks;
    static int defaultVideotracksValue_helper();
    int mAudiotracks;
    static int defaultAudiotracksValue_helper();
    int mAudio_channels;
    static int defaultAudio_channelsValue_helper();
    bool mEnableproxy;
    static bool defaultEnableproxyValue_helper();
    bool mExternalproxy;
    static bool defaultExternalproxyValue_helper();
    bool mGenerateproxy;
    static bool defaultGenerateproxyValue_helper();
    int mExternal_proxy_profile;
    static int defaultExternal_proxy_profileValue_helper();
    QString mExternalProxyProfile;
    static QString defaultExternalProxyProfileValue_helper();
    bool mGenerateimageproxy;
    static bool defaultGenerateimageproxyValue_helper();
    int mProxyminsize;
    static int defaultProxyminsizeValue_helper();
    int mProxyimageminsize;
    static int defaultProxyimageminsizeValue_helper();
    int mProxyimagesize;
    static int defaultProxyimagesizeValue_helper();
    int mProxyscale;
    static int defaultProxyscaleValue_helper();
    bool mEnforceLowerTrackCompositing;
    static bool defaultEnforceLowerTrackCompositingValue_helper();
    QString mProxyextension;
    static QString defaultProxyextensionValue_helper();
    QString mProxyparams;
    static QString defaultProxyparamsValue_helper();
    int mProxy_profile;
    static int defaultProxy_profileValue_helper();
    QString mProxyalphaextension;
    static QString defaultProxyalphaextensionValue_helper();
    QString mProxyalphaparams;
    static QString defaultProxyalphaparamsValue_helper();
    int mAlpha_profile;
    static int defaultAlpha_profileValue_helper();
    QString mTranscodeFriendly;
    static QString defaultTranscodeFriendlyValue_helper();
    bool mTranscodingReplace;
    static bool defaultTranscodingReplaceValue_helper();
    QString mPreviewextension;
    static QString defaultPreviewextensionValue_helper();
    int mPreview_profile;
    static int defaultPreview_profileValue_helper();
    QString mPreviewparams;
    static QString defaultPreviewparamsValue_helper();
    bool mParallelrender;
    static bool defaultParallelrenderValue_helper();
    QString mRenderInterp;
    static QString defaultRenderInterpValue_helper();
    QString mRenderDeinterlacer;
    static QString defaultRenderDeinterlacerValue_helper();
    bool mVaapiEnabled;
    static bool defaultVaapiEnabledValue_helper();
    bool mAmfEnabled;
    static bool defaultAmfEnabledValue_helper();
    QStringList mSupportedHWCodecs;
    static QStringList defaultSupportedHWCodecsValue_helper();
    bool mNvScalingEnabled;
    static bool defaultNvScalingEnabledValue_helper();
    QString mHwDecoding;
    static QString defaultHwDecodingValue_helper();
    bool mShowRenderTextParameters;
    static bool defaultShowRenderTextParametersValue_helper();

    // timeline
    int mHeaderwidth;
    static int defaultHeaderwidthValue_helper();
    int mDefaultkeyframeinterp;
    static int defaultDefaultkeyframeinterpValue_helper();
    int mTimelinechunks;
    static int defaultTimelinechunksValue_helper();
    bool mAutopreview;
    static bool defaultAutopreviewValue_helper();
    bool mDraginprogress;
    static bool defaultDraginprogressValue_helper();
    bool mProxypreview;
    static bool defaultProxypreviewValue_helper();
    int mMultistream;
    static int defaultMultistreamValue_helper();
    bool mMultistream_checktrack;
    static bool defaultMultistream_checktrackValue_helper();
    bool mVideothumbnails;
    static bool defaultVideothumbnailsValue_helper();
    bool mAudiothumbnails;
    static bool defaultAudiothumbnailsValue_helper();
    int mWaveformScaler;
    static int defaultWaveformScalerValue_helper();
    bool mShowmarkers;
    static bool defaultShowmarkersValue_helper();
    bool mDisplayallchannels;
    static bool defaultDisplayallchannelsValue_helper();
    bool mNormalizechannels;
    static bool defaultNormalizechannelsValue_helper();
    bool mAutotrackheight;
    static bool defaultAutotrackheightValue_helper();
    bool mAutoscroll;
    static bool defaultAutoscrollValue_helper();
    bool mCenteredplayhead;
    static bool defaultCenteredplayheadValue_helper();
    bool mJumptostart;
    static bool defaultJumptostartValue_helper();
    bool mPauseonseek;
    static bool defaultPauseonseekValue_helper();
    bool mSeekonaddeffect;
    static bool defaultSeekonaddeffectValue_helper();
    bool mEnableBuiltInEffects;
    static bool defaultEnableBuiltInEffectsValue_helper();
    bool mTenbitpipeline;
    static bool defaultTenbitpipelineValue_helper();
    bool mEffectsFilter;
    static bool defaultEffectsFilterValue_helper();
    bool mTransitionsFilter;
    static bool defaultTransitionsFilterValue_helper();
    bool mScrollvertically;
    static bool defaultScrollverticallyValue_helper();
    int mTrackheight;
    static int defaultTrackheightValue_helper();
    int mAudiotracksbelow;
    static int defaultAudiotracksbelowValue_helper();
    bool mRaisepropsclips;
    static bool defaultRaisepropsclipsValue_helper();
    bool mRaisepropscompositions;
    static bool defaultRaisepropscompositionsValue_helper();
    bool mRaisepropsmixes;
    static bool defaultRaisepropsmixesValue_helper();
    bool mRaisepropstracks;
    static bool defaultRaisepropstracksValue_helper();
    bool mUiDebugMode;
    static bool defaultUiDebugModeValue_helper();

    // sdl
    bool mGpu_accel;
    static bool defaultGpu_accelValue_helper();
    bool mAudio_scrub;
    static bool defaultAudio_scrubValue_helper();
    QString mSdlAudioBackend;
    static QString defaultSdlAudioBackendValue_helper();
    int mAudio_backend;
    static int defaultAudio_backendValue_helper();
    QString mAudiobackend;
    static QString defaultAudiobackendValue_helper();
    uint mAudio_driver;
    static uint defaultAudio_driverValue_helper();
    QString mAudiodevicename;
    static QString defaultAudiodevicenameValue_helper();
    QString mAudiodrivername;
    static QString defaultAudiodrivernameValue_helper();
    bool mDisablereccountdown;
    static bool defaultDisablereccountdownValue_helper();
    QString mVideodrivername;
    static QString defaultVideodrivernameValue_helper();
    int mAudio_device;
    static int defaultAudio_deviceValue_helper();
    QColor mWindow_background;
    static QColor defaultWindow_backgroundValue_helper();
    bool mShowMonitorGrid;
    static bool defaultShowMonitorGridValue_helper();
    int mMonitorGridH;
    static int defaultMonitorGridHValue_helper();
    int mMonitorGridV;
    static int defaultMonitorGridVValue_helper();
    QString mMonitor_background;
    static QString defaultMonitor_backgroundValue_helper();
    bool mMonitor_progressive;
    static bool defaultMonitor_progressiveValue_helper();
    int mVolume;
    static int defaultVolumeValue_helper();
    bool mMonitor_dropframes;
    static bool defaultMonitor_dropframesValue_helper();
    bool mExternal_display;
    static bool defaultExternal_displayValue_helper();
    int mBlackmagic_output_device;
    static int defaultBlackmagic_output_deviceValue_helper();
    bool mPlay_monitor_on_click;
    static bool defaultPlay_monitor_on_clickValue_helper();
    bool mMirrorMonitorOnFullscreen;
    static bool defaultMirrorMonitorOnFullscreenValue_helper();
    QString mFullscreen_monitor;
    static QString defaultFullscreen_monitorValue_helper();
    QString mProject_monitor_fullscreen;
    static QString defaultProject_monitor_fullscreenValue_helper();
    QString mClip_monitor_fullscreen;
    static QString defaultClip_monitor_fullscreenValue_helper();
    QString mPreferredcomposite;
    static QString defaultPreferredcompositeValue_helper();
    QStringList mCompositingList;
    static QStringList defaultCompositingListValue_helper();

    // tools
    int mSubtitle_razor_mode;
    static int defaultSubtitle_razor_modeValue_helper();

    // env
    QString mMltpath;
    static QString defaultMltpathValue_helper();
    QString mKdenliverendererpath;
    static QString defaultKdenliverendererpathValue_helper();
    QString mMeltpath;
    static QString defaultMeltpathValue_helper();
    QString mFfmpegpath;
    static QString defaultFfmpegpathValue_helper();
    QString mFfplaypath;
    static QString defaultFfplaypathValue_helper();
    QString mFfprobepath;
    static QString defaultFfprobepathValue_helper();
    int mProcessingthreads;
    static int defaultProcessingthreadsValue_helper();
    int mProxythreads;
    static int defaultProxythreadsValue_helper();
    int mEncodethreads;
    static int defaultEncodethreadsValue_helper();
    QString mCurrenttmpfolder;
    static QString defaultCurrenttmpfolderValue_helper();
    int mMaxcachesize;
    static int defaultMaxcachesizeValue_helper();
    bool mCheckForUpdate;
    static bool defaultCheckForUpdateValue_helper();
    bool mUsePowerManagement;
    static bool defaultUsePowerManagementValue_helper();
    QDateTime mLastCacheCheck;
    static QDateTime defaultLastCacheCheckValue_helper();
    QString mDefaultprojectfolder;
    static QString defaultDefaultprojectfolderValue_helper();
    bool mCustomprojectfolder;
    static bool defaultCustomprojectfolderValue_helper();
    bool mSameprojectfolder;
    static bool defaultSameprojectfolderValue_helper();
    int mCapturetoprojectfolder;
    static int defaultCapturetoprojectfolderValue_helper();
    QString mCapturefolder;
    static QString defaultCapturefolderValue_helper();
    QString mCaptureprojectsubfolder;
    static QString defaultCaptureprojectsubfolderValue_helper();
    bool mLibrarytodefaultfolder;
    static bool defaultLibrarytodefaultfolderValue_helper();
    int mVideotodefaultfolder;
    static int defaultVideotodefaultfolderValue_helper();
    QString mLibraryfolder;
    static QString defaultLibraryfolderValue_helper();
    QString mVideofolder;
    static QString defaultVideofolderValue_helper();
    QString mDefaultimageapp;
    static QString defaultDefaultimageappValue_helper();
    QString mDefaultaudioapp;
    static QString defaultDefaultaudioappValue_helper();
    QString mGlaxnimatePath;
    static QString defaultGlaxnimatePathValue_helper();
    QString mDefaultvideoapp;
    static QString defaultDefaultvideoappValue_helper();
    bool mNice_tasks;
    static bool defaultNice_tasksValue_helper();
    QString mExportGuidesFormat;
    static QString defaultExportGuidesFormatValue_helper();
    double mMultipleguidesinterval;
    static double defaultMultipleguidesintervalValue_helper();
    bool mGuidesShowThumbs;
    static bool defaultGuidesShowThumbsValue_helper();
    bool mGuidesSelectZone;
    static bool defaultGuidesSelectZoneValue_helper();

    // capture
    QString mDefaultaudiocapture;
    static QString defaultDefaultaudiocaptureValue_helper();
    int mAudiocapturevolume;
    static int defaultAudiocapturevolumeValue_helper();
    int mAudiocapturechannels;
    static int defaultAudiocapturechannelsValue_helper();
    int mAudiocapturesamplerate;
    static int defaultAudiocapturesamplerateValue_helper();
    int mAudiocapturesampleformat;
    static int defaultAudiocapturesampleformatValue_helper();
    int mDefaultcapture;
    static int defaultDefaultcaptureValue_helper();
    uint mAlsachannels;
    static uint defaultAlsachannelsValue_helper();
    int mGrab_profile;
    static int defaultGrab_profileValue_helper();
    QString mGrab_parameters;
    static QString defaultGrab_parametersValue_helper();
    QString mGrab_extension;
    static QString defaultGrab_extensionValue_helper();
    int mGrab_capture_type;
    static int defaultGrab_capture_typeValue_helper();
    bool mGrab_follow_mouse;
    static bool defaultGrab_follow_mouseValue_helper();
    int mGrab_offsetx;
    static int defaultGrab_offsetxValue_helper();
    int mGrab_offsety;
    static int defaultGrab_offsetyValue_helper();
    int mGrab_width;
    static int defaultGrab_widthValue_helper();
    int mGrab_height;
    static int defaultGrab_heightValue_helper();
    double mGrab_fps;
    static double defaultGrab_fpsValue_helper();
    bool mGrab_hide_frame;
    static bool defaultGrab_hide_frameValue_helper();
    bool mGrab_hide_mouse;
    static bool defaultGrab_hide_mouseValue_helper();
    bool mDecklink_device_found;
    static bool defaultDecklink_device_foundValue_helper();
    uint mDecklink_capturedevice;
    static uint defaultDecklink_capturedeviceValue_helper();
    int mDecklink_profile;
    static int defaultDecklink_profileValue_helper();
    QString mDecklink_filename;
    static QString defaultDecklink_filenameValue_helper();
    QString mDecklink_parameters;
    static QString defaultDecklink_parametersValue_helper();
    QString mDecklink_extension;
    static QString defaultDecklink_extensionValue_helper();

    // shuttle
    bool mEnableshuttle;
    static bool defaultEnableshuttleValue_helper();
    QString mShuttledevice;
    static QString defaultShuttledeviceValue_helper();
    QStringList mShuttledevicenames;
    static QStringList defaultShuttledevicenamesValue_helper();
    QStringList mShuttledevicepaths;
    static QStringList defaultShuttledevicepathsValue_helper();
    QString mShuttlebuttons;
    static QString defaultShuttlebuttonsValue_helper();

    // bezier_spline
    int mBezier_gridlines;
    static int defaultBezier_gridlinesValue_helper();
    bool mBezier_showpixmap;
    static bool defaultBezier_showpixmapValue_helper();
    bool mBezier_showallhandles;
    static bool defaultBezier_showallhandlesValue_helper();

    // drag_value
    int mDragvalue_mode;
    static int defaultDragvalue_modeValue_helper();
    bool mDragvalue_directupdate;
    static bool defaultDragvalue_directupdateValue_helper();

    // Recent Profiles
    QStringList mRecentProfiles;
    static QStringList defaultRecentProfilesValue_helper();
    QStringList mRecentProfileNames;
    static QStringList defaultRecentProfileNamesValue_helper();

    // unmanaged
    int mProperties_panel_page;
    static int defaultProperties_panel_pageValue_helper();
    double mProject_fps;
    static double defaultProject_fpsValue_helper();
    QString mDefault_profile;
    static QString defaultDefault_profileValue_helper();
    QString mKdockLayout;
    static QString defaultKdockLayoutValue_helper();
    QStringList mLayoutsOrder;
    static QStringList defaultLayoutsOrderValue_helper();
    bool mShowdescriptioncolumn;
    static bool defaultShowdescriptioncolumnValue_helper();
    bool mShowratingcolumn;
    static bool defaultShowratingcolumnValue_helper();
    bool mShowdatecolumn;
    static bool defaultShowdatecolumnValue_helper();
    bool mFrametimecode;
    static bool defaultFrametimecodeValue_helper();
    bool mRectimecode;
    static bool defaultRectimecodeValue_helper();
    bool mSnaptopoints;
    static bool defaultSnaptopointsValue_helper();
    bool mShowClipOverlays;
    static bool defaultShowClipOverlaysValue_helper();
    bool mRippleResize;
    static bool defaultRippleResizeValue_helper();
    bool mLockedGuides;
    static bool defaultLockedGuidesValue_helper();
    QStringList mGuidesCategories;
    static QStringList defaultGuidesCategoriesValue_helper();
    bool mTagsintimeline;
    static bool defaultTagsintimelineValue_helper();
    bool mTimelinemousezoomonplayhead;
    static bool defaultTimelinemousezoomonplayheadValue_helper();
    bool mTransitionfollowcursor;
    static bool defaultTransitionfollowcursorValue_helper();
    bool mKeyframeseek;
    static bool defaultKeyframeseekValue_helper();
    bool mShoweffectinfo;
    static bool defaultShoweffectinfoValue_helper();
    bool mApplyEffectParamsToGroup;
    static bool defaultApplyEffectParamsToGroupValue_helper();
    bool mApplyEffectParamsToGroupWithSameValue;
    static bool defaultApplyEffectParamsToGroupWithSameValueValue_helper();
    QString mRenderProfile;
    static QString defaultRenderProfileValue_helper();
    bool mKeepRenderLogFiles;
    static bool defaultKeepRenderLogFilesValue_helper();
    QStringList mValidated_luts;
    static QStringList defaultValidated_lutsValue_helper();
    int mDisplayClipMonitorInfo;
    static int defaultDisplayClipMonitorInfoValue_helper();
    bool mShowClipMonitorSafeZone;
    static bool defaultShowClipMonitorSafeZoneValue_helper();
    bool mShowProjectMonitorSafeZone;
    static bool defaultShowProjectMonitorSafeZoneValue_helper();
    int mDisplayProjectMonitorInfo;
    static int defaultDisplayProjectMonitorInfoValue_helper();
    int mPreviewScaling;
    static int defaultPreviewScalingValue_helper();
    bool mAutoKeyframe;
    static bool defaultAutoKeyframeValue_helper();
    int mLimitAutoKeyframes;
    static int defaultLimitAutoKeyframesValue_helper();
    int mLimitAutoKeyframesInterval;
    static int defaultLimitAutoKeyframesIntervalValue_helper();
    int mMaskOpacity;
    static int defaultMaskOpacityValue_helper();
    bool mMaskInverted;
    static bool defaultMaskInvertedValue_helper();
    int mClipMonitorOverlayGuides;
    static int defaultClipMonitorOverlayGuidesValue_helper();
    int mProjectMonitorOverlayGuides;
    static int defaultProjectMonitorOverlayGuidesValue_helper();
    bool mAlwaysShowMonitorAudio;
    static bool defaultAlwaysShowMonitorAudioValue_helper();
    bool mDisplayAudioOverlay;
    static bool defaultDisplayAudioOverlayValue_helper();
    int mMonitoraudio;
    static int defaultMonitoraudioValue_helper();
    bool mShowOnMonitorScene;
    static bool defaultShowOnMonitorSceneValue_helper();
    QString mAutoaudiodrivername;
    static QString defaultAutoaudiodrivernameValue_helper();
    bool mMixerCollapse;
    static bool defaultMixerCollapseValue_helper();
    QStringList mConsumerslist;
    static QStringList defaultConsumerslistValue_helper();
    QStringList mProducerslist;
    static QStringList defaultProducerslistValue_helper();
    QString mWidgetstyle;
    static QString defaultWidgetstyleValue_helper();
    bool mShowslideshowthumbs;
    static bool defaultShowslideshowthumbsValue_helper();
    bool mShowtitlebars;
    static bool defaultShowtitlebarsValue_helper();
    QColor mColorclipcolor;
    static QColor defaultColorclipcolorValue_helper();
    bool mShowSubtitles;
    static bool defaultShowSubtitlesValue_helper();
    double mSubtitleEditFontSize;
    static double defaultSubtitleEditFontSizeValue_helper();
    QColor mThumbColor1;
    static QColor defaultThumbColor1Value_helper();
    QColor mThumbColor2;
    static QColor defaultThumbColor2Value_helper();
    QColor mOverlayColor;
    static QColor defaultOverlayColorValue_helper();
    QColor mSafeColor;
    static QColor defaultSafeColorValue_helper();
    int mDefaultrescalewidth;
    static int defaultDefaultrescalewidthValue_helper();
    int mDefaultrescaleheight;
    static int defaultDefaultrescaleheightValue_helper();
    bool mSlideshowbymime;
    static bool defaultSlideshowbymimeValue_helper();
    QString mSlideshowmimeextension;
    static QString defaultSlideshowmimeextensionValue_helper();
    bool mMonitorscene_directupdate;
    static bool defaultMonitorscene_directupdateValue_helper();
    bool mAnalyse_stopmotion;
    static bool defaultAnalyse_stopmotionValue_helper();
    bool mEnableaudiospectrum;
    static bool defaultEnableaudiospectrumValue_helper();
    bool mShowstopmotionthumbs;
    static bool defaultShowstopmotionthumbsValue_helper();
    int mCaptureinterval;
    static int defaultCaptureintervalValue_helper();
    int mSm_notifytime;
    static int defaultSm_notifytimeValue_helper();
    bool mSm_prenotify;
    static bool defaultSm_prenotifyValue_helper();
    bool mSm_loop;
    static bool defaultSm_loopValue_helper();
    bool mSm_playsound;
    static bool defaultSm_playsoundValue_helper();
    int mSm_framesplayback;
    static int defaultSm_framesplaybackValue_helper();
    int mStopmotioneffect;
    static int defaultStopmotioneffectValue_helper();
    bool mOnmonitoreffects_cornersshowlines;
    static bool defaultOnmonitoreffects_cornersshowlinesValue_helper();
    bool mOnmonitoreffects_geometryshowprevious;
    static bool defaultOnmonitoreffects_geometryshowpreviousValue_helper();
    bool mOnmonitoreffects_geometryshowpath;
    static bool defaultOnmonitoreffects_geometryshowpathValue_helper();
    bool mOnmonitoreffects_cornersshowcontrols;
    static bool defaultOnmonitoreffects_cornersshowcontrolsValue_helper();
    bool mProjectloading_avformatnovalidate;
    static bool defaultProjectloading_avformatnovalidateValue_helper();
    bool mMonitor_audio;
    static bool defaultMonitor_audioValue_helper();
    bool mEnable_recording_preview;
    static bool defaultEnable_recording_previewValue_helper();
    bool mAdd_new_clip;
    static bool defaultAdd_new_clipValue_helper();
    bool mAdd_new_clip_to_folder;
    static bool defaultAdd_new_clip_to_folderValue_helper();
    int mDefault_marker_type;
    static int defaultDefault_marker_typeValue_helper();
    QString mMltdeinterlacer;
    static QString defaultMltdeinterlacerValue_helper();
    QString mMltinterpolation;
    static QString defaultMltinterpolationValue_helper();
    QStringList mFavorite_effects;
    static QStringList defaultFavorite_effectsValue_helper();
    QStringList mFavorite_transitions;
    static QStringList defaultFavorite_transitionsValue_helper();
    int mSelected_effecttab;
    static int defaultSelected_effecttabValue_helper();
    bool mEffectViewAsIcon;
    static bool defaultEffectViewAsIconValue_helper();
    bool mTransitionViewAsIcon;
    static bool defaultTransitionViewAsIconValue_helper();

    // startup
    bool mForce_breeze;
    static bool defaultForce_breezeValue_helper();
    bool mUse_dark_breeze;
    static bool defaultUse_dark_breezeValue_helper();
    bool mShowWelcome;
    static bool defaultShowWelcomeValue_helper();
    int mLastSeenVersionMajor;
    static int defaultLastSeenVersionMajorValue_helper();
    int mLastSeenVersionMinor;
    static int defaultLastSeenVersionMinorValue_helper();
    int mLastSeenVersionMicro;
    static int defaultLastSeenVersionMicroValue_helper();

    // effects
    bool mLock_ratio;
    static bool defaultLock_ratioValue_helper();

    // titles
    QString mSelected_template;
    static QString defaultSelected_templateValue_helper();
    bool mTitlerShowGuides;
    static bool defaultTitlerShowGuidesValue_helper();
    int mTitlerVersion;
    static int defaultTitlerVersionValue_helper();
    int mTitlerHGuides;
    static int defaultTitlerHGuidesValue_helper();
    int mTitlerVGuides;
    static int defaultTitlerVGuidesValue_helper();
    QColor mTitleGuideColor;
    static QColor defaultTitleGuideColorValue_helper();
    int mTitlerbg;
    static int defaultTitlerbgValue_helper();
    bool mTitlerShowbg;
    static bool defaultTitlerShowbgValue_helper();
    int mTitlerAlign;
    static int defaultTitlerAlignValue_helper();

    // sam
    QString mSamModelFile;
    static QString defaultSamModelFileValue_helper();
    bool mSam_offload_video;
    static bool defaultSam_offload_videoValue_helper();
    bool mSam_system_python;
    static bool defaultSam_system_pythonValue_helper();
    QString mSam_system_python_path;
    static QString defaultSam_system_python_pathValue_helper();
    int mMaskBorderWidth;
    static int defaultMaskBorderWidthValue_helper();
    QColor mMaskBorderColor;
    static QColor defaultMaskBorderColorValue_helper();
    QColor mMaskColor;
    static QColor defaultMaskColorValue_helper();

    // speech
    bool mSpeech_system_python;
    static bool defaultSpeech_system_pythonValue_helper();
    QString mSpeech_system_python_path;
    static QString defaultSpeech_system_python_pathValue_helper();
    QString mVosk_folder_path;
    static QString defaultVosk_folder_pathValue_helper();
    QString mVosk_text_model;
    static QString defaultVosk_text_modelValue_helper();
    QString mVosk_srt_model;
    static QString defaultVosk_srt_modelValue_helper();
    bool mSpeech_zone;
    static bool defaultSpeech_zoneValue_helper();
    QString mWhisperModel;
    static QString defaultWhisperModelValue_helper();
    QStringList mWhisperInstalledModels;
    static QStringList defaultWhisperInstalledModelsValue_helper();
    QStringList mWhisperAvailableModels;
    static QStringList defaultWhisperAvailableModelsValue_helper();
    QStringList mWhisperAvailableModelsHash;
    static QStringList defaultWhisperAvailableModelsHashValue_helper();
    QString mWhisperModelFolder;
    static QString defaultWhisperModelFolderValue_helper();
    QString mWhisperLanguage;
    static QString defaultWhisperLanguageValue_helper();
    bool mEnableSeamless;
    static bool defaultEnableSeamlessValue_helper();
    bool mSrtSeamlessTranslate;
    static bool defaultSrtSeamlessTranslateValue_helper();
    QString mSeamless_input;
    static QString defaultSeamless_inputValue_helper();
    QString mSeamless_output;
    static QString defaultSeamless_outputValue_helper();
    int mWhisperMaxChars;
    static int defaultWhisperMaxCharsValue_helper();
    int mSubtitleMode;
    static int defaultSubtitleModeValue_helper();
    bool mCutWhisperMaxChars;
    static bool defaultCutWhisperMaxCharsValue_helper();
    QString mWhisperDevice;
    static QString defaultWhisperDeviceValue_helper();
    QString mSamDevice;
    static QString defaultSamDeviceValue_helper();
    bool mWhisperTranslate;
    static bool defaultWhisperTranslateValue_helper();
    bool mWhisperDisableFP16;
    static bool defaultWhisperDisableFP16Value_helper();
    QString mWhisperExtra;
    static QString defaultWhisperExtraValue_helper();
    QString mSpeechEngine;
    static QString defaultSpeechEngineValue_helper();

    // Media Browser
    int mMediaIconSize;
    static int defaultMediaIconSizeValue_helper();
    QString mMediaManagerPanelLayout;
    static QString defaultMediaManagerPanelLayoutValue_helper();
    int mMediaManagerPanelWidth;
    static int defaultMediaManagerPanelWidthValue_helper();
    bool mMediaBrowserAutoPlay;
    static bool defaultMediaBrowserAutoPlayValue_helper();
    bool mMediaBrowserWithAudio;
    static bool defaultMediaBrowserWithAudioValue_helper();
    bool mMediaDoubleClickImport;
    static bool defaultMediaDoubleClickImportValue_helper();
    bool mMediaBrowserInlinePreview;
    static bool defaultMediaBrowserInlinePreviewValue_helper();
};

#endif

