/****************************************************************************
** Meta object code from reading C++ file 'kdenlivesettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../kdenlivesettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kdenlivesettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16KdenliveSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto KdenliveSettings::qt_create_metaobjectdata<qt_meta_tag_ZN16KdenliveSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KdenliveSettings",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "treeviewheadersChanged",
        "",
        "binSortingChanged",
        "binModeChanged",
        "bin_zoomChanged",
        "addedExtensionsChanged",
        "hoverPreviewChanged",
        "binsCountChanged",
        "scenesplitthresholdChanged",
        "scenesplitmarkersChanged",
        "scenesplitrangemarkersChanged",
        "scenesplitsubclipsChanged",
        "cleanCacheMonthsChanged",
        "openlastprojectChanged",
        "crashrecoveryChanged",
        "autosave_timeChanged",
        "autosave_opsChanged",
        "tabpositionChanged",
        "checkfirstprojectclipChanged",
        "keep_original_frame_sizeChanged",
        "exportframe_usingsourceresChanged",
        "color_durationChanged",
        "image_durationChanged",
        "sequence_durationChanged",
        "fade_durationChanged",
        "mix_durationChanged",
        "subtitle_durationChanged",
        "autoimagesequenceChanged",
        "ignoresubdirstructureChanged",
        "disableimagescalingChanged",
        "automultistreamsChanged",
        "use_exiftoolChanged",
        "use_magicLanternChanged",
        "title_durationChanged",
        "transition_durationChanged",
        "enableAssetsIncludeListChanged",
        "effectsInfoHeightChanged",
        "showEffectsInfoChanged",
        "transitionsInfoHeightChanged",
        "showTransitionsInfoChanged",
        "disable_effect_parametersChanged",
        "profile_fps_filterChanged",
        "profile_scanning_filterChanged",
        "opengl_backendChanged",
        "videotracksChanged",
        "audiotracksChanged",
        "audio_channelsChanged",
        "enableproxyChanged",
        "externalproxyChanged",
        "generateproxyChanged",
        "external_proxy_profileChanged",
        "externalProxyProfileChanged",
        "generateimageproxyChanged",
        "proxyminsizeChanged",
        "proxyimageminsizeChanged",
        "proxyimagesizeChanged",
        "proxyscaleChanged",
        "enforceLowerTrackCompositingChanged",
        "proxyextensionChanged",
        "proxyparamsChanged",
        "proxy_profileChanged",
        "proxyalphaextensionChanged",
        "proxyalphaparamsChanged",
        "alpha_profileChanged",
        "transcodeFriendlyChanged",
        "transcodingReplaceChanged",
        "previewextensionChanged",
        "preview_profileChanged",
        "previewparamsChanged",
        "parallelrenderChanged",
        "renderInterpChanged",
        "renderDeinterlacerChanged",
        "vaapiEnabledChanged",
        "amfEnabledChanged",
        "SupportedHWCodecsChanged",
        "nvScalingEnabledChanged",
        "hwDecodingChanged",
        "showRenderTextParametersChanged",
        "headerwidthChanged",
        "defaultkeyframeinterpChanged",
        "timelinechunksChanged",
        "autopreviewChanged",
        "draginprogressChanged",
        "proxypreviewChanged",
        "multistreamChanged",
        "multistream_checktrackChanged",
        "videothumbnailsChanged",
        "audiothumbnailsChanged",
        "waveformScalerChanged",
        "showmarkersChanged",
        "displayallchannelsChanged",
        "normalizechannelsChanged",
        "autotrackheightChanged",
        "autoscrollChanged",
        "centeredplayheadChanged",
        "jumptostartChanged",
        "pauseonseekChanged",
        "seekonaddeffectChanged",
        "enableBuiltInEffectsChanged",
        "tenbitpipelineChanged",
        "effectsFilterChanged",
        "transitionsFilterChanged",
        "scrollverticallyChanged",
        "trackheightChanged",
        "audiotracksbelowChanged",
        "raisepropsclipsChanged",
        "raisepropscompositionsChanged",
        "raisepropsmixesChanged",
        "raisepropstracksChanged",
        "uiDebugModeChanged",
        "gpu_accelChanged",
        "audio_scrubChanged",
        "sdlAudioBackendChanged",
        "audio_backendChanged",
        "audiobackendChanged",
        "audio_driverChanged",
        "audiodevicenameChanged",
        "audiodrivernameChanged",
        "disablereccountdownChanged",
        "videodrivernameChanged",
        "audio_deviceChanged",
        "window_backgroundChanged",
        "showMonitorGridChanged",
        "monitorGridHChanged",
        "monitorGridVChanged",
        "monitor_backgroundChanged",
        "monitor_progressiveChanged",
        "volumeChanged",
        "monitor_dropframesChanged",
        "external_displayChanged",
        "blackmagic_output_deviceChanged",
        "play_monitor_on_clickChanged",
        "mirrorMonitorOnFullscreenChanged",
        "fullscreen_monitorChanged",
        "project_monitor_fullscreenChanged",
        "clip_monitor_fullscreenChanged",
        "preferredcompositeChanged",
        "compositingListChanged",
        "subtitle_razor_modeChanged",
        "mltpathChanged",
        "kdenliverendererpathChanged",
        "meltpathChanged",
        "ffmpegpathChanged",
        "ffplaypathChanged",
        "ffprobepathChanged",
        "processingthreadsChanged",
        "proxythreadsChanged",
        "encodethreadsChanged",
        "currenttmpfolderChanged",
        "maxcachesizeChanged",
        "checkForUpdateChanged",
        "usePowerManagementChanged",
        "lastCacheCheckChanged",
        "defaultprojectfolderChanged",
        "customprojectfolderChanged",
        "sameprojectfolderChanged",
        "capturetoprojectfolderChanged",
        "capturefolderChanged",
        "captureprojectsubfolderChanged",
        "librarytodefaultfolderChanged",
        "videotodefaultfolderChanged",
        "libraryfolderChanged",
        "videofolderChanged",
        "defaultimageappChanged",
        "defaultaudioappChanged",
        "glaxnimatePathChanged",
        "defaultvideoappChanged",
        "nice_tasksChanged",
        "exportGuidesFormatChanged",
        "multipleguidesintervalChanged",
        "guidesShowThumbsChanged",
        "guidesSelectZoneChanged",
        "defaultaudiocaptureChanged",
        "audiocapturevolumeChanged",
        "audiocapturechannelsChanged",
        "audiocapturesamplerateChanged",
        "audiocapturesampleformatChanged",
        "defaultcaptureChanged",
        "alsachannelsChanged",
        "grab_profileChanged",
        "grab_parametersChanged",
        "grab_extensionChanged",
        "grab_capture_typeChanged",
        "grab_follow_mouseChanged",
        "grab_offsetxChanged",
        "grab_offsetyChanged",
        "grab_widthChanged",
        "grab_heightChanged",
        "grab_fpsChanged",
        "grab_hide_frameChanged",
        "grab_hide_mouseChanged",
        "decklink_device_foundChanged",
        "decklink_capturedeviceChanged",
        "decklink_profileChanged",
        "decklink_filenameChanged",
        "decklink_parametersChanged",
        "decklink_extensionChanged",
        "enableshuttleChanged",
        "shuttledeviceChanged",
        "shuttledevicenamesChanged",
        "shuttledevicepathsChanged",
        "shuttlebuttonsChanged",
        "bezier_gridlinesChanged",
        "bezier_showpixmapChanged",
        "bezier_showallhandlesChanged",
        "dragvalue_modeChanged",
        "dragvalue_directupdateChanged",
        "recentProfilesChanged",
        "recentProfileNamesChanged",
        "properties_panel_pageChanged",
        "project_fpsChanged",
        "default_profileChanged",
        "kdockLayoutChanged",
        "layoutsOrderChanged",
        "showdescriptioncolumnChanged",
        "showratingcolumnChanged",
        "showdatecolumnChanged",
        "frametimecodeChanged",
        "rectimecodeChanged",
        "snaptopointsChanged",
        "showClipOverlaysChanged",
        "rippleResizeChanged",
        "lockedGuidesChanged",
        "guidesCategoriesChanged",
        "tagsintimelineChanged",
        "timelinemousezoomonplayheadChanged",
        "transitionfollowcursorChanged",
        "keyframeseekChanged",
        "showeffectinfoChanged",
        "applyEffectParamsToGroupChanged",
        "applyEffectParamsToGroupWithSameValueChanged",
        "renderProfileChanged",
        "keepRenderLogFilesChanged",
        "validated_lutsChanged",
        "displayClipMonitorInfoChanged",
        "showClipMonitorSafeZoneChanged",
        "showProjectMonitorSafeZoneChanged",
        "displayProjectMonitorInfoChanged",
        "previewScalingChanged",
        "autoKeyframeChanged",
        "limitAutoKeyframesChanged",
        "limitAutoKeyframesIntervalChanged",
        "maskOpacityChanged",
        "maskInvertedChanged",
        "clipMonitorOverlayGuidesChanged",
        "projectMonitorOverlayGuidesChanged",
        "alwaysShowMonitorAudioChanged",
        "displayAudioOverlayChanged",
        "monitoraudioChanged",
        "showOnMonitorSceneChanged",
        "autoaudiodrivernameChanged",
        "mixerCollapseChanged",
        "consumerslistChanged",
        "producerslistChanged",
        "widgetstyleChanged",
        "showslideshowthumbsChanged",
        "showtitlebarsChanged",
        "colorclipcolorChanged",
        "showSubtitlesChanged",
        "subtitleEditFontSizeChanged",
        "thumbColor1Changed",
        "thumbColor2Changed",
        "overlayColorChanged",
        "safeColorChanged",
        "defaultrescalewidthChanged",
        "defaultrescaleheightChanged",
        "slideshowbymimeChanged",
        "slideshowmimeextensionChanged",
        "monitorscene_directupdateChanged",
        "analyse_stopmotionChanged",
        "enableaudiospectrumChanged",
        "showstopmotionthumbsChanged",
        "captureintervalChanged",
        "sm_notifytimeChanged",
        "sm_prenotifyChanged",
        "sm_loopChanged",
        "sm_playsoundChanged",
        "sm_framesplaybackChanged",
        "stopmotioneffectChanged",
        "onmonitoreffects_cornersshowlinesChanged",
        "onmonitoreffects_geometryshowpreviousChanged",
        "onmonitoreffects_geometryshowpathChanged",
        "onmonitoreffects_cornersshowcontrolsChanged",
        "projectloading_avformatnovalidateChanged",
        "monitor_audioChanged",
        "enable_recording_previewChanged",
        "add_new_clipChanged",
        "add_new_clip_to_folderChanged",
        "default_marker_typeChanged",
        "mltdeinterlacerChanged",
        "mltinterpolationChanged",
        "favorite_effectsChanged",
        "favorite_transitionsChanged",
        "selected_effecttabChanged",
        "effectViewAsIconChanged",
        "transitionViewAsIconChanged",
        "force_breezeChanged",
        "use_dark_breezeChanged",
        "showWelcomeChanged",
        "lastSeenVersionMajorChanged",
        "lastSeenVersionMinorChanged",
        "lastSeenVersionMicroChanged",
        "lock_ratioChanged",
        "selected_templateChanged",
        "titlerShowGuidesChanged",
        "titlerVersionChanged",
        "titlerHGuidesChanged",
        "titlerVGuidesChanged",
        "titleGuideColorChanged",
        "titlerbgChanged",
        "titlerShowbgChanged",
        "titlerAlignChanged",
        "samModelFileChanged",
        "sam_offload_videoChanged",
        "sam_system_pythonChanged",
        "sam_system_python_pathChanged",
        "maskBorderWidthChanged",
        "maskBorderColorChanged",
        "maskColorChanged",
        "speech_system_pythonChanged",
        "speech_system_python_pathChanged",
        "vosk_folder_pathChanged",
        "vosk_text_modelChanged",
        "vosk_srt_modelChanged",
        "speech_zoneChanged",
        "whisperModelChanged",
        "whisperInstalledModelsChanged",
        "whisperAvailableModelsChanged",
        "whisperAvailableModelsHashChanged",
        "whisperModelFolderChanged",
        "whisperLanguageChanged",
        "enableSeamlessChanged",
        "srtSeamlessTranslateChanged",
        "seamless_inputChanged",
        "seamless_outputChanged",
        "whisperMaxCharsChanged",
        "subtitleModeChanged",
        "cutWhisperMaxCharsChanged",
        "whisperDeviceChanged",
        "samDeviceChanged",
        "whisperTranslateChanged",
        "whisperDisableFP16Changed",
        "whisperExtraChanged",
        "speechEngineChanged",
        "mediaIconSizeChanged",
        "mediaManagerPanelLayoutChanged",
        "mediaManagerPanelWidthChanged",
        "mediaBrowserAutoPlayChanged",
        "mediaBrowserWithAudioChanged",
        "mediaDoubleClickImportChanged",
        "mediaBrowserInlinePreviewChanged",
        "treeviewheaders",
        "isTreeviewheadersImmutable",
        "binSorting",
        "isBinSortingImmutable",
        "defaultBinSortingValue",
        "binMode",
        "isBinModeImmutable",
        "defaultBinModeValue",
        "bin_zoom",
        "isBin_zoomImmutable",
        "defaultBin_zoomValue",
        "addedExtensions",
        "isAddedExtensionsImmutable",
        "hoverPreview",
        "isHoverPreviewImmutable",
        "defaultHoverPreviewValue",
        "binsCount",
        "isBinsCountImmutable",
        "defaultBinsCountValue",
        "scenesplitthreshold",
        "isScenesplitthresholdImmutable",
        "defaultScenesplitthresholdValue",
        "scenesplitmarkers",
        "isScenesplitmarkersImmutable",
        "defaultScenesplitmarkersValue",
        "scenesplitrangemarkers",
        "isScenesplitrangemarkersImmutable",
        "defaultScenesplitrangemarkersValue",
        "scenesplitsubclips",
        "isScenesplitsubclipsImmutable",
        "defaultScenesplitsubclipsValue",
        "cleanCacheMonths",
        "isCleanCacheMonthsImmutable",
        "defaultCleanCacheMonthsValue",
        "openlastproject",
        "isOpenlastprojectImmutable",
        "defaultOpenlastprojectValue",
        "crashrecovery",
        "isCrashrecoveryImmutable",
        "defaultCrashrecoveryValue",
        "autosave_time",
        "isAutosave_timeImmutable",
        "defaultAutosave_timeValue",
        "autosave_ops",
        "isAutosave_opsImmutable",
        "defaultAutosave_opsValue",
        "tabposition",
        "isTabpositionImmutable",
        "defaultTabpositionValue",
        "checkfirstprojectclip",
        "isCheckfirstprojectclipImmutable",
        "defaultCheckfirstprojectclipValue",
        "keep_original_frame_size",
        "isKeep_original_frame_sizeImmutable",
        "defaultKeep_original_frame_sizeValue",
        "exportframe_usingsourceres",
        "isExportframe_usingsourceresImmutable",
        "defaultExportframe_usingsourceresValue",
        "color_duration",
        "isColor_durationImmutable",
        "defaultColor_durationValue",
        "image_duration",
        "isImage_durationImmutable",
        "defaultImage_durationValue",
        "sequence_duration",
        "isSequence_durationImmutable",
        "defaultSequence_durationValue",
        "fade_duration",
        "isFade_durationImmutable",
        "defaultFade_durationValue",
        "mix_duration",
        "isMix_durationImmutable",
        "defaultMix_durationValue",
        "subtitle_duration",
        "isSubtitle_durationImmutable",
        "defaultSubtitle_durationValue",
        "autoimagesequence",
        "isAutoimagesequenceImmutable",
        "defaultAutoimagesequenceValue",
        "ignoresubdirstructure",
        "isIgnoresubdirstructureImmutable",
        "defaultIgnoresubdirstructureValue",
        "disableimagescaling",
        "isDisableimagescalingImmutable",
        "defaultDisableimagescalingValue",
        "automultistreams",
        "isAutomultistreamsImmutable",
        "defaultAutomultistreamsValue",
        "use_exiftool",
        "isUse_exiftoolImmutable",
        "defaultUse_exiftoolValue",
        "use_magicLantern",
        "isUse_magicLanternImmutable",
        "defaultUse_magicLanternValue",
        "title_duration",
        "isTitle_durationImmutable",
        "defaultTitle_durationValue",
        "transition_duration",
        "isTransition_durationImmutable",
        "defaultTransition_durationValue",
        "enableAssetsIncludeList",
        "isEnableAssetsIncludeListImmutable",
        "defaultEnableAssetsIncludeListValue",
        "effectsInfoHeight",
        "isEffectsInfoHeightImmutable",
        "showEffectsInfo",
        "isShowEffectsInfoImmutable",
        "defaultShowEffectsInfoValue",
        "transitionsInfoHeight",
        "isTransitionsInfoHeightImmutable",
        "showTransitionsInfo",
        "isShowTransitionsInfoImmutable",
        "defaultShowTransitionsInfoValue",
        "disable_effect_parameters",
        "isDisable_effect_parametersImmutable",
        "defaultDisable_effect_parametersValue",
        "profile_fps_filter",
        "isProfile_fps_filterImmutable",
        "profile_scanning_filter",
        "isProfile_scanning_filterImmutable",
        "opengl_backend",
        "isOpengl_backendImmutable",
        "defaultOpengl_backendValue",
        "videotracks",
        "isVideotracksImmutable",
        "defaultVideotracksValue",
        "audiotracks",
        "isAudiotracksImmutable",
        "defaultAudiotracksValue",
        "audio_channels",
        "isAudio_channelsImmutable",
        "defaultAudio_channelsValue",
        "enableproxy",
        "isEnableproxyImmutable",
        "defaultEnableproxyValue",
        "externalproxy",
        "isExternalproxyImmutable",
        "defaultExternalproxyValue",
        "generateproxy",
        "isGenerateproxyImmutable",
        "defaultGenerateproxyValue",
        "external_proxy_profile",
        "isExternal_proxy_profileImmutable",
        "externalProxyProfile",
        "isExternalProxyProfileImmutable",
        "generateimageproxy",
        "isGenerateimageproxyImmutable",
        "defaultGenerateimageproxyValue",
        "proxyminsize",
        "isProxyminsizeImmutable",
        "defaultProxyminsizeValue",
        "proxyimageminsize",
        "isProxyimageminsizeImmutable",
        "defaultProxyimageminsizeValue",
        "proxyimagesize",
        "isProxyimagesizeImmutable",
        "defaultProxyimagesizeValue",
        "proxyscale",
        "isProxyscaleImmutable",
        "defaultProxyscaleValue",
        "enforceLowerTrackCompositing",
        "isEnforceLowerTrackCompositingImmutable",
        "defaultEnforceLowerTrackCompositingValue",
        "proxyextension",
        "isProxyextensionImmutable",
        "proxyparams",
        "isProxyparamsImmutable",
        "proxy_profile",
        "isProxy_profileImmutable",
        "defaultProxy_profileValue",
        "proxyalphaextension",
        "isProxyalphaextensionImmutable",
        "proxyalphaparams",
        "isProxyalphaparamsImmutable",
        "alpha_profile",
        "isAlpha_profileImmutable",
        "defaultAlpha_profileValue",
        "transcodeFriendly",
        "isTranscodeFriendlyImmutable",
        "transcodingReplace",
        "isTranscodingReplaceImmutable",
        "defaultTranscodingReplaceValue",
        "previewextension",
        "isPreviewextensionImmutable",
        "preview_profile",
        "isPreview_profileImmutable",
        "defaultPreview_profileValue",
        "previewparams",
        "isPreviewparamsImmutable",
        "parallelrender",
        "isParallelrenderImmutable",
        "defaultParallelrenderValue",
        "renderInterp",
        "isRenderInterpImmutable",
        "defaultRenderInterpValue",
        "renderDeinterlacer",
        "isRenderDeinterlacerImmutable",
        "defaultRenderDeinterlacerValue",
        "vaapiEnabled",
        "isVaapiEnabledImmutable",
        "defaultVaapiEnabledValue",
        "amfEnabled",
        "isAmfEnabledImmutable",
        "defaultAmfEnabledValue",
        "supportedHWCodecs",
        "isSupportedHWCodecsImmutable",
        "nvScalingEnabled",
        "isNvScalingEnabledImmutable",
        "defaultNvScalingEnabledValue",
        "hwDecoding",
        "isHwDecodingImmutable",
        "showRenderTextParameters",
        "isShowRenderTextParametersImmutable",
        "defaultShowRenderTextParametersValue",
        "headerwidth",
        "isHeaderwidthImmutable",
        "defaultHeaderwidthValue",
        "defaultkeyframeinterp",
        "isDefaultkeyframeinterpImmutable",
        "defaultDefaultkeyframeinterpValue",
        "timelinechunks",
        "isTimelinechunksImmutable",
        "defaultTimelinechunksValue",
        "autopreview",
        "isAutopreviewImmutable",
        "defaultAutopreviewValue",
        "draginprogress",
        "isDraginprogressImmutable",
        "defaultDraginprogressValue",
        "proxypreview",
        "isProxypreviewImmutable",
        "defaultProxypreviewValue",
        "multistream",
        "isMultistreamImmutable",
        "defaultMultistreamValue",
        "multistream_checktrack",
        "isMultistream_checktrackImmutable",
        "defaultMultistream_checktrackValue",
        "videothumbnails",
        "isVideothumbnailsImmutable",
        "defaultVideothumbnailsValue",
        "audiothumbnails",
        "isAudiothumbnailsImmutable",
        "defaultAudiothumbnailsValue",
        "waveformScaler",
        "isWaveformScalerImmutable",
        "defaultWaveformScalerValue",
        "showmarkers",
        "isShowmarkersImmutable",
        "defaultShowmarkersValue",
        "displayallchannels",
        "isDisplayallchannelsImmutable",
        "defaultDisplayallchannelsValue",
        "normalizechannels",
        "isNormalizechannelsImmutable",
        "defaultNormalizechannelsValue",
        "autotrackheight",
        "isAutotrackheightImmutable",
        "defaultAutotrackheightValue",
        "autoscroll",
        "isAutoscrollImmutable",
        "defaultAutoscrollValue",
        "centeredplayhead",
        "isCenteredplayheadImmutable",
        "defaultCenteredplayheadValue",
        "jumptostart",
        "isJumptostartImmutable",
        "defaultJumptostartValue",
        "pauseonseek",
        "isPauseonseekImmutable",
        "defaultPauseonseekValue",
        "seekonaddeffect",
        "isSeekonaddeffectImmutable",
        "defaultSeekonaddeffectValue",
        "enableBuiltInEffects",
        "isEnableBuiltInEffectsImmutable",
        "defaultEnableBuiltInEffectsValue",
        "tenbitpipeline",
        "isTenbitpipelineImmutable",
        "defaultTenbitpipelineValue",
        "effectsFilter",
        "isEffectsFilterImmutable",
        "defaultEffectsFilterValue",
        "transitionsFilter",
        "isTransitionsFilterImmutable",
        "defaultTransitionsFilterValue",
        "scrollvertically",
        "isScrollverticallyImmutable",
        "defaultScrollverticallyValue",
        "trackheight",
        "isTrackheightImmutable",
        "defaultTrackheightValue",
        "audiotracksbelow",
        "isAudiotracksbelowImmutable",
        "defaultAudiotracksbelowValue",
        "raisepropsclips",
        "isRaisepropsclipsImmutable",
        "defaultRaisepropsclipsValue",
        "raisepropscompositions",
        "isRaisepropscompositionsImmutable",
        "defaultRaisepropscompositionsValue",
        "raisepropsmixes",
        "isRaisepropsmixesImmutable",
        "defaultRaisepropsmixesValue",
        "raisepropstracks",
        "isRaisepropstracksImmutable",
        "defaultRaisepropstracksValue",
        "uiDebugMode",
        "isUiDebugModeImmutable",
        "defaultUiDebugModeValue",
        "gpu_accel",
        "isGpu_accelImmutable",
        "defaultGpu_accelValue",
        "audio_scrub",
        "isAudio_scrubImmutable",
        "defaultAudio_scrubValue",
        "sdlAudioBackend",
        "isSdlAudioBackendImmutable",
        "defaultSdlAudioBackendValue",
        "audio_backend",
        "isAudio_backendImmutable",
        "defaultAudio_backendValue",
        "audiobackend",
        "isAudiobackendImmutable",
        "defaultAudiobackendValue",
        "audio_driver",
        "isAudio_driverImmutable",
        "defaultAudio_driverValue",
        "audiodevicename",
        "isAudiodevicenameImmutable",
        "audiodrivername",
        "isAudiodrivernameImmutable",
        "disablereccountdown",
        "isDisablereccountdownImmutable",
        "defaultDisablereccountdownValue",
        "videodrivername",
        "isVideodrivernameImmutable",
        "audio_device",
        "isAudio_deviceImmutable",
        "window_background",
        "QColor",
        "isWindow_backgroundImmutable",
        "defaultWindow_backgroundValue",
        "showMonitorGrid",
        "isShowMonitorGridImmutable",
        "defaultShowMonitorGridValue",
        "monitorGridH",
        "isMonitorGridHImmutable",
        "defaultMonitorGridHValue",
        "monitorGridV",
        "isMonitorGridVImmutable",
        "defaultMonitorGridVValue",
        "monitor_background",
        "isMonitor_backgroundImmutable",
        "defaultMonitor_backgroundValue",
        "monitor_progressive",
        "isMonitor_progressiveImmutable",
        "defaultMonitor_progressiveValue",
        "volume",
        "isVolumeImmutable",
        "defaultVolumeValue",
        "monitor_dropframes",
        "isMonitor_dropframesImmutable",
        "defaultMonitor_dropframesValue",
        "external_display",
        "isExternal_displayImmutable",
        "defaultExternal_displayValue",
        "blackmagic_output_device",
        "isBlackmagic_output_deviceImmutable",
        "defaultBlackmagic_output_deviceValue",
        "play_monitor_on_click",
        "isPlay_monitor_on_clickImmutable",
        "defaultPlay_monitor_on_clickValue",
        "mirrorMonitorOnFullscreen",
        "isMirrorMonitorOnFullscreenImmutable",
        "defaultMirrorMonitorOnFullscreenValue",
        "fullscreen_monitor",
        "isFullscreen_monitorImmutable",
        "project_monitor_fullscreen",
        "isProject_monitor_fullscreenImmutable",
        "clip_monitor_fullscreen",
        "isClip_monitor_fullscreenImmutable",
        "preferredcomposite",
        "isPreferredcompositeImmutable",
        "compositingList",
        "isCompositingListImmutable",
        "defaultCompositingListValue",
        "subtitle_razor_mode",
        "isSubtitle_razor_modeImmutable",
        "defaultSubtitle_razor_modeValue",
        "mltpath",
        "isMltpathImmutable",
        "kdenliverendererpath",
        "isKdenliverendererpathImmutable",
        "meltpath",
        "isMeltpathImmutable",
        "ffmpegpath",
        "isFfmpegpathImmutable",
        "ffplaypath",
        "isFfplaypathImmutable",
        "ffprobepath",
        "isFfprobepathImmutable",
        "processingthreads",
        "isProcessingthreadsImmutable",
        "defaultProcessingthreadsValue",
        "proxythreads",
        "isProxythreadsImmutable",
        "defaultProxythreadsValue",
        "encodethreads",
        "isEncodethreadsImmutable",
        "defaultEncodethreadsValue",
        "currenttmpfolder",
        "isCurrenttmpfolderImmutable",
        "defaultCurrenttmpfolderValue",
        "maxcachesize",
        "isMaxcachesizeImmutable",
        "defaultMaxcachesizeValue",
        "checkForUpdate",
        "isCheckForUpdateImmutable",
        "defaultCheckForUpdateValue",
        "usePowerManagement",
        "isUsePowerManagementImmutable",
        "defaultUsePowerManagementValue",
        "lastCacheCheck",
        "isLastCacheCheckImmutable",
        "defaultprojectfolder",
        "isDefaultprojectfolderImmutable",
        "customprojectfolder",
        "isCustomprojectfolderImmutable",
        "defaultCustomprojectfolderValue",
        "sameprojectfolder",
        "isSameprojectfolderImmutable",
        "defaultSameprojectfolderValue",
        "capturetoprojectfolder",
        "isCapturetoprojectfolderImmutable",
        "defaultCapturetoprojectfolderValue",
        "capturefolder",
        "isCapturefolderImmutable",
        "defaultCapturefolderValue",
        "captureprojectsubfolder",
        "isCaptureprojectsubfolderImmutable",
        "librarytodefaultfolder",
        "isLibrarytodefaultfolderImmutable",
        "defaultLibrarytodefaultfolderValue",
        "videotodefaultfolder",
        "isVideotodefaultfolderImmutable",
        "defaultVideotodefaultfolderValue",
        "libraryfolder",
        "isLibraryfolderImmutable",
        "videofolder",
        "isVideofolderImmutable",
        "defaultimageapp",
        "isDefaultimageappImmutable",
        "defaultaudioapp",
        "isDefaultaudioappImmutable",
        "glaxnimatePath",
        "isGlaxnimatePathImmutable",
        "defaultvideoapp",
        "isDefaultvideoappImmutable",
        "nice_tasks",
        "isNice_tasksImmutable",
        "defaultNice_tasksValue",
        "exportGuidesFormat",
        "isExportGuidesFormatImmutable",
        "multipleguidesinterval",
        "isMultipleguidesintervalImmutable",
        "defaultMultipleguidesintervalValue",
        "guidesShowThumbs",
        "isGuidesShowThumbsImmutable",
        "defaultGuidesShowThumbsValue",
        "guidesSelectZone",
        "isGuidesSelectZoneImmutable",
        "defaultGuidesSelectZoneValue",
        "defaultaudiocapture",
        "isDefaultaudiocaptureImmutable",
        "defaultDefaultaudiocaptureValue",
        "audiocapturevolume",
        "isAudiocapturevolumeImmutable",
        "defaultAudiocapturevolumeValue",
        "audiocapturechannels",
        "isAudiocapturechannelsImmutable",
        "defaultAudiocapturechannelsValue",
        "audiocapturesamplerate",
        "isAudiocapturesamplerateImmutable",
        "defaultAudiocapturesamplerateValue",
        "audiocapturesampleformat",
        "isAudiocapturesampleformatImmutable",
        "defaultAudiocapturesampleformatValue",
        "defaultcapture",
        "isDefaultcaptureImmutable",
        "defaultDefaultcaptureValue",
        "alsachannels",
        "isAlsachannelsImmutable",
        "defaultAlsachannelsValue",
        "grab_profile",
        "isGrab_profileImmutable",
        "defaultGrab_profileValue",
        "grab_parameters",
        "isGrab_parametersImmutable",
        "grab_extension",
        "isGrab_extensionImmutable",
        "grab_capture_type",
        "isGrab_capture_typeImmutable",
        "defaultGrab_capture_typeValue",
        "grab_follow_mouse",
        "isGrab_follow_mouseImmutable",
        "defaultGrab_follow_mouseValue",
        "grab_offsetx",
        "isGrab_offsetxImmutable",
        "defaultGrab_offsetxValue",
        "grab_offsety",
        "isGrab_offsetyImmutable",
        "defaultGrab_offsetyValue",
        "grab_width",
        "isGrab_widthImmutable",
        "defaultGrab_widthValue",
        "grab_height",
        "isGrab_heightImmutable",
        "defaultGrab_heightValue",
        "grab_fps",
        "isGrab_fpsImmutable",
        "defaultGrab_fpsValue",
        "grab_hide_frame",
        "isGrab_hide_frameImmutable",
        "defaultGrab_hide_frameValue",
        "grab_hide_mouse",
        "isGrab_hide_mouseImmutable",
        "defaultGrab_hide_mouseValue",
        "decklink_device_found",
        "isDecklink_device_foundImmutable",
        "defaultDecklink_device_foundValue",
        "decklink_capturedevice",
        "isDecklink_capturedeviceImmutable",
        "defaultDecklink_capturedeviceValue",
        "decklink_profile",
        "isDecklink_profileImmutable",
        "defaultDecklink_profileValue",
        "decklink_filename",
        "isDecklink_filenameImmutable",
        "defaultDecklink_filenameValue",
        "decklink_parameters",
        "isDecklink_parametersImmutable",
        "decklink_extension",
        "isDecklink_extensionImmutable",
        "enableshuttle",
        "isEnableshuttleImmutable",
        "defaultEnableshuttleValue",
        "shuttledevice",
        "isShuttledeviceImmutable",
        "shuttledevicenames",
        "isShuttledevicenamesImmutable",
        "shuttledevicepaths",
        "isShuttledevicepathsImmutable",
        "shuttlebuttons",
        "isShuttlebuttonsImmutable",
        "bezier_gridlines",
        "isBezier_gridlinesImmutable",
        "defaultBezier_gridlinesValue",
        "bezier_showpixmap",
        "isBezier_showpixmapImmutable",
        "defaultBezier_showpixmapValue",
        "bezier_showallhandles",
        "isBezier_showallhandlesImmutable",
        "defaultBezier_showallhandlesValue",
        "dragvalue_mode",
        "isDragvalue_modeImmutable",
        "defaultDragvalue_modeValue",
        "dragvalue_directupdate",
        "isDragvalue_directupdateImmutable",
        "defaultDragvalue_directupdateValue",
        "recentProfiles",
        "isRecentProfilesImmutable",
        "recentProfileNames",
        "isRecentProfileNamesImmutable",
        "properties_panel_page",
        "isProperties_panel_pageImmutable",
        "defaultProperties_panel_pageValue",
        "project_fps",
        "isProject_fpsImmutable",
        "defaultProject_fpsValue",
        "default_profile",
        "isDefault_profileImmutable",
        "kdockLayout",
        "isKdockLayoutImmutable",
        "layoutsOrder",
        "isLayoutsOrderImmutable",
        "defaultLayoutsOrderValue",
        "showdescriptioncolumn",
        "isShowdescriptioncolumnImmutable",
        "defaultShowdescriptioncolumnValue",
        "showratingcolumn",
        "isShowratingcolumnImmutable",
        "defaultShowratingcolumnValue",
        "showdatecolumn",
        "isShowdatecolumnImmutable",
        "defaultShowdatecolumnValue",
        "frametimecode",
        "isFrametimecodeImmutable",
        "defaultFrametimecodeValue",
        "rectimecode",
        "isRectimecodeImmutable",
        "defaultRectimecodeValue",
        "snaptopoints",
        "isSnaptopointsImmutable",
        "defaultSnaptopointsValue",
        "showClipOverlays",
        "isShowClipOverlaysImmutable",
        "defaultShowClipOverlaysValue",
        "rippleResize",
        "isRippleResizeImmutable",
        "defaultRippleResizeValue",
        "lockedGuides",
        "isLockedGuidesImmutable",
        "defaultLockedGuidesValue",
        "guidesCategories",
        "isGuidesCategoriesImmutable",
        "tagsintimeline",
        "isTagsintimelineImmutable",
        "defaultTagsintimelineValue",
        "timelinemousezoomonplayhead",
        "isTimelinemousezoomonplayheadImmutable",
        "defaultTimelinemousezoomonplayheadValue",
        "transitionfollowcursor",
        "isTransitionfollowcursorImmutable",
        "defaultTransitionfollowcursorValue",
        "keyframeseek",
        "isKeyframeseekImmutable",
        "defaultKeyframeseekValue",
        "showeffectinfo",
        "isShoweffectinfoImmutable",
        "defaultShoweffectinfoValue",
        "applyEffectParamsToGroup",
        "isApplyEffectParamsToGroupImmutable",
        "defaultApplyEffectParamsToGroupValue",
        "applyEffectParamsToGroupWithSameValue",
        "isApplyEffectParamsToGroupWithSameValueImmutable",
        "defaultApplyEffectParamsToGroupWithSameValueValue",
        "renderProfile",
        "isRenderProfileImmutable",
        "defaultRenderProfileValue",
        "keepRenderLogFiles",
        "isKeepRenderLogFilesImmutable",
        "defaultKeepRenderLogFilesValue",
        "validated_luts",
        "isValidated_lutsImmutable",
        "displayClipMonitorInfo",
        "isDisplayClipMonitorInfoImmutable",
        "defaultDisplayClipMonitorInfoValue",
        "showClipMonitorSafeZone",
        "isShowClipMonitorSafeZoneImmutable",
        "defaultShowClipMonitorSafeZoneValue",
        "showProjectMonitorSafeZone",
        "isShowProjectMonitorSafeZoneImmutable",
        "defaultShowProjectMonitorSafeZoneValue",
        "displayProjectMonitorInfo",
        "isDisplayProjectMonitorInfoImmutable",
        "defaultDisplayProjectMonitorInfoValue",
        "previewScaling",
        "isPreviewScalingImmutable",
        "defaultPreviewScalingValue",
        "autoKeyframe",
        "isAutoKeyframeImmutable",
        "defaultAutoKeyframeValue",
        "limitAutoKeyframes",
        "isLimitAutoKeyframesImmutable",
        "defaultLimitAutoKeyframesValue",
        "limitAutoKeyframesInterval",
        "isLimitAutoKeyframesIntervalImmutable",
        "defaultLimitAutoKeyframesIntervalValue",
        "maskOpacity",
        "isMaskOpacityImmutable",
        "defaultMaskOpacityValue",
        "maskInverted",
        "isMaskInvertedImmutable",
        "defaultMaskInvertedValue",
        "clipMonitorOverlayGuides",
        "isClipMonitorOverlayGuidesImmutable",
        "defaultClipMonitorOverlayGuidesValue",
        "projectMonitorOverlayGuides",
        "isProjectMonitorOverlayGuidesImmutable",
        "defaultProjectMonitorOverlayGuidesValue",
        "alwaysShowMonitorAudio",
        "isAlwaysShowMonitorAudioImmutable",
        "defaultAlwaysShowMonitorAudioValue",
        "displayAudioOverlay",
        "isDisplayAudioOverlayImmutable",
        "defaultDisplayAudioOverlayValue",
        "monitoraudio",
        "isMonitoraudioImmutable",
        "defaultMonitoraudioValue",
        "showOnMonitorScene",
        "isShowOnMonitorSceneImmutable",
        "defaultShowOnMonitorSceneValue",
        "autoaudiodrivername",
        "isAutoaudiodrivernameImmutable",
        "mixerCollapse",
        "isMixerCollapseImmutable",
        "defaultMixerCollapseValue",
        "consumerslist",
        "isConsumerslistImmutable",
        "producerslist",
        "isProducerslistImmutable",
        "widgetstyle",
        "isWidgetstyleImmutable",
        "showslideshowthumbs",
        "isShowslideshowthumbsImmutable",
        "defaultShowslideshowthumbsValue",
        "showtitlebars",
        "isShowtitlebarsImmutable",
        "defaultShowtitlebarsValue",
        "colorclipcolor",
        "isColorclipcolorImmutable",
        "defaultColorclipcolorValue",
        "showSubtitles",
        "isShowSubtitlesImmutable",
        "defaultShowSubtitlesValue",
        "subtitleEditFontSize",
        "isSubtitleEditFontSizeImmutable",
        "defaultSubtitleEditFontSizeValue",
        "thumbColor1",
        "isThumbColor1Immutable",
        "defaultThumbColor1Value",
        "thumbColor2",
        "isThumbColor2Immutable",
        "defaultThumbColor2Value",
        "overlayColor",
        "isOverlayColorImmutable",
        "defaultOverlayColorValue",
        "safeColor",
        "isSafeColorImmutable",
        "defaultSafeColorValue",
        "defaultrescalewidth",
        "isDefaultrescalewidthImmutable",
        "defaultDefaultrescalewidthValue",
        "defaultrescaleheight",
        "isDefaultrescaleheightImmutable",
        "defaultDefaultrescaleheightValue",
        "slideshowbymime",
        "isSlideshowbymimeImmutable",
        "defaultSlideshowbymimeValue",
        "slideshowmimeextension",
        "isSlideshowmimeextensionImmutable",
        "monitorscene_directupdate",
        "isMonitorscene_directupdateImmutable",
        "defaultMonitorscene_directupdateValue",
        "analyse_stopmotion",
        "isAnalyse_stopmotionImmutable",
        "defaultAnalyse_stopmotionValue",
        "enableaudiospectrum",
        "isEnableaudiospectrumImmutable",
        "defaultEnableaudiospectrumValue",
        "showstopmotionthumbs",
        "isShowstopmotionthumbsImmutable",
        "defaultShowstopmotionthumbsValue",
        "captureinterval",
        "isCaptureintervalImmutable",
        "defaultCaptureintervalValue",
        "sm_notifytime",
        "isSm_notifytimeImmutable",
        "defaultSm_notifytimeValue",
        "sm_prenotify",
        "isSm_prenotifyImmutable",
        "defaultSm_prenotifyValue",
        "sm_loop",
        "isSm_loopImmutable",
        "defaultSm_loopValue",
        "sm_playsound",
        "isSm_playsoundImmutable",
        "defaultSm_playsoundValue",
        "sm_framesplayback",
        "isSm_framesplaybackImmutable",
        "defaultSm_framesplaybackValue",
        "stopmotioneffect",
        "isStopmotioneffectImmutable",
        "defaultStopmotioneffectValue",
        "onmonitoreffects_cornersshowlines",
        "isOnmonitoreffects_cornersshowlinesImmutable",
        "defaultOnmonitoreffects_cornersshowlinesValue",
        "onmonitoreffects_geometryshowprevious",
        "isOnmonitoreffects_geometryshowpreviousImmutable",
        "defaultOnmonitoreffects_geometryshowpreviousValue",
        "onmonitoreffects_geometryshowpath",
        "isOnmonitoreffects_geometryshowpathImmutable",
        "defaultOnmonitoreffects_geometryshowpathValue",
        "onmonitoreffects_cornersshowcontrols",
        "isOnmonitoreffects_cornersshowcontrolsImmutable",
        "defaultOnmonitoreffects_cornersshowcontrolsValue",
        "projectloading_avformatnovalidate",
        "isProjectloading_avformatnovalidateImmutable",
        "defaultProjectloading_avformatnovalidateValue",
        "monitor_audio",
        "isMonitor_audioImmutable",
        "defaultMonitor_audioValue",
        "enable_recording_preview",
        "isEnable_recording_previewImmutable",
        "defaultEnable_recording_previewValue",
        "add_new_clip",
        "isAdd_new_clipImmutable",
        "defaultAdd_new_clipValue",
        "add_new_clip_to_folder",
        "isAdd_new_clip_to_folderImmutable",
        "defaultAdd_new_clip_to_folderValue",
        "default_marker_type",
        "isDefault_marker_typeImmutable",
        "defaultDefault_marker_typeValue",
        "mltdeinterlacer",
        "isMltdeinterlacerImmutable",
        "defaultMltdeinterlacerValue",
        "mltinterpolation",
        "isMltinterpolationImmutable",
        "defaultMltinterpolationValue",
        "favorite_effects",
        "isFavorite_effectsImmutable",
        "defaultFavorite_effectsValue",
        "favorite_transitions",
        "isFavorite_transitionsImmutable",
        "defaultFavorite_transitionsValue",
        "selected_effecttab",
        "isSelected_effecttabImmutable",
        "defaultSelected_effecttabValue",
        "effectViewAsIcon",
        "isEffectViewAsIconImmutable",
        "defaultEffectViewAsIconValue",
        "transitionViewAsIcon",
        "isTransitionViewAsIconImmutable",
        "defaultTransitionViewAsIconValue",
        "force_breeze",
        "isForce_breezeImmutable",
        "defaultForce_breezeValue",
        "use_dark_breeze",
        "isUse_dark_breezeImmutable",
        "defaultUse_dark_breezeValue",
        "showWelcome",
        "isShowWelcomeImmutable",
        "defaultShowWelcomeValue",
        "lastSeenVersionMajor",
        "isLastSeenVersionMajorImmutable",
        "defaultLastSeenVersionMajorValue",
        "lastSeenVersionMinor",
        "isLastSeenVersionMinorImmutable",
        "defaultLastSeenVersionMinorValue",
        "lastSeenVersionMicro",
        "isLastSeenVersionMicroImmutable",
        "defaultLastSeenVersionMicroValue",
        "lock_ratio",
        "isLock_ratioImmutable",
        "defaultLock_ratioValue",
        "selected_template",
        "isSelected_templateImmutable",
        "titlerShowGuides",
        "isTitlerShowGuidesImmutable",
        "defaultTitlerShowGuidesValue",
        "titlerVersion",
        "isTitlerVersionImmutable",
        "defaultTitlerVersionValue",
        "titlerHGuides",
        "isTitlerHGuidesImmutable",
        "defaultTitlerHGuidesValue",
        "titlerVGuides",
        "isTitlerVGuidesImmutable",
        "defaultTitlerVGuidesValue",
        "titleGuideColor",
        "isTitleGuideColorImmutable",
        "defaultTitleGuideColorValue",
        "titlerbg",
        "isTitlerbgImmutable",
        "defaultTitlerbgValue",
        "titlerShowbg",
        "isTitlerShowbgImmutable",
        "defaultTitlerShowbgValue",
        "titlerAlign",
        "isTitlerAlignImmutable",
        "defaultTitlerAlignValue",
        "samModelFile",
        "isSamModelFileImmutable",
        "sam_offload_video",
        "isSam_offload_videoImmutable",
        "defaultSam_offload_videoValue",
        "sam_system_python",
        "isSam_system_pythonImmutable",
        "defaultSam_system_pythonValue",
        "sam_system_python_path",
        "isSam_system_python_pathImmutable",
        "maskBorderWidth",
        "isMaskBorderWidthImmutable",
        "defaultMaskBorderWidthValue",
        "maskBorderColor",
        "isMaskBorderColorImmutable",
        "defaultMaskBorderColorValue",
        "maskColor",
        "isMaskColorImmutable",
        "defaultMaskColorValue",
        "speech_system_python",
        "isSpeech_system_pythonImmutable",
        "defaultSpeech_system_pythonValue",
        "speech_system_python_path",
        "isSpeech_system_python_pathImmutable",
        "vosk_folder_path",
        "isVosk_folder_pathImmutable",
        "vosk_text_model",
        "isVosk_text_modelImmutable",
        "vosk_srt_model",
        "isVosk_srt_modelImmutable",
        "speech_zone",
        "isSpeech_zoneImmutable",
        "defaultSpeech_zoneValue",
        "whisperModel",
        "isWhisperModelImmutable",
        "defaultWhisperModelValue",
        "whisperInstalledModels",
        "isWhisperInstalledModelsImmutable",
        "whisperAvailableModels",
        "isWhisperAvailableModelsImmutable",
        "defaultWhisperAvailableModelsValue",
        "whisperAvailableModelsHash",
        "isWhisperAvailableModelsHashImmutable",
        "whisperModelFolder",
        "isWhisperModelFolderImmutable",
        "whisperLanguage",
        "isWhisperLanguageImmutable",
        "enableSeamless",
        "isEnableSeamlessImmutable",
        "defaultEnableSeamlessValue",
        "srtSeamlessTranslate",
        "isSrtSeamlessTranslateImmutable",
        "defaultSrtSeamlessTranslateValue",
        "seamless_input",
        "isSeamless_inputImmutable",
        "seamless_output",
        "isSeamless_outputImmutable",
        "whisperMaxChars",
        "isWhisperMaxCharsImmutable",
        "defaultWhisperMaxCharsValue",
        "subtitleMode",
        "isSubtitleModeImmutable",
        "defaultSubtitleModeValue",
        "cutWhisperMaxChars",
        "isCutWhisperMaxCharsImmutable",
        "defaultCutWhisperMaxCharsValue",
        "whisperDevice",
        "isWhisperDeviceImmutable",
        "defaultWhisperDeviceValue",
        "samDevice",
        "isSamDeviceImmutable",
        "defaultSamDeviceValue",
        "whisperTranslate",
        "isWhisperTranslateImmutable",
        "defaultWhisperTranslateValue",
        "whisperDisableFP16",
        "isWhisperDisableFP16Immutable",
        "defaultWhisperDisableFP16Value",
        "whisperExtra",
        "isWhisperExtraImmutable",
        "speechEngine",
        "isSpeechEngineImmutable",
        "defaultSpeechEngineValue",
        "mediaIconSize",
        "isMediaIconSizeImmutable",
        "defaultMediaIconSizeValue",
        "mediaManagerPanelLayout",
        "isMediaManagerPanelLayoutImmutable",
        "mediaManagerPanelWidth",
        "isMediaManagerPanelWidthImmutable",
        "defaultMediaManagerPanelWidthValue",
        "mediaBrowserAutoPlay",
        "isMediaBrowserAutoPlayImmutable",
        "defaultMediaBrowserAutoPlayValue",
        "mediaBrowserWithAudio",
        "isMediaBrowserWithAudioImmutable",
        "defaultMediaBrowserWithAudioValue",
        "mediaDoubleClickImport",
        "isMediaDoubleClickImportImmutable",
        "defaultMediaDoubleClickImportValue",
        "mediaBrowserInlinePreview",
        "isMediaBrowserInlinePreviewImmutable",
        "defaultMediaBrowserInlinePreviewValue"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'treeviewheadersChanged'
        QtMocHelpers::SignalData<void()>(5, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binSortingChanged'
        QtMocHelpers::SignalData<void()>(7, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binModeChanged'
        QtMocHelpers::SignalData<void()>(8, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bin_zoomChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'addedExtensionsChanged'
        QtMocHelpers::SignalData<void()>(10, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hoverPreviewChanged'
        QtMocHelpers::SignalData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'binsCountChanged'
        QtMocHelpers::SignalData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scenesplitthresholdChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scenesplitmarkersChanged'
        QtMocHelpers::SignalData<void()>(14, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scenesplitrangemarkersChanged'
        QtMocHelpers::SignalData<void()>(15, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scenesplitsubclipsChanged'
        QtMocHelpers::SignalData<void()>(16, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cleanCacheMonthsChanged'
        QtMocHelpers::SignalData<void()>(17, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'openlastprojectChanged'
        QtMocHelpers::SignalData<void()>(18, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'crashrecoveryChanged'
        QtMocHelpers::SignalData<void()>(19, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autosave_timeChanged'
        QtMocHelpers::SignalData<void()>(20, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autosave_opsChanged'
        QtMocHelpers::SignalData<void()>(21, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tabpositionChanged'
        QtMocHelpers::SignalData<void()>(22, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkfirstprojectclipChanged'
        QtMocHelpers::SignalData<void()>(23, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keep_original_frame_sizeChanged'
        QtMocHelpers::SignalData<void()>(24, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exportframe_usingsourceresChanged'
        QtMocHelpers::SignalData<void()>(25, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'color_durationChanged'
        QtMocHelpers::SignalData<void()>(26, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'image_durationChanged'
        QtMocHelpers::SignalData<void()>(27, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sequence_durationChanged'
        QtMocHelpers::SignalData<void()>(28, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fade_durationChanged'
        QtMocHelpers::SignalData<void()>(29, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mix_durationChanged'
        QtMocHelpers::SignalData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subtitle_durationChanged'
        QtMocHelpers::SignalData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoimagesequenceChanged'
        QtMocHelpers::SignalData<void()>(32, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ignoresubdirstructureChanged'
        QtMocHelpers::SignalData<void()>(33, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disableimagescalingChanged'
        QtMocHelpers::SignalData<void()>(34, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'automultistreamsChanged'
        QtMocHelpers::SignalData<void()>(35, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'use_exiftoolChanged'
        QtMocHelpers::SignalData<void()>(36, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'use_magicLanternChanged'
        QtMocHelpers::SignalData<void()>(37, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'title_durationChanged'
        QtMocHelpers::SignalData<void()>(38, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transition_durationChanged'
        QtMocHelpers::SignalData<void()>(39, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableAssetsIncludeListChanged'
        QtMocHelpers::SignalData<void()>(40, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectsInfoHeightChanged'
        QtMocHelpers::SignalData<void()>(41, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showEffectsInfoChanged'
        QtMocHelpers::SignalData<void()>(42, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionsInfoHeightChanged'
        QtMocHelpers::SignalData<void()>(43, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showTransitionsInfoChanged'
        QtMocHelpers::SignalData<void()>(44, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disable_effect_parametersChanged'
        QtMocHelpers::SignalData<void()>(45, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profile_fps_filterChanged'
        QtMocHelpers::SignalData<void()>(46, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'profile_scanning_filterChanged'
        QtMocHelpers::SignalData<void()>(47, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'opengl_backendChanged'
        QtMocHelpers::SignalData<void()>(48, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videotracksChanged'
        QtMocHelpers::SignalData<void()>(49, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiotracksChanged'
        QtMocHelpers::SignalData<void()>(50, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audio_channelsChanged'
        QtMocHelpers::SignalData<void()>(51, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableproxyChanged'
        QtMocHelpers::SignalData<void()>(52, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalproxyChanged'
        QtMocHelpers::SignalData<void()>(53, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'generateproxyChanged'
        QtMocHelpers::SignalData<void()>(54, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'external_proxy_profileChanged'
        QtMocHelpers::SignalData<void()>(55, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'externalProxyProfileChanged'
        QtMocHelpers::SignalData<void()>(56, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'generateimageproxyChanged'
        QtMocHelpers::SignalData<void()>(57, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyminsizeChanged'
        QtMocHelpers::SignalData<void()>(58, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyimageminsizeChanged'
        QtMocHelpers::SignalData<void()>(59, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyimagesizeChanged'
        QtMocHelpers::SignalData<void()>(60, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyscaleChanged'
        QtMocHelpers::SignalData<void()>(61, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enforceLowerTrackCompositingChanged'
        QtMocHelpers::SignalData<void()>(62, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyextensionChanged'
        QtMocHelpers::SignalData<void()>(63, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyparamsChanged'
        QtMocHelpers::SignalData<void()>(64, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxy_profileChanged'
        QtMocHelpers::SignalData<void()>(65, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyalphaextensionChanged'
        QtMocHelpers::SignalData<void()>(66, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxyalphaparamsChanged'
        QtMocHelpers::SignalData<void()>(67, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alpha_profileChanged'
        QtMocHelpers::SignalData<void()>(68, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transcodeFriendlyChanged'
        QtMocHelpers::SignalData<void()>(69, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transcodingReplaceChanged'
        QtMocHelpers::SignalData<void()>(70, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewextensionChanged'
        QtMocHelpers::SignalData<void()>(71, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preview_profileChanged'
        QtMocHelpers::SignalData<void()>(72, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewparamsChanged'
        QtMocHelpers::SignalData<void()>(73, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'parallelrenderChanged'
        QtMocHelpers::SignalData<void()>(74, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderInterpChanged'
        QtMocHelpers::SignalData<void()>(75, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderDeinterlacerChanged'
        QtMocHelpers::SignalData<void()>(76, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vaapiEnabledChanged'
        QtMocHelpers::SignalData<void()>(77, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'amfEnabledChanged'
        QtMocHelpers::SignalData<void()>(78, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'SupportedHWCodecsChanged'
        QtMocHelpers::SignalData<void()>(79, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nvScalingEnabledChanged'
        QtMocHelpers::SignalData<void()>(80, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hwDecodingChanged'
        QtMocHelpers::SignalData<void()>(81, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showRenderTextParametersChanged'
        QtMocHelpers::SignalData<void()>(82, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'headerwidthChanged'
        QtMocHelpers::SignalData<void()>(83, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultkeyframeinterpChanged'
        QtMocHelpers::SignalData<void()>(84, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelinechunksChanged'
        QtMocHelpers::SignalData<void()>(85, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autopreviewChanged'
        QtMocHelpers::SignalData<void()>(86, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'draginprogressChanged'
        QtMocHelpers::SignalData<void()>(87, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxypreviewChanged'
        QtMocHelpers::SignalData<void()>(88, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multistreamChanged'
        QtMocHelpers::SignalData<void()>(89, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multistream_checktrackChanged'
        QtMocHelpers::SignalData<void()>(90, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videothumbnailsChanged'
        QtMocHelpers::SignalData<void()>(91, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiothumbnailsChanged'
        QtMocHelpers::SignalData<void()>(92, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'waveformScalerChanged'
        QtMocHelpers::SignalData<void()>(93, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showmarkersChanged'
        QtMocHelpers::SignalData<void()>(94, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayallchannelsChanged'
        QtMocHelpers::SignalData<void()>(95, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'normalizechannelsChanged'
        QtMocHelpers::SignalData<void()>(96, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autotrackheightChanged'
        QtMocHelpers::SignalData<void()>(97, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoscrollChanged'
        QtMocHelpers::SignalData<void()>(98, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'centeredplayheadChanged'
        QtMocHelpers::SignalData<void()>(99, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'jumptostartChanged'
        QtMocHelpers::SignalData<void()>(100, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pauseonseekChanged'
        QtMocHelpers::SignalData<void()>(101, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seekonaddeffectChanged'
        QtMocHelpers::SignalData<void()>(102, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableBuiltInEffectsChanged'
        QtMocHelpers::SignalData<void()>(103, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tenbitpipelineChanged'
        QtMocHelpers::SignalData<void()>(104, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectsFilterChanged'
        QtMocHelpers::SignalData<void()>(105, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionsFilterChanged'
        QtMocHelpers::SignalData<void()>(106, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scrollverticallyChanged'
        QtMocHelpers::SignalData<void()>(107, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trackheightChanged'
        QtMocHelpers::SignalData<void()>(108, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiotracksbelowChanged'
        QtMocHelpers::SignalData<void()>(109, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisepropsclipsChanged'
        QtMocHelpers::SignalData<void()>(110, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisepropscompositionsChanged'
        QtMocHelpers::SignalData<void()>(111, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisepropsmixesChanged'
        QtMocHelpers::SignalData<void()>(112, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'raisepropstracksChanged'
        QtMocHelpers::SignalData<void()>(113, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'uiDebugModeChanged'
        QtMocHelpers::SignalData<void()>(114, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'gpu_accelChanged'
        QtMocHelpers::SignalData<void()>(115, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audio_scrubChanged'
        QtMocHelpers::SignalData<void()>(116, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sdlAudioBackendChanged'
        QtMocHelpers::SignalData<void()>(117, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audio_backendChanged'
        QtMocHelpers::SignalData<void()>(118, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiobackendChanged'
        QtMocHelpers::SignalData<void()>(119, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audio_driverChanged'
        QtMocHelpers::SignalData<void()>(120, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiodevicenameChanged'
        QtMocHelpers::SignalData<void()>(121, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiodrivernameChanged'
        QtMocHelpers::SignalData<void()>(122, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'disablereccountdownChanged'
        QtMocHelpers::SignalData<void()>(123, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videodrivernameChanged'
        QtMocHelpers::SignalData<void()>(124, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audio_deviceChanged'
        QtMocHelpers::SignalData<void()>(125, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'window_backgroundChanged'
        QtMocHelpers::SignalData<void()>(126, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showMonitorGridChanged'
        QtMocHelpers::SignalData<void()>(127, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitorGridHChanged'
        QtMocHelpers::SignalData<void()>(128, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitorGridVChanged'
        QtMocHelpers::SignalData<void()>(129, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitor_backgroundChanged'
        QtMocHelpers::SignalData<void()>(130, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitor_progressiveChanged'
        QtMocHelpers::SignalData<void()>(131, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'volumeChanged'
        QtMocHelpers::SignalData<void()>(132, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitor_dropframesChanged'
        QtMocHelpers::SignalData<void()>(133, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'external_displayChanged'
        QtMocHelpers::SignalData<void()>(134, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'blackmagic_output_deviceChanged'
        QtMocHelpers::SignalData<void()>(135, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'play_monitor_on_clickChanged'
        QtMocHelpers::SignalData<void()>(136, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mirrorMonitorOnFullscreenChanged'
        QtMocHelpers::SignalData<void()>(137, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'fullscreen_monitorChanged'
        QtMocHelpers::SignalData<void()>(138, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'project_monitor_fullscreenChanged'
        QtMocHelpers::SignalData<void()>(139, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clip_monitor_fullscreenChanged'
        QtMocHelpers::SignalData<void()>(140, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'preferredcompositeChanged'
        QtMocHelpers::SignalData<void()>(141, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'compositingListChanged'
        QtMocHelpers::SignalData<void()>(142, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subtitle_razor_modeChanged'
        QtMocHelpers::SignalData<void()>(143, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mltpathChanged'
        QtMocHelpers::SignalData<void()>(144, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kdenliverendererpathChanged'
        QtMocHelpers::SignalData<void()>(145, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'meltpathChanged'
        QtMocHelpers::SignalData<void()>(146, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ffmpegpathChanged'
        QtMocHelpers::SignalData<void()>(147, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ffplaypathChanged'
        QtMocHelpers::SignalData<void()>(148, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'ffprobepathChanged'
        QtMocHelpers::SignalData<void()>(149, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'processingthreadsChanged'
        QtMocHelpers::SignalData<void()>(150, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'proxythreadsChanged'
        QtMocHelpers::SignalData<void()>(151, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'encodethreadsChanged'
        QtMocHelpers::SignalData<void()>(152, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currenttmpfolderChanged'
        QtMocHelpers::SignalData<void()>(153, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maxcachesizeChanged'
        QtMocHelpers::SignalData<void()>(154, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'checkForUpdateChanged'
        QtMocHelpers::SignalData<void()>(155, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'usePowerManagementChanged'
        QtMocHelpers::SignalData<void()>(156, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastCacheCheckChanged'
        QtMocHelpers::SignalData<void()>(157, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultprojectfolderChanged'
        QtMocHelpers::SignalData<void()>(158, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'customprojectfolderChanged'
        QtMocHelpers::SignalData<void()>(159, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sameprojectfolderChanged'
        QtMocHelpers::SignalData<void()>(160, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'capturetoprojectfolderChanged'
        QtMocHelpers::SignalData<void()>(161, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'capturefolderChanged'
        QtMocHelpers::SignalData<void()>(162, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureprojectsubfolderChanged'
        QtMocHelpers::SignalData<void()>(163, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'librarytodefaultfolderChanged'
        QtMocHelpers::SignalData<void()>(164, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videotodefaultfolderChanged'
        QtMocHelpers::SignalData<void()>(165, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'libraryfolderChanged'
        QtMocHelpers::SignalData<void()>(166, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'videofolderChanged'
        QtMocHelpers::SignalData<void()>(167, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultimageappChanged'
        QtMocHelpers::SignalData<void()>(168, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultaudioappChanged'
        QtMocHelpers::SignalData<void()>(169, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'glaxnimatePathChanged'
        QtMocHelpers::SignalData<void()>(170, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultvideoappChanged'
        QtMocHelpers::SignalData<void()>(171, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'nice_tasksChanged'
        QtMocHelpers::SignalData<void()>(172, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exportGuidesFormatChanged'
        QtMocHelpers::SignalData<void()>(173, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'multipleguidesintervalChanged'
        QtMocHelpers::SignalData<void()>(174, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guidesShowThumbsChanged'
        QtMocHelpers::SignalData<void()>(175, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guidesSelectZoneChanged'
        QtMocHelpers::SignalData<void()>(176, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultaudiocaptureChanged'
        QtMocHelpers::SignalData<void()>(177, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiocapturevolumeChanged'
        QtMocHelpers::SignalData<void()>(178, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiocapturechannelsChanged'
        QtMocHelpers::SignalData<void()>(179, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiocapturesamplerateChanged'
        QtMocHelpers::SignalData<void()>(180, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'audiocapturesampleformatChanged'
        QtMocHelpers::SignalData<void()>(181, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultcaptureChanged'
        QtMocHelpers::SignalData<void()>(182, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alsachannelsChanged'
        QtMocHelpers::SignalData<void()>(183, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_profileChanged'
        QtMocHelpers::SignalData<void()>(184, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_parametersChanged'
        QtMocHelpers::SignalData<void()>(185, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_extensionChanged'
        QtMocHelpers::SignalData<void()>(186, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_capture_typeChanged'
        QtMocHelpers::SignalData<void()>(187, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_follow_mouseChanged'
        QtMocHelpers::SignalData<void()>(188, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_offsetxChanged'
        QtMocHelpers::SignalData<void()>(189, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_offsetyChanged'
        QtMocHelpers::SignalData<void()>(190, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_widthChanged'
        QtMocHelpers::SignalData<void()>(191, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_heightChanged'
        QtMocHelpers::SignalData<void()>(192, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_fpsChanged'
        QtMocHelpers::SignalData<void()>(193, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_hide_frameChanged'
        QtMocHelpers::SignalData<void()>(194, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'grab_hide_mouseChanged'
        QtMocHelpers::SignalData<void()>(195, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_device_foundChanged'
        QtMocHelpers::SignalData<void()>(196, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_capturedeviceChanged'
        QtMocHelpers::SignalData<void()>(197, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_profileChanged'
        QtMocHelpers::SignalData<void()>(198, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_filenameChanged'
        QtMocHelpers::SignalData<void()>(199, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_parametersChanged'
        QtMocHelpers::SignalData<void()>(200, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'decklink_extensionChanged'
        QtMocHelpers::SignalData<void()>(201, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableshuttleChanged'
        QtMocHelpers::SignalData<void()>(202, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuttledeviceChanged'
        QtMocHelpers::SignalData<void()>(203, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuttledevicenamesChanged'
        QtMocHelpers::SignalData<void()>(204, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuttledevicepathsChanged'
        QtMocHelpers::SignalData<void()>(205, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'shuttlebuttonsChanged'
        QtMocHelpers::SignalData<void()>(206, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bezier_gridlinesChanged'
        QtMocHelpers::SignalData<void()>(207, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bezier_showpixmapChanged'
        QtMocHelpers::SignalData<void()>(208, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'bezier_showallhandlesChanged'
        QtMocHelpers::SignalData<void()>(209, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragvalue_modeChanged'
        QtMocHelpers::SignalData<void()>(210, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dragvalue_directupdateChanged'
        QtMocHelpers::SignalData<void()>(211, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recentProfilesChanged'
        QtMocHelpers::SignalData<void()>(212, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recentProfileNamesChanged'
        QtMocHelpers::SignalData<void()>(213, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'properties_panel_pageChanged'
        QtMocHelpers::SignalData<void()>(214, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'project_fpsChanged'
        QtMocHelpers::SignalData<void()>(215, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'default_profileChanged'
        QtMocHelpers::SignalData<void()>(216, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'kdockLayoutChanged'
        QtMocHelpers::SignalData<void()>(217, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layoutsOrderChanged'
        QtMocHelpers::SignalData<void()>(218, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showdescriptioncolumnChanged'
        QtMocHelpers::SignalData<void()>(219, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showratingcolumnChanged'
        QtMocHelpers::SignalData<void()>(220, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showdatecolumnChanged'
        QtMocHelpers::SignalData<void()>(221, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'frametimecodeChanged'
        QtMocHelpers::SignalData<void()>(222, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rectimecodeChanged'
        QtMocHelpers::SignalData<void()>(223, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'snaptopointsChanged'
        QtMocHelpers::SignalData<void()>(224, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showClipOverlaysChanged'
        QtMocHelpers::SignalData<void()>(225, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'rippleResizeChanged'
        QtMocHelpers::SignalData<void()>(226, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lockedGuidesChanged'
        QtMocHelpers::SignalData<void()>(227, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'guidesCategoriesChanged'
        QtMocHelpers::SignalData<void()>(228, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'tagsintimelineChanged'
        QtMocHelpers::SignalData<void()>(229, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'timelinemousezoomonplayheadChanged'
        QtMocHelpers::SignalData<void()>(230, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionfollowcursorChanged'
        QtMocHelpers::SignalData<void()>(231, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyframeseekChanged'
        QtMocHelpers::SignalData<void()>(232, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showeffectinfoChanged'
        QtMocHelpers::SignalData<void()>(233, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyEffectParamsToGroupChanged'
        QtMocHelpers::SignalData<void()>(234, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'applyEffectParamsToGroupWithSameValueChanged'
        QtMocHelpers::SignalData<void()>(235, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'renderProfileChanged'
        QtMocHelpers::SignalData<void()>(236, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keepRenderLogFilesChanged'
        QtMocHelpers::SignalData<void()>(237, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'validated_lutsChanged'
        QtMocHelpers::SignalData<void()>(238, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayClipMonitorInfoChanged'
        QtMocHelpers::SignalData<void()>(239, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showClipMonitorSafeZoneChanged'
        QtMocHelpers::SignalData<void()>(240, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showProjectMonitorSafeZoneChanged'
        QtMocHelpers::SignalData<void()>(241, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayProjectMonitorInfoChanged'
        QtMocHelpers::SignalData<void()>(242, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'previewScalingChanged'
        QtMocHelpers::SignalData<void()>(243, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoKeyframeChanged'
        QtMocHelpers::SignalData<void()>(244, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'limitAutoKeyframesChanged'
        QtMocHelpers::SignalData<void()>(245, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'limitAutoKeyframesIntervalChanged'
        QtMocHelpers::SignalData<void()>(246, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskOpacityChanged'
        QtMocHelpers::SignalData<void()>(247, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskInvertedChanged'
        QtMocHelpers::SignalData<void()>(248, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'clipMonitorOverlayGuidesChanged'
        QtMocHelpers::SignalData<void()>(249, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'projectMonitorOverlayGuidesChanged'
        QtMocHelpers::SignalData<void()>(250, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'alwaysShowMonitorAudioChanged'
        QtMocHelpers::SignalData<void()>(251, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'displayAudioOverlayChanged'
        QtMocHelpers::SignalData<void()>(252, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitoraudioChanged'
        QtMocHelpers::SignalData<void()>(253, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showOnMonitorSceneChanged'
        QtMocHelpers::SignalData<void()>(254, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'autoaudiodrivernameChanged'
        QtMocHelpers::SignalData<void()>(255, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mixerCollapseChanged'
        QtMocHelpers::SignalData<void()>(256, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'consumerslistChanged'
        QtMocHelpers::SignalData<void()>(257, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'producerslistChanged'
        QtMocHelpers::SignalData<void()>(258, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widgetstyleChanged'
        QtMocHelpers::SignalData<void()>(259, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showslideshowthumbsChanged'
        QtMocHelpers::SignalData<void()>(260, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showtitlebarsChanged'
        QtMocHelpers::SignalData<void()>(261, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'colorclipcolorChanged'
        QtMocHelpers::SignalData<void()>(262, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showSubtitlesChanged'
        QtMocHelpers::SignalData<void()>(263, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subtitleEditFontSizeChanged'
        QtMocHelpers::SignalData<void()>(264, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thumbColor1Changed'
        QtMocHelpers::SignalData<void()>(265, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'thumbColor2Changed'
        QtMocHelpers::SignalData<void()>(266, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlayColorChanged'
        QtMocHelpers::SignalData<void()>(267, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'safeColorChanged'
        QtMocHelpers::SignalData<void()>(268, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultrescalewidthChanged'
        QtMocHelpers::SignalData<void()>(269, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'defaultrescaleheightChanged'
        QtMocHelpers::SignalData<void()>(270, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideshowbymimeChanged'
        QtMocHelpers::SignalData<void()>(271, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'slideshowmimeextensionChanged'
        QtMocHelpers::SignalData<void()>(272, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitorscene_directupdateChanged'
        QtMocHelpers::SignalData<void()>(273, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'analyse_stopmotionChanged'
        QtMocHelpers::SignalData<void()>(274, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableaudiospectrumChanged'
        QtMocHelpers::SignalData<void()>(275, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showstopmotionthumbsChanged'
        QtMocHelpers::SignalData<void()>(276, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'captureintervalChanged'
        QtMocHelpers::SignalData<void()>(277, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sm_notifytimeChanged'
        QtMocHelpers::SignalData<void()>(278, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sm_prenotifyChanged'
        QtMocHelpers::SignalData<void()>(279, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sm_loopChanged'
        QtMocHelpers::SignalData<void()>(280, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sm_playsoundChanged'
        QtMocHelpers::SignalData<void()>(281, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sm_framesplaybackChanged'
        QtMocHelpers::SignalData<void()>(282, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stopmotioneffectChanged'
        QtMocHelpers::SignalData<void()>(283, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onmonitoreffects_cornersshowlinesChanged'
        QtMocHelpers::SignalData<void()>(284, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onmonitoreffects_geometryshowpreviousChanged'
        QtMocHelpers::SignalData<void()>(285, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onmonitoreffects_geometryshowpathChanged'
        QtMocHelpers::SignalData<void()>(286, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'onmonitoreffects_cornersshowcontrolsChanged'
        QtMocHelpers::SignalData<void()>(287, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'projectloading_avformatnovalidateChanged'
        QtMocHelpers::SignalData<void()>(288, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'monitor_audioChanged'
        QtMocHelpers::SignalData<void()>(289, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enable_recording_previewChanged'
        QtMocHelpers::SignalData<void()>(290, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'add_new_clipChanged'
        QtMocHelpers::SignalData<void()>(291, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'add_new_clip_to_folderChanged'
        QtMocHelpers::SignalData<void()>(292, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'default_marker_typeChanged'
        QtMocHelpers::SignalData<void()>(293, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mltdeinterlacerChanged'
        QtMocHelpers::SignalData<void()>(294, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mltinterpolationChanged'
        QtMocHelpers::SignalData<void()>(295, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favorite_effectsChanged'
        QtMocHelpers::SignalData<void()>(296, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'favorite_transitionsChanged'
        QtMocHelpers::SignalData<void()>(297, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selected_effecttabChanged'
        QtMocHelpers::SignalData<void()>(298, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'effectViewAsIconChanged'
        QtMocHelpers::SignalData<void()>(299, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'transitionViewAsIconChanged'
        QtMocHelpers::SignalData<void()>(300, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'force_breezeChanged'
        QtMocHelpers::SignalData<void()>(301, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'use_dark_breezeChanged'
        QtMocHelpers::SignalData<void()>(302, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'showWelcomeChanged'
        QtMocHelpers::SignalData<void()>(303, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastSeenVersionMajorChanged'
        QtMocHelpers::SignalData<void()>(304, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastSeenVersionMinorChanged'
        QtMocHelpers::SignalData<void()>(305, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lastSeenVersionMicroChanged'
        QtMocHelpers::SignalData<void()>(306, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'lock_ratioChanged'
        QtMocHelpers::SignalData<void()>(307, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'selected_templateChanged'
        QtMocHelpers::SignalData<void()>(308, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerShowGuidesChanged'
        QtMocHelpers::SignalData<void()>(309, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerVersionChanged'
        QtMocHelpers::SignalData<void()>(310, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerHGuidesChanged'
        QtMocHelpers::SignalData<void()>(311, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerVGuidesChanged'
        QtMocHelpers::SignalData<void()>(312, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titleGuideColorChanged'
        QtMocHelpers::SignalData<void()>(313, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerbgChanged'
        QtMocHelpers::SignalData<void()>(314, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerShowbgChanged'
        QtMocHelpers::SignalData<void()>(315, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'titlerAlignChanged'
        QtMocHelpers::SignalData<void()>(316, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'samModelFileChanged'
        QtMocHelpers::SignalData<void()>(317, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sam_offload_videoChanged'
        QtMocHelpers::SignalData<void()>(318, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sam_system_pythonChanged'
        QtMocHelpers::SignalData<void()>(319, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sam_system_python_pathChanged'
        QtMocHelpers::SignalData<void()>(320, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskBorderWidthChanged'
        QtMocHelpers::SignalData<void()>(321, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskBorderColorChanged'
        QtMocHelpers::SignalData<void()>(322, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'maskColorChanged'
        QtMocHelpers::SignalData<void()>(323, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speech_system_pythonChanged'
        QtMocHelpers::SignalData<void()>(324, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speech_system_python_pathChanged'
        QtMocHelpers::SignalData<void()>(325, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vosk_folder_pathChanged'
        QtMocHelpers::SignalData<void()>(326, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vosk_text_modelChanged'
        QtMocHelpers::SignalData<void()>(327, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'vosk_srt_modelChanged'
        QtMocHelpers::SignalData<void()>(328, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speech_zoneChanged'
        QtMocHelpers::SignalData<void()>(329, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperModelChanged'
        QtMocHelpers::SignalData<void()>(330, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperInstalledModelsChanged'
        QtMocHelpers::SignalData<void()>(331, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperAvailableModelsChanged'
        QtMocHelpers::SignalData<void()>(332, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperAvailableModelsHashChanged'
        QtMocHelpers::SignalData<void()>(333, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperModelFolderChanged'
        QtMocHelpers::SignalData<void()>(334, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperLanguageChanged'
        QtMocHelpers::SignalData<void()>(335, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'enableSeamlessChanged'
        QtMocHelpers::SignalData<void()>(336, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'srtSeamlessTranslateChanged'
        QtMocHelpers::SignalData<void()>(337, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seamless_inputChanged'
        QtMocHelpers::SignalData<void()>(338, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'seamless_outputChanged'
        QtMocHelpers::SignalData<void()>(339, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperMaxCharsChanged'
        QtMocHelpers::SignalData<void()>(340, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'subtitleModeChanged'
        QtMocHelpers::SignalData<void()>(341, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cutWhisperMaxCharsChanged'
        QtMocHelpers::SignalData<void()>(342, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperDeviceChanged'
        QtMocHelpers::SignalData<void()>(343, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'samDeviceChanged'
        QtMocHelpers::SignalData<void()>(344, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperTranslateChanged'
        QtMocHelpers::SignalData<void()>(345, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperDisableFP16Changed'
        QtMocHelpers::SignalData<void()>(346, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'whisperExtraChanged'
        QtMocHelpers::SignalData<void()>(347, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'speechEngineChanged'
        QtMocHelpers::SignalData<void()>(348, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaIconSizeChanged'
        QtMocHelpers::SignalData<void()>(349, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaManagerPanelLayoutChanged'
        QtMocHelpers::SignalData<void()>(350, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaManagerPanelWidthChanged'
        QtMocHelpers::SignalData<void()>(351, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaBrowserAutoPlayChanged'
        QtMocHelpers::SignalData<void()>(352, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaBrowserWithAudioChanged'
        QtMocHelpers::SignalData<void()>(353, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaDoubleClickImportChanged'
        QtMocHelpers::SignalData<void()>(354, 6, QMC::AccessPublic, QMetaType::Void),
        // Signal 'mediaBrowserInlinePreviewChanged'
        QtMocHelpers::SignalData<void()>(355, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'treeviewheaders'
        QtMocHelpers::PropertyData<QString>(356, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'isTreeviewheadersImmutable'
        QtMocHelpers::PropertyData<bool>(357, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'binSorting'
        QtMocHelpers::PropertyData<int>(358, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'isBinSortingImmutable'
        QtMocHelpers::PropertyData<bool>(359, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBinSortingValue'
        QtMocHelpers::PropertyData<int>(360, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'binMode'
        QtMocHelpers::PropertyData<int>(361, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'isBinModeImmutable'
        QtMocHelpers::PropertyData<bool>(362, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBinModeValue'
        QtMocHelpers::PropertyData<int>(363, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bin_zoom'
        QtMocHelpers::PropertyData<int>(364, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 3),
        // property 'isBin_zoomImmutable'
        QtMocHelpers::PropertyData<bool>(365, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBin_zoomValue'
        QtMocHelpers::PropertyData<int>(366, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'addedExtensions'
        QtMocHelpers::PropertyData<QString>(367, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'isAddedExtensionsImmutable'
        QtMocHelpers::PropertyData<bool>(368, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hoverPreview'
        QtMocHelpers::PropertyData<bool>(369, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 5),
        // property 'isHoverPreviewImmutable'
        QtMocHelpers::PropertyData<bool>(370, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHoverPreviewValue'
        QtMocHelpers::PropertyData<bool>(371, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'binsCount'
        QtMocHelpers::PropertyData<int>(372, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 6),
        // property 'isBinsCountImmutable'
        QtMocHelpers::PropertyData<bool>(373, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBinsCountValue'
        QtMocHelpers::PropertyData<int>(374, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scenesplitthreshold'
        QtMocHelpers::PropertyData<int>(375, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 7),
        // property 'isScenesplitthresholdImmutable'
        QtMocHelpers::PropertyData<bool>(376, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScenesplitthresholdValue'
        QtMocHelpers::PropertyData<int>(377, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scenesplitmarkers'
        QtMocHelpers::PropertyData<bool>(378, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 8),
        // property 'isScenesplitmarkersImmutable'
        QtMocHelpers::PropertyData<bool>(379, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScenesplitmarkersValue'
        QtMocHelpers::PropertyData<bool>(380, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scenesplitrangemarkers'
        QtMocHelpers::PropertyData<bool>(381, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 9),
        // property 'isScenesplitrangemarkersImmutable'
        QtMocHelpers::PropertyData<bool>(382, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScenesplitrangemarkersValue'
        QtMocHelpers::PropertyData<bool>(383, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scenesplitsubclips'
        QtMocHelpers::PropertyData<bool>(384, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 10),
        // property 'isScenesplitsubclipsImmutable'
        QtMocHelpers::PropertyData<bool>(385, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScenesplitsubclipsValue'
        QtMocHelpers::PropertyData<bool>(386, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cleanCacheMonths'
        QtMocHelpers::PropertyData<int>(387, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 11),
        // property 'isCleanCacheMonthsImmutable'
        QtMocHelpers::PropertyData<bool>(388, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCleanCacheMonthsValue'
        QtMocHelpers::PropertyData<int>(389, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'openlastproject'
        QtMocHelpers::PropertyData<bool>(390, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 12),
        // property 'isOpenlastprojectImmutable'
        QtMocHelpers::PropertyData<bool>(391, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOpenlastprojectValue'
        QtMocHelpers::PropertyData<bool>(392, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'crashrecovery'
        QtMocHelpers::PropertyData<bool>(393, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 13),
        // property 'isCrashrecoveryImmutable'
        QtMocHelpers::PropertyData<bool>(394, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCrashrecoveryValue'
        QtMocHelpers::PropertyData<bool>(395, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autosave_time'
        QtMocHelpers::PropertyData<int>(396, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 14),
        // property 'isAutosave_timeImmutable'
        QtMocHelpers::PropertyData<bool>(397, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutosave_timeValue'
        QtMocHelpers::PropertyData<int>(398, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autosave_ops'
        QtMocHelpers::PropertyData<int>(399, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 15),
        // property 'isAutosave_opsImmutable'
        QtMocHelpers::PropertyData<bool>(400, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutosave_opsValue'
        QtMocHelpers::PropertyData<int>(401, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tabposition'
        QtMocHelpers::PropertyData<int>(402, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 16),
        // property 'isTabpositionImmutable'
        QtMocHelpers::PropertyData<bool>(403, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTabpositionValue'
        QtMocHelpers::PropertyData<int>(404, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'checkfirstprojectclip'
        QtMocHelpers::PropertyData<bool>(405, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 17),
        // property 'isCheckfirstprojectclipImmutable'
        QtMocHelpers::PropertyData<bool>(406, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCheckfirstprojectclipValue'
        QtMocHelpers::PropertyData<bool>(407, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keep_original_frame_size'
        QtMocHelpers::PropertyData<bool>(408, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 18),
        // property 'isKeep_original_frame_sizeImmutable'
        QtMocHelpers::PropertyData<bool>(409, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeep_original_frame_sizeValue'
        QtMocHelpers::PropertyData<bool>(410, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'exportframe_usingsourceres'
        QtMocHelpers::PropertyData<bool>(411, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 19),
        // property 'isExportframe_usingsourceresImmutable'
        QtMocHelpers::PropertyData<bool>(412, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExportframe_usingsourceresValue'
        QtMocHelpers::PropertyData<bool>(413, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'color_duration'
        QtMocHelpers::PropertyData<QString>(414, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 20),
        // property 'isColor_durationImmutable'
        QtMocHelpers::PropertyData<bool>(415, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColor_durationValue'
        QtMocHelpers::PropertyData<QString>(416, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'image_duration'
        QtMocHelpers::PropertyData<QString>(417, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 21),
        // property 'isImage_durationImmutable'
        QtMocHelpers::PropertyData<bool>(418, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultImage_durationValue'
        QtMocHelpers::PropertyData<QString>(419, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sequence_duration'
        QtMocHelpers::PropertyData<QString>(420, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 22),
        // property 'isSequence_durationImmutable'
        QtMocHelpers::PropertyData<bool>(421, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSequence_durationValue'
        QtMocHelpers::PropertyData<QString>(422, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fade_duration'
        QtMocHelpers::PropertyData<QString>(423, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 23),
        // property 'isFade_durationImmutable'
        QtMocHelpers::PropertyData<bool>(424, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFade_durationValue'
        QtMocHelpers::PropertyData<QString>(425, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mix_duration'
        QtMocHelpers::PropertyData<QString>(426, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 24),
        // property 'isMix_durationImmutable'
        QtMocHelpers::PropertyData<bool>(427, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMix_durationValue'
        QtMocHelpers::PropertyData<QString>(428, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'subtitle_duration'
        QtMocHelpers::PropertyData<QString>(429, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 25),
        // property 'isSubtitle_durationImmutable'
        QtMocHelpers::PropertyData<bool>(430, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSubtitle_durationValue'
        QtMocHelpers::PropertyData<QString>(431, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoimagesequence'
        QtMocHelpers::PropertyData<bool>(432, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 26),
        // property 'isAutoimagesequenceImmutable'
        QtMocHelpers::PropertyData<bool>(433, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoimagesequenceValue'
        QtMocHelpers::PropertyData<bool>(434, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ignoresubdirstructure'
        QtMocHelpers::PropertyData<bool>(435, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 27),
        // property 'isIgnoresubdirstructureImmutable'
        QtMocHelpers::PropertyData<bool>(436, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultIgnoresubdirstructureValue'
        QtMocHelpers::PropertyData<bool>(437, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disableimagescaling'
        QtMocHelpers::PropertyData<bool>(438, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 28),
        // property 'isDisableimagescalingImmutable'
        QtMocHelpers::PropertyData<bool>(439, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisableimagescalingValue'
        QtMocHelpers::PropertyData<bool>(440, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'automultistreams'
        QtMocHelpers::PropertyData<bool>(441, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 29),
        // property 'isAutomultistreamsImmutable'
        QtMocHelpers::PropertyData<bool>(442, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutomultistreamsValue'
        QtMocHelpers::PropertyData<bool>(443, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'use_exiftool'
        QtMocHelpers::PropertyData<bool>(444, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 30),
        // property 'isUse_exiftoolImmutable'
        QtMocHelpers::PropertyData<bool>(445, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUse_exiftoolValue'
        QtMocHelpers::PropertyData<bool>(446, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'use_magicLantern'
        QtMocHelpers::PropertyData<bool>(447, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 31),
        // property 'isUse_magicLanternImmutable'
        QtMocHelpers::PropertyData<bool>(448, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUse_magicLanternValue'
        QtMocHelpers::PropertyData<bool>(449, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'title_duration'
        QtMocHelpers::PropertyData<QString>(450, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 32),
        // property 'isTitle_durationImmutable'
        QtMocHelpers::PropertyData<bool>(451, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitle_durationValue'
        QtMocHelpers::PropertyData<QString>(452, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transition_duration'
        QtMocHelpers::PropertyData<QString>(453, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 33),
        // property 'isTransition_durationImmutable'
        QtMocHelpers::PropertyData<bool>(454, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransition_durationValue'
        QtMocHelpers::PropertyData<QString>(455, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableAssetsIncludeList'
        QtMocHelpers::PropertyData<bool>(456, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 34),
        // property 'isEnableAssetsIncludeListImmutable'
        QtMocHelpers::PropertyData<bool>(457, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableAssetsIncludeListValue'
        QtMocHelpers::PropertyData<bool>(458, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'effectsInfoHeight'
        QtMocHelpers::PropertyData<QString>(459, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 35),
        // property 'isEffectsInfoHeightImmutable'
        QtMocHelpers::PropertyData<bool>(460, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showEffectsInfo'
        QtMocHelpers::PropertyData<bool>(461, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 36),
        // property 'isShowEffectsInfoImmutable'
        QtMocHelpers::PropertyData<bool>(462, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowEffectsInfoValue'
        QtMocHelpers::PropertyData<bool>(463, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionsInfoHeight'
        QtMocHelpers::PropertyData<QString>(464, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 37),
        // property 'isTransitionsInfoHeightImmutable'
        QtMocHelpers::PropertyData<bool>(465, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showTransitionsInfo'
        QtMocHelpers::PropertyData<bool>(466, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 38),
        // property 'isShowTransitionsInfoImmutable'
        QtMocHelpers::PropertyData<bool>(467, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowTransitionsInfoValue'
        QtMocHelpers::PropertyData<bool>(468, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disable_effect_parameters'
        QtMocHelpers::PropertyData<bool>(469, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 39),
        // property 'isDisable_effect_parametersImmutable'
        QtMocHelpers::PropertyData<bool>(470, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisable_effect_parametersValue'
        QtMocHelpers::PropertyData<bool>(471, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profile_fps_filter'
        QtMocHelpers::PropertyData<QString>(472, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 40),
        // property 'isProfile_fps_filterImmutable'
        QtMocHelpers::PropertyData<bool>(473, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'profile_scanning_filter'
        QtMocHelpers::PropertyData<QString>(474, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 41),
        // property 'isProfile_scanning_filterImmutable'
        QtMocHelpers::PropertyData<bool>(475, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'opengl_backend'
        QtMocHelpers::PropertyData<int>(476, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 42),
        // property 'isOpengl_backendImmutable'
        QtMocHelpers::PropertyData<bool>(477, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOpengl_backendValue'
        QtMocHelpers::PropertyData<int>(478, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videotracks'
        QtMocHelpers::PropertyData<int>(479, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 43),
        // property 'isVideotracksImmutable'
        QtMocHelpers::PropertyData<bool>(480, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideotracksValue'
        QtMocHelpers::PropertyData<int>(481, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiotracks'
        QtMocHelpers::PropertyData<int>(482, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 44),
        // property 'isAudiotracksImmutable'
        QtMocHelpers::PropertyData<bool>(483, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiotracksValue'
        QtMocHelpers::PropertyData<int>(484, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audio_channels'
        QtMocHelpers::PropertyData<int>(485, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 45),
        // property 'isAudio_channelsImmutable'
        QtMocHelpers::PropertyData<bool>(486, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudio_channelsValue'
        QtMocHelpers::PropertyData<int>(487, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableproxy'
        QtMocHelpers::PropertyData<bool>(488, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 46),
        // property 'isEnableproxyImmutable'
        QtMocHelpers::PropertyData<bool>(489, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableproxyValue'
        QtMocHelpers::PropertyData<bool>(490, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'externalproxy'
        QtMocHelpers::PropertyData<bool>(491, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 47),
        // property 'isExternalproxyImmutable'
        QtMocHelpers::PropertyData<bool>(492, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExternalproxyValue'
        QtMocHelpers::PropertyData<bool>(493, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'generateproxy'
        QtMocHelpers::PropertyData<bool>(494, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 48),
        // property 'isGenerateproxyImmutable'
        QtMocHelpers::PropertyData<bool>(495, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGenerateproxyValue'
        QtMocHelpers::PropertyData<bool>(496, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'external_proxy_profile'
        QtMocHelpers::PropertyData<int>(497, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 49),
        // property 'isExternal_proxy_profileImmutable'
        QtMocHelpers::PropertyData<bool>(498, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'externalProxyProfile'
        QtMocHelpers::PropertyData<QString>(499, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 50),
        // property 'isExternalProxyProfileImmutable'
        QtMocHelpers::PropertyData<bool>(500, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'generateimageproxy'
        QtMocHelpers::PropertyData<bool>(501, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 51),
        // property 'isGenerateimageproxyImmutable'
        QtMocHelpers::PropertyData<bool>(502, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGenerateimageproxyValue'
        QtMocHelpers::PropertyData<bool>(503, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyminsize'
        QtMocHelpers::PropertyData<int>(504, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 52),
        // property 'isProxyminsizeImmutable'
        QtMocHelpers::PropertyData<bool>(505, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyminsizeValue'
        QtMocHelpers::PropertyData<int>(506, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyimageminsize'
        QtMocHelpers::PropertyData<int>(507, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 53),
        // property 'isProxyimageminsizeImmutable'
        QtMocHelpers::PropertyData<bool>(508, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyimageminsizeValue'
        QtMocHelpers::PropertyData<int>(509, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyimagesize'
        QtMocHelpers::PropertyData<int>(510, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 54),
        // property 'isProxyimagesizeImmutable'
        QtMocHelpers::PropertyData<bool>(511, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyimagesizeValue'
        QtMocHelpers::PropertyData<int>(512, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyscale'
        QtMocHelpers::PropertyData<int>(513, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 55),
        // property 'isProxyscaleImmutable'
        QtMocHelpers::PropertyData<bool>(514, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxyscaleValue'
        QtMocHelpers::PropertyData<int>(515, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enforceLowerTrackCompositing'
        QtMocHelpers::PropertyData<bool>(516, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 56),
        // property 'isEnforceLowerTrackCompositingImmutable'
        QtMocHelpers::PropertyData<bool>(517, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnforceLowerTrackCompositingValue'
        QtMocHelpers::PropertyData<bool>(518, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyextension'
        QtMocHelpers::PropertyData<QString>(519, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 57),
        // property 'isProxyextensionImmutable'
        QtMocHelpers::PropertyData<bool>(520, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyparams'
        QtMocHelpers::PropertyData<QString>(521, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 58),
        // property 'isProxyparamsImmutable'
        QtMocHelpers::PropertyData<bool>(522, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxy_profile'
        QtMocHelpers::PropertyData<int>(523, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 59),
        // property 'isProxy_profileImmutable'
        QtMocHelpers::PropertyData<bool>(524, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxy_profileValue'
        QtMocHelpers::PropertyData<int>(525, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyalphaextension'
        QtMocHelpers::PropertyData<QString>(526, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 60),
        // property 'isProxyalphaextensionImmutable'
        QtMocHelpers::PropertyData<bool>(527, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxyalphaparams'
        QtMocHelpers::PropertyData<QString>(528, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 61),
        // property 'isProxyalphaparamsImmutable'
        QtMocHelpers::PropertyData<bool>(529, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alpha_profile'
        QtMocHelpers::PropertyData<int>(530, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 62),
        // property 'isAlpha_profileImmutable'
        QtMocHelpers::PropertyData<bool>(531, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlpha_profileValue'
        QtMocHelpers::PropertyData<int>(532, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transcodeFriendly'
        QtMocHelpers::PropertyData<QString>(533, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 63),
        // property 'isTranscodeFriendlyImmutable'
        QtMocHelpers::PropertyData<bool>(534, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transcodingReplace'
        QtMocHelpers::PropertyData<bool>(535, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 64),
        // property 'isTranscodingReplaceImmutable'
        QtMocHelpers::PropertyData<bool>(536, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTranscodingReplaceValue'
        QtMocHelpers::PropertyData<bool>(537, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'previewextension'
        QtMocHelpers::PropertyData<QString>(538, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 65),
        // property 'isPreviewextensionImmutable'
        QtMocHelpers::PropertyData<bool>(539, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preview_profile'
        QtMocHelpers::PropertyData<int>(540, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 66),
        // property 'isPreview_profileImmutable'
        QtMocHelpers::PropertyData<bool>(541, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPreview_profileValue'
        QtMocHelpers::PropertyData<int>(542, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'previewparams'
        QtMocHelpers::PropertyData<QString>(543, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 67),
        // property 'isPreviewparamsImmutable'
        QtMocHelpers::PropertyData<bool>(544, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'parallelrender'
        QtMocHelpers::PropertyData<bool>(545, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 68),
        // property 'isParallelrenderImmutable'
        QtMocHelpers::PropertyData<bool>(546, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultParallelrenderValue'
        QtMocHelpers::PropertyData<bool>(547, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'renderInterp'
        QtMocHelpers::PropertyData<QString>(548, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 69),
        // property 'isRenderInterpImmutable'
        QtMocHelpers::PropertyData<bool>(549, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRenderInterpValue'
        QtMocHelpers::PropertyData<QString>(550, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'renderDeinterlacer'
        QtMocHelpers::PropertyData<QString>(551, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 70),
        // property 'isRenderDeinterlacerImmutable'
        QtMocHelpers::PropertyData<bool>(552, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRenderDeinterlacerValue'
        QtMocHelpers::PropertyData<QString>(553, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'vaapiEnabled'
        QtMocHelpers::PropertyData<bool>(554, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 71),
        // property 'isVaapiEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(555, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVaapiEnabledValue'
        QtMocHelpers::PropertyData<bool>(556, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'amfEnabled'
        QtMocHelpers::PropertyData<bool>(557, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 72),
        // property 'isAmfEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(558, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAmfEnabledValue'
        QtMocHelpers::PropertyData<bool>(559, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'supportedHWCodecs'
        QtMocHelpers::PropertyData<QStringList>(560, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 73),
        // property 'isSupportedHWCodecsImmutable'
        QtMocHelpers::PropertyData<bool>(561, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nvScalingEnabled'
        QtMocHelpers::PropertyData<bool>(562, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 74),
        // property 'isNvScalingEnabledImmutable'
        QtMocHelpers::PropertyData<bool>(563, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNvScalingEnabledValue'
        QtMocHelpers::PropertyData<bool>(564, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'hwDecoding'
        QtMocHelpers::PropertyData<QString>(565, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 75),
        // property 'isHwDecodingImmutable'
        QtMocHelpers::PropertyData<bool>(566, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showRenderTextParameters'
        QtMocHelpers::PropertyData<bool>(567, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 76),
        // property 'isShowRenderTextParametersImmutable'
        QtMocHelpers::PropertyData<bool>(568, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowRenderTextParametersValue'
        QtMocHelpers::PropertyData<bool>(569, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'headerwidth'
        QtMocHelpers::PropertyData<int>(570, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 77),
        // property 'isHeaderwidthImmutable'
        QtMocHelpers::PropertyData<bool>(571, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultHeaderwidthValue'
        QtMocHelpers::PropertyData<int>(572, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultkeyframeinterp'
        QtMocHelpers::PropertyData<int>(573, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 78),
        // property 'isDefaultkeyframeinterpImmutable'
        QtMocHelpers::PropertyData<bool>(574, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultkeyframeinterpValue'
        QtMocHelpers::PropertyData<int>(575, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timelinechunks'
        QtMocHelpers::PropertyData<int>(576, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 79),
        // property 'isTimelinechunksImmutable'
        QtMocHelpers::PropertyData<bool>(577, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTimelinechunksValue'
        QtMocHelpers::PropertyData<int>(578, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autopreview'
        QtMocHelpers::PropertyData<bool>(579, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 80),
        // property 'isAutopreviewImmutable'
        QtMocHelpers::PropertyData<bool>(580, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutopreviewValue'
        QtMocHelpers::PropertyData<bool>(581, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'draginprogress'
        QtMocHelpers::PropertyData<bool>(582, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 81),
        // property 'isDraginprogressImmutable'
        QtMocHelpers::PropertyData<bool>(583, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDraginprogressValue'
        QtMocHelpers::PropertyData<bool>(584, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxypreview'
        QtMocHelpers::PropertyData<bool>(585, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 82),
        // property 'isProxypreviewImmutable'
        QtMocHelpers::PropertyData<bool>(586, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxypreviewValue'
        QtMocHelpers::PropertyData<bool>(587, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multistream'
        QtMocHelpers::PropertyData<int>(588, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 83),
        // property 'isMultistreamImmutable'
        QtMocHelpers::PropertyData<bool>(589, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMultistreamValue'
        QtMocHelpers::PropertyData<int>(590, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multistream_checktrack'
        QtMocHelpers::PropertyData<bool>(591, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 84),
        // property 'isMultistream_checktrackImmutable'
        QtMocHelpers::PropertyData<bool>(592, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMultistream_checktrackValue'
        QtMocHelpers::PropertyData<bool>(593, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videothumbnails'
        QtMocHelpers::PropertyData<bool>(594, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 85),
        // property 'isVideothumbnailsImmutable'
        QtMocHelpers::PropertyData<bool>(595, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideothumbnailsValue'
        QtMocHelpers::PropertyData<bool>(596, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiothumbnails'
        QtMocHelpers::PropertyData<bool>(597, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 86),
        // property 'isAudiothumbnailsImmutable'
        QtMocHelpers::PropertyData<bool>(598, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiothumbnailsValue'
        QtMocHelpers::PropertyData<bool>(599, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'waveformScaler'
        QtMocHelpers::PropertyData<int>(600, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 87),
        // property 'isWaveformScalerImmutable'
        QtMocHelpers::PropertyData<bool>(601, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWaveformScalerValue'
        QtMocHelpers::PropertyData<int>(602, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showmarkers'
        QtMocHelpers::PropertyData<bool>(603, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 88),
        // property 'isShowmarkersImmutable'
        QtMocHelpers::PropertyData<bool>(604, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowmarkersValue'
        QtMocHelpers::PropertyData<bool>(605, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayallchannels'
        QtMocHelpers::PropertyData<bool>(606, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 89),
        // property 'isDisplayallchannelsImmutable'
        QtMocHelpers::PropertyData<bool>(607, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayallchannelsValue'
        QtMocHelpers::PropertyData<bool>(608, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'normalizechannels'
        QtMocHelpers::PropertyData<bool>(609, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 90),
        // property 'isNormalizechannelsImmutable'
        QtMocHelpers::PropertyData<bool>(610, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNormalizechannelsValue'
        QtMocHelpers::PropertyData<bool>(611, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autotrackheight'
        QtMocHelpers::PropertyData<bool>(612, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 91),
        // property 'isAutotrackheightImmutable'
        QtMocHelpers::PropertyData<bool>(613, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutotrackheightValue'
        QtMocHelpers::PropertyData<bool>(614, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoscroll'
        QtMocHelpers::PropertyData<bool>(615, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 92),
        // property 'isAutoscrollImmutable'
        QtMocHelpers::PropertyData<bool>(616, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoscrollValue'
        QtMocHelpers::PropertyData<bool>(617, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'centeredplayhead'
        QtMocHelpers::PropertyData<bool>(618, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 93),
        // property 'isCenteredplayheadImmutable'
        QtMocHelpers::PropertyData<bool>(619, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCenteredplayheadValue'
        QtMocHelpers::PropertyData<bool>(620, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'jumptostart'
        QtMocHelpers::PropertyData<bool>(621, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 94),
        // property 'isJumptostartImmutable'
        QtMocHelpers::PropertyData<bool>(622, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultJumptostartValue'
        QtMocHelpers::PropertyData<bool>(623, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pauseonseek'
        QtMocHelpers::PropertyData<bool>(624, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 95),
        // property 'isPauseonseekImmutable'
        QtMocHelpers::PropertyData<bool>(625, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPauseonseekValue'
        QtMocHelpers::PropertyData<bool>(626, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'seekonaddeffect'
        QtMocHelpers::PropertyData<bool>(627, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 96),
        // property 'isSeekonaddeffectImmutable'
        QtMocHelpers::PropertyData<bool>(628, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSeekonaddeffectValue'
        QtMocHelpers::PropertyData<bool>(629, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableBuiltInEffects'
        QtMocHelpers::PropertyData<bool>(630, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 97),
        // property 'isEnableBuiltInEffectsImmutable'
        QtMocHelpers::PropertyData<bool>(631, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableBuiltInEffectsValue'
        QtMocHelpers::PropertyData<bool>(632, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tenbitpipeline'
        QtMocHelpers::PropertyData<bool>(633, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 98),
        // property 'isTenbitpipelineImmutable'
        QtMocHelpers::PropertyData<bool>(634, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTenbitpipelineValue'
        QtMocHelpers::PropertyData<bool>(635, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'effectsFilter'
        QtMocHelpers::PropertyData<bool>(636, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 99),
        // property 'isEffectsFilterImmutable'
        QtMocHelpers::PropertyData<bool>(637, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEffectsFilterValue'
        QtMocHelpers::PropertyData<bool>(638, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionsFilter'
        QtMocHelpers::PropertyData<bool>(639, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 100),
        // property 'isTransitionsFilterImmutable'
        QtMocHelpers::PropertyData<bool>(640, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransitionsFilterValue'
        QtMocHelpers::PropertyData<bool>(641, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'scrollvertically'
        QtMocHelpers::PropertyData<bool>(642, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 101),
        // property 'isScrollverticallyImmutable'
        QtMocHelpers::PropertyData<bool>(643, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultScrollverticallyValue'
        QtMocHelpers::PropertyData<bool>(644, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'trackheight'
        QtMocHelpers::PropertyData<int>(645, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 102),
        // property 'isTrackheightImmutable'
        QtMocHelpers::PropertyData<bool>(646, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTrackheightValue'
        QtMocHelpers::PropertyData<int>(647, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiotracksbelow'
        QtMocHelpers::PropertyData<int>(648, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 103),
        // property 'isAudiotracksbelowImmutable'
        QtMocHelpers::PropertyData<bool>(649, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiotracksbelowValue'
        QtMocHelpers::PropertyData<int>(650, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'raisepropsclips'
        QtMocHelpers::PropertyData<bool>(651, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 104),
        // property 'isRaisepropsclipsImmutable'
        QtMocHelpers::PropertyData<bool>(652, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRaisepropsclipsValue'
        QtMocHelpers::PropertyData<bool>(653, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'raisepropscompositions'
        QtMocHelpers::PropertyData<bool>(654, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 105),
        // property 'isRaisepropscompositionsImmutable'
        QtMocHelpers::PropertyData<bool>(655, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRaisepropscompositionsValue'
        QtMocHelpers::PropertyData<bool>(656, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'raisepropsmixes'
        QtMocHelpers::PropertyData<bool>(657, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 106),
        // property 'isRaisepropsmixesImmutable'
        QtMocHelpers::PropertyData<bool>(658, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRaisepropsmixesValue'
        QtMocHelpers::PropertyData<bool>(659, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'raisepropstracks'
        QtMocHelpers::PropertyData<bool>(660, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 107),
        // property 'isRaisepropstracksImmutable'
        QtMocHelpers::PropertyData<bool>(661, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRaisepropstracksValue'
        QtMocHelpers::PropertyData<bool>(662, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'uiDebugMode'
        QtMocHelpers::PropertyData<bool>(663, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 108),
        // property 'isUiDebugModeImmutable'
        QtMocHelpers::PropertyData<bool>(664, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUiDebugModeValue'
        QtMocHelpers::PropertyData<bool>(665, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'gpu_accel'
        QtMocHelpers::PropertyData<bool>(666, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 109),
        // property 'isGpu_accelImmutable'
        QtMocHelpers::PropertyData<bool>(667, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGpu_accelValue'
        QtMocHelpers::PropertyData<bool>(668, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audio_scrub'
        QtMocHelpers::PropertyData<bool>(669, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 110),
        // property 'isAudio_scrubImmutable'
        QtMocHelpers::PropertyData<bool>(670, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudio_scrubValue'
        QtMocHelpers::PropertyData<bool>(671, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sdlAudioBackend'
        QtMocHelpers::PropertyData<QString>(672, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 111),
        // property 'isSdlAudioBackendImmutable'
        QtMocHelpers::PropertyData<bool>(673, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSdlAudioBackendValue'
        QtMocHelpers::PropertyData<QString>(674, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audio_backend'
        QtMocHelpers::PropertyData<int>(675, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 112),
        // property 'isAudio_backendImmutable'
        QtMocHelpers::PropertyData<bool>(676, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudio_backendValue'
        QtMocHelpers::PropertyData<int>(677, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiobackend'
        QtMocHelpers::PropertyData<QString>(678, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 113),
        // property 'isAudiobackendImmutable'
        QtMocHelpers::PropertyData<bool>(679, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiobackendValue'
        QtMocHelpers::PropertyData<QString>(680, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audio_driver'
        QtMocHelpers::PropertyData<uint>(681, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 114),
        // property 'isAudio_driverImmutable'
        QtMocHelpers::PropertyData<bool>(682, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudio_driverValue'
        QtMocHelpers::PropertyData<uint>(683, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiodevicename'
        QtMocHelpers::PropertyData<QString>(684, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 115),
        // property 'isAudiodevicenameImmutable'
        QtMocHelpers::PropertyData<bool>(685, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiodrivername'
        QtMocHelpers::PropertyData<QString>(686, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 116),
        // property 'isAudiodrivernameImmutable'
        QtMocHelpers::PropertyData<bool>(687, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'disablereccountdown'
        QtMocHelpers::PropertyData<bool>(688, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 117),
        // property 'isDisablereccountdownImmutable'
        QtMocHelpers::PropertyData<bool>(689, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisablereccountdownValue'
        QtMocHelpers::PropertyData<bool>(690, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videodrivername'
        QtMocHelpers::PropertyData<QString>(691, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 118),
        // property 'isVideodrivernameImmutable'
        QtMocHelpers::PropertyData<bool>(692, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audio_device'
        QtMocHelpers::PropertyData<int>(693, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 119),
        // property 'isAudio_deviceImmutable'
        QtMocHelpers::PropertyData<bool>(694, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'window_background'
        QtMocHelpers::PropertyData<QColor>(695, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 120),
        // property 'isWindow_backgroundImmutable'
        QtMocHelpers::PropertyData<bool>(697, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWindow_backgroundValue'
        QtMocHelpers::PropertyData<QColor>(698, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showMonitorGrid'
        QtMocHelpers::PropertyData<bool>(699, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 121),
        // property 'isShowMonitorGridImmutable'
        QtMocHelpers::PropertyData<bool>(700, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowMonitorGridValue'
        QtMocHelpers::PropertyData<bool>(701, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitorGridH'
        QtMocHelpers::PropertyData<int>(702, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 122),
        // property 'isMonitorGridHImmutable'
        QtMocHelpers::PropertyData<bool>(703, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitorGridHValue'
        QtMocHelpers::PropertyData<int>(704, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitorGridV'
        QtMocHelpers::PropertyData<int>(705, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 123),
        // property 'isMonitorGridVImmutable'
        QtMocHelpers::PropertyData<bool>(706, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitorGridVValue'
        QtMocHelpers::PropertyData<int>(707, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitor_background'
        QtMocHelpers::PropertyData<QString>(708, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 124),
        // property 'isMonitor_backgroundImmutable'
        QtMocHelpers::PropertyData<bool>(709, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitor_backgroundValue'
        QtMocHelpers::PropertyData<QString>(710, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitor_progressive'
        QtMocHelpers::PropertyData<bool>(711, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 125),
        // property 'isMonitor_progressiveImmutable'
        QtMocHelpers::PropertyData<bool>(712, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitor_progressiveValue'
        QtMocHelpers::PropertyData<bool>(713, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'volume'
        QtMocHelpers::PropertyData<int>(714, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 126),
        // property 'isVolumeImmutable'
        QtMocHelpers::PropertyData<bool>(715, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVolumeValue'
        QtMocHelpers::PropertyData<int>(716, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitor_dropframes'
        QtMocHelpers::PropertyData<bool>(717, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 127),
        // property 'isMonitor_dropframesImmutable'
        QtMocHelpers::PropertyData<bool>(718, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitor_dropframesValue'
        QtMocHelpers::PropertyData<bool>(719, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'external_display'
        QtMocHelpers::PropertyData<bool>(720, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 128),
        // property 'isExternal_displayImmutable'
        QtMocHelpers::PropertyData<bool>(721, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultExternal_displayValue'
        QtMocHelpers::PropertyData<bool>(722, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'blackmagic_output_device'
        QtMocHelpers::PropertyData<int>(723, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 129),
        // property 'isBlackmagic_output_deviceImmutable'
        QtMocHelpers::PropertyData<bool>(724, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBlackmagic_output_deviceValue'
        QtMocHelpers::PropertyData<int>(725, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'play_monitor_on_click'
        QtMocHelpers::PropertyData<bool>(726, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 130),
        // property 'isPlay_monitor_on_clickImmutable'
        QtMocHelpers::PropertyData<bool>(727, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPlay_monitor_on_clickValue'
        QtMocHelpers::PropertyData<bool>(728, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mirrorMonitorOnFullscreen'
        QtMocHelpers::PropertyData<bool>(729, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 131),
        // property 'isMirrorMonitorOnFullscreenImmutable'
        QtMocHelpers::PropertyData<bool>(730, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMirrorMonitorOnFullscreenValue'
        QtMocHelpers::PropertyData<bool>(731, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'fullscreen_monitor'
        QtMocHelpers::PropertyData<QString>(732, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 132),
        // property 'isFullscreen_monitorImmutable'
        QtMocHelpers::PropertyData<bool>(733, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'project_monitor_fullscreen'
        QtMocHelpers::PropertyData<QString>(734, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 133),
        // property 'isProject_monitor_fullscreenImmutable'
        QtMocHelpers::PropertyData<bool>(735, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clip_monitor_fullscreen'
        QtMocHelpers::PropertyData<QString>(736, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 134),
        // property 'isClip_monitor_fullscreenImmutable'
        QtMocHelpers::PropertyData<bool>(737, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'preferredcomposite'
        QtMocHelpers::PropertyData<QString>(738, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 135),
        // property 'isPreferredcompositeImmutable'
        QtMocHelpers::PropertyData<bool>(739, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'compositingList'
        QtMocHelpers::PropertyData<QStringList>(740, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 136),
        // property 'isCompositingListImmutable'
        QtMocHelpers::PropertyData<bool>(741, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCompositingListValue'
        QtMocHelpers::PropertyData<QStringList>(742, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'subtitle_razor_mode'
        QtMocHelpers::PropertyData<int>(743, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 137),
        // property 'isSubtitle_razor_modeImmutable'
        QtMocHelpers::PropertyData<bool>(744, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSubtitle_razor_modeValue'
        QtMocHelpers::PropertyData<int>(745, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mltpath'
        QtMocHelpers::PropertyData<QString>(746, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 138),
        // property 'isMltpathImmutable'
        QtMocHelpers::PropertyData<bool>(747, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'kdenliverendererpath'
        QtMocHelpers::PropertyData<QString>(748, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 139),
        // property 'isKdenliverendererpathImmutable'
        QtMocHelpers::PropertyData<bool>(749, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'meltpath'
        QtMocHelpers::PropertyData<QString>(750, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 140),
        // property 'isMeltpathImmutable'
        QtMocHelpers::PropertyData<bool>(751, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ffmpegpath'
        QtMocHelpers::PropertyData<QString>(752, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 141),
        // property 'isFfmpegpathImmutable'
        QtMocHelpers::PropertyData<bool>(753, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ffplaypath'
        QtMocHelpers::PropertyData<QString>(754, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 142),
        // property 'isFfplaypathImmutable'
        QtMocHelpers::PropertyData<bool>(755, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'ffprobepath'
        QtMocHelpers::PropertyData<QString>(756, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 143),
        // property 'isFfprobepathImmutable'
        QtMocHelpers::PropertyData<bool>(757, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'processingthreads'
        QtMocHelpers::PropertyData<int>(758, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 144),
        // property 'isProcessingthreadsImmutable'
        QtMocHelpers::PropertyData<bool>(759, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProcessingthreadsValue'
        QtMocHelpers::PropertyData<int>(760, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'proxythreads'
        QtMocHelpers::PropertyData<int>(761, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 145),
        // property 'isProxythreadsImmutable'
        QtMocHelpers::PropertyData<bool>(762, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProxythreadsValue'
        QtMocHelpers::PropertyData<int>(763, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'encodethreads'
        QtMocHelpers::PropertyData<int>(764, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 146),
        // property 'isEncodethreadsImmutable'
        QtMocHelpers::PropertyData<bool>(765, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEncodethreadsValue'
        QtMocHelpers::PropertyData<int>(766, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'currenttmpfolder'
        QtMocHelpers::PropertyData<QString>(767, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 147),
        // property 'isCurrenttmpfolderImmutable'
        QtMocHelpers::PropertyData<bool>(768, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCurrenttmpfolderValue'
        QtMocHelpers::PropertyData<QString>(769, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maxcachesize'
        QtMocHelpers::PropertyData<int>(770, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 148),
        // property 'isMaxcachesizeImmutable'
        QtMocHelpers::PropertyData<bool>(771, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaxcachesizeValue'
        QtMocHelpers::PropertyData<int>(772, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'checkForUpdate'
        QtMocHelpers::PropertyData<bool>(773, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 149),
        // property 'isCheckForUpdateImmutable'
        QtMocHelpers::PropertyData<bool>(774, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCheckForUpdateValue'
        QtMocHelpers::PropertyData<bool>(775, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'usePowerManagement'
        QtMocHelpers::PropertyData<bool>(776, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 150),
        // property 'isUsePowerManagementImmutable'
        QtMocHelpers::PropertyData<bool>(777, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUsePowerManagementValue'
        QtMocHelpers::PropertyData<bool>(778, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastCacheCheck'
        QtMocHelpers::PropertyData<QDateTime>(779, QMetaType::QDateTime, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 151),
        // property 'isLastCacheCheckImmutable'
        QtMocHelpers::PropertyData<bool>(780, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultprojectfolder'
        QtMocHelpers::PropertyData<QString>(781, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 152),
        // property 'isDefaultprojectfolderImmutable'
        QtMocHelpers::PropertyData<bool>(782, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'customprojectfolder'
        QtMocHelpers::PropertyData<bool>(783, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 153),
        // property 'isCustomprojectfolderImmutable'
        QtMocHelpers::PropertyData<bool>(784, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCustomprojectfolderValue'
        QtMocHelpers::PropertyData<bool>(785, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sameprojectfolder'
        QtMocHelpers::PropertyData<bool>(786, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 154),
        // property 'isSameprojectfolderImmutable'
        QtMocHelpers::PropertyData<bool>(787, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSameprojectfolderValue'
        QtMocHelpers::PropertyData<bool>(788, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'capturetoprojectfolder'
        QtMocHelpers::PropertyData<int>(789, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 155),
        // property 'isCapturetoprojectfolderImmutable'
        QtMocHelpers::PropertyData<bool>(790, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCapturetoprojectfolderValue'
        QtMocHelpers::PropertyData<int>(791, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'capturefolder'
        QtMocHelpers::PropertyData<QString>(792, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 156),
        // property 'isCapturefolderImmutable'
        QtMocHelpers::PropertyData<bool>(793, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCapturefolderValue'
        QtMocHelpers::PropertyData<QString>(794, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureprojectsubfolder'
        QtMocHelpers::PropertyData<QString>(795, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 157),
        // property 'isCaptureprojectsubfolderImmutable'
        QtMocHelpers::PropertyData<bool>(796, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'librarytodefaultfolder'
        QtMocHelpers::PropertyData<bool>(797, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 158),
        // property 'isLibrarytodefaultfolderImmutable'
        QtMocHelpers::PropertyData<bool>(798, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLibrarytodefaultfolderValue'
        QtMocHelpers::PropertyData<bool>(799, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videotodefaultfolder'
        QtMocHelpers::PropertyData<int>(800, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 159),
        // property 'isVideotodefaultfolderImmutable'
        QtMocHelpers::PropertyData<bool>(801, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultVideotodefaultfolderValue'
        QtMocHelpers::PropertyData<int>(802, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'libraryfolder'
        QtMocHelpers::PropertyData<QString>(803, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 160),
        // property 'isLibraryfolderImmutable'
        QtMocHelpers::PropertyData<bool>(804, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'videofolder'
        QtMocHelpers::PropertyData<QString>(805, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 161),
        // property 'isVideofolderImmutable'
        QtMocHelpers::PropertyData<bool>(806, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultimageapp'
        QtMocHelpers::PropertyData<QString>(807, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 162),
        // property 'isDefaultimageappImmutable'
        QtMocHelpers::PropertyData<bool>(808, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultaudioapp'
        QtMocHelpers::PropertyData<QString>(809, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 163),
        // property 'isDefaultaudioappImmutable'
        QtMocHelpers::PropertyData<bool>(810, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'glaxnimatePath'
        QtMocHelpers::PropertyData<QString>(811, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 164),
        // property 'isGlaxnimatePathImmutable'
        QtMocHelpers::PropertyData<bool>(812, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultvideoapp'
        QtMocHelpers::PropertyData<QString>(813, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 165),
        // property 'isDefaultvideoappImmutable'
        QtMocHelpers::PropertyData<bool>(814, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'nice_tasks'
        QtMocHelpers::PropertyData<bool>(815, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 166),
        // property 'isNice_tasksImmutable'
        QtMocHelpers::PropertyData<bool>(816, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultNice_tasksValue'
        QtMocHelpers::PropertyData<bool>(817, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'exportGuidesFormat'
        QtMocHelpers::PropertyData<QString>(818, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 167),
        // property 'isExportGuidesFormatImmutable'
        QtMocHelpers::PropertyData<bool>(819, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'multipleguidesinterval'
        QtMocHelpers::PropertyData<double>(820, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 168),
        // property 'isMultipleguidesintervalImmutable'
        QtMocHelpers::PropertyData<bool>(821, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMultipleguidesintervalValue'
        QtMocHelpers::PropertyData<double>(822, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guidesShowThumbs'
        QtMocHelpers::PropertyData<bool>(823, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 169),
        // property 'isGuidesShowThumbsImmutable'
        QtMocHelpers::PropertyData<bool>(824, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGuidesShowThumbsValue'
        QtMocHelpers::PropertyData<bool>(825, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guidesSelectZone'
        QtMocHelpers::PropertyData<bool>(826, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 170),
        // property 'isGuidesSelectZoneImmutable'
        QtMocHelpers::PropertyData<bool>(827, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGuidesSelectZoneValue'
        QtMocHelpers::PropertyData<bool>(828, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultaudiocapture'
        QtMocHelpers::PropertyData<QString>(829, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 171),
        // property 'isDefaultaudiocaptureImmutable'
        QtMocHelpers::PropertyData<bool>(830, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultaudiocaptureValue'
        QtMocHelpers::PropertyData<QString>(831, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiocapturevolume'
        QtMocHelpers::PropertyData<int>(832, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 172),
        // property 'isAudiocapturevolumeImmutable'
        QtMocHelpers::PropertyData<bool>(833, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiocapturevolumeValue'
        QtMocHelpers::PropertyData<int>(834, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiocapturechannels'
        QtMocHelpers::PropertyData<int>(835, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 173),
        // property 'isAudiocapturechannelsImmutable'
        QtMocHelpers::PropertyData<bool>(836, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiocapturechannelsValue'
        QtMocHelpers::PropertyData<int>(837, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiocapturesamplerate'
        QtMocHelpers::PropertyData<int>(838, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 174),
        // property 'isAudiocapturesamplerateImmutable'
        QtMocHelpers::PropertyData<bool>(839, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiocapturesamplerateValue'
        QtMocHelpers::PropertyData<int>(840, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'audiocapturesampleformat'
        QtMocHelpers::PropertyData<int>(841, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 175),
        // property 'isAudiocapturesampleformatImmutable'
        QtMocHelpers::PropertyData<bool>(842, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAudiocapturesampleformatValue'
        QtMocHelpers::PropertyData<int>(843, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultcapture'
        QtMocHelpers::PropertyData<int>(844, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 176),
        // property 'isDefaultcaptureImmutable'
        QtMocHelpers::PropertyData<bool>(845, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultcaptureValue'
        QtMocHelpers::PropertyData<int>(846, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alsachannels'
        QtMocHelpers::PropertyData<uint>(847, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 177),
        // property 'isAlsachannelsImmutable'
        QtMocHelpers::PropertyData<bool>(848, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlsachannelsValue'
        QtMocHelpers::PropertyData<uint>(849, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_profile'
        QtMocHelpers::PropertyData<int>(850, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 178),
        // property 'isGrab_profileImmutable'
        QtMocHelpers::PropertyData<bool>(851, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_profileValue'
        QtMocHelpers::PropertyData<int>(852, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_parameters'
        QtMocHelpers::PropertyData<QString>(853, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 179),
        // property 'isGrab_parametersImmutable'
        QtMocHelpers::PropertyData<bool>(854, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_extension'
        QtMocHelpers::PropertyData<QString>(855, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 180),
        // property 'isGrab_extensionImmutable'
        QtMocHelpers::PropertyData<bool>(856, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_capture_type'
        QtMocHelpers::PropertyData<int>(857, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 181),
        // property 'isGrab_capture_typeImmutable'
        QtMocHelpers::PropertyData<bool>(858, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_capture_typeValue'
        QtMocHelpers::PropertyData<int>(859, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_follow_mouse'
        QtMocHelpers::PropertyData<bool>(860, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 182),
        // property 'isGrab_follow_mouseImmutable'
        QtMocHelpers::PropertyData<bool>(861, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_follow_mouseValue'
        QtMocHelpers::PropertyData<bool>(862, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_offsetx'
        QtMocHelpers::PropertyData<int>(863, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 183),
        // property 'isGrab_offsetxImmutable'
        QtMocHelpers::PropertyData<bool>(864, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_offsetxValue'
        QtMocHelpers::PropertyData<int>(865, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_offsety'
        QtMocHelpers::PropertyData<int>(866, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 184),
        // property 'isGrab_offsetyImmutable'
        QtMocHelpers::PropertyData<bool>(867, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_offsetyValue'
        QtMocHelpers::PropertyData<int>(868, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_width'
        QtMocHelpers::PropertyData<int>(869, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 185),
        // property 'isGrab_widthImmutable'
        QtMocHelpers::PropertyData<bool>(870, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_widthValue'
        QtMocHelpers::PropertyData<int>(871, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_height'
        QtMocHelpers::PropertyData<int>(872, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 186),
        // property 'isGrab_heightImmutable'
        QtMocHelpers::PropertyData<bool>(873, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_heightValue'
        QtMocHelpers::PropertyData<int>(874, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_fps'
        QtMocHelpers::PropertyData<double>(875, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 187),
        // property 'isGrab_fpsImmutable'
        QtMocHelpers::PropertyData<bool>(876, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_fpsValue'
        QtMocHelpers::PropertyData<double>(877, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_hide_frame'
        QtMocHelpers::PropertyData<bool>(878, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 188),
        // property 'isGrab_hide_frameImmutable'
        QtMocHelpers::PropertyData<bool>(879, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_hide_frameValue'
        QtMocHelpers::PropertyData<bool>(880, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'grab_hide_mouse'
        QtMocHelpers::PropertyData<bool>(881, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 189),
        // property 'isGrab_hide_mouseImmutable'
        QtMocHelpers::PropertyData<bool>(882, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultGrab_hide_mouseValue'
        QtMocHelpers::PropertyData<bool>(883, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_device_found'
        QtMocHelpers::PropertyData<bool>(884, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 190),
        // property 'isDecklink_device_foundImmutable'
        QtMocHelpers::PropertyData<bool>(885, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecklink_device_foundValue'
        QtMocHelpers::PropertyData<bool>(886, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_capturedevice'
        QtMocHelpers::PropertyData<uint>(887, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 191),
        // property 'isDecklink_capturedeviceImmutable'
        QtMocHelpers::PropertyData<bool>(888, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecklink_capturedeviceValue'
        QtMocHelpers::PropertyData<uint>(889, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_profile'
        QtMocHelpers::PropertyData<int>(890, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 192),
        // property 'isDecklink_profileImmutable'
        QtMocHelpers::PropertyData<bool>(891, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecklink_profileValue'
        QtMocHelpers::PropertyData<int>(892, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_filename'
        QtMocHelpers::PropertyData<QString>(893, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 193),
        // property 'isDecklink_filenameImmutable'
        QtMocHelpers::PropertyData<bool>(894, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDecklink_filenameValue'
        QtMocHelpers::PropertyData<QString>(895, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_parameters'
        QtMocHelpers::PropertyData<QString>(896, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 194),
        // property 'isDecklink_parametersImmutable'
        QtMocHelpers::PropertyData<bool>(897, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'decklink_extension'
        QtMocHelpers::PropertyData<QString>(898, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 195),
        // property 'isDecklink_extensionImmutable'
        QtMocHelpers::PropertyData<bool>(899, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableshuttle'
        QtMocHelpers::PropertyData<bool>(900, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 196),
        // property 'isEnableshuttleImmutable'
        QtMocHelpers::PropertyData<bool>(901, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableshuttleValue'
        QtMocHelpers::PropertyData<bool>(902, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shuttledevice'
        QtMocHelpers::PropertyData<QString>(903, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 197),
        // property 'isShuttledeviceImmutable'
        QtMocHelpers::PropertyData<bool>(904, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shuttledevicenames'
        QtMocHelpers::PropertyData<QStringList>(905, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 198),
        // property 'isShuttledevicenamesImmutable'
        QtMocHelpers::PropertyData<bool>(906, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shuttledevicepaths'
        QtMocHelpers::PropertyData<QStringList>(907, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 199),
        // property 'isShuttledevicepathsImmutable'
        QtMocHelpers::PropertyData<bool>(908, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'shuttlebuttons'
        QtMocHelpers::PropertyData<QString>(909, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 200),
        // property 'isShuttlebuttonsImmutable'
        QtMocHelpers::PropertyData<bool>(910, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bezier_gridlines'
        QtMocHelpers::PropertyData<int>(911, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 201),
        // property 'isBezier_gridlinesImmutable'
        QtMocHelpers::PropertyData<bool>(912, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBezier_gridlinesValue'
        QtMocHelpers::PropertyData<int>(913, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bezier_showpixmap'
        QtMocHelpers::PropertyData<bool>(914, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 202),
        // property 'isBezier_showpixmapImmutable'
        QtMocHelpers::PropertyData<bool>(915, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBezier_showpixmapValue'
        QtMocHelpers::PropertyData<bool>(916, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'bezier_showallhandles'
        QtMocHelpers::PropertyData<bool>(917, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 203),
        // property 'isBezier_showallhandlesImmutable'
        QtMocHelpers::PropertyData<bool>(918, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultBezier_showallhandlesValue'
        QtMocHelpers::PropertyData<bool>(919, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dragvalue_mode'
        QtMocHelpers::PropertyData<int>(920, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 204),
        // property 'isDragvalue_modeImmutable'
        QtMocHelpers::PropertyData<bool>(921, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDragvalue_modeValue'
        QtMocHelpers::PropertyData<int>(922, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'dragvalue_directupdate'
        QtMocHelpers::PropertyData<bool>(923, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 205),
        // property 'isDragvalue_directupdateImmutable'
        QtMocHelpers::PropertyData<bool>(924, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDragvalue_directupdateValue'
        QtMocHelpers::PropertyData<bool>(925, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'recentProfiles'
        QtMocHelpers::PropertyData<QStringList>(926, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 206),
        // property 'isRecentProfilesImmutable'
        QtMocHelpers::PropertyData<bool>(927, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'recentProfileNames'
        QtMocHelpers::PropertyData<QStringList>(928, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 207),
        // property 'isRecentProfileNamesImmutable'
        QtMocHelpers::PropertyData<bool>(929, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'properties_panel_page'
        QtMocHelpers::PropertyData<int>(930, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 208),
        // property 'isProperties_panel_pageImmutable'
        QtMocHelpers::PropertyData<bool>(931, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProperties_panel_pageValue'
        QtMocHelpers::PropertyData<int>(932, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'project_fps'
        QtMocHelpers::PropertyData<double>(933, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 209),
        // property 'isProject_fpsImmutable'
        QtMocHelpers::PropertyData<bool>(934, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProject_fpsValue'
        QtMocHelpers::PropertyData<double>(935, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'default_profile'
        QtMocHelpers::PropertyData<QString>(936, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 210),
        // property 'isDefault_profileImmutable'
        QtMocHelpers::PropertyData<bool>(937, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'kdockLayout'
        QtMocHelpers::PropertyData<QString>(938, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 211),
        // property 'isKdockLayoutImmutable'
        QtMocHelpers::PropertyData<bool>(939, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'layoutsOrder'
        QtMocHelpers::PropertyData<QStringList>(940, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 212),
        // property 'isLayoutsOrderImmutable'
        QtMocHelpers::PropertyData<bool>(941, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLayoutsOrderValue'
        QtMocHelpers::PropertyData<QStringList>(942, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showdescriptioncolumn'
        QtMocHelpers::PropertyData<bool>(943, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 213),
        // property 'isShowdescriptioncolumnImmutable'
        QtMocHelpers::PropertyData<bool>(944, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowdescriptioncolumnValue'
        QtMocHelpers::PropertyData<bool>(945, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showratingcolumn'
        QtMocHelpers::PropertyData<bool>(946, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 214),
        // property 'isShowratingcolumnImmutable'
        QtMocHelpers::PropertyData<bool>(947, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowratingcolumnValue'
        QtMocHelpers::PropertyData<bool>(948, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showdatecolumn'
        QtMocHelpers::PropertyData<bool>(949, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 215),
        // property 'isShowdatecolumnImmutable'
        QtMocHelpers::PropertyData<bool>(950, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowdatecolumnValue'
        QtMocHelpers::PropertyData<bool>(951, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'frametimecode'
        QtMocHelpers::PropertyData<bool>(952, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 216),
        // property 'isFrametimecodeImmutable'
        QtMocHelpers::PropertyData<bool>(953, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFrametimecodeValue'
        QtMocHelpers::PropertyData<bool>(954, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rectimecode'
        QtMocHelpers::PropertyData<bool>(955, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 217),
        // property 'isRectimecodeImmutable'
        QtMocHelpers::PropertyData<bool>(956, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRectimecodeValue'
        QtMocHelpers::PropertyData<bool>(957, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'snaptopoints'
        QtMocHelpers::PropertyData<bool>(958, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 218),
        // property 'isSnaptopointsImmutable'
        QtMocHelpers::PropertyData<bool>(959, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSnaptopointsValue'
        QtMocHelpers::PropertyData<bool>(960, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showClipOverlays'
        QtMocHelpers::PropertyData<bool>(961, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 219),
        // property 'isShowClipOverlaysImmutable'
        QtMocHelpers::PropertyData<bool>(962, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowClipOverlaysValue'
        QtMocHelpers::PropertyData<bool>(963, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'rippleResize'
        QtMocHelpers::PropertyData<bool>(964, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 220),
        // property 'isRippleResizeImmutable'
        QtMocHelpers::PropertyData<bool>(965, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRippleResizeValue'
        QtMocHelpers::PropertyData<bool>(966, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lockedGuides'
        QtMocHelpers::PropertyData<bool>(967, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 221),
        // property 'isLockedGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(968, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLockedGuidesValue'
        QtMocHelpers::PropertyData<bool>(969, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'guidesCategories'
        QtMocHelpers::PropertyData<QStringList>(970, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 222),
        // property 'isGuidesCategoriesImmutable'
        QtMocHelpers::PropertyData<bool>(971, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'tagsintimeline'
        QtMocHelpers::PropertyData<bool>(972, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 223),
        // property 'isTagsintimelineImmutable'
        QtMocHelpers::PropertyData<bool>(973, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTagsintimelineValue'
        QtMocHelpers::PropertyData<bool>(974, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'timelinemousezoomonplayhead'
        QtMocHelpers::PropertyData<bool>(975, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 224),
        // property 'isTimelinemousezoomonplayheadImmutable'
        QtMocHelpers::PropertyData<bool>(976, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTimelinemousezoomonplayheadValue'
        QtMocHelpers::PropertyData<bool>(977, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionfollowcursor'
        QtMocHelpers::PropertyData<bool>(978, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 225),
        // property 'isTransitionfollowcursorImmutable'
        QtMocHelpers::PropertyData<bool>(979, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransitionfollowcursorValue'
        QtMocHelpers::PropertyData<bool>(980, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keyframeseek'
        QtMocHelpers::PropertyData<bool>(981, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 226),
        // property 'isKeyframeseekImmutable'
        QtMocHelpers::PropertyData<bool>(982, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeyframeseekValue'
        QtMocHelpers::PropertyData<bool>(983, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showeffectinfo'
        QtMocHelpers::PropertyData<bool>(984, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 227),
        // property 'isShoweffectinfoImmutable'
        QtMocHelpers::PropertyData<bool>(985, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShoweffectinfoValue'
        QtMocHelpers::PropertyData<bool>(986, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applyEffectParamsToGroup'
        QtMocHelpers::PropertyData<bool>(987, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 228),
        // property 'isApplyEffectParamsToGroupImmutable'
        QtMocHelpers::PropertyData<bool>(988, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultApplyEffectParamsToGroupValue'
        QtMocHelpers::PropertyData<bool>(989, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'applyEffectParamsToGroupWithSameValue'
        QtMocHelpers::PropertyData<bool>(990, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 229),
        // property 'isApplyEffectParamsToGroupWithSameValueImmutable'
        QtMocHelpers::PropertyData<bool>(991, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultApplyEffectParamsToGroupWithSameValueValue'
        QtMocHelpers::PropertyData<bool>(992, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'renderProfile'
        QtMocHelpers::PropertyData<QString>(993, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 230),
        // property 'isRenderProfileImmutable'
        QtMocHelpers::PropertyData<bool>(994, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultRenderProfileValue'
        QtMocHelpers::PropertyData<QString>(995, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'keepRenderLogFiles'
        QtMocHelpers::PropertyData<bool>(996, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 231),
        // property 'isKeepRenderLogFilesImmutable'
        QtMocHelpers::PropertyData<bool>(997, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultKeepRenderLogFilesValue'
        QtMocHelpers::PropertyData<bool>(998, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'validated_luts'
        QtMocHelpers::PropertyData<QStringList>(999, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 232),
        // property 'isValidated_lutsImmutable'
        QtMocHelpers::PropertyData<bool>(1000, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayClipMonitorInfo'
        QtMocHelpers::PropertyData<int>(1001, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 233),
        // property 'isDisplayClipMonitorInfoImmutable'
        QtMocHelpers::PropertyData<bool>(1002, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayClipMonitorInfoValue'
        QtMocHelpers::PropertyData<int>(1003, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showClipMonitorSafeZone'
        QtMocHelpers::PropertyData<bool>(1004, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 234),
        // property 'isShowClipMonitorSafeZoneImmutable'
        QtMocHelpers::PropertyData<bool>(1005, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowClipMonitorSafeZoneValue'
        QtMocHelpers::PropertyData<bool>(1006, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showProjectMonitorSafeZone'
        QtMocHelpers::PropertyData<bool>(1007, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 235),
        // property 'isShowProjectMonitorSafeZoneImmutable'
        QtMocHelpers::PropertyData<bool>(1008, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowProjectMonitorSafeZoneValue'
        QtMocHelpers::PropertyData<bool>(1009, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayProjectMonitorInfo'
        QtMocHelpers::PropertyData<int>(1010, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 236),
        // property 'isDisplayProjectMonitorInfoImmutable'
        QtMocHelpers::PropertyData<bool>(1011, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayProjectMonitorInfoValue'
        QtMocHelpers::PropertyData<int>(1012, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'previewScaling'
        QtMocHelpers::PropertyData<int>(1013, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 237),
        // property 'isPreviewScalingImmutable'
        QtMocHelpers::PropertyData<bool>(1014, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultPreviewScalingValue'
        QtMocHelpers::PropertyData<int>(1015, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoKeyframe'
        QtMocHelpers::PropertyData<bool>(1016, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 238),
        // property 'isAutoKeyframeImmutable'
        QtMocHelpers::PropertyData<bool>(1017, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAutoKeyframeValue'
        QtMocHelpers::PropertyData<bool>(1018, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limitAutoKeyframes'
        QtMocHelpers::PropertyData<int>(1019, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 239),
        // property 'isLimitAutoKeyframesImmutable'
        QtMocHelpers::PropertyData<bool>(1020, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLimitAutoKeyframesValue'
        QtMocHelpers::PropertyData<int>(1021, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'limitAutoKeyframesInterval'
        QtMocHelpers::PropertyData<int>(1022, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 240),
        // property 'isLimitAutoKeyframesIntervalImmutable'
        QtMocHelpers::PropertyData<bool>(1023, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLimitAutoKeyframesIntervalValue'
        QtMocHelpers::PropertyData<int>(1024, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maskOpacity'
        QtMocHelpers::PropertyData<int>(1025, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 241),
        // property 'isMaskOpacityImmutable'
        QtMocHelpers::PropertyData<bool>(1026, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaskOpacityValue'
        QtMocHelpers::PropertyData<int>(1027, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maskInverted'
        QtMocHelpers::PropertyData<bool>(1028, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 242),
        // property 'isMaskInvertedImmutable'
        QtMocHelpers::PropertyData<bool>(1029, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaskInvertedValue'
        QtMocHelpers::PropertyData<bool>(1030, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'clipMonitorOverlayGuides'
        QtMocHelpers::PropertyData<int>(1031, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 243),
        // property 'isClipMonitorOverlayGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(1032, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultClipMonitorOverlayGuidesValue'
        QtMocHelpers::PropertyData<int>(1033, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'projectMonitorOverlayGuides'
        QtMocHelpers::PropertyData<int>(1034, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 244),
        // property 'isProjectMonitorOverlayGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(1035, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProjectMonitorOverlayGuidesValue'
        QtMocHelpers::PropertyData<int>(1036, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'alwaysShowMonitorAudio'
        QtMocHelpers::PropertyData<bool>(1037, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 245),
        // property 'isAlwaysShowMonitorAudioImmutable'
        QtMocHelpers::PropertyData<bool>(1038, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAlwaysShowMonitorAudioValue'
        QtMocHelpers::PropertyData<bool>(1039, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'displayAudioOverlay'
        QtMocHelpers::PropertyData<bool>(1040, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 246),
        // property 'isDisplayAudioOverlayImmutable'
        QtMocHelpers::PropertyData<bool>(1041, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDisplayAudioOverlayValue'
        QtMocHelpers::PropertyData<bool>(1042, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitoraudio'
        QtMocHelpers::PropertyData<int>(1043, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 247),
        // property 'isMonitoraudioImmutable'
        QtMocHelpers::PropertyData<bool>(1044, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitoraudioValue'
        QtMocHelpers::PropertyData<int>(1045, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showOnMonitorScene'
        QtMocHelpers::PropertyData<bool>(1046, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 248),
        // property 'isShowOnMonitorSceneImmutable'
        QtMocHelpers::PropertyData<bool>(1047, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowOnMonitorSceneValue'
        QtMocHelpers::PropertyData<bool>(1048, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'autoaudiodrivername'
        QtMocHelpers::PropertyData<QString>(1049, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 249),
        // property 'isAutoaudiodrivernameImmutable'
        QtMocHelpers::PropertyData<bool>(1050, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mixerCollapse'
        QtMocHelpers::PropertyData<bool>(1051, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 250),
        // property 'isMixerCollapseImmutable'
        QtMocHelpers::PropertyData<bool>(1052, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMixerCollapseValue'
        QtMocHelpers::PropertyData<bool>(1053, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'consumerslist'
        QtMocHelpers::PropertyData<QStringList>(1054, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 251),
        // property 'isConsumerslistImmutable'
        QtMocHelpers::PropertyData<bool>(1055, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'producerslist'
        QtMocHelpers::PropertyData<QStringList>(1056, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 252),
        // property 'isProducerslistImmutable'
        QtMocHelpers::PropertyData<bool>(1057, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'widgetstyle'
        QtMocHelpers::PropertyData<QString>(1058, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 253),
        // property 'isWidgetstyleImmutable'
        QtMocHelpers::PropertyData<bool>(1059, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showslideshowthumbs'
        QtMocHelpers::PropertyData<bool>(1060, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 254),
        // property 'isShowslideshowthumbsImmutable'
        QtMocHelpers::PropertyData<bool>(1061, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowslideshowthumbsValue'
        QtMocHelpers::PropertyData<bool>(1062, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showtitlebars'
        QtMocHelpers::PropertyData<bool>(1063, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 255),
        // property 'isShowtitlebarsImmutable'
        QtMocHelpers::PropertyData<bool>(1064, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowtitlebarsValue'
        QtMocHelpers::PropertyData<bool>(1065, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'colorclipcolor'
        QtMocHelpers::PropertyData<QColor>(1066, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 256),
        // property 'isColorclipcolorImmutable'
        QtMocHelpers::PropertyData<bool>(1067, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultColorclipcolorValue'
        QtMocHelpers::PropertyData<QColor>(1068, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'showSubtitles'
        QtMocHelpers::PropertyData<bool>(1069, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 257),
        // property 'isShowSubtitlesImmutable'
        QtMocHelpers::PropertyData<bool>(1070, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowSubtitlesValue'
        QtMocHelpers::PropertyData<bool>(1071, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'subtitleEditFontSize'
        QtMocHelpers::PropertyData<double>(1072, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 258),
        // property 'isSubtitleEditFontSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1073, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSubtitleEditFontSizeValue'
        QtMocHelpers::PropertyData<double>(1074, QMetaType::Double, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'thumbColor1'
        QtMocHelpers::PropertyData<QColor>(1075, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 259),
        // property 'isThumbColor1Immutable'
        QtMocHelpers::PropertyData<bool>(1076, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultThumbColor1Value'
        QtMocHelpers::PropertyData<QColor>(1077, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'thumbColor2'
        QtMocHelpers::PropertyData<QColor>(1078, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 260),
        // property 'isThumbColor2Immutable'
        QtMocHelpers::PropertyData<bool>(1079, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultThumbColor2Value'
        QtMocHelpers::PropertyData<QColor>(1080, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'overlayColor'
        QtMocHelpers::PropertyData<QColor>(1081, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 261),
        // property 'isOverlayColorImmutable'
        QtMocHelpers::PropertyData<bool>(1082, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOverlayColorValue'
        QtMocHelpers::PropertyData<QColor>(1083, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'safeColor'
        QtMocHelpers::PropertyData<QColor>(1084, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 262),
        // property 'isSafeColorImmutable'
        QtMocHelpers::PropertyData<bool>(1085, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSafeColorValue'
        QtMocHelpers::PropertyData<QColor>(1086, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'defaultrescalewidth'
        QtMocHelpers::PropertyData<int>(1087, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 263),
        // property 'isDefaultrescalewidthImmutable'
        QtMocHelpers::PropertyData<bool>(1088, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultrescalewidthValue'
        QtMocHelpers::PropertyData<int>(1089, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultrescaleheight'
        QtMocHelpers::PropertyData<int>(1090, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 264),
        // property 'isDefaultrescaleheightImmutable'
        QtMocHelpers::PropertyData<bool>(1091, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefaultrescaleheightValue'
        QtMocHelpers::PropertyData<int>(1092, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slideshowbymime'
        QtMocHelpers::PropertyData<bool>(1093, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 265),
        // property 'isSlideshowbymimeImmutable'
        QtMocHelpers::PropertyData<bool>(1094, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSlideshowbymimeValue'
        QtMocHelpers::PropertyData<bool>(1095, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'slideshowmimeextension'
        QtMocHelpers::PropertyData<QString>(1096, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 266),
        // property 'isSlideshowmimeextensionImmutable'
        QtMocHelpers::PropertyData<bool>(1097, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitorscene_directupdate'
        QtMocHelpers::PropertyData<bool>(1098, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 267),
        // property 'isMonitorscene_directupdateImmutable'
        QtMocHelpers::PropertyData<bool>(1099, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitorscene_directupdateValue'
        QtMocHelpers::PropertyData<bool>(1100, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'analyse_stopmotion'
        QtMocHelpers::PropertyData<bool>(1101, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 268),
        // property 'isAnalyse_stopmotionImmutable'
        QtMocHelpers::PropertyData<bool>(1102, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAnalyse_stopmotionValue'
        QtMocHelpers::PropertyData<bool>(1103, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableaudiospectrum'
        QtMocHelpers::PropertyData<bool>(1104, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 269),
        // property 'isEnableaudiospectrumImmutable'
        QtMocHelpers::PropertyData<bool>(1105, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableaudiospectrumValue'
        QtMocHelpers::PropertyData<bool>(1106, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showstopmotionthumbs'
        QtMocHelpers::PropertyData<bool>(1107, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 270),
        // property 'isShowstopmotionthumbsImmutable'
        QtMocHelpers::PropertyData<bool>(1108, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowstopmotionthumbsValue'
        QtMocHelpers::PropertyData<bool>(1109, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'captureinterval'
        QtMocHelpers::PropertyData<int>(1110, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 271),
        // property 'isCaptureintervalImmutable'
        QtMocHelpers::PropertyData<bool>(1111, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCaptureintervalValue'
        QtMocHelpers::PropertyData<int>(1112, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sm_notifytime'
        QtMocHelpers::PropertyData<int>(1113, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 272),
        // property 'isSm_notifytimeImmutable'
        QtMocHelpers::PropertyData<bool>(1114, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSm_notifytimeValue'
        QtMocHelpers::PropertyData<int>(1115, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sm_prenotify'
        QtMocHelpers::PropertyData<bool>(1116, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 273),
        // property 'isSm_prenotifyImmutable'
        QtMocHelpers::PropertyData<bool>(1117, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSm_prenotifyValue'
        QtMocHelpers::PropertyData<bool>(1118, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sm_loop'
        QtMocHelpers::PropertyData<bool>(1119, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 274),
        // property 'isSm_loopImmutable'
        QtMocHelpers::PropertyData<bool>(1120, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSm_loopValue'
        QtMocHelpers::PropertyData<bool>(1121, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sm_playsound'
        QtMocHelpers::PropertyData<bool>(1122, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 275),
        // property 'isSm_playsoundImmutable'
        QtMocHelpers::PropertyData<bool>(1123, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSm_playsoundValue'
        QtMocHelpers::PropertyData<bool>(1124, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sm_framesplayback'
        QtMocHelpers::PropertyData<int>(1125, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 276),
        // property 'isSm_framesplaybackImmutable'
        QtMocHelpers::PropertyData<bool>(1126, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSm_framesplaybackValue'
        QtMocHelpers::PropertyData<int>(1127, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'stopmotioneffect'
        QtMocHelpers::PropertyData<int>(1128, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 277),
        // property 'isStopmotioneffectImmutable'
        QtMocHelpers::PropertyData<bool>(1129, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultStopmotioneffectValue'
        QtMocHelpers::PropertyData<int>(1130, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'onmonitoreffects_cornersshowlines'
        QtMocHelpers::PropertyData<bool>(1131, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 278),
        // property 'isOnmonitoreffects_cornersshowlinesImmutable'
        QtMocHelpers::PropertyData<bool>(1132, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOnmonitoreffects_cornersshowlinesValue'
        QtMocHelpers::PropertyData<bool>(1133, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'onmonitoreffects_geometryshowprevious'
        QtMocHelpers::PropertyData<bool>(1134, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 279),
        // property 'isOnmonitoreffects_geometryshowpreviousImmutable'
        QtMocHelpers::PropertyData<bool>(1135, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOnmonitoreffects_geometryshowpreviousValue'
        QtMocHelpers::PropertyData<bool>(1136, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'onmonitoreffects_geometryshowpath'
        QtMocHelpers::PropertyData<bool>(1137, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 280),
        // property 'isOnmonitoreffects_geometryshowpathImmutable'
        QtMocHelpers::PropertyData<bool>(1138, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOnmonitoreffects_geometryshowpathValue'
        QtMocHelpers::PropertyData<bool>(1139, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'onmonitoreffects_cornersshowcontrols'
        QtMocHelpers::PropertyData<bool>(1140, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 281),
        // property 'isOnmonitoreffects_cornersshowcontrolsImmutable'
        QtMocHelpers::PropertyData<bool>(1141, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultOnmonitoreffects_cornersshowcontrolsValue'
        QtMocHelpers::PropertyData<bool>(1142, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'projectloading_avformatnovalidate'
        QtMocHelpers::PropertyData<bool>(1143, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 282),
        // property 'isProjectloading_avformatnovalidateImmutable'
        QtMocHelpers::PropertyData<bool>(1144, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultProjectloading_avformatnovalidateValue'
        QtMocHelpers::PropertyData<bool>(1145, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'monitor_audio'
        QtMocHelpers::PropertyData<bool>(1146, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 283),
        // property 'isMonitor_audioImmutable'
        QtMocHelpers::PropertyData<bool>(1147, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMonitor_audioValue'
        QtMocHelpers::PropertyData<bool>(1148, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enable_recording_preview'
        QtMocHelpers::PropertyData<bool>(1149, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 284),
        // property 'isEnable_recording_previewImmutable'
        QtMocHelpers::PropertyData<bool>(1150, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnable_recording_previewValue'
        QtMocHelpers::PropertyData<bool>(1151, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'add_new_clip'
        QtMocHelpers::PropertyData<bool>(1152, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 285),
        // property 'isAdd_new_clipImmutable'
        QtMocHelpers::PropertyData<bool>(1153, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdd_new_clipValue'
        QtMocHelpers::PropertyData<bool>(1154, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'add_new_clip_to_folder'
        QtMocHelpers::PropertyData<bool>(1155, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 286),
        // property 'isAdd_new_clip_to_folderImmutable'
        QtMocHelpers::PropertyData<bool>(1156, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultAdd_new_clip_to_folderValue'
        QtMocHelpers::PropertyData<bool>(1157, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'default_marker_type'
        QtMocHelpers::PropertyData<int>(1158, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 287),
        // property 'isDefault_marker_typeImmutable'
        QtMocHelpers::PropertyData<bool>(1159, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultDefault_marker_typeValue'
        QtMocHelpers::PropertyData<int>(1160, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mltdeinterlacer'
        QtMocHelpers::PropertyData<QString>(1161, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 288),
        // property 'isMltdeinterlacerImmutable'
        QtMocHelpers::PropertyData<bool>(1162, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMltdeinterlacerValue'
        QtMocHelpers::PropertyData<QString>(1163, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mltinterpolation'
        QtMocHelpers::PropertyData<QString>(1164, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 289),
        // property 'isMltinterpolationImmutable'
        QtMocHelpers::PropertyData<bool>(1165, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMltinterpolationValue'
        QtMocHelpers::PropertyData<QString>(1166, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'favorite_effects'
        QtMocHelpers::PropertyData<QStringList>(1167, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 290),
        // property 'isFavorite_effectsImmutable'
        QtMocHelpers::PropertyData<bool>(1168, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFavorite_effectsValue'
        QtMocHelpers::PropertyData<QStringList>(1169, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'favorite_transitions'
        QtMocHelpers::PropertyData<QStringList>(1170, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 291),
        // property 'isFavorite_transitionsImmutable'
        QtMocHelpers::PropertyData<bool>(1171, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultFavorite_transitionsValue'
        QtMocHelpers::PropertyData<QStringList>(1172, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'selected_effecttab'
        QtMocHelpers::PropertyData<int>(1173, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 292),
        // property 'isSelected_effecttabImmutable'
        QtMocHelpers::PropertyData<bool>(1174, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSelected_effecttabValue'
        QtMocHelpers::PropertyData<int>(1175, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'effectViewAsIcon'
        QtMocHelpers::PropertyData<bool>(1176, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 293),
        // property 'isEffectViewAsIconImmutable'
        QtMocHelpers::PropertyData<bool>(1177, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEffectViewAsIconValue'
        QtMocHelpers::PropertyData<bool>(1178, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'transitionViewAsIcon'
        QtMocHelpers::PropertyData<bool>(1179, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 294),
        // property 'isTransitionViewAsIconImmutable'
        QtMocHelpers::PropertyData<bool>(1180, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTransitionViewAsIconValue'
        QtMocHelpers::PropertyData<bool>(1181, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'force_breeze'
        QtMocHelpers::PropertyData<bool>(1182, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 295),
        // property 'isForce_breezeImmutable'
        QtMocHelpers::PropertyData<bool>(1183, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultForce_breezeValue'
        QtMocHelpers::PropertyData<bool>(1184, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'use_dark_breeze'
        QtMocHelpers::PropertyData<bool>(1185, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 296),
        // property 'isUse_dark_breezeImmutable'
        QtMocHelpers::PropertyData<bool>(1186, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultUse_dark_breezeValue'
        QtMocHelpers::PropertyData<bool>(1187, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'showWelcome'
        QtMocHelpers::PropertyData<bool>(1188, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 297),
        // property 'isShowWelcomeImmutable'
        QtMocHelpers::PropertyData<bool>(1189, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultShowWelcomeValue'
        QtMocHelpers::PropertyData<bool>(1190, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastSeenVersionMajor'
        QtMocHelpers::PropertyData<int>(1191, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 298),
        // property 'isLastSeenVersionMajorImmutable'
        QtMocHelpers::PropertyData<bool>(1192, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastSeenVersionMajorValue'
        QtMocHelpers::PropertyData<int>(1193, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastSeenVersionMinor'
        QtMocHelpers::PropertyData<int>(1194, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 299),
        // property 'isLastSeenVersionMinorImmutable'
        QtMocHelpers::PropertyData<bool>(1195, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastSeenVersionMinorValue'
        QtMocHelpers::PropertyData<int>(1196, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lastSeenVersionMicro'
        QtMocHelpers::PropertyData<int>(1197, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 300),
        // property 'isLastSeenVersionMicroImmutable'
        QtMocHelpers::PropertyData<bool>(1198, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLastSeenVersionMicroValue'
        QtMocHelpers::PropertyData<int>(1199, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'lock_ratio'
        QtMocHelpers::PropertyData<bool>(1200, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 301),
        // property 'isLock_ratioImmutable'
        QtMocHelpers::PropertyData<bool>(1201, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultLock_ratioValue'
        QtMocHelpers::PropertyData<bool>(1202, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'selected_template'
        QtMocHelpers::PropertyData<QString>(1203, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 302),
        // property 'isSelected_templateImmutable'
        QtMocHelpers::PropertyData<bool>(1204, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerShowGuides'
        QtMocHelpers::PropertyData<bool>(1205, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 303),
        // property 'isTitlerShowGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(1206, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerShowGuidesValue'
        QtMocHelpers::PropertyData<bool>(1207, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerVersion'
        QtMocHelpers::PropertyData<int>(1208, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 304),
        // property 'isTitlerVersionImmutable'
        QtMocHelpers::PropertyData<bool>(1209, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerVersionValue'
        QtMocHelpers::PropertyData<int>(1210, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerHGuides'
        QtMocHelpers::PropertyData<int>(1211, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 305),
        // property 'isTitlerHGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(1212, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerHGuidesValue'
        QtMocHelpers::PropertyData<int>(1213, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerVGuides'
        QtMocHelpers::PropertyData<int>(1214, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 306),
        // property 'isTitlerVGuidesImmutable'
        QtMocHelpers::PropertyData<bool>(1215, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerVGuidesValue'
        QtMocHelpers::PropertyData<int>(1216, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titleGuideColor'
        QtMocHelpers::PropertyData<QColor>(1217, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 307),
        // property 'isTitleGuideColorImmutable'
        QtMocHelpers::PropertyData<bool>(1218, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitleGuideColorValue'
        QtMocHelpers::PropertyData<QColor>(1219, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'titlerbg'
        QtMocHelpers::PropertyData<int>(1220, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 308),
        // property 'isTitlerbgImmutable'
        QtMocHelpers::PropertyData<bool>(1221, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerbgValue'
        QtMocHelpers::PropertyData<int>(1222, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerShowbg'
        QtMocHelpers::PropertyData<bool>(1223, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 309),
        // property 'isTitlerShowbgImmutable'
        QtMocHelpers::PropertyData<bool>(1224, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerShowbgValue'
        QtMocHelpers::PropertyData<bool>(1225, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'titlerAlign'
        QtMocHelpers::PropertyData<int>(1226, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 310),
        // property 'isTitlerAlignImmutable'
        QtMocHelpers::PropertyData<bool>(1227, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultTitlerAlignValue'
        QtMocHelpers::PropertyData<int>(1228, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'samModelFile'
        QtMocHelpers::PropertyData<QString>(1229, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 311),
        // property 'isSamModelFileImmutable'
        QtMocHelpers::PropertyData<bool>(1230, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sam_offload_video'
        QtMocHelpers::PropertyData<bool>(1231, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 312),
        // property 'isSam_offload_videoImmutable'
        QtMocHelpers::PropertyData<bool>(1232, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSam_offload_videoValue'
        QtMocHelpers::PropertyData<bool>(1233, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sam_system_python'
        QtMocHelpers::PropertyData<bool>(1234, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 313),
        // property 'isSam_system_pythonImmutable'
        QtMocHelpers::PropertyData<bool>(1235, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSam_system_pythonValue'
        QtMocHelpers::PropertyData<bool>(1236, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'sam_system_python_path'
        QtMocHelpers::PropertyData<QString>(1237, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 314),
        // property 'isSam_system_python_pathImmutable'
        QtMocHelpers::PropertyData<bool>(1238, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maskBorderWidth'
        QtMocHelpers::PropertyData<int>(1239, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 315),
        // property 'isMaskBorderWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1240, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaskBorderWidthValue'
        QtMocHelpers::PropertyData<int>(1241, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'maskBorderColor'
        QtMocHelpers::PropertyData<QColor>(1242, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 316),
        // property 'isMaskBorderColorImmutable'
        QtMocHelpers::PropertyData<bool>(1243, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaskBorderColorValue'
        QtMocHelpers::PropertyData<QColor>(1244, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'maskColor'
        QtMocHelpers::PropertyData<QColor>(1245, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 317),
        // property 'isMaskColorImmutable'
        QtMocHelpers::PropertyData<bool>(1246, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMaskColorValue'
        QtMocHelpers::PropertyData<QColor>(1247, 0x80000000 | 696, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'speech_system_python'
        QtMocHelpers::PropertyData<bool>(1248, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 318),
        // property 'isSpeech_system_pythonImmutable'
        QtMocHelpers::PropertyData<bool>(1249, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpeech_system_pythonValue'
        QtMocHelpers::PropertyData<bool>(1250, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'speech_system_python_path'
        QtMocHelpers::PropertyData<QString>(1251, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 319),
        // property 'isSpeech_system_python_pathImmutable'
        QtMocHelpers::PropertyData<bool>(1252, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'vosk_folder_path'
        QtMocHelpers::PropertyData<QString>(1253, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 320),
        // property 'isVosk_folder_pathImmutable'
        QtMocHelpers::PropertyData<bool>(1254, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'vosk_text_model'
        QtMocHelpers::PropertyData<QString>(1255, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 321),
        // property 'isVosk_text_modelImmutable'
        QtMocHelpers::PropertyData<bool>(1256, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'vosk_srt_model'
        QtMocHelpers::PropertyData<QString>(1257, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 322),
        // property 'isVosk_srt_modelImmutable'
        QtMocHelpers::PropertyData<bool>(1258, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'speech_zone'
        QtMocHelpers::PropertyData<bool>(1259, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 323),
        // property 'isSpeech_zoneImmutable'
        QtMocHelpers::PropertyData<bool>(1260, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpeech_zoneValue'
        QtMocHelpers::PropertyData<bool>(1261, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperModel'
        QtMocHelpers::PropertyData<QString>(1262, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 324),
        // property 'isWhisperModelImmutable'
        QtMocHelpers::PropertyData<bool>(1263, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperModelValue'
        QtMocHelpers::PropertyData<QString>(1264, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperInstalledModels'
        QtMocHelpers::PropertyData<QStringList>(1265, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 325),
        // property 'isWhisperInstalledModelsImmutable'
        QtMocHelpers::PropertyData<bool>(1266, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperAvailableModels'
        QtMocHelpers::PropertyData<QStringList>(1267, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 326),
        // property 'isWhisperAvailableModelsImmutable'
        QtMocHelpers::PropertyData<bool>(1268, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperAvailableModelsValue'
        QtMocHelpers::PropertyData<QStringList>(1269, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperAvailableModelsHash'
        QtMocHelpers::PropertyData<QStringList>(1270, QMetaType::QStringList, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 327),
        // property 'isWhisperAvailableModelsHashImmutable'
        QtMocHelpers::PropertyData<bool>(1271, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperModelFolder'
        QtMocHelpers::PropertyData<QString>(1272, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 328),
        // property 'isWhisperModelFolderImmutable'
        QtMocHelpers::PropertyData<bool>(1273, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperLanguage'
        QtMocHelpers::PropertyData<QString>(1274, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 329),
        // property 'isWhisperLanguageImmutable'
        QtMocHelpers::PropertyData<bool>(1275, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'enableSeamless'
        QtMocHelpers::PropertyData<bool>(1276, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 330),
        // property 'isEnableSeamlessImmutable'
        QtMocHelpers::PropertyData<bool>(1277, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultEnableSeamlessValue'
        QtMocHelpers::PropertyData<bool>(1278, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'srtSeamlessTranslate'
        QtMocHelpers::PropertyData<bool>(1279, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 331),
        // property 'isSrtSeamlessTranslateImmutable'
        QtMocHelpers::PropertyData<bool>(1280, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSrtSeamlessTranslateValue'
        QtMocHelpers::PropertyData<bool>(1281, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'seamless_input'
        QtMocHelpers::PropertyData<QString>(1282, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 332),
        // property 'isSeamless_inputImmutable'
        QtMocHelpers::PropertyData<bool>(1283, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'seamless_output'
        QtMocHelpers::PropertyData<QString>(1284, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 333),
        // property 'isSeamless_outputImmutable'
        QtMocHelpers::PropertyData<bool>(1285, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperMaxChars'
        QtMocHelpers::PropertyData<int>(1286, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 334),
        // property 'isWhisperMaxCharsImmutable'
        QtMocHelpers::PropertyData<bool>(1287, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperMaxCharsValue'
        QtMocHelpers::PropertyData<int>(1288, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'subtitleMode'
        QtMocHelpers::PropertyData<int>(1289, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 335),
        // property 'isSubtitleModeImmutable'
        QtMocHelpers::PropertyData<bool>(1290, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSubtitleModeValue'
        QtMocHelpers::PropertyData<int>(1291, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'cutWhisperMaxChars'
        QtMocHelpers::PropertyData<bool>(1292, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 336),
        // property 'isCutWhisperMaxCharsImmutable'
        QtMocHelpers::PropertyData<bool>(1293, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultCutWhisperMaxCharsValue'
        QtMocHelpers::PropertyData<bool>(1294, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperDevice'
        QtMocHelpers::PropertyData<QString>(1295, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 337),
        // property 'isWhisperDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(1296, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperDeviceValue'
        QtMocHelpers::PropertyData<QString>(1297, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'samDevice'
        QtMocHelpers::PropertyData<QString>(1298, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 338),
        // property 'isSamDeviceImmutable'
        QtMocHelpers::PropertyData<bool>(1299, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSamDeviceValue'
        QtMocHelpers::PropertyData<QString>(1300, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperTranslate'
        QtMocHelpers::PropertyData<bool>(1301, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 339),
        // property 'isWhisperTranslateImmutable'
        QtMocHelpers::PropertyData<bool>(1302, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperTranslateValue'
        QtMocHelpers::PropertyData<bool>(1303, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperDisableFP16'
        QtMocHelpers::PropertyData<bool>(1304, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 340),
        // property 'isWhisperDisableFP16Immutable'
        QtMocHelpers::PropertyData<bool>(1305, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultWhisperDisableFP16Value'
        QtMocHelpers::PropertyData<bool>(1306, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'whisperExtra'
        QtMocHelpers::PropertyData<QString>(1307, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 341),
        // property 'isWhisperExtraImmutable'
        QtMocHelpers::PropertyData<bool>(1308, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'speechEngine'
        QtMocHelpers::PropertyData<QString>(1309, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 342),
        // property 'isSpeechEngineImmutable'
        QtMocHelpers::PropertyData<bool>(1310, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultSpeechEngineValue'
        QtMocHelpers::PropertyData<QString>(1311, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaIconSize'
        QtMocHelpers::PropertyData<int>(1312, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 343),
        // property 'isMediaIconSizeImmutable'
        QtMocHelpers::PropertyData<bool>(1313, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaIconSizeValue'
        QtMocHelpers::PropertyData<int>(1314, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaManagerPanelLayout'
        QtMocHelpers::PropertyData<QString>(1315, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 344),
        // property 'isMediaManagerPanelLayoutImmutable'
        QtMocHelpers::PropertyData<bool>(1316, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaManagerPanelWidth'
        QtMocHelpers::PropertyData<int>(1317, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 345),
        // property 'isMediaManagerPanelWidthImmutable'
        QtMocHelpers::PropertyData<bool>(1318, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaManagerPanelWidthValue'
        QtMocHelpers::PropertyData<int>(1319, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaBrowserAutoPlay'
        QtMocHelpers::PropertyData<bool>(1320, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 346),
        // property 'isMediaBrowserAutoPlayImmutable'
        QtMocHelpers::PropertyData<bool>(1321, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaBrowserAutoPlayValue'
        QtMocHelpers::PropertyData<bool>(1322, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaBrowserWithAudio'
        QtMocHelpers::PropertyData<bool>(1323, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 347),
        // property 'isMediaBrowserWithAudioImmutable'
        QtMocHelpers::PropertyData<bool>(1324, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaBrowserWithAudioValue'
        QtMocHelpers::PropertyData<bool>(1325, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaDoubleClickImport'
        QtMocHelpers::PropertyData<bool>(1326, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 348),
        // property 'isMediaDoubleClickImportImmutable'
        QtMocHelpers::PropertyData<bool>(1327, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaDoubleClickImportValue'
        QtMocHelpers::PropertyData<bool>(1328, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mediaBrowserInlinePreview'
        QtMocHelpers::PropertyData<bool>(1329, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 349),
        // property 'isMediaBrowserInlinePreviewImmutable'
        QtMocHelpers::PropertyData<bool>(1330, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'defaultMediaBrowserInlinePreviewValue'
        QtMocHelpers::PropertyData<bool>(1331, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<KdenliveSettings, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KdenliveSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<KConfigSkeleton::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KdenliveSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KdenliveSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16KdenliveSettingsE_t>.metaTypes,
    nullptr
} };

void KdenliveSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KdenliveSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->treeviewheadersChanged(); break;
        case 1: _t->binSortingChanged(); break;
        case 2: _t->binModeChanged(); break;
        case 3: _t->bin_zoomChanged(); break;
        case 4: _t->addedExtensionsChanged(); break;
        case 5: _t->hoverPreviewChanged(); break;
        case 6: _t->binsCountChanged(); break;
        case 7: _t->scenesplitthresholdChanged(); break;
        case 8: _t->scenesplitmarkersChanged(); break;
        case 9: _t->scenesplitrangemarkersChanged(); break;
        case 10: _t->scenesplitsubclipsChanged(); break;
        case 11: _t->cleanCacheMonthsChanged(); break;
        case 12: _t->openlastprojectChanged(); break;
        case 13: _t->crashrecoveryChanged(); break;
        case 14: _t->autosave_timeChanged(); break;
        case 15: _t->autosave_opsChanged(); break;
        case 16: _t->tabpositionChanged(); break;
        case 17: _t->checkfirstprojectclipChanged(); break;
        case 18: _t->keep_original_frame_sizeChanged(); break;
        case 19: _t->exportframe_usingsourceresChanged(); break;
        case 20: _t->color_durationChanged(); break;
        case 21: _t->image_durationChanged(); break;
        case 22: _t->sequence_durationChanged(); break;
        case 23: _t->fade_durationChanged(); break;
        case 24: _t->mix_durationChanged(); break;
        case 25: _t->subtitle_durationChanged(); break;
        case 26: _t->autoimagesequenceChanged(); break;
        case 27: _t->ignoresubdirstructureChanged(); break;
        case 28: _t->disableimagescalingChanged(); break;
        case 29: _t->automultistreamsChanged(); break;
        case 30: _t->use_exiftoolChanged(); break;
        case 31: _t->use_magicLanternChanged(); break;
        case 32: _t->title_durationChanged(); break;
        case 33: _t->transition_durationChanged(); break;
        case 34: _t->enableAssetsIncludeListChanged(); break;
        case 35: _t->effectsInfoHeightChanged(); break;
        case 36: _t->showEffectsInfoChanged(); break;
        case 37: _t->transitionsInfoHeightChanged(); break;
        case 38: _t->showTransitionsInfoChanged(); break;
        case 39: _t->disable_effect_parametersChanged(); break;
        case 40: _t->profile_fps_filterChanged(); break;
        case 41: _t->profile_scanning_filterChanged(); break;
        case 42: _t->opengl_backendChanged(); break;
        case 43: _t->videotracksChanged(); break;
        case 44: _t->audiotracksChanged(); break;
        case 45: _t->audio_channelsChanged(); break;
        case 46: _t->enableproxyChanged(); break;
        case 47: _t->externalproxyChanged(); break;
        case 48: _t->generateproxyChanged(); break;
        case 49: _t->external_proxy_profileChanged(); break;
        case 50: _t->externalProxyProfileChanged(); break;
        case 51: _t->generateimageproxyChanged(); break;
        case 52: _t->proxyminsizeChanged(); break;
        case 53: _t->proxyimageminsizeChanged(); break;
        case 54: _t->proxyimagesizeChanged(); break;
        case 55: _t->proxyscaleChanged(); break;
        case 56: _t->enforceLowerTrackCompositingChanged(); break;
        case 57: _t->proxyextensionChanged(); break;
        case 58: _t->proxyparamsChanged(); break;
        case 59: _t->proxy_profileChanged(); break;
        case 60: _t->proxyalphaextensionChanged(); break;
        case 61: _t->proxyalphaparamsChanged(); break;
        case 62: _t->alpha_profileChanged(); break;
        case 63: _t->transcodeFriendlyChanged(); break;
        case 64: _t->transcodingReplaceChanged(); break;
        case 65: _t->previewextensionChanged(); break;
        case 66: _t->preview_profileChanged(); break;
        case 67: _t->previewparamsChanged(); break;
        case 68: _t->parallelrenderChanged(); break;
        case 69: _t->renderInterpChanged(); break;
        case 70: _t->renderDeinterlacerChanged(); break;
        case 71: _t->vaapiEnabledChanged(); break;
        case 72: _t->amfEnabledChanged(); break;
        case 73: _t->SupportedHWCodecsChanged(); break;
        case 74: _t->nvScalingEnabledChanged(); break;
        case 75: _t->hwDecodingChanged(); break;
        case 76: _t->showRenderTextParametersChanged(); break;
        case 77: _t->headerwidthChanged(); break;
        case 78: _t->defaultkeyframeinterpChanged(); break;
        case 79: _t->timelinechunksChanged(); break;
        case 80: _t->autopreviewChanged(); break;
        case 81: _t->draginprogressChanged(); break;
        case 82: _t->proxypreviewChanged(); break;
        case 83: _t->multistreamChanged(); break;
        case 84: _t->multistream_checktrackChanged(); break;
        case 85: _t->videothumbnailsChanged(); break;
        case 86: _t->audiothumbnailsChanged(); break;
        case 87: _t->waveformScalerChanged(); break;
        case 88: _t->showmarkersChanged(); break;
        case 89: _t->displayallchannelsChanged(); break;
        case 90: _t->normalizechannelsChanged(); break;
        case 91: _t->autotrackheightChanged(); break;
        case 92: _t->autoscrollChanged(); break;
        case 93: _t->centeredplayheadChanged(); break;
        case 94: _t->jumptostartChanged(); break;
        case 95: _t->pauseonseekChanged(); break;
        case 96: _t->seekonaddeffectChanged(); break;
        case 97: _t->enableBuiltInEffectsChanged(); break;
        case 98: _t->tenbitpipelineChanged(); break;
        case 99: _t->effectsFilterChanged(); break;
        case 100: _t->transitionsFilterChanged(); break;
        case 101: _t->scrollverticallyChanged(); break;
        case 102: _t->trackheightChanged(); break;
        case 103: _t->audiotracksbelowChanged(); break;
        case 104: _t->raisepropsclipsChanged(); break;
        case 105: _t->raisepropscompositionsChanged(); break;
        case 106: _t->raisepropsmixesChanged(); break;
        case 107: _t->raisepropstracksChanged(); break;
        case 108: _t->uiDebugModeChanged(); break;
        case 109: _t->gpu_accelChanged(); break;
        case 110: _t->audio_scrubChanged(); break;
        case 111: _t->sdlAudioBackendChanged(); break;
        case 112: _t->audio_backendChanged(); break;
        case 113: _t->audiobackendChanged(); break;
        case 114: _t->audio_driverChanged(); break;
        case 115: _t->audiodevicenameChanged(); break;
        case 116: _t->audiodrivernameChanged(); break;
        case 117: _t->disablereccountdownChanged(); break;
        case 118: _t->videodrivernameChanged(); break;
        case 119: _t->audio_deviceChanged(); break;
        case 120: _t->window_backgroundChanged(); break;
        case 121: _t->showMonitorGridChanged(); break;
        case 122: _t->monitorGridHChanged(); break;
        case 123: _t->monitorGridVChanged(); break;
        case 124: _t->monitor_backgroundChanged(); break;
        case 125: _t->monitor_progressiveChanged(); break;
        case 126: _t->volumeChanged(); break;
        case 127: _t->monitor_dropframesChanged(); break;
        case 128: _t->external_displayChanged(); break;
        case 129: _t->blackmagic_output_deviceChanged(); break;
        case 130: _t->play_monitor_on_clickChanged(); break;
        case 131: _t->mirrorMonitorOnFullscreenChanged(); break;
        case 132: _t->fullscreen_monitorChanged(); break;
        case 133: _t->project_monitor_fullscreenChanged(); break;
        case 134: _t->clip_monitor_fullscreenChanged(); break;
        case 135: _t->preferredcompositeChanged(); break;
        case 136: _t->compositingListChanged(); break;
        case 137: _t->subtitle_razor_modeChanged(); break;
        case 138: _t->mltpathChanged(); break;
        case 139: _t->kdenliverendererpathChanged(); break;
        case 140: _t->meltpathChanged(); break;
        case 141: _t->ffmpegpathChanged(); break;
        case 142: _t->ffplaypathChanged(); break;
        case 143: _t->ffprobepathChanged(); break;
        case 144: _t->processingthreadsChanged(); break;
        case 145: _t->proxythreadsChanged(); break;
        case 146: _t->encodethreadsChanged(); break;
        case 147: _t->currenttmpfolderChanged(); break;
        case 148: _t->maxcachesizeChanged(); break;
        case 149: _t->checkForUpdateChanged(); break;
        case 150: _t->usePowerManagementChanged(); break;
        case 151: _t->lastCacheCheckChanged(); break;
        case 152: _t->defaultprojectfolderChanged(); break;
        case 153: _t->customprojectfolderChanged(); break;
        case 154: _t->sameprojectfolderChanged(); break;
        case 155: _t->capturetoprojectfolderChanged(); break;
        case 156: _t->capturefolderChanged(); break;
        case 157: _t->captureprojectsubfolderChanged(); break;
        case 158: _t->librarytodefaultfolderChanged(); break;
        case 159: _t->videotodefaultfolderChanged(); break;
        case 160: _t->libraryfolderChanged(); break;
        case 161: _t->videofolderChanged(); break;
        case 162: _t->defaultimageappChanged(); break;
        case 163: _t->defaultaudioappChanged(); break;
        case 164: _t->glaxnimatePathChanged(); break;
        case 165: _t->defaultvideoappChanged(); break;
        case 166: _t->nice_tasksChanged(); break;
        case 167: _t->exportGuidesFormatChanged(); break;
        case 168: _t->multipleguidesintervalChanged(); break;
        case 169: _t->guidesShowThumbsChanged(); break;
        case 170: _t->guidesSelectZoneChanged(); break;
        case 171: _t->defaultaudiocaptureChanged(); break;
        case 172: _t->audiocapturevolumeChanged(); break;
        case 173: _t->audiocapturechannelsChanged(); break;
        case 174: _t->audiocapturesamplerateChanged(); break;
        case 175: _t->audiocapturesampleformatChanged(); break;
        case 176: _t->defaultcaptureChanged(); break;
        case 177: _t->alsachannelsChanged(); break;
        case 178: _t->grab_profileChanged(); break;
        case 179: _t->grab_parametersChanged(); break;
        case 180: _t->grab_extensionChanged(); break;
        case 181: _t->grab_capture_typeChanged(); break;
        case 182: _t->grab_follow_mouseChanged(); break;
        case 183: _t->grab_offsetxChanged(); break;
        case 184: _t->grab_offsetyChanged(); break;
        case 185: _t->grab_widthChanged(); break;
        case 186: _t->grab_heightChanged(); break;
        case 187: _t->grab_fpsChanged(); break;
        case 188: _t->grab_hide_frameChanged(); break;
        case 189: _t->grab_hide_mouseChanged(); break;
        case 190: _t->decklink_device_foundChanged(); break;
        case 191: _t->decklink_capturedeviceChanged(); break;
        case 192: _t->decklink_profileChanged(); break;
        case 193: _t->decklink_filenameChanged(); break;
        case 194: _t->decklink_parametersChanged(); break;
        case 195: _t->decklink_extensionChanged(); break;
        case 196: _t->enableshuttleChanged(); break;
        case 197: _t->shuttledeviceChanged(); break;
        case 198: _t->shuttledevicenamesChanged(); break;
        case 199: _t->shuttledevicepathsChanged(); break;
        case 200: _t->shuttlebuttonsChanged(); break;
        case 201: _t->bezier_gridlinesChanged(); break;
        case 202: _t->bezier_showpixmapChanged(); break;
        case 203: _t->bezier_showallhandlesChanged(); break;
        case 204: _t->dragvalue_modeChanged(); break;
        case 205: _t->dragvalue_directupdateChanged(); break;
        case 206: _t->recentProfilesChanged(); break;
        case 207: _t->recentProfileNamesChanged(); break;
        case 208: _t->properties_panel_pageChanged(); break;
        case 209: _t->project_fpsChanged(); break;
        case 210: _t->default_profileChanged(); break;
        case 211: _t->kdockLayoutChanged(); break;
        case 212: _t->layoutsOrderChanged(); break;
        case 213: _t->showdescriptioncolumnChanged(); break;
        case 214: _t->showratingcolumnChanged(); break;
        case 215: _t->showdatecolumnChanged(); break;
        case 216: _t->frametimecodeChanged(); break;
        case 217: _t->rectimecodeChanged(); break;
        case 218: _t->snaptopointsChanged(); break;
        case 219: _t->showClipOverlaysChanged(); break;
        case 220: _t->rippleResizeChanged(); break;
        case 221: _t->lockedGuidesChanged(); break;
        case 222: _t->guidesCategoriesChanged(); break;
        case 223: _t->tagsintimelineChanged(); break;
        case 224: _t->timelinemousezoomonplayheadChanged(); break;
        case 225: _t->transitionfollowcursorChanged(); break;
        case 226: _t->keyframeseekChanged(); break;
        case 227: _t->showeffectinfoChanged(); break;
        case 228: _t->applyEffectParamsToGroupChanged(); break;
        case 229: _t->applyEffectParamsToGroupWithSameValueChanged(); break;
        case 230: _t->renderProfileChanged(); break;
        case 231: _t->keepRenderLogFilesChanged(); break;
        case 232: _t->validated_lutsChanged(); break;
        case 233: _t->displayClipMonitorInfoChanged(); break;
        case 234: _t->showClipMonitorSafeZoneChanged(); break;
        case 235: _t->showProjectMonitorSafeZoneChanged(); break;
        case 236: _t->displayProjectMonitorInfoChanged(); break;
        case 237: _t->previewScalingChanged(); break;
        case 238: _t->autoKeyframeChanged(); break;
        case 239: _t->limitAutoKeyframesChanged(); break;
        case 240: _t->limitAutoKeyframesIntervalChanged(); break;
        case 241: _t->maskOpacityChanged(); break;
        case 242: _t->maskInvertedChanged(); break;
        case 243: _t->clipMonitorOverlayGuidesChanged(); break;
        case 244: _t->projectMonitorOverlayGuidesChanged(); break;
        case 245: _t->alwaysShowMonitorAudioChanged(); break;
        case 246: _t->displayAudioOverlayChanged(); break;
        case 247: _t->monitoraudioChanged(); break;
        case 248: _t->showOnMonitorSceneChanged(); break;
        case 249: _t->autoaudiodrivernameChanged(); break;
        case 250: _t->mixerCollapseChanged(); break;
        case 251: _t->consumerslistChanged(); break;
        case 252: _t->producerslistChanged(); break;
        case 253: _t->widgetstyleChanged(); break;
        case 254: _t->showslideshowthumbsChanged(); break;
        case 255: _t->showtitlebarsChanged(); break;
        case 256: _t->colorclipcolorChanged(); break;
        case 257: _t->showSubtitlesChanged(); break;
        case 258: _t->subtitleEditFontSizeChanged(); break;
        case 259: _t->thumbColor1Changed(); break;
        case 260: _t->thumbColor2Changed(); break;
        case 261: _t->overlayColorChanged(); break;
        case 262: _t->safeColorChanged(); break;
        case 263: _t->defaultrescalewidthChanged(); break;
        case 264: _t->defaultrescaleheightChanged(); break;
        case 265: _t->slideshowbymimeChanged(); break;
        case 266: _t->slideshowmimeextensionChanged(); break;
        case 267: _t->monitorscene_directupdateChanged(); break;
        case 268: _t->analyse_stopmotionChanged(); break;
        case 269: _t->enableaudiospectrumChanged(); break;
        case 270: _t->showstopmotionthumbsChanged(); break;
        case 271: _t->captureintervalChanged(); break;
        case 272: _t->sm_notifytimeChanged(); break;
        case 273: _t->sm_prenotifyChanged(); break;
        case 274: _t->sm_loopChanged(); break;
        case 275: _t->sm_playsoundChanged(); break;
        case 276: _t->sm_framesplaybackChanged(); break;
        case 277: _t->stopmotioneffectChanged(); break;
        case 278: _t->onmonitoreffects_cornersshowlinesChanged(); break;
        case 279: _t->onmonitoreffects_geometryshowpreviousChanged(); break;
        case 280: _t->onmonitoreffects_geometryshowpathChanged(); break;
        case 281: _t->onmonitoreffects_cornersshowcontrolsChanged(); break;
        case 282: _t->projectloading_avformatnovalidateChanged(); break;
        case 283: _t->monitor_audioChanged(); break;
        case 284: _t->enable_recording_previewChanged(); break;
        case 285: _t->add_new_clipChanged(); break;
        case 286: _t->add_new_clip_to_folderChanged(); break;
        case 287: _t->default_marker_typeChanged(); break;
        case 288: _t->mltdeinterlacerChanged(); break;
        case 289: _t->mltinterpolationChanged(); break;
        case 290: _t->favorite_effectsChanged(); break;
        case 291: _t->favorite_transitionsChanged(); break;
        case 292: _t->selected_effecttabChanged(); break;
        case 293: _t->effectViewAsIconChanged(); break;
        case 294: _t->transitionViewAsIconChanged(); break;
        case 295: _t->force_breezeChanged(); break;
        case 296: _t->use_dark_breezeChanged(); break;
        case 297: _t->showWelcomeChanged(); break;
        case 298: _t->lastSeenVersionMajorChanged(); break;
        case 299: _t->lastSeenVersionMinorChanged(); break;
        case 300: _t->lastSeenVersionMicroChanged(); break;
        case 301: _t->lock_ratioChanged(); break;
        case 302: _t->selected_templateChanged(); break;
        case 303: _t->titlerShowGuidesChanged(); break;
        case 304: _t->titlerVersionChanged(); break;
        case 305: _t->titlerHGuidesChanged(); break;
        case 306: _t->titlerVGuidesChanged(); break;
        case 307: _t->titleGuideColorChanged(); break;
        case 308: _t->titlerbgChanged(); break;
        case 309: _t->titlerShowbgChanged(); break;
        case 310: _t->titlerAlignChanged(); break;
        case 311: _t->samModelFileChanged(); break;
        case 312: _t->sam_offload_videoChanged(); break;
        case 313: _t->sam_system_pythonChanged(); break;
        case 314: _t->sam_system_python_pathChanged(); break;
        case 315: _t->maskBorderWidthChanged(); break;
        case 316: _t->maskBorderColorChanged(); break;
        case 317: _t->maskColorChanged(); break;
        case 318: _t->speech_system_pythonChanged(); break;
        case 319: _t->speech_system_python_pathChanged(); break;
        case 320: _t->vosk_folder_pathChanged(); break;
        case 321: _t->vosk_text_modelChanged(); break;
        case 322: _t->vosk_srt_modelChanged(); break;
        case 323: _t->speech_zoneChanged(); break;
        case 324: _t->whisperModelChanged(); break;
        case 325: _t->whisperInstalledModelsChanged(); break;
        case 326: _t->whisperAvailableModelsChanged(); break;
        case 327: _t->whisperAvailableModelsHashChanged(); break;
        case 328: _t->whisperModelFolderChanged(); break;
        case 329: _t->whisperLanguageChanged(); break;
        case 330: _t->enableSeamlessChanged(); break;
        case 331: _t->srtSeamlessTranslateChanged(); break;
        case 332: _t->seamless_inputChanged(); break;
        case 333: _t->seamless_outputChanged(); break;
        case 334: _t->whisperMaxCharsChanged(); break;
        case 335: _t->subtitleModeChanged(); break;
        case 336: _t->cutWhisperMaxCharsChanged(); break;
        case 337: _t->whisperDeviceChanged(); break;
        case 338: _t->samDeviceChanged(); break;
        case 339: _t->whisperTranslateChanged(); break;
        case 340: _t->whisperDisableFP16Changed(); break;
        case 341: _t->whisperExtraChanged(); break;
        case 342: _t->speechEngineChanged(); break;
        case 343: _t->mediaIconSizeChanged(); break;
        case 344: _t->mediaManagerPanelLayoutChanged(); break;
        case 345: _t->mediaManagerPanelWidthChanged(); break;
        case 346: _t->mediaBrowserAutoPlayChanged(); break;
        case 347: _t->mediaBrowserWithAudioChanged(); break;
        case 348: _t->mediaDoubleClickImportChanged(); break;
        case 349: _t->mediaBrowserInlinePreviewChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::treeviewheadersChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::binSortingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::binModeChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::bin_zoomChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::addedExtensionsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::hoverPreviewChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::binsCountChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::scenesplitthresholdChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::scenesplitmarkersChanged, 8))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::scenesplitrangemarkersChanged, 9))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::scenesplitsubclipsChanged, 10))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::cleanCacheMonthsChanged, 11))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::openlastprojectChanged, 12))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::crashrecoveryChanged, 13))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autosave_timeChanged, 14))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autosave_opsChanged, 15))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::tabpositionChanged, 16))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::checkfirstprojectclipChanged, 17))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::keep_original_frame_sizeChanged, 18))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::exportframe_usingsourceresChanged, 19))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::color_durationChanged, 20))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::image_durationChanged, 21))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sequence_durationChanged, 22))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::fade_durationChanged, 23))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mix_durationChanged, 24))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::subtitle_durationChanged, 25))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autoimagesequenceChanged, 26))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::ignoresubdirstructureChanged, 27))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::disableimagescalingChanged, 28))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::automultistreamsChanged, 29))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::use_exiftoolChanged, 30))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::use_magicLanternChanged, 31))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::title_durationChanged, 32))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transition_durationChanged, 33))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableAssetsIncludeListChanged, 34))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::effectsInfoHeightChanged, 35))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showEffectsInfoChanged, 36))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transitionsInfoHeightChanged, 37))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showTransitionsInfoChanged, 38))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::disable_effect_parametersChanged, 39))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::profile_fps_filterChanged, 40))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::profile_scanning_filterChanged, 41))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::opengl_backendChanged, 42))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::videotracksChanged, 43))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiotracksChanged, 44))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audio_channelsChanged, 45))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableproxyChanged, 46))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::externalproxyChanged, 47))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::generateproxyChanged, 48))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::external_proxy_profileChanged, 49))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::externalProxyProfileChanged, 50))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::generateimageproxyChanged, 51))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyminsizeChanged, 52))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyimageminsizeChanged, 53))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyimagesizeChanged, 54))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyscaleChanged, 55))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enforceLowerTrackCompositingChanged, 56))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyextensionChanged, 57))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyparamsChanged, 58))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxy_profileChanged, 59))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyalphaextensionChanged, 60))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxyalphaparamsChanged, 61))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::alpha_profileChanged, 62))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transcodeFriendlyChanged, 63))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transcodingReplaceChanged, 64))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::previewextensionChanged, 65))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::preview_profileChanged, 66))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::previewparamsChanged, 67))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::parallelrenderChanged, 68))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::renderInterpChanged, 69))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::renderDeinterlacerChanged, 70))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::vaapiEnabledChanged, 71))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::amfEnabledChanged, 72))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::SupportedHWCodecsChanged, 73))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::nvScalingEnabledChanged, 74))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::hwDecodingChanged, 75))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showRenderTextParametersChanged, 76))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::headerwidthChanged, 77))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultkeyframeinterpChanged, 78))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::timelinechunksChanged, 79))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autopreviewChanged, 80))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::draginprogressChanged, 81))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxypreviewChanged, 82))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::multistreamChanged, 83))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::multistream_checktrackChanged, 84))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::videothumbnailsChanged, 85))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiothumbnailsChanged, 86))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::waveformScalerChanged, 87))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showmarkersChanged, 88))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::displayallchannelsChanged, 89))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::normalizechannelsChanged, 90))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autotrackheightChanged, 91))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autoscrollChanged, 92))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::centeredplayheadChanged, 93))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::jumptostartChanged, 94))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::pauseonseekChanged, 95))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::seekonaddeffectChanged, 96))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableBuiltInEffectsChanged, 97))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::tenbitpipelineChanged, 98))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::effectsFilterChanged, 99))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transitionsFilterChanged, 100))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::scrollverticallyChanged, 101))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::trackheightChanged, 102))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiotracksbelowChanged, 103))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::raisepropsclipsChanged, 104))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::raisepropscompositionsChanged, 105))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::raisepropsmixesChanged, 106))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::raisepropstracksChanged, 107))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::uiDebugModeChanged, 108))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::gpu_accelChanged, 109))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audio_scrubChanged, 110))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sdlAudioBackendChanged, 111))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audio_backendChanged, 112))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiobackendChanged, 113))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audio_driverChanged, 114))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiodevicenameChanged, 115))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiodrivernameChanged, 116))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::disablereccountdownChanged, 117))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::videodrivernameChanged, 118))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audio_deviceChanged, 119))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::window_backgroundChanged, 120))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showMonitorGridChanged, 121))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitorGridHChanged, 122))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitorGridVChanged, 123))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitor_backgroundChanged, 124))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitor_progressiveChanged, 125))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::volumeChanged, 126))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitor_dropframesChanged, 127))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::external_displayChanged, 128))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::blackmagic_output_deviceChanged, 129))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::play_monitor_on_clickChanged, 130))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mirrorMonitorOnFullscreenChanged, 131))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::fullscreen_monitorChanged, 132))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::project_monitor_fullscreenChanged, 133))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::clip_monitor_fullscreenChanged, 134))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::preferredcompositeChanged, 135))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::compositingListChanged, 136))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::subtitle_razor_modeChanged, 137))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mltpathChanged, 138))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::kdenliverendererpathChanged, 139))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::meltpathChanged, 140))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::ffmpegpathChanged, 141))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::ffplaypathChanged, 142))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::ffprobepathChanged, 143))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::processingthreadsChanged, 144))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::proxythreadsChanged, 145))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::encodethreadsChanged, 146))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::currenttmpfolderChanged, 147))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maxcachesizeChanged, 148))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::checkForUpdateChanged, 149))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::usePowerManagementChanged, 150))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lastCacheCheckChanged, 151))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultprojectfolderChanged, 152))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::customprojectfolderChanged, 153))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sameprojectfolderChanged, 154))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::capturetoprojectfolderChanged, 155))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::capturefolderChanged, 156))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::captureprojectsubfolderChanged, 157))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::librarytodefaultfolderChanged, 158))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::videotodefaultfolderChanged, 159))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::libraryfolderChanged, 160))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::videofolderChanged, 161))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultimageappChanged, 162))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultaudioappChanged, 163))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::glaxnimatePathChanged, 164))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultvideoappChanged, 165))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::nice_tasksChanged, 166))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::exportGuidesFormatChanged, 167))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::multipleguidesintervalChanged, 168))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::guidesShowThumbsChanged, 169))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::guidesSelectZoneChanged, 170))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultaudiocaptureChanged, 171))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiocapturevolumeChanged, 172))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiocapturechannelsChanged, 173))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiocapturesamplerateChanged, 174))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::audiocapturesampleformatChanged, 175))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultcaptureChanged, 176))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::alsachannelsChanged, 177))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_profileChanged, 178))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_parametersChanged, 179))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_extensionChanged, 180))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_capture_typeChanged, 181))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_follow_mouseChanged, 182))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_offsetxChanged, 183))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_offsetyChanged, 184))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_widthChanged, 185))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_heightChanged, 186))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_fpsChanged, 187))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_hide_frameChanged, 188))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::grab_hide_mouseChanged, 189))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_device_foundChanged, 190))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_capturedeviceChanged, 191))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_profileChanged, 192))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_filenameChanged, 193))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_parametersChanged, 194))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::decklink_extensionChanged, 195))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableshuttleChanged, 196))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::shuttledeviceChanged, 197))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::shuttledevicenamesChanged, 198))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::shuttledevicepathsChanged, 199))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::shuttlebuttonsChanged, 200))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::bezier_gridlinesChanged, 201))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::bezier_showpixmapChanged, 202))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::bezier_showallhandlesChanged, 203))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::dragvalue_modeChanged, 204))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::dragvalue_directupdateChanged, 205))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::recentProfilesChanged, 206))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::recentProfileNamesChanged, 207))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::properties_panel_pageChanged, 208))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::project_fpsChanged, 209))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::default_profileChanged, 210))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::kdockLayoutChanged, 211))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::layoutsOrderChanged, 212))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showdescriptioncolumnChanged, 213))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showratingcolumnChanged, 214))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showdatecolumnChanged, 215))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::frametimecodeChanged, 216))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::rectimecodeChanged, 217))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::snaptopointsChanged, 218))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showClipOverlaysChanged, 219))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::rippleResizeChanged, 220))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lockedGuidesChanged, 221))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::guidesCategoriesChanged, 222))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::tagsintimelineChanged, 223))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::timelinemousezoomonplayheadChanged, 224))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transitionfollowcursorChanged, 225))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::keyframeseekChanged, 226))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showeffectinfoChanged, 227))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::applyEffectParamsToGroupChanged, 228))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::applyEffectParamsToGroupWithSameValueChanged, 229))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::renderProfileChanged, 230))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::keepRenderLogFilesChanged, 231))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::validated_lutsChanged, 232))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::displayClipMonitorInfoChanged, 233))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showClipMonitorSafeZoneChanged, 234))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showProjectMonitorSafeZoneChanged, 235))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::displayProjectMonitorInfoChanged, 236))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::previewScalingChanged, 237))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autoKeyframeChanged, 238))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::limitAutoKeyframesChanged, 239))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::limitAutoKeyframesIntervalChanged, 240))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maskOpacityChanged, 241))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maskInvertedChanged, 242))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::clipMonitorOverlayGuidesChanged, 243))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::projectMonitorOverlayGuidesChanged, 244))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::alwaysShowMonitorAudioChanged, 245))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::displayAudioOverlayChanged, 246))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitoraudioChanged, 247))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showOnMonitorSceneChanged, 248))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::autoaudiodrivernameChanged, 249))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mixerCollapseChanged, 250))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::consumerslistChanged, 251))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::producerslistChanged, 252))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::widgetstyleChanged, 253))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showslideshowthumbsChanged, 254))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showtitlebarsChanged, 255))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::colorclipcolorChanged, 256))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showSubtitlesChanged, 257))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::subtitleEditFontSizeChanged, 258))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::thumbColor1Changed, 259))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::thumbColor2Changed, 260))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::overlayColorChanged, 261))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::safeColorChanged, 262))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultrescalewidthChanged, 263))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::defaultrescaleheightChanged, 264))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::slideshowbymimeChanged, 265))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::slideshowmimeextensionChanged, 266))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitorscene_directupdateChanged, 267))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::analyse_stopmotionChanged, 268))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableaudiospectrumChanged, 269))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showstopmotionthumbsChanged, 270))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::captureintervalChanged, 271))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sm_notifytimeChanged, 272))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sm_prenotifyChanged, 273))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sm_loopChanged, 274))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sm_playsoundChanged, 275))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sm_framesplaybackChanged, 276))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::stopmotioneffectChanged, 277))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::onmonitoreffects_cornersshowlinesChanged, 278))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::onmonitoreffects_geometryshowpreviousChanged, 279))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::onmonitoreffects_geometryshowpathChanged, 280))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::onmonitoreffects_cornersshowcontrolsChanged, 281))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::projectloading_avformatnovalidateChanged, 282))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::monitor_audioChanged, 283))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enable_recording_previewChanged, 284))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::add_new_clipChanged, 285))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::add_new_clip_to_folderChanged, 286))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::default_marker_typeChanged, 287))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mltdeinterlacerChanged, 288))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mltinterpolationChanged, 289))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::favorite_effectsChanged, 290))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::favorite_transitionsChanged, 291))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::selected_effecttabChanged, 292))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::effectViewAsIconChanged, 293))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::transitionViewAsIconChanged, 294))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::force_breezeChanged, 295))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::use_dark_breezeChanged, 296))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::showWelcomeChanged, 297))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lastSeenVersionMajorChanged, 298))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lastSeenVersionMinorChanged, 299))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lastSeenVersionMicroChanged, 300))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::lock_ratioChanged, 301))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::selected_templateChanged, 302))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerShowGuidesChanged, 303))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerVersionChanged, 304))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerHGuidesChanged, 305))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerVGuidesChanged, 306))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titleGuideColorChanged, 307))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerbgChanged, 308))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerShowbgChanged, 309))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::titlerAlignChanged, 310))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::samModelFileChanged, 311))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sam_offload_videoChanged, 312))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sam_system_pythonChanged, 313))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::sam_system_python_pathChanged, 314))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maskBorderWidthChanged, 315))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maskBorderColorChanged, 316))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::maskColorChanged, 317))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::speech_system_pythonChanged, 318))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::speech_system_python_pathChanged, 319))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::vosk_folder_pathChanged, 320))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::vosk_text_modelChanged, 321))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::vosk_srt_modelChanged, 322))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::speech_zoneChanged, 323))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperModelChanged, 324))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperInstalledModelsChanged, 325))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperAvailableModelsChanged, 326))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperAvailableModelsHashChanged, 327))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperModelFolderChanged, 328))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperLanguageChanged, 329))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::enableSeamlessChanged, 330))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::srtSeamlessTranslateChanged, 331))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::seamless_inputChanged, 332))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::seamless_outputChanged, 333))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperMaxCharsChanged, 334))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::subtitleModeChanged, 335))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::cutWhisperMaxCharsChanged, 336))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperDeviceChanged, 337))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::samDeviceChanged, 338))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperTranslateChanged, 339))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperDisableFP16Changed, 340))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::whisperExtraChanged, 341))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::speechEngineChanged, 342))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaIconSizeChanged, 343))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaManagerPanelLayoutChanged, 344))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaManagerPanelWidthChanged, 345))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaBrowserAutoPlayChanged, 346))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaBrowserWithAudioChanged, 347))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaDoubleClickImportChanged, 348))
            return;
        if (QtMocHelpers::indexOfMethod<void (KdenliveSettings::*)()>(_a, &KdenliveSettings::mediaBrowserInlinePreviewChanged, 349))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->treeviewheaders(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->isTreeviewheadersImmutable(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->binSorting(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isBinSortingImmutable(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->defaultBinSortingValue(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->binMode(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isBinModeImmutable(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->defaultBinModeValue(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->bin_zoom(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->isBin_zoomImmutable(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->defaultBin_zoomValue(); break;
        case 11: *reinterpret_cast<QString*>(_v) = _t->addedExtensions(); break;
        case 12: *reinterpret_cast<bool*>(_v) = _t->isAddedExtensionsImmutable(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->hoverPreview(); break;
        case 14: *reinterpret_cast<bool*>(_v) = _t->isHoverPreviewImmutable(); break;
        case 15: *reinterpret_cast<bool*>(_v) = _t->defaultHoverPreviewValue(); break;
        case 16: *reinterpret_cast<int*>(_v) = _t->binsCount(); break;
        case 17: *reinterpret_cast<bool*>(_v) = _t->isBinsCountImmutable(); break;
        case 18: *reinterpret_cast<int*>(_v) = _t->defaultBinsCountValue(); break;
        case 19: *reinterpret_cast<int*>(_v) = _t->scenesplitthreshold(); break;
        case 20: *reinterpret_cast<bool*>(_v) = _t->isScenesplitthresholdImmutable(); break;
        case 21: *reinterpret_cast<int*>(_v) = _t->defaultScenesplitthresholdValue(); break;
        case 22: *reinterpret_cast<bool*>(_v) = _t->scenesplitmarkers(); break;
        case 23: *reinterpret_cast<bool*>(_v) = _t->isScenesplitmarkersImmutable(); break;
        case 24: *reinterpret_cast<bool*>(_v) = _t->defaultScenesplitmarkersValue(); break;
        case 25: *reinterpret_cast<bool*>(_v) = _t->scenesplitrangemarkers(); break;
        case 26: *reinterpret_cast<bool*>(_v) = _t->isScenesplitrangemarkersImmutable(); break;
        case 27: *reinterpret_cast<bool*>(_v) = _t->defaultScenesplitrangemarkersValue(); break;
        case 28: *reinterpret_cast<bool*>(_v) = _t->scenesplitsubclips(); break;
        case 29: *reinterpret_cast<bool*>(_v) = _t->isScenesplitsubclipsImmutable(); break;
        case 30: *reinterpret_cast<bool*>(_v) = _t->defaultScenesplitsubclipsValue(); break;
        case 31: *reinterpret_cast<int*>(_v) = _t->cleanCacheMonths(); break;
        case 32: *reinterpret_cast<bool*>(_v) = _t->isCleanCacheMonthsImmutable(); break;
        case 33: *reinterpret_cast<int*>(_v) = _t->defaultCleanCacheMonthsValue(); break;
        case 34: *reinterpret_cast<bool*>(_v) = _t->openlastproject(); break;
        case 35: *reinterpret_cast<bool*>(_v) = _t->isOpenlastprojectImmutable(); break;
        case 36: *reinterpret_cast<bool*>(_v) = _t->defaultOpenlastprojectValue(); break;
        case 37: *reinterpret_cast<bool*>(_v) = _t->crashrecovery(); break;
        case 38: *reinterpret_cast<bool*>(_v) = _t->isCrashrecoveryImmutable(); break;
        case 39: *reinterpret_cast<bool*>(_v) = _t->defaultCrashrecoveryValue(); break;
        case 40: *reinterpret_cast<int*>(_v) = _t->autosave_time(); break;
        case 41: *reinterpret_cast<bool*>(_v) = _t->isAutosave_timeImmutable(); break;
        case 42: *reinterpret_cast<int*>(_v) = _t->defaultAutosave_timeValue(); break;
        case 43: *reinterpret_cast<int*>(_v) = _t->autosave_ops(); break;
        case 44: *reinterpret_cast<bool*>(_v) = _t->isAutosave_opsImmutable(); break;
        case 45: *reinterpret_cast<int*>(_v) = _t->defaultAutosave_opsValue(); break;
        case 46: *reinterpret_cast<int*>(_v) = _t->tabposition(); break;
        case 47: *reinterpret_cast<bool*>(_v) = _t->isTabpositionImmutable(); break;
        case 48: *reinterpret_cast<int*>(_v) = _t->defaultTabpositionValue(); break;
        case 49: *reinterpret_cast<bool*>(_v) = _t->checkfirstprojectclip(); break;
        case 50: *reinterpret_cast<bool*>(_v) = _t->isCheckfirstprojectclipImmutable(); break;
        case 51: *reinterpret_cast<bool*>(_v) = _t->defaultCheckfirstprojectclipValue(); break;
        case 52: *reinterpret_cast<bool*>(_v) = _t->keep_original_frame_size(); break;
        case 53: *reinterpret_cast<bool*>(_v) = _t->isKeep_original_frame_sizeImmutable(); break;
        case 54: *reinterpret_cast<bool*>(_v) = _t->defaultKeep_original_frame_sizeValue(); break;
        case 55: *reinterpret_cast<bool*>(_v) = _t->exportframe_usingsourceres(); break;
        case 56: *reinterpret_cast<bool*>(_v) = _t->isExportframe_usingsourceresImmutable(); break;
        case 57: *reinterpret_cast<bool*>(_v) = _t->defaultExportframe_usingsourceresValue(); break;
        case 58: *reinterpret_cast<QString*>(_v) = _t->color_duration(); break;
        case 59: *reinterpret_cast<bool*>(_v) = _t->isColor_durationImmutable(); break;
        case 60: *reinterpret_cast<QString*>(_v) = _t->defaultColor_durationValue(); break;
        case 61: *reinterpret_cast<QString*>(_v) = _t->image_duration(); break;
        case 62: *reinterpret_cast<bool*>(_v) = _t->isImage_durationImmutable(); break;
        case 63: *reinterpret_cast<QString*>(_v) = _t->defaultImage_durationValue(); break;
        case 64: *reinterpret_cast<QString*>(_v) = _t->sequence_duration(); break;
        case 65: *reinterpret_cast<bool*>(_v) = _t->isSequence_durationImmutable(); break;
        case 66: *reinterpret_cast<QString*>(_v) = _t->defaultSequence_durationValue(); break;
        case 67: *reinterpret_cast<QString*>(_v) = _t->fade_duration(); break;
        case 68: *reinterpret_cast<bool*>(_v) = _t->isFade_durationImmutable(); break;
        case 69: *reinterpret_cast<QString*>(_v) = _t->defaultFade_durationValue(); break;
        case 70: *reinterpret_cast<QString*>(_v) = _t->mix_duration(); break;
        case 71: *reinterpret_cast<bool*>(_v) = _t->isMix_durationImmutable(); break;
        case 72: *reinterpret_cast<QString*>(_v) = _t->defaultMix_durationValue(); break;
        case 73: *reinterpret_cast<QString*>(_v) = _t->subtitle_duration(); break;
        case 74: *reinterpret_cast<bool*>(_v) = _t->isSubtitle_durationImmutable(); break;
        case 75: *reinterpret_cast<QString*>(_v) = _t->defaultSubtitle_durationValue(); break;
        case 76: *reinterpret_cast<bool*>(_v) = _t->autoimagesequence(); break;
        case 77: *reinterpret_cast<bool*>(_v) = _t->isAutoimagesequenceImmutable(); break;
        case 78: *reinterpret_cast<bool*>(_v) = _t->defaultAutoimagesequenceValue(); break;
        case 79: *reinterpret_cast<bool*>(_v) = _t->ignoresubdirstructure(); break;
        case 80: *reinterpret_cast<bool*>(_v) = _t->isIgnoresubdirstructureImmutable(); break;
        case 81: *reinterpret_cast<bool*>(_v) = _t->defaultIgnoresubdirstructureValue(); break;
        case 82: *reinterpret_cast<bool*>(_v) = _t->disableimagescaling(); break;
        case 83: *reinterpret_cast<bool*>(_v) = _t->isDisableimagescalingImmutable(); break;
        case 84: *reinterpret_cast<bool*>(_v) = _t->defaultDisableimagescalingValue(); break;
        case 85: *reinterpret_cast<bool*>(_v) = _t->automultistreams(); break;
        case 86: *reinterpret_cast<bool*>(_v) = _t->isAutomultistreamsImmutable(); break;
        case 87: *reinterpret_cast<bool*>(_v) = _t->defaultAutomultistreamsValue(); break;
        case 88: *reinterpret_cast<bool*>(_v) = _t->use_exiftool(); break;
        case 89: *reinterpret_cast<bool*>(_v) = _t->isUse_exiftoolImmutable(); break;
        case 90: *reinterpret_cast<bool*>(_v) = _t->defaultUse_exiftoolValue(); break;
        case 91: *reinterpret_cast<bool*>(_v) = _t->use_magicLantern(); break;
        case 92: *reinterpret_cast<bool*>(_v) = _t->isUse_magicLanternImmutable(); break;
        case 93: *reinterpret_cast<bool*>(_v) = _t->defaultUse_magicLanternValue(); break;
        case 94: *reinterpret_cast<QString*>(_v) = _t->title_duration(); break;
        case 95: *reinterpret_cast<bool*>(_v) = _t->isTitle_durationImmutable(); break;
        case 96: *reinterpret_cast<QString*>(_v) = _t->defaultTitle_durationValue(); break;
        case 97: *reinterpret_cast<QString*>(_v) = _t->transition_duration(); break;
        case 98: *reinterpret_cast<bool*>(_v) = _t->isTransition_durationImmutable(); break;
        case 99: *reinterpret_cast<QString*>(_v) = _t->defaultTransition_durationValue(); break;
        case 100: *reinterpret_cast<bool*>(_v) = _t->enableAssetsIncludeList(); break;
        case 101: *reinterpret_cast<bool*>(_v) = _t->isEnableAssetsIncludeListImmutable(); break;
        case 102: *reinterpret_cast<bool*>(_v) = _t->defaultEnableAssetsIncludeListValue(); break;
        case 103: *reinterpret_cast<QString*>(_v) = _t->effectsInfoHeight(); break;
        case 104: *reinterpret_cast<bool*>(_v) = _t->isEffectsInfoHeightImmutable(); break;
        case 105: *reinterpret_cast<bool*>(_v) = _t->showEffectsInfo(); break;
        case 106: *reinterpret_cast<bool*>(_v) = _t->isShowEffectsInfoImmutable(); break;
        case 107: *reinterpret_cast<bool*>(_v) = _t->defaultShowEffectsInfoValue(); break;
        case 108: *reinterpret_cast<QString*>(_v) = _t->transitionsInfoHeight(); break;
        case 109: *reinterpret_cast<bool*>(_v) = _t->isTransitionsInfoHeightImmutable(); break;
        case 110: *reinterpret_cast<bool*>(_v) = _t->showTransitionsInfo(); break;
        case 111: *reinterpret_cast<bool*>(_v) = _t->isShowTransitionsInfoImmutable(); break;
        case 112: *reinterpret_cast<bool*>(_v) = _t->defaultShowTransitionsInfoValue(); break;
        case 113: *reinterpret_cast<bool*>(_v) = _t->disable_effect_parameters(); break;
        case 114: *reinterpret_cast<bool*>(_v) = _t->isDisable_effect_parametersImmutable(); break;
        case 115: *reinterpret_cast<bool*>(_v) = _t->defaultDisable_effect_parametersValue(); break;
        case 116: *reinterpret_cast<QString*>(_v) = _t->profile_fps_filter(); break;
        case 117: *reinterpret_cast<bool*>(_v) = _t->isProfile_fps_filterImmutable(); break;
        case 118: *reinterpret_cast<QString*>(_v) = _t->profile_scanning_filter(); break;
        case 119: *reinterpret_cast<bool*>(_v) = _t->isProfile_scanning_filterImmutable(); break;
        case 120: *reinterpret_cast<int*>(_v) = _t->opengl_backend(); break;
        case 121: *reinterpret_cast<bool*>(_v) = _t->isOpengl_backendImmutable(); break;
        case 122: *reinterpret_cast<int*>(_v) = _t->defaultOpengl_backendValue(); break;
        case 123: *reinterpret_cast<int*>(_v) = _t->videotracks(); break;
        case 124: *reinterpret_cast<bool*>(_v) = _t->isVideotracksImmutable(); break;
        case 125: *reinterpret_cast<int*>(_v) = _t->defaultVideotracksValue(); break;
        case 126: *reinterpret_cast<int*>(_v) = _t->audiotracks(); break;
        case 127: *reinterpret_cast<bool*>(_v) = _t->isAudiotracksImmutable(); break;
        case 128: *reinterpret_cast<int*>(_v) = _t->defaultAudiotracksValue(); break;
        case 129: *reinterpret_cast<int*>(_v) = _t->audio_channels(); break;
        case 130: *reinterpret_cast<bool*>(_v) = _t->isAudio_channelsImmutable(); break;
        case 131: *reinterpret_cast<int*>(_v) = _t->defaultAudio_channelsValue(); break;
        case 132: *reinterpret_cast<bool*>(_v) = _t->enableproxy(); break;
        case 133: *reinterpret_cast<bool*>(_v) = _t->isEnableproxyImmutable(); break;
        case 134: *reinterpret_cast<bool*>(_v) = _t->defaultEnableproxyValue(); break;
        case 135: *reinterpret_cast<bool*>(_v) = _t->externalproxy(); break;
        case 136: *reinterpret_cast<bool*>(_v) = _t->isExternalproxyImmutable(); break;
        case 137: *reinterpret_cast<bool*>(_v) = _t->defaultExternalproxyValue(); break;
        case 138: *reinterpret_cast<bool*>(_v) = _t->generateproxy(); break;
        case 139: *reinterpret_cast<bool*>(_v) = _t->isGenerateproxyImmutable(); break;
        case 140: *reinterpret_cast<bool*>(_v) = _t->defaultGenerateproxyValue(); break;
        case 141: *reinterpret_cast<int*>(_v) = _t->external_proxy_profile(); break;
        case 142: *reinterpret_cast<bool*>(_v) = _t->isExternal_proxy_profileImmutable(); break;
        case 143: *reinterpret_cast<QString*>(_v) = _t->externalProxyProfile(); break;
        case 144: *reinterpret_cast<bool*>(_v) = _t->isExternalProxyProfileImmutable(); break;
        case 145: *reinterpret_cast<bool*>(_v) = _t->generateimageproxy(); break;
        case 146: *reinterpret_cast<bool*>(_v) = _t->isGenerateimageproxyImmutable(); break;
        case 147: *reinterpret_cast<bool*>(_v) = _t->defaultGenerateimageproxyValue(); break;
        case 148: *reinterpret_cast<int*>(_v) = _t->proxyminsize(); break;
        case 149: *reinterpret_cast<bool*>(_v) = _t->isProxyminsizeImmutable(); break;
        case 150: *reinterpret_cast<int*>(_v) = _t->defaultProxyminsizeValue(); break;
        case 151: *reinterpret_cast<int*>(_v) = _t->proxyimageminsize(); break;
        case 152: *reinterpret_cast<bool*>(_v) = _t->isProxyimageminsizeImmutable(); break;
        case 153: *reinterpret_cast<int*>(_v) = _t->defaultProxyimageminsizeValue(); break;
        case 154: *reinterpret_cast<int*>(_v) = _t->proxyimagesize(); break;
        case 155: *reinterpret_cast<bool*>(_v) = _t->isProxyimagesizeImmutable(); break;
        case 156: *reinterpret_cast<int*>(_v) = _t->defaultProxyimagesizeValue(); break;
        case 157: *reinterpret_cast<int*>(_v) = _t->proxyscale(); break;
        case 158: *reinterpret_cast<bool*>(_v) = _t->isProxyscaleImmutable(); break;
        case 159: *reinterpret_cast<int*>(_v) = _t->defaultProxyscaleValue(); break;
        case 160: *reinterpret_cast<bool*>(_v) = _t->enforceLowerTrackCompositing(); break;
        case 161: *reinterpret_cast<bool*>(_v) = _t->isEnforceLowerTrackCompositingImmutable(); break;
        case 162: *reinterpret_cast<bool*>(_v) = _t->defaultEnforceLowerTrackCompositingValue(); break;
        case 163: *reinterpret_cast<QString*>(_v) = _t->proxyextension(); break;
        case 164: *reinterpret_cast<bool*>(_v) = _t->isProxyextensionImmutable(); break;
        case 165: *reinterpret_cast<QString*>(_v) = _t->proxyparams(); break;
        case 166: *reinterpret_cast<bool*>(_v) = _t->isProxyparamsImmutable(); break;
        case 167: *reinterpret_cast<int*>(_v) = _t->proxy_profile(); break;
        case 168: *reinterpret_cast<bool*>(_v) = _t->isProxy_profileImmutable(); break;
        case 169: *reinterpret_cast<int*>(_v) = _t->defaultProxy_profileValue(); break;
        case 170: *reinterpret_cast<QString*>(_v) = _t->proxyalphaextension(); break;
        case 171: *reinterpret_cast<bool*>(_v) = _t->isProxyalphaextensionImmutable(); break;
        case 172: *reinterpret_cast<QString*>(_v) = _t->proxyalphaparams(); break;
        case 173: *reinterpret_cast<bool*>(_v) = _t->isProxyalphaparamsImmutable(); break;
        case 174: *reinterpret_cast<int*>(_v) = _t->alpha_profile(); break;
        case 175: *reinterpret_cast<bool*>(_v) = _t->isAlpha_profileImmutable(); break;
        case 176: *reinterpret_cast<int*>(_v) = _t->defaultAlpha_profileValue(); break;
        case 177: *reinterpret_cast<QString*>(_v) = _t->transcodeFriendly(); break;
        case 178: *reinterpret_cast<bool*>(_v) = _t->isTranscodeFriendlyImmutable(); break;
        case 179: *reinterpret_cast<bool*>(_v) = _t->transcodingReplace(); break;
        case 180: *reinterpret_cast<bool*>(_v) = _t->isTranscodingReplaceImmutable(); break;
        case 181: *reinterpret_cast<bool*>(_v) = _t->defaultTranscodingReplaceValue(); break;
        case 182: *reinterpret_cast<QString*>(_v) = _t->previewextension(); break;
        case 183: *reinterpret_cast<bool*>(_v) = _t->isPreviewextensionImmutable(); break;
        case 184: *reinterpret_cast<int*>(_v) = _t->preview_profile(); break;
        case 185: *reinterpret_cast<bool*>(_v) = _t->isPreview_profileImmutable(); break;
        case 186: *reinterpret_cast<int*>(_v) = _t->defaultPreview_profileValue(); break;
        case 187: *reinterpret_cast<QString*>(_v) = _t->previewparams(); break;
        case 188: *reinterpret_cast<bool*>(_v) = _t->isPreviewparamsImmutable(); break;
        case 189: *reinterpret_cast<bool*>(_v) = _t->parallelrender(); break;
        case 190: *reinterpret_cast<bool*>(_v) = _t->isParallelrenderImmutable(); break;
        case 191: *reinterpret_cast<bool*>(_v) = _t->defaultParallelrenderValue(); break;
        case 192: *reinterpret_cast<QString*>(_v) = _t->renderInterp(); break;
        case 193: *reinterpret_cast<bool*>(_v) = _t->isRenderInterpImmutable(); break;
        case 194: *reinterpret_cast<QString*>(_v) = _t->defaultRenderInterpValue(); break;
        case 195: *reinterpret_cast<QString*>(_v) = _t->renderDeinterlacer(); break;
        case 196: *reinterpret_cast<bool*>(_v) = _t->isRenderDeinterlacerImmutable(); break;
        case 197: *reinterpret_cast<QString*>(_v) = _t->defaultRenderDeinterlacerValue(); break;
        case 198: *reinterpret_cast<bool*>(_v) = _t->vaapiEnabled(); break;
        case 199: *reinterpret_cast<bool*>(_v) = _t->isVaapiEnabledImmutable(); break;
        case 200: *reinterpret_cast<bool*>(_v) = _t->defaultVaapiEnabledValue(); break;
        case 201: *reinterpret_cast<bool*>(_v) = _t->amfEnabled(); break;
        case 202: *reinterpret_cast<bool*>(_v) = _t->isAmfEnabledImmutable(); break;
        case 203: *reinterpret_cast<bool*>(_v) = _t->defaultAmfEnabledValue(); break;
        case 204: *reinterpret_cast<QStringList*>(_v) = _t->supportedHWCodecs(); break;
        case 205: *reinterpret_cast<bool*>(_v) = _t->isSupportedHWCodecsImmutable(); break;
        case 206: *reinterpret_cast<bool*>(_v) = _t->nvScalingEnabled(); break;
        case 207: *reinterpret_cast<bool*>(_v) = _t->isNvScalingEnabledImmutable(); break;
        case 208: *reinterpret_cast<bool*>(_v) = _t->defaultNvScalingEnabledValue(); break;
        case 209: *reinterpret_cast<QString*>(_v) = _t->hwDecoding(); break;
        case 210: *reinterpret_cast<bool*>(_v) = _t->isHwDecodingImmutable(); break;
        case 211: *reinterpret_cast<bool*>(_v) = _t->showRenderTextParameters(); break;
        case 212: *reinterpret_cast<bool*>(_v) = _t->isShowRenderTextParametersImmutable(); break;
        case 213: *reinterpret_cast<bool*>(_v) = _t->defaultShowRenderTextParametersValue(); break;
        case 214: *reinterpret_cast<int*>(_v) = _t->headerwidth(); break;
        case 215: *reinterpret_cast<bool*>(_v) = _t->isHeaderwidthImmutable(); break;
        case 216: *reinterpret_cast<int*>(_v) = _t->defaultHeaderwidthValue(); break;
        case 217: *reinterpret_cast<int*>(_v) = _t->defaultkeyframeinterp(); break;
        case 218: *reinterpret_cast<bool*>(_v) = _t->isDefaultkeyframeinterpImmutable(); break;
        case 219: *reinterpret_cast<int*>(_v) = _t->defaultDefaultkeyframeinterpValue(); break;
        case 220: *reinterpret_cast<int*>(_v) = _t->timelinechunks(); break;
        case 221: *reinterpret_cast<bool*>(_v) = _t->isTimelinechunksImmutable(); break;
        case 222: *reinterpret_cast<int*>(_v) = _t->defaultTimelinechunksValue(); break;
        case 223: *reinterpret_cast<bool*>(_v) = _t->autopreview(); break;
        case 224: *reinterpret_cast<bool*>(_v) = _t->isAutopreviewImmutable(); break;
        case 225: *reinterpret_cast<bool*>(_v) = _t->defaultAutopreviewValue(); break;
        case 226: *reinterpret_cast<bool*>(_v) = _t->draginprogress(); break;
        case 227: *reinterpret_cast<bool*>(_v) = _t->isDraginprogressImmutable(); break;
        case 228: *reinterpret_cast<bool*>(_v) = _t->defaultDraginprogressValue(); break;
        case 229: *reinterpret_cast<bool*>(_v) = _t->proxypreview(); break;
        case 230: *reinterpret_cast<bool*>(_v) = _t->isProxypreviewImmutable(); break;
        case 231: *reinterpret_cast<bool*>(_v) = _t->defaultProxypreviewValue(); break;
        case 232: *reinterpret_cast<int*>(_v) = _t->multistream(); break;
        case 233: *reinterpret_cast<bool*>(_v) = _t->isMultistreamImmutable(); break;
        case 234: *reinterpret_cast<int*>(_v) = _t->defaultMultistreamValue(); break;
        case 235: *reinterpret_cast<bool*>(_v) = _t->multistream_checktrack(); break;
        case 236: *reinterpret_cast<bool*>(_v) = _t->isMultistream_checktrackImmutable(); break;
        case 237: *reinterpret_cast<bool*>(_v) = _t->defaultMultistream_checktrackValue(); break;
        case 238: *reinterpret_cast<bool*>(_v) = _t->videothumbnails(); break;
        case 239: *reinterpret_cast<bool*>(_v) = _t->isVideothumbnailsImmutable(); break;
        case 240: *reinterpret_cast<bool*>(_v) = _t->defaultVideothumbnailsValue(); break;
        case 241: *reinterpret_cast<bool*>(_v) = _t->audiothumbnails(); break;
        case 242: *reinterpret_cast<bool*>(_v) = _t->isAudiothumbnailsImmutable(); break;
        case 243: *reinterpret_cast<bool*>(_v) = _t->defaultAudiothumbnailsValue(); break;
        case 244: *reinterpret_cast<int*>(_v) = _t->waveformScaler(); break;
        case 245: *reinterpret_cast<bool*>(_v) = _t->isWaveformScalerImmutable(); break;
        case 246: *reinterpret_cast<int*>(_v) = _t->defaultWaveformScalerValue(); break;
        case 247: *reinterpret_cast<bool*>(_v) = _t->showmarkers(); break;
        case 248: *reinterpret_cast<bool*>(_v) = _t->isShowmarkersImmutable(); break;
        case 249: *reinterpret_cast<bool*>(_v) = _t->defaultShowmarkersValue(); break;
        case 250: *reinterpret_cast<bool*>(_v) = _t->displayallchannels(); break;
        case 251: *reinterpret_cast<bool*>(_v) = _t->isDisplayallchannelsImmutable(); break;
        case 252: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayallchannelsValue(); break;
        case 253: *reinterpret_cast<bool*>(_v) = _t->normalizechannels(); break;
        case 254: *reinterpret_cast<bool*>(_v) = _t->isNormalizechannelsImmutable(); break;
        case 255: *reinterpret_cast<bool*>(_v) = _t->defaultNormalizechannelsValue(); break;
        case 256: *reinterpret_cast<bool*>(_v) = _t->autotrackheight(); break;
        case 257: *reinterpret_cast<bool*>(_v) = _t->isAutotrackheightImmutable(); break;
        case 258: *reinterpret_cast<bool*>(_v) = _t->defaultAutotrackheightValue(); break;
        case 259: *reinterpret_cast<bool*>(_v) = _t->autoscroll(); break;
        case 260: *reinterpret_cast<bool*>(_v) = _t->isAutoscrollImmutable(); break;
        case 261: *reinterpret_cast<bool*>(_v) = _t->defaultAutoscrollValue(); break;
        case 262: *reinterpret_cast<bool*>(_v) = _t->centeredplayhead(); break;
        case 263: *reinterpret_cast<bool*>(_v) = _t->isCenteredplayheadImmutable(); break;
        case 264: *reinterpret_cast<bool*>(_v) = _t->defaultCenteredplayheadValue(); break;
        case 265: *reinterpret_cast<bool*>(_v) = _t->jumptostart(); break;
        case 266: *reinterpret_cast<bool*>(_v) = _t->isJumptostartImmutable(); break;
        case 267: *reinterpret_cast<bool*>(_v) = _t->defaultJumptostartValue(); break;
        case 268: *reinterpret_cast<bool*>(_v) = _t->pauseonseek(); break;
        case 269: *reinterpret_cast<bool*>(_v) = _t->isPauseonseekImmutable(); break;
        case 270: *reinterpret_cast<bool*>(_v) = _t->defaultPauseonseekValue(); break;
        case 271: *reinterpret_cast<bool*>(_v) = _t->seekonaddeffect(); break;
        case 272: *reinterpret_cast<bool*>(_v) = _t->isSeekonaddeffectImmutable(); break;
        case 273: *reinterpret_cast<bool*>(_v) = _t->defaultSeekonaddeffectValue(); break;
        case 274: *reinterpret_cast<bool*>(_v) = _t->enableBuiltInEffects(); break;
        case 275: *reinterpret_cast<bool*>(_v) = _t->isEnableBuiltInEffectsImmutable(); break;
        case 276: *reinterpret_cast<bool*>(_v) = _t->defaultEnableBuiltInEffectsValue(); break;
        case 277: *reinterpret_cast<bool*>(_v) = _t->tenbitpipeline(); break;
        case 278: *reinterpret_cast<bool*>(_v) = _t->isTenbitpipelineImmutable(); break;
        case 279: *reinterpret_cast<bool*>(_v) = _t->defaultTenbitpipelineValue(); break;
        case 280: *reinterpret_cast<bool*>(_v) = _t->effectsFilter(); break;
        case 281: *reinterpret_cast<bool*>(_v) = _t->isEffectsFilterImmutable(); break;
        case 282: *reinterpret_cast<bool*>(_v) = _t->defaultEffectsFilterValue(); break;
        case 283: *reinterpret_cast<bool*>(_v) = _t->transitionsFilter(); break;
        case 284: *reinterpret_cast<bool*>(_v) = _t->isTransitionsFilterImmutable(); break;
        case 285: *reinterpret_cast<bool*>(_v) = _t->defaultTransitionsFilterValue(); break;
        case 286: *reinterpret_cast<bool*>(_v) = _t->scrollvertically(); break;
        case 287: *reinterpret_cast<bool*>(_v) = _t->isScrollverticallyImmutable(); break;
        case 288: *reinterpret_cast<bool*>(_v) = _t->defaultScrollverticallyValue(); break;
        case 289: *reinterpret_cast<int*>(_v) = _t->trackheight(); break;
        case 290: *reinterpret_cast<bool*>(_v) = _t->isTrackheightImmutable(); break;
        case 291: *reinterpret_cast<int*>(_v) = _t->defaultTrackheightValue(); break;
        case 292: *reinterpret_cast<int*>(_v) = _t->audiotracksbelow(); break;
        case 293: *reinterpret_cast<bool*>(_v) = _t->isAudiotracksbelowImmutable(); break;
        case 294: *reinterpret_cast<int*>(_v) = _t->defaultAudiotracksbelowValue(); break;
        case 295: *reinterpret_cast<bool*>(_v) = _t->raisepropsclips(); break;
        case 296: *reinterpret_cast<bool*>(_v) = _t->isRaisepropsclipsImmutable(); break;
        case 297: *reinterpret_cast<bool*>(_v) = _t->defaultRaisepropsclipsValue(); break;
        case 298: *reinterpret_cast<bool*>(_v) = _t->raisepropscompositions(); break;
        case 299: *reinterpret_cast<bool*>(_v) = _t->isRaisepropscompositionsImmutable(); break;
        case 300: *reinterpret_cast<bool*>(_v) = _t->defaultRaisepropscompositionsValue(); break;
        case 301: *reinterpret_cast<bool*>(_v) = _t->raisepropsmixes(); break;
        case 302: *reinterpret_cast<bool*>(_v) = _t->isRaisepropsmixesImmutable(); break;
        case 303: *reinterpret_cast<bool*>(_v) = _t->defaultRaisepropsmixesValue(); break;
        case 304: *reinterpret_cast<bool*>(_v) = _t->raisepropstracks(); break;
        case 305: *reinterpret_cast<bool*>(_v) = _t->isRaisepropstracksImmutable(); break;
        case 306: *reinterpret_cast<bool*>(_v) = _t->defaultRaisepropstracksValue(); break;
        case 307: *reinterpret_cast<bool*>(_v) = _t->uiDebugMode(); break;
        case 308: *reinterpret_cast<bool*>(_v) = _t->isUiDebugModeImmutable(); break;
        case 309: *reinterpret_cast<bool*>(_v) = _t->defaultUiDebugModeValue(); break;
        case 310: *reinterpret_cast<bool*>(_v) = _t->gpu_accel(); break;
        case 311: *reinterpret_cast<bool*>(_v) = _t->isGpu_accelImmutable(); break;
        case 312: *reinterpret_cast<bool*>(_v) = _t->defaultGpu_accelValue(); break;
        case 313: *reinterpret_cast<bool*>(_v) = _t->audio_scrub(); break;
        case 314: *reinterpret_cast<bool*>(_v) = _t->isAudio_scrubImmutable(); break;
        case 315: *reinterpret_cast<bool*>(_v) = _t->defaultAudio_scrubValue(); break;
        case 316: *reinterpret_cast<QString*>(_v) = _t->sdlAudioBackend(); break;
        case 317: *reinterpret_cast<bool*>(_v) = _t->isSdlAudioBackendImmutable(); break;
        case 318: *reinterpret_cast<QString*>(_v) = _t->defaultSdlAudioBackendValue(); break;
        case 319: *reinterpret_cast<int*>(_v) = _t->audio_backend(); break;
        case 320: *reinterpret_cast<bool*>(_v) = _t->isAudio_backendImmutable(); break;
        case 321: *reinterpret_cast<int*>(_v) = _t->defaultAudio_backendValue(); break;
        case 322: *reinterpret_cast<QString*>(_v) = _t->audiobackend(); break;
        case 323: *reinterpret_cast<bool*>(_v) = _t->isAudiobackendImmutable(); break;
        case 324: *reinterpret_cast<QString*>(_v) = _t->defaultAudiobackendValue(); break;
        case 325: *reinterpret_cast<uint*>(_v) = _t->audio_driver(); break;
        case 326: *reinterpret_cast<bool*>(_v) = _t->isAudio_driverImmutable(); break;
        case 327: *reinterpret_cast<uint*>(_v) = _t->defaultAudio_driverValue(); break;
        case 328: *reinterpret_cast<QString*>(_v) = _t->audiodevicename(); break;
        case 329: *reinterpret_cast<bool*>(_v) = _t->isAudiodevicenameImmutable(); break;
        case 330: *reinterpret_cast<QString*>(_v) = _t->audiodrivername(); break;
        case 331: *reinterpret_cast<bool*>(_v) = _t->isAudiodrivernameImmutable(); break;
        case 332: *reinterpret_cast<bool*>(_v) = _t->disablereccountdown(); break;
        case 333: *reinterpret_cast<bool*>(_v) = _t->isDisablereccountdownImmutable(); break;
        case 334: *reinterpret_cast<bool*>(_v) = _t->defaultDisablereccountdownValue(); break;
        case 335: *reinterpret_cast<QString*>(_v) = _t->videodrivername(); break;
        case 336: *reinterpret_cast<bool*>(_v) = _t->isVideodrivernameImmutable(); break;
        case 337: *reinterpret_cast<int*>(_v) = _t->audio_device(); break;
        case 338: *reinterpret_cast<bool*>(_v) = _t->isAudio_deviceImmutable(); break;
        case 339: *reinterpret_cast<QColor*>(_v) = _t->window_background(); break;
        case 340: *reinterpret_cast<bool*>(_v) = _t->isWindow_backgroundImmutable(); break;
        case 341: *reinterpret_cast<QColor*>(_v) = _t->defaultWindow_backgroundValue(); break;
        case 342: *reinterpret_cast<bool*>(_v) = _t->showMonitorGrid(); break;
        case 343: *reinterpret_cast<bool*>(_v) = _t->isShowMonitorGridImmutable(); break;
        case 344: *reinterpret_cast<bool*>(_v) = _t->defaultShowMonitorGridValue(); break;
        case 345: *reinterpret_cast<int*>(_v) = _t->monitorGridH(); break;
        case 346: *reinterpret_cast<bool*>(_v) = _t->isMonitorGridHImmutable(); break;
        case 347: *reinterpret_cast<int*>(_v) = _t->defaultMonitorGridHValue(); break;
        case 348: *reinterpret_cast<int*>(_v) = _t->monitorGridV(); break;
        case 349: *reinterpret_cast<bool*>(_v) = _t->isMonitorGridVImmutable(); break;
        case 350: *reinterpret_cast<int*>(_v) = _t->defaultMonitorGridVValue(); break;
        case 351: *reinterpret_cast<QString*>(_v) = _t->monitor_background(); break;
        case 352: *reinterpret_cast<bool*>(_v) = _t->isMonitor_backgroundImmutable(); break;
        case 353: *reinterpret_cast<QString*>(_v) = _t->defaultMonitor_backgroundValue(); break;
        case 354: *reinterpret_cast<bool*>(_v) = _t->monitor_progressive(); break;
        case 355: *reinterpret_cast<bool*>(_v) = _t->isMonitor_progressiveImmutable(); break;
        case 356: *reinterpret_cast<bool*>(_v) = _t->defaultMonitor_progressiveValue(); break;
        case 357: *reinterpret_cast<int*>(_v) = _t->volume(); break;
        case 358: *reinterpret_cast<bool*>(_v) = _t->isVolumeImmutable(); break;
        case 359: *reinterpret_cast<int*>(_v) = _t->defaultVolumeValue(); break;
        case 360: *reinterpret_cast<bool*>(_v) = _t->monitor_dropframes(); break;
        case 361: *reinterpret_cast<bool*>(_v) = _t->isMonitor_dropframesImmutable(); break;
        case 362: *reinterpret_cast<bool*>(_v) = _t->defaultMonitor_dropframesValue(); break;
        case 363: *reinterpret_cast<bool*>(_v) = _t->external_display(); break;
        case 364: *reinterpret_cast<bool*>(_v) = _t->isExternal_displayImmutable(); break;
        case 365: *reinterpret_cast<bool*>(_v) = _t->defaultExternal_displayValue(); break;
        case 366: *reinterpret_cast<int*>(_v) = _t->blackmagic_output_device(); break;
        case 367: *reinterpret_cast<bool*>(_v) = _t->isBlackmagic_output_deviceImmutable(); break;
        case 368: *reinterpret_cast<int*>(_v) = _t->defaultBlackmagic_output_deviceValue(); break;
        case 369: *reinterpret_cast<bool*>(_v) = _t->play_monitor_on_click(); break;
        case 370: *reinterpret_cast<bool*>(_v) = _t->isPlay_monitor_on_clickImmutable(); break;
        case 371: *reinterpret_cast<bool*>(_v) = _t->defaultPlay_monitor_on_clickValue(); break;
        case 372: *reinterpret_cast<bool*>(_v) = _t->mirrorMonitorOnFullscreen(); break;
        case 373: *reinterpret_cast<bool*>(_v) = _t->isMirrorMonitorOnFullscreenImmutable(); break;
        case 374: *reinterpret_cast<bool*>(_v) = _t->defaultMirrorMonitorOnFullscreenValue(); break;
        case 375: *reinterpret_cast<QString*>(_v) = _t->fullscreen_monitor(); break;
        case 376: *reinterpret_cast<bool*>(_v) = _t->isFullscreen_monitorImmutable(); break;
        case 377: *reinterpret_cast<QString*>(_v) = _t->project_monitor_fullscreen(); break;
        case 378: *reinterpret_cast<bool*>(_v) = _t->isProject_monitor_fullscreenImmutable(); break;
        case 379: *reinterpret_cast<QString*>(_v) = _t->clip_monitor_fullscreen(); break;
        case 380: *reinterpret_cast<bool*>(_v) = _t->isClip_monitor_fullscreenImmutable(); break;
        case 381: *reinterpret_cast<QString*>(_v) = _t->preferredcomposite(); break;
        case 382: *reinterpret_cast<bool*>(_v) = _t->isPreferredcompositeImmutable(); break;
        case 383: *reinterpret_cast<QStringList*>(_v) = _t->compositingList(); break;
        case 384: *reinterpret_cast<bool*>(_v) = _t->isCompositingListImmutable(); break;
        case 385: *reinterpret_cast<QStringList*>(_v) = _t->defaultCompositingListValue(); break;
        case 386: *reinterpret_cast<int*>(_v) = _t->subtitle_razor_mode(); break;
        case 387: *reinterpret_cast<bool*>(_v) = _t->isSubtitle_razor_modeImmutable(); break;
        case 388: *reinterpret_cast<int*>(_v) = _t->defaultSubtitle_razor_modeValue(); break;
        case 389: *reinterpret_cast<QString*>(_v) = _t->mltpath(); break;
        case 390: *reinterpret_cast<bool*>(_v) = _t->isMltpathImmutable(); break;
        case 391: *reinterpret_cast<QString*>(_v) = _t->kdenliverendererpath(); break;
        case 392: *reinterpret_cast<bool*>(_v) = _t->isKdenliverendererpathImmutable(); break;
        case 393: *reinterpret_cast<QString*>(_v) = _t->meltpath(); break;
        case 394: *reinterpret_cast<bool*>(_v) = _t->isMeltpathImmutable(); break;
        case 395: *reinterpret_cast<QString*>(_v) = _t->ffmpegpath(); break;
        case 396: *reinterpret_cast<bool*>(_v) = _t->isFfmpegpathImmutable(); break;
        case 397: *reinterpret_cast<QString*>(_v) = _t->ffplaypath(); break;
        case 398: *reinterpret_cast<bool*>(_v) = _t->isFfplaypathImmutable(); break;
        case 399: *reinterpret_cast<QString*>(_v) = _t->ffprobepath(); break;
        case 400: *reinterpret_cast<bool*>(_v) = _t->isFfprobepathImmutable(); break;
        case 401: *reinterpret_cast<int*>(_v) = _t->processingthreads(); break;
        case 402: *reinterpret_cast<bool*>(_v) = _t->isProcessingthreadsImmutable(); break;
        case 403: *reinterpret_cast<int*>(_v) = _t->defaultProcessingthreadsValue(); break;
        case 404: *reinterpret_cast<int*>(_v) = _t->proxythreads(); break;
        case 405: *reinterpret_cast<bool*>(_v) = _t->isProxythreadsImmutable(); break;
        case 406: *reinterpret_cast<int*>(_v) = _t->defaultProxythreadsValue(); break;
        case 407: *reinterpret_cast<int*>(_v) = _t->encodethreads(); break;
        case 408: *reinterpret_cast<bool*>(_v) = _t->isEncodethreadsImmutable(); break;
        case 409: *reinterpret_cast<int*>(_v) = _t->defaultEncodethreadsValue(); break;
        case 410: *reinterpret_cast<QString*>(_v) = _t->currenttmpfolder(); break;
        case 411: *reinterpret_cast<bool*>(_v) = _t->isCurrenttmpfolderImmutable(); break;
        case 412: *reinterpret_cast<QString*>(_v) = _t->defaultCurrenttmpfolderValue(); break;
        case 413: *reinterpret_cast<int*>(_v) = _t->maxcachesize(); break;
        case 414: *reinterpret_cast<bool*>(_v) = _t->isMaxcachesizeImmutable(); break;
        case 415: *reinterpret_cast<int*>(_v) = _t->defaultMaxcachesizeValue(); break;
        case 416: *reinterpret_cast<bool*>(_v) = _t->checkForUpdate(); break;
        case 417: *reinterpret_cast<bool*>(_v) = _t->isCheckForUpdateImmutable(); break;
        case 418: *reinterpret_cast<bool*>(_v) = _t->defaultCheckForUpdateValue(); break;
        case 419: *reinterpret_cast<bool*>(_v) = _t->usePowerManagement(); break;
        case 420: *reinterpret_cast<bool*>(_v) = _t->isUsePowerManagementImmutable(); break;
        case 421: *reinterpret_cast<bool*>(_v) = _t->defaultUsePowerManagementValue(); break;
        case 422: *reinterpret_cast<QDateTime*>(_v) = _t->lastCacheCheck(); break;
        case 423: *reinterpret_cast<bool*>(_v) = _t->isLastCacheCheckImmutable(); break;
        case 424: *reinterpret_cast<QString*>(_v) = _t->defaultprojectfolder(); break;
        case 425: *reinterpret_cast<bool*>(_v) = _t->isDefaultprojectfolderImmutable(); break;
        case 426: *reinterpret_cast<bool*>(_v) = _t->customprojectfolder(); break;
        case 427: *reinterpret_cast<bool*>(_v) = _t->isCustomprojectfolderImmutable(); break;
        case 428: *reinterpret_cast<bool*>(_v) = _t->defaultCustomprojectfolderValue(); break;
        case 429: *reinterpret_cast<bool*>(_v) = _t->sameprojectfolder(); break;
        case 430: *reinterpret_cast<bool*>(_v) = _t->isSameprojectfolderImmutable(); break;
        case 431: *reinterpret_cast<bool*>(_v) = _t->defaultSameprojectfolderValue(); break;
        case 432: *reinterpret_cast<int*>(_v) = _t->capturetoprojectfolder(); break;
        case 433: *reinterpret_cast<bool*>(_v) = _t->isCapturetoprojectfolderImmutable(); break;
        case 434: *reinterpret_cast<int*>(_v) = _t->defaultCapturetoprojectfolderValue(); break;
        case 435: *reinterpret_cast<QString*>(_v) = _t->capturefolder(); break;
        case 436: *reinterpret_cast<bool*>(_v) = _t->isCapturefolderImmutable(); break;
        case 437: *reinterpret_cast<QString*>(_v) = _t->defaultCapturefolderValue(); break;
        case 438: *reinterpret_cast<QString*>(_v) = _t->captureprojectsubfolder(); break;
        case 439: *reinterpret_cast<bool*>(_v) = _t->isCaptureprojectsubfolderImmutable(); break;
        case 440: *reinterpret_cast<bool*>(_v) = _t->librarytodefaultfolder(); break;
        case 441: *reinterpret_cast<bool*>(_v) = _t->isLibrarytodefaultfolderImmutable(); break;
        case 442: *reinterpret_cast<bool*>(_v) = _t->defaultLibrarytodefaultfolderValue(); break;
        case 443: *reinterpret_cast<int*>(_v) = _t->videotodefaultfolder(); break;
        case 444: *reinterpret_cast<bool*>(_v) = _t->isVideotodefaultfolderImmutable(); break;
        case 445: *reinterpret_cast<int*>(_v) = _t->defaultVideotodefaultfolderValue(); break;
        case 446: *reinterpret_cast<QString*>(_v) = _t->libraryfolder(); break;
        case 447: *reinterpret_cast<bool*>(_v) = _t->isLibraryfolderImmutable(); break;
        case 448: *reinterpret_cast<QString*>(_v) = _t->videofolder(); break;
        case 449: *reinterpret_cast<bool*>(_v) = _t->isVideofolderImmutable(); break;
        case 450: *reinterpret_cast<QString*>(_v) = _t->defaultimageapp(); break;
        case 451: *reinterpret_cast<bool*>(_v) = _t->isDefaultimageappImmutable(); break;
        case 452: *reinterpret_cast<QString*>(_v) = _t->defaultaudioapp(); break;
        case 453: *reinterpret_cast<bool*>(_v) = _t->isDefaultaudioappImmutable(); break;
        case 454: *reinterpret_cast<QString*>(_v) = _t->glaxnimatePath(); break;
        case 455: *reinterpret_cast<bool*>(_v) = _t->isGlaxnimatePathImmutable(); break;
        case 456: *reinterpret_cast<QString*>(_v) = _t->defaultvideoapp(); break;
        case 457: *reinterpret_cast<bool*>(_v) = _t->isDefaultvideoappImmutable(); break;
        case 458: *reinterpret_cast<bool*>(_v) = _t->nice_tasks(); break;
        case 459: *reinterpret_cast<bool*>(_v) = _t->isNice_tasksImmutable(); break;
        case 460: *reinterpret_cast<bool*>(_v) = _t->defaultNice_tasksValue(); break;
        case 461: *reinterpret_cast<QString*>(_v) = _t->exportGuidesFormat(); break;
        case 462: *reinterpret_cast<bool*>(_v) = _t->isExportGuidesFormatImmutable(); break;
        case 463: *reinterpret_cast<double*>(_v) = _t->multipleguidesinterval(); break;
        case 464: *reinterpret_cast<bool*>(_v) = _t->isMultipleguidesintervalImmutable(); break;
        case 465: *reinterpret_cast<double*>(_v) = _t->defaultMultipleguidesintervalValue(); break;
        case 466: *reinterpret_cast<bool*>(_v) = _t->guidesShowThumbs(); break;
        case 467: *reinterpret_cast<bool*>(_v) = _t->isGuidesShowThumbsImmutable(); break;
        case 468: *reinterpret_cast<bool*>(_v) = _t->defaultGuidesShowThumbsValue(); break;
        case 469: *reinterpret_cast<bool*>(_v) = _t->guidesSelectZone(); break;
        case 470: *reinterpret_cast<bool*>(_v) = _t->isGuidesSelectZoneImmutable(); break;
        case 471: *reinterpret_cast<bool*>(_v) = _t->defaultGuidesSelectZoneValue(); break;
        case 472: *reinterpret_cast<QString*>(_v) = _t->defaultaudiocapture(); break;
        case 473: *reinterpret_cast<bool*>(_v) = _t->isDefaultaudiocaptureImmutable(); break;
        case 474: *reinterpret_cast<QString*>(_v) = _t->defaultDefaultaudiocaptureValue(); break;
        case 475: *reinterpret_cast<int*>(_v) = _t->audiocapturevolume(); break;
        case 476: *reinterpret_cast<bool*>(_v) = _t->isAudiocapturevolumeImmutable(); break;
        case 477: *reinterpret_cast<int*>(_v) = _t->defaultAudiocapturevolumeValue(); break;
        case 478: *reinterpret_cast<int*>(_v) = _t->audiocapturechannels(); break;
        case 479: *reinterpret_cast<bool*>(_v) = _t->isAudiocapturechannelsImmutable(); break;
        case 480: *reinterpret_cast<int*>(_v) = _t->defaultAudiocapturechannelsValue(); break;
        case 481: *reinterpret_cast<int*>(_v) = _t->audiocapturesamplerate(); break;
        case 482: *reinterpret_cast<bool*>(_v) = _t->isAudiocapturesamplerateImmutable(); break;
        case 483: *reinterpret_cast<int*>(_v) = _t->defaultAudiocapturesamplerateValue(); break;
        case 484: *reinterpret_cast<int*>(_v) = _t->audiocapturesampleformat(); break;
        case 485: *reinterpret_cast<bool*>(_v) = _t->isAudiocapturesampleformatImmutable(); break;
        case 486: *reinterpret_cast<int*>(_v) = _t->defaultAudiocapturesampleformatValue(); break;
        case 487: *reinterpret_cast<int*>(_v) = _t->defaultcapture(); break;
        case 488: *reinterpret_cast<bool*>(_v) = _t->isDefaultcaptureImmutable(); break;
        case 489: *reinterpret_cast<int*>(_v) = _t->defaultDefaultcaptureValue(); break;
        case 490: *reinterpret_cast<uint*>(_v) = _t->alsachannels(); break;
        case 491: *reinterpret_cast<bool*>(_v) = _t->isAlsachannelsImmutable(); break;
        case 492: *reinterpret_cast<uint*>(_v) = _t->defaultAlsachannelsValue(); break;
        case 493: *reinterpret_cast<int*>(_v) = _t->grab_profile(); break;
        case 494: *reinterpret_cast<bool*>(_v) = _t->isGrab_profileImmutable(); break;
        case 495: *reinterpret_cast<int*>(_v) = _t->defaultGrab_profileValue(); break;
        case 496: *reinterpret_cast<QString*>(_v) = _t->grab_parameters(); break;
        case 497: *reinterpret_cast<bool*>(_v) = _t->isGrab_parametersImmutable(); break;
        case 498: *reinterpret_cast<QString*>(_v) = _t->grab_extension(); break;
        case 499: *reinterpret_cast<bool*>(_v) = _t->isGrab_extensionImmutable(); break;
        case 500: *reinterpret_cast<int*>(_v) = _t->grab_capture_type(); break;
        case 501: *reinterpret_cast<bool*>(_v) = _t->isGrab_capture_typeImmutable(); break;
        case 502: *reinterpret_cast<int*>(_v) = _t->defaultGrab_capture_typeValue(); break;
        case 503: *reinterpret_cast<bool*>(_v) = _t->grab_follow_mouse(); break;
        case 504: *reinterpret_cast<bool*>(_v) = _t->isGrab_follow_mouseImmutable(); break;
        case 505: *reinterpret_cast<bool*>(_v) = _t->defaultGrab_follow_mouseValue(); break;
        case 506: *reinterpret_cast<int*>(_v) = _t->grab_offsetx(); break;
        case 507: *reinterpret_cast<bool*>(_v) = _t->isGrab_offsetxImmutable(); break;
        case 508: *reinterpret_cast<int*>(_v) = _t->defaultGrab_offsetxValue(); break;
        case 509: *reinterpret_cast<int*>(_v) = _t->grab_offsety(); break;
        case 510: *reinterpret_cast<bool*>(_v) = _t->isGrab_offsetyImmutable(); break;
        case 511: *reinterpret_cast<int*>(_v) = _t->defaultGrab_offsetyValue(); break;
        case 512: *reinterpret_cast<int*>(_v) = _t->grab_width(); break;
        case 513: *reinterpret_cast<bool*>(_v) = _t->isGrab_widthImmutable(); break;
        case 514: *reinterpret_cast<int*>(_v) = _t->defaultGrab_widthValue(); break;
        case 515: *reinterpret_cast<int*>(_v) = _t->grab_height(); break;
        case 516: *reinterpret_cast<bool*>(_v) = _t->isGrab_heightImmutable(); break;
        case 517: *reinterpret_cast<int*>(_v) = _t->defaultGrab_heightValue(); break;
        case 518: *reinterpret_cast<double*>(_v) = _t->grab_fps(); break;
        case 519: *reinterpret_cast<bool*>(_v) = _t->isGrab_fpsImmutable(); break;
        case 520: *reinterpret_cast<double*>(_v) = _t->defaultGrab_fpsValue(); break;
        case 521: *reinterpret_cast<bool*>(_v) = _t->grab_hide_frame(); break;
        case 522: *reinterpret_cast<bool*>(_v) = _t->isGrab_hide_frameImmutable(); break;
        case 523: *reinterpret_cast<bool*>(_v) = _t->defaultGrab_hide_frameValue(); break;
        case 524: *reinterpret_cast<bool*>(_v) = _t->grab_hide_mouse(); break;
        case 525: *reinterpret_cast<bool*>(_v) = _t->isGrab_hide_mouseImmutable(); break;
        case 526: *reinterpret_cast<bool*>(_v) = _t->defaultGrab_hide_mouseValue(); break;
        case 527: *reinterpret_cast<bool*>(_v) = _t->decklink_device_found(); break;
        case 528: *reinterpret_cast<bool*>(_v) = _t->isDecklink_device_foundImmutable(); break;
        case 529: *reinterpret_cast<bool*>(_v) = _t->defaultDecklink_device_foundValue(); break;
        case 530: *reinterpret_cast<uint*>(_v) = _t->decklink_capturedevice(); break;
        case 531: *reinterpret_cast<bool*>(_v) = _t->isDecklink_capturedeviceImmutable(); break;
        case 532: *reinterpret_cast<uint*>(_v) = _t->defaultDecklink_capturedeviceValue(); break;
        case 533: *reinterpret_cast<int*>(_v) = _t->decklink_profile(); break;
        case 534: *reinterpret_cast<bool*>(_v) = _t->isDecklink_profileImmutable(); break;
        case 535: *reinterpret_cast<int*>(_v) = _t->defaultDecklink_profileValue(); break;
        case 536: *reinterpret_cast<QString*>(_v) = _t->decklink_filename(); break;
        case 537: *reinterpret_cast<bool*>(_v) = _t->isDecklink_filenameImmutable(); break;
        case 538: *reinterpret_cast<QString*>(_v) = _t->defaultDecklink_filenameValue(); break;
        case 539: *reinterpret_cast<QString*>(_v) = _t->decklink_parameters(); break;
        case 540: *reinterpret_cast<bool*>(_v) = _t->isDecklink_parametersImmutable(); break;
        case 541: *reinterpret_cast<QString*>(_v) = _t->decklink_extension(); break;
        case 542: *reinterpret_cast<bool*>(_v) = _t->isDecklink_extensionImmutable(); break;
        case 543: *reinterpret_cast<bool*>(_v) = _t->enableshuttle(); break;
        case 544: *reinterpret_cast<bool*>(_v) = _t->isEnableshuttleImmutable(); break;
        case 545: *reinterpret_cast<bool*>(_v) = _t->defaultEnableshuttleValue(); break;
        case 546: *reinterpret_cast<QString*>(_v) = _t->shuttledevice(); break;
        case 547: *reinterpret_cast<bool*>(_v) = _t->isShuttledeviceImmutable(); break;
        case 548: *reinterpret_cast<QStringList*>(_v) = _t->shuttledevicenames(); break;
        case 549: *reinterpret_cast<bool*>(_v) = _t->isShuttledevicenamesImmutable(); break;
        case 550: *reinterpret_cast<QStringList*>(_v) = _t->shuttledevicepaths(); break;
        case 551: *reinterpret_cast<bool*>(_v) = _t->isShuttledevicepathsImmutable(); break;
        case 552: *reinterpret_cast<QString*>(_v) = _t->shuttlebuttons(); break;
        case 553: *reinterpret_cast<bool*>(_v) = _t->isShuttlebuttonsImmutable(); break;
        case 554: *reinterpret_cast<int*>(_v) = _t->bezier_gridlines(); break;
        case 555: *reinterpret_cast<bool*>(_v) = _t->isBezier_gridlinesImmutable(); break;
        case 556: *reinterpret_cast<int*>(_v) = _t->defaultBezier_gridlinesValue(); break;
        case 557: *reinterpret_cast<bool*>(_v) = _t->bezier_showpixmap(); break;
        case 558: *reinterpret_cast<bool*>(_v) = _t->isBezier_showpixmapImmutable(); break;
        case 559: *reinterpret_cast<bool*>(_v) = _t->defaultBezier_showpixmapValue(); break;
        case 560: *reinterpret_cast<bool*>(_v) = _t->bezier_showallhandles(); break;
        case 561: *reinterpret_cast<bool*>(_v) = _t->isBezier_showallhandlesImmutable(); break;
        case 562: *reinterpret_cast<bool*>(_v) = _t->defaultBezier_showallhandlesValue(); break;
        case 563: *reinterpret_cast<int*>(_v) = _t->dragvalue_mode(); break;
        case 564: *reinterpret_cast<bool*>(_v) = _t->isDragvalue_modeImmutable(); break;
        case 565: *reinterpret_cast<int*>(_v) = _t->defaultDragvalue_modeValue(); break;
        case 566: *reinterpret_cast<bool*>(_v) = _t->dragvalue_directupdate(); break;
        case 567: *reinterpret_cast<bool*>(_v) = _t->isDragvalue_directupdateImmutable(); break;
        case 568: *reinterpret_cast<bool*>(_v) = _t->defaultDragvalue_directupdateValue(); break;
        case 569: *reinterpret_cast<QStringList*>(_v) = _t->recentProfiles(); break;
        case 570: *reinterpret_cast<bool*>(_v) = _t->isRecentProfilesImmutable(); break;
        case 571: *reinterpret_cast<QStringList*>(_v) = _t->recentProfileNames(); break;
        case 572: *reinterpret_cast<bool*>(_v) = _t->isRecentProfileNamesImmutable(); break;
        case 573: *reinterpret_cast<int*>(_v) = _t->properties_panel_page(); break;
        case 574: *reinterpret_cast<bool*>(_v) = _t->isProperties_panel_pageImmutable(); break;
        case 575: *reinterpret_cast<int*>(_v) = _t->defaultProperties_panel_pageValue(); break;
        case 576: *reinterpret_cast<double*>(_v) = _t->project_fps(); break;
        case 577: *reinterpret_cast<bool*>(_v) = _t->isProject_fpsImmutable(); break;
        case 578: *reinterpret_cast<double*>(_v) = _t->defaultProject_fpsValue(); break;
        case 579: *reinterpret_cast<QString*>(_v) = _t->default_profile(); break;
        case 580: *reinterpret_cast<bool*>(_v) = _t->isDefault_profileImmutable(); break;
        case 581: *reinterpret_cast<QString*>(_v) = _t->kdockLayout(); break;
        case 582: *reinterpret_cast<bool*>(_v) = _t->isKdockLayoutImmutable(); break;
        case 583: *reinterpret_cast<QStringList*>(_v) = _t->layoutsOrder(); break;
        case 584: *reinterpret_cast<bool*>(_v) = _t->isLayoutsOrderImmutable(); break;
        case 585: *reinterpret_cast<QStringList*>(_v) = _t->defaultLayoutsOrderValue(); break;
        case 586: *reinterpret_cast<bool*>(_v) = _t->showdescriptioncolumn(); break;
        case 587: *reinterpret_cast<bool*>(_v) = _t->isShowdescriptioncolumnImmutable(); break;
        case 588: *reinterpret_cast<bool*>(_v) = _t->defaultShowdescriptioncolumnValue(); break;
        case 589: *reinterpret_cast<bool*>(_v) = _t->showratingcolumn(); break;
        case 590: *reinterpret_cast<bool*>(_v) = _t->isShowratingcolumnImmutable(); break;
        case 591: *reinterpret_cast<bool*>(_v) = _t->defaultShowratingcolumnValue(); break;
        case 592: *reinterpret_cast<bool*>(_v) = _t->showdatecolumn(); break;
        case 593: *reinterpret_cast<bool*>(_v) = _t->isShowdatecolumnImmutable(); break;
        case 594: *reinterpret_cast<bool*>(_v) = _t->defaultShowdatecolumnValue(); break;
        case 595: *reinterpret_cast<bool*>(_v) = _t->frametimecode(); break;
        case 596: *reinterpret_cast<bool*>(_v) = _t->isFrametimecodeImmutable(); break;
        case 597: *reinterpret_cast<bool*>(_v) = _t->defaultFrametimecodeValue(); break;
        case 598: *reinterpret_cast<bool*>(_v) = _t->rectimecode(); break;
        case 599: *reinterpret_cast<bool*>(_v) = _t->isRectimecodeImmutable(); break;
        case 600: *reinterpret_cast<bool*>(_v) = _t->defaultRectimecodeValue(); break;
        case 601: *reinterpret_cast<bool*>(_v) = _t->snaptopoints(); break;
        case 602: *reinterpret_cast<bool*>(_v) = _t->isSnaptopointsImmutable(); break;
        case 603: *reinterpret_cast<bool*>(_v) = _t->defaultSnaptopointsValue(); break;
        case 604: *reinterpret_cast<bool*>(_v) = _t->showClipOverlays(); break;
        case 605: *reinterpret_cast<bool*>(_v) = _t->isShowClipOverlaysImmutable(); break;
        case 606: *reinterpret_cast<bool*>(_v) = _t->defaultShowClipOverlaysValue(); break;
        case 607: *reinterpret_cast<bool*>(_v) = _t->rippleResize(); break;
        case 608: *reinterpret_cast<bool*>(_v) = _t->isRippleResizeImmutable(); break;
        case 609: *reinterpret_cast<bool*>(_v) = _t->defaultRippleResizeValue(); break;
        case 610: *reinterpret_cast<bool*>(_v) = _t->lockedGuides(); break;
        case 611: *reinterpret_cast<bool*>(_v) = _t->isLockedGuidesImmutable(); break;
        case 612: *reinterpret_cast<bool*>(_v) = _t->defaultLockedGuidesValue(); break;
        case 613: *reinterpret_cast<QStringList*>(_v) = _t->guidesCategories(); break;
        case 614: *reinterpret_cast<bool*>(_v) = _t->isGuidesCategoriesImmutable(); break;
        case 615: *reinterpret_cast<bool*>(_v) = _t->tagsintimeline(); break;
        case 616: *reinterpret_cast<bool*>(_v) = _t->isTagsintimelineImmutable(); break;
        case 617: *reinterpret_cast<bool*>(_v) = _t->defaultTagsintimelineValue(); break;
        case 618: *reinterpret_cast<bool*>(_v) = _t->timelinemousezoomonplayhead(); break;
        case 619: *reinterpret_cast<bool*>(_v) = _t->isTimelinemousezoomonplayheadImmutable(); break;
        case 620: *reinterpret_cast<bool*>(_v) = _t->defaultTimelinemousezoomonplayheadValue(); break;
        case 621: *reinterpret_cast<bool*>(_v) = _t->transitionfollowcursor(); break;
        case 622: *reinterpret_cast<bool*>(_v) = _t->isTransitionfollowcursorImmutable(); break;
        case 623: *reinterpret_cast<bool*>(_v) = _t->defaultTransitionfollowcursorValue(); break;
        case 624: *reinterpret_cast<bool*>(_v) = _t->keyframeseek(); break;
        case 625: *reinterpret_cast<bool*>(_v) = _t->isKeyframeseekImmutable(); break;
        case 626: *reinterpret_cast<bool*>(_v) = _t->defaultKeyframeseekValue(); break;
        case 627: *reinterpret_cast<bool*>(_v) = _t->showeffectinfo(); break;
        case 628: *reinterpret_cast<bool*>(_v) = _t->isShoweffectinfoImmutable(); break;
        case 629: *reinterpret_cast<bool*>(_v) = _t->defaultShoweffectinfoValue(); break;
        case 630: *reinterpret_cast<bool*>(_v) = _t->applyEffectParamsToGroup(); break;
        case 631: *reinterpret_cast<bool*>(_v) = _t->isApplyEffectParamsToGroupImmutable(); break;
        case 632: *reinterpret_cast<bool*>(_v) = _t->defaultApplyEffectParamsToGroupValue(); break;
        case 633: *reinterpret_cast<bool*>(_v) = _t->applyEffectParamsToGroupWithSameValue(); break;
        case 634: *reinterpret_cast<bool*>(_v) = _t->isApplyEffectParamsToGroupWithSameValueImmutable(); break;
        case 635: *reinterpret_cast<bool*>(_v) = _t->defaultApplyEffectParamsToGroupWithSameValueValue(); break;
        case 636: *reinterpret_cast<QString*>(_v) = _t->renderProfile(); break;
        case 637: *reinterpret_cast<bool*>(_v) = _t->isRenderProfileImmutable(); break;
        case 638: *reinterpret_cast<QString*>(_v) = _t->defaultRenderProfileValue(); break;
        case 639: *reinterpret_cast<bool*>(_v) = _t->keepRenderLogFiles(); break;
        case 640: *reinterpret_cast<bool*>(_v) = _t->isKeepRenderLogFilesImmutable(); break;
        case 641: *reinterpret_cast<bool*>(_v) = _t->defaultKeepRenderLogFilesValue(); break;
        case 642: *reinterpret_cast<QStringList*>(_v) = _t->validated_luts(); break;
        case 643: *reinterpret_cast<bool*>(_v) = _t->isValidated_lutsImmutable(); break;
        case 644: *reinterpret_cast<int*>(_v) = _t->displayClipMonitorInfo(); break;
        case 645: *reinterpret_cast<bool*>(_v) = _t->isDisplayClipMonitorInfoImmutable(); break;
        case 646: *reinterpret_cast<int*>(_v) = _t->defaultDisplayClipMonitorInfoValue(); break;
        case 647: *reinterpret_cast<bool*>(_v) = _t->showClipMonitorSafeZone(); break;
        case 648: *reinterpret_cast<bool*>(_v) = _t->isShowClipMonitorSafeZoneImmutable(); break;
        case 649: *reinterpret_cast<bool*>(_v) = _t->defaultShowClipMonitorSafeZoneValue(); break;
        case 650: *reinterpret_cast<bool*>(_v) = _t->showProjectMonitorSafeZone(); break;
        case 651: *reinterpret_cast<bool*>(_v) = _t->isShowProjectMonitorSafeZoneImmutable(); break;
        case 652: *reinterpret_cast<bool*>(_v) = _t->defaultShowProjectMonitorSafeZoneValue(); break;
        case 653: *reinterpret_cast<int*>(_v) = _t->displayProjectMonitorInfo(); break;
        case 654: *reinterpret_cast<bool*>(_v) = _t->isDisplayProjectMonitorInfoImmutable(); break;
        case 655: *reinterpret_cast<int*>(_v) = _t->defaultDisplayProjectMonitorInfoValue(); break;
        case 656: *reinterpret_cast<int*>(_v) = _t->previewScaling(); break;
        case 657: *reinterpret_cast<bool*>(_v) = _t->isPreviewScalingImmutable(); break;
        case 658: *reinterpret_cast<int*>(_v) = _t->defaultPreviewScalingValue(); break;
        case 659: *reinterpret_cast<bool*>(_v) = _t->autoKeyframe(); break;
        case 660: *reinterpret_cast<bool*>(_v) = _t->isAutoKeyframeImmutable(); break;
        case 661: *reinterpret_cast<bool*>(_v) = _t->defaultAutoKeyframeValue(); break;
        case 662: *reinterpret_cast<int*>(_v) = _t->limitAutoKeyframes(); break;
        case 663: *reinterpret_cast<bool*>(_v) = _t->isLimitAutoKeyframesImmutable(); break;
        case 664: *reinterpret_cast<int*>(_v) = _t->defaultLimitAutoKeyframesValue(); break;
        case 665: *reinterpret_cast<int*>(_v) = _t->limitAutoKeyframesInterval(); break;
        case 666: *reinterpret_cast<bool*>(_v) = _t->isLimitAutoKeyframesIntervalImmutable(); break;
        case 667: *reinterpret_cast<int*>(_v) = _t->defaultLimitAutoKeyframesIntervalValue(); break;
        case 668: *reinterpret_cast<int*>(_v) = _t->maskOpacity(); break;
        case 669: *reinterpret_cast<bool*>(_v) = _t->isMaskOpacityImmutable(); break;
        case 670: *reinterpret_cast<int*>(_v) = _t->defaultMaskOpacityValue(); break;
        case 671: *reinterpret_cast<bool*>(_v) = _t->maskInverted(); break;
        case 672: *reinterpret_cast<bool*>(_v) = _t->isMaskInvertedImmutable(); break;
        case 673: *reinterpret_cast<bool*>(_v) = _t->defaultMaskInvertedValue(); break;
        case 674: *reinterpret_cast<int*>(_v) = _t->clipMonitorOverlayGuides(); break;
        case 675: *reinterpret_cast<bool*>(_v) = _t->isClipMonitorOverlayGuidesImmutable(); break;
        case 676: *reinterpret_cast<int*>(_v) = _t->defaultClipMonitorOverlayGuidesValue(); break;
        case 677: *reinterpret_cast<int*>(_v) = _t->projectMonitorOverlayGuides(); break;
        case 678: *reinterpret_cast<bool*>(_v) = _t->isProjectMonitorOverlayGuidesImmutable(); break;
        case 679: *reinterpret_cast<int*>(_v) = _t->defaultProjectMonitorOverlayGuidesValue(); break;
        case 680: *reinterpret_cast<bool*>(_v) = _t->alwaysShowMonitorAudio(); break;
        case 681: *reinterpret_cast<bool*>(_v) = _t->isAlwaysShowMonitorAudioImmutable(); break;
        case 682: *reinterpret_cast<bool*>(_v) = _t->defaultAlwaysShowMonitorAudioValue(); break;
        case 683: *reinterpret_cast<bool*>(_v) = _t->displayAudioOverlay(); break;
        case 684: *reinterpret_cast<bool*>(_v) = _t->isDisplayAudioOverlayImmutable(); break;
        case 685: *reinterpret_cast<bool*>(_v) = _t->defaultDisplayAudioOverlayValue(); break;
        case 686: *reinterpret_cast<int*>(_v) = _t->monitoraudio(); break;
        case 687: *reinterpret_cast<bool*>(_v) = _t->isMonitoraudioImmutable(); break;
        case 688: *reinterpret_cast<int*>(_v) = _t->defaultMonitoraudioValue(); break;
        case 689: *reinterpret_cast<bool*>(_v) = _t->showOnMonitorScene(); break;
        case 690: *reinterpret_cast<bool*>(_v) = _t->isShowOnMonitorSceneImmutable(); break;
        case 691: *reinterpret_cast<bool*>(_v) = _t->defaultShowOnMonitorSceneValue(); break;
        case 692: *reinterpret_cast<QString*>(_v) = _t->autoaudiodrivername(); break;
        case 693: *reinterpret_cast<bool*>(_v) = _t->isAutoaudiodrivernameImmutable(); break;
        case 694: *reinterpret_cast<bool*>(_v) = _t->mixerCollapse(); break;
        case 695: *reinterpret_cast<bool*>(_v) = _t->isMixerCollapseImmutable(); break;
        case 696: *reinterpret_cast<bool*>(_v) = _t->defaultMixerCollapseValue(); break;
        case 697: *reinterpret_cast<QStringList*>(_v) = _t->consumerslist(); break;
        case 698: *reinterpret_cast<bool*>(_v) = _t->isConsumerslistImmutable(); break;
        case 699: *reinterpret_cast<QStringList*>(_v) = _t->producerslist(); break;
        case 700: *reinterpret_cast<bool*>(_v) = _t->isProducerslistImmutable(); break;
        case 701: *reinterpret_cast<QString*>(_v) = _t->widgetstyle(); break;
        case 702: *reinterpret_cast<bool*>(_v) = _t->isWidgetstyleImmutable(); break;
        case 703: *reinterpret_cast<bool*>(_v) = _t->showslideshowthumbs(); break;
        case 704: *reinterpret_cast<bool*>(_v) = _t->isShowslideshowthumbsImmutable(); break;
        case 705: *reinterpret_cast<bool*>(_v) = _t->defaultShowslideshowthumbsValue(); break;
        case 706: *reinterpret_cast<bool*>(_v) = _t->showtitlebars(); break;
        case 707: *reinterpret_cast<bool*>(_v) = _t->isShowtitlebarsImmutable(); break;
        case 708: *reinterpret_cast<bool*>(_v) = _t->defaultShowtitlebarsValue(); break;
        case 709: *reinterpret_cast<QColor*>(_v) = _t->colorclipcolor(); break;
        case 710: *reinterpret_cast<bool*>(_v) = _t->isColorclipcolorImmutable(); break;
        case 711: *reinterpret_cast<QColor*>(_v) = _t->defaultColorclipcolorValue(); break;
        case 712: *reinterpret_cast<bool*>(_v) = _t->showSubtitles(); break;
        case 713: *reinterpret_cast<bool*>(_v) = _t->isShowSubtitlesImmutable(); break;
        case 714: *reinterpret_cast<bool*>(_v) = _t->defaultShowSubtitlesValue(); break;
        case 715: *reinterpret_cast<double*>(_v) = _t->subtitleEditFontSize(); break;
        case 716: *reinterpret_cast<bool*>(_v) = _t->isSubtitleEditFontSizeImmutable(); break;
        case 717: *reinterpret_cast<double*>(_v) = _t->defaultSubtitleEditFontSizeValue(); break;
        case 718: *reinterpret_cast<QColor*>(_v) = _t->thumbColor1(); break;
        case 719: *reinterpret_cast<bool*>(_v) = _t->isThumbColor1Immutable(); break;
        case 720: *reinterpret_cast<QColor*>(_v) = _t->defaultThumbColor1Value(); break;
        case 721: *reinterpret_cast<QColor*>(_v) = _t->thumbColor2(); break;
        case 722: *reinterpret_cast<bool*>(_v) = _t->isThumbColor2Immutable(); break;
        case 723: *reinterpret_cast<QColor*>(_v) = _t->defaultThumbColor2Value(); break;
        case 724: *reinterpret_cast<QColor*>(_v) = _t->overlayColor(); break;
        case 725: *reinterpret_cast<bool*>(_v) = _t->isOverlayColorImmutable(); break;
        case 726: *reinterpret_cast<QColor*>(_v) = _t->defaultOverlayColorValue(); break;
        case 727: *reinterpret_cast<QColor*>(_v) = _t->safeColor(); break;
        case 728: *reinterpret_cast<bool*>(_v) = _t->isSafeColorImmutable(); break;
        case 729: *reinterpret_cast<QColor*>(_v) = _t->defaultSafeColorValue(); break;
        case 730: *reinterpret_cast<int*>(_v) = _t->defaultrescalewidth(); break;
        case 731: *reinterpret_cast<bool*>(_v) = _t->isDefaultrescalewidthImmutable(); break;
        case 732: *reinterpret_cast<int*>(_v) = _t->defaultDefaultrescalewidthValue(); break;
        case 733: *reinterpret_cast<int*>(_v) = _t->defaultrescaleheight(); break;
        case 734: *reinterpret_cast<bool*>(_v) = _t->isDefaultrescaleheightImmutable(); break;
        case 735: *reinterpret_cast<int*>(_v) = _t->defaultDefaultrescaleheightValue(); break;
        case 736: *reinterpret_cast<bool*>(_v) = _t->slideshowbymime(); break;
        case 737: *reinterpret_cast<bool*>(_v) = _t->isSlideshowbymimeImmutable(); break;
        case 738: *reinterpret_cast<bool*>(_v) = _t->defaultSlideshowbymimeValue(); break;
        case 739: *reinterpret_cast<QString*>(_v) = _t->slideshowmimeextension(); break;
        case 740: *reinterpret_cast<bool*>(_v) = _t->isSlideshowmimeextensionImmutable(); break;
        case 741: *reinterpret_cast<bool*>(_v) = _t->monitorscene_directupdate(); break;
        case 742: *reinterpret_cast<bool*>(_v) = _t->isMonitorscene_directupdateImmutable(); break;
        case 743: *reinterpret_cast<bool*>(_v) = _t->defaultMonitorscene_directupdateValue(); break;
        case 744: *reinterpret_cast<bool*>(_v) = _t->analyse_stopmotion(); break;
        case 745: *reinterpret_cast<bool*>(_v) = _t->isAnalyse_stopmotionImmutable(); break;
        case 746: *reinterpret_cast<bool*>(_v) = _t->defaultAnalyse_stopmotionValue(); break;
        case 747: *reinterpret_cast<bool*>(_v) = _t->enableaudiospectrum(); break;
        case 748: *reinterpret_cast<bool*>(_v) = _t->isEnableaudiospectrumImmutable(); break;
        case 749: *reinterpret_cast<bool*>(_v) = _t->defaultEnableaudiospectrumValue(); break;
        case 750: *reinterpret_cast<bool*>(_v) = _t->showstopmotionthumbs(); break;
        case 751: *reinterpret_cast<bool*>(_v) = _t->isShowstopmotionthumbsImmutable(); break;
        case 752: *reinterpret_cast<bool*>(_v) = _t->defaultShowstopmotionthumbsValue(); break;
        case 753: *reinterpret_cast<int*>(_v) = _t->captureinterval(); break;
        case 754: *reinterpret_cast<bool*>(_v) = _t->isCaptureintervalImmutable(); break;
        case 755: *reinterpret_cast<int*>(_v) = _t->defaultCaptureintervalValue(); break;
        case 756: *reinterpret_cast<int*>(_v) = _t->sm_notifytime(); break;
        case 757: *reinterpret_cast<bool*>(_v) = _t->isSm_notifytimeImmutable(); break;
        case 758: *reinterpret_cast<int*>(_v) = _t->defaultSm_notifytimeValue(); break;
        case 759: *reinterpret_cast<bool*>(_v) = _t->sm_prenotify(); break;
        case 760: *reinterpret_cast<bool*>(_v) = _t->isSm_prenotifyImmutable(); break;
        case 761: *reinterpret_cast<bool*>(_v) = _t->defaultSm_prenotifyValue(); break;
        case 762: *reinterpret_cast<bool*>(_v) = _t->sm_loop(); break;
        case 763: *reinterpret_cast<bool*>(_v) = _t->isSm_loopImmutable(); break;
        case 764: *reinterpret_cast<bool*>(_v) = _t->defaultSm_loopValue(); break;
        case 765: *reinterpret_cast<bool*>(_v) = _t->sm_playsound(); break;
        case 766: *reinterpret_cast<bool*>(_v) = _t->isSm_playsoundImmutable(); break;
        case 767: *reinterpret_cast<bool*>(_v) = _t->defaultSm_playsoundValue(); break;
        case 768: *reinterpret_cast<int*>(_v) = _t->sm_framesplayback(); break;
        case 769: *reinterpret_cast<bool*>(_v) = _t->isSm_framesplaybackImmutable(); break;
        case 770: *reinterpret_cast<int*>(_v) = _t->defaultSm_framesplaybackValue(); break;
        case 771: *reinterpret_cast<int*>(_v) = _t->stopmotioneffect(); break;
        case 772: *reinterpret_cast<bool*>(_v) = _t->isStopmotioneffectImmutable(); break;
        case 773: *reinterpret_cast<int*>(_v) = _t->defaultStopmotioneffectValue(); break;
        case 774: *reinterpret_cast<bool*>(_v) = _t->onmonitoreffects_cornersshowlines(); break;
        case 775: *reinterpret_cast<bool*>(_v) = _t->isOnmonitoreffects_cornersshowlinesImmutable(); break;
        case 776: *reinterpret_cast<bool*>(_v) = _t->defaultOnmonitoreffects_cornersshowlinesValue(); break;
        case 777: *reinterpret_cast<bool*>(_v) = _t->onmonitoreffects_geometryshowprevious(); break;
        case 778: *reinterpret_cast<bool*>(_v) = _t->isOnmonitoreffects_geometryshowpreviousImmutable(); break;
        case 779: *reinterpret_cast<bool*>(_v) = _t->defaultOnmonitoreffects_geometryshowpreviousValue(); break;
        case 780: *reinterpret_cast<bool*>(_v) = _t->onmonitoreffects_geometryshowpath(); break;
        case 781: *reinterpret_cast<bool*>(_v) = _t->isOnmonitoreffects_geometryshowpathImmutable(); break;
        case 782: *reinterpret_cast<bool*>(_v) = _t->defaultOnmonitoreffects_geometryshowpathValue(); break;
        case 783: *reinterpret_cast<bool*>(_v) = _t->onmonitoreffects_cornersshowcontrols(); break;
        case 784: *reinterpret_cast<bool*>(_v) = _t->isOnmonitoreffects_cornersshowcontrolsImmutable(); break;
        case 785: *reinterpret_cast<bool*>(_v) = _t->defaultOnmonitoreffects_cornersshowcontrolsValue(); break;
        case 786: *reinterpret_cast<bool*>(_v) = _t->projectloading_avformatnovalidate(); break;
        case 787: *reinterpret_cast<bool*>(_v) = _t->isProjectloading_avformatnovalidateImmutable(); break;
        case 788: *reinterpret_cast<bool*>(_v) = _t->defaultProjectloading_avformatnovalidateValue(); break;
        case 789: *reinterpret_cast<bool*>(_v) = _t->monitor_audio(); break;
        case 790: *reinterpret_cast<bool*>(_v) = _t->isMonitor_audioImmutable(); break;
        case 791: *reinterpret_cast<bool*>(_v) = _t->defaultMonitor_audioValue(); break;
        case 792: *reinterpret_cast<bool*>(_v) = _t->enable_recording_preview(); break;
        case 793: *reinterpret_cast<bool*>(_v) = _t->isEnable_recording_previewImmutable(); break;
        case 794: *reinterpret_cast<bool*>(_v) = _t->defaultEnable_recording_previewValue(); break;
        case 795: *reinterpret_cast<bool*>(_v) = _t->add_new_clip(); break;
        case 796: *reinterpret_cast<bool*>(_v) = _t->isAdd_new_clipImmutable(); break;
        case 797: *reinterpret_cast<bool*>(_v) = _t->defaultAdd_new_clipValue(); break;
        case 798: *reinterpret_cast<bool*>(_v) = _t->add_new_clip_to_folder(); break;
        case 799: *reinterpret_cast<bool*>(_v) = _t->isAdd_new_clip_to_folderImmutable(); break;
        case 800: *reinterpret_cast<bool*>(_v) = _t->defaultAdd_new_clip_to_folderValue(); break;
        case 801: *reinterpret_cast<int*>(_v) = _t->default_marker_type(); break;
        case 802: *reinterpret_cast<bool*>(_v) = _t->isDefault_marker_typeImmutable(); break;
        case 803: *reinterpret_cast<int*>(_v) = _t->defaultDefault_marker_typeValue(); break;
        case 804: *reinterpret_cast<QString*>(_v) = _t->mltdeinterlacer(); break;
        case 805: *reinterpret_cast<bool*>(_v) = _t->isMltdeinterlacerImmutable(); break;
        case 806: *reinterpret_cast<QString*>(_v) = _t->defaultMltdeinterlacerValue(); break;
        case 807: *reinterpret_cast<QString*>(_v) = _t->mltinterpolation(); break;
        case 808: *reinterpret_cast<bool*>(_v) = _t->isMltinterpolationImmutable(); break;
        case 809: *reinterpret_cast<QString*>(_v) = _t->defaultMltinterpolationValue(); break;
        case 810: *reinterpret_cast<QStringList*>(_v) = _t->favorite_effects(); break;
        case 811: *reinterpret_cast<bool*>(_v) = _t->isFavorite_effectsImmutable(); break;
        case 812: *reinterpret_cast<QStringList*>(_v) = _t->defaultFavorite_effectsValue(); break;
        case 813: *reinterpret_cast<QStringList*>(_v) = _t->favorite_transitions(); break;
        case 814: *reinterpret_cast<bool*>(_v) = _t->isFavorite_transitionsImmutable(); break;
        case 815: *reinterpret_cast<QStringList*>(_v) = _t->defaultFavorite_transitionsValue(); break;
        case 816: *reinterpret_cast<int*>(_v) = _t->selected_effecttab(); break;
        case 817: *reinterpret_cast<bool*>(_v) = _t->isSelected_effecttabImmutable(); break;
        case 818: *reinterpret_cast<int*>(_v) = _t->defaultSelected_effecttabValue(); break;
        case 819: *reinterpret_cast<bool*>(_v) = _t->effectViewAsIcon(); break;
        case 820: *reinterpret_cast<bool*>(_v) = _t->isEffectViewAsIconImmutable(); break;
        case 821: *reinterpret_cast<bool*>(_v) = _t->defaultEffectViewAsIconValue(); break;
        case 822: *reinterpret_cast<bool*>(_v) = _t->transitionViewAsIcon(); break;
        case 823: *reinterpret_cast<bool*>(_v) = _t->isTransitionViewAsIconImmutable(); break;
        case 824: *reinterpret_cast<bool*>(_v) = _t->defaultTransitionViewAsIconValue(); break;
        case 825: *reinterpret_cast<bool*>(_v) = _t->force_breeze(); break;
        case 826: *reinterpret_cast<bool*>(_v) = _t->isForce_breezeImmutable(); break;
        case 827: *reinterpret_cast<bool*>(_v) = _t->defaultForce_breezeValue(); break;
        case 828: *reinterpret_cast<bool*>(_v) = _t->use_dark_breeze(); break;
        case 829: *reinterpret_cast<bool*>(_v) = _t->isUse_dark_breezeImmutable(); break;
        case 830: *reinterpret_cast<bool*>(_v) = _t->defaultUse_dark_breezeValue(); break;
        case 831: *reinterpret_cast<bool*>(_v) = _t->showWelcome(); break;
        case 832: *reinterpret_cast<bool*>(_v) = _t->isShowWelcomeImmutable(); break;
        case 833: *reinterpret_cast<bool*>(_v) = _t->defaultShowWelcomeValue(); break;
        case 834: *reinterpret_cast<int*>(_v) = _t->lastSeenVersionMajor(); break;
        case 835: *reinterpret_cast<bool*>(_v) = _t->isLastSeenVersionMajorImmutable(); break;
        case 836: *reinterpret_cast<int*>(_v) = _t->defaultLastSeenVersionMajorValue(); break;
        case 837: *reinterpret_cast<int*>(_v) = _t->lastSeenVersionMinor(); break;
        case 838: *reinterpret_cast<bool*>(_v) = _t->isLastSeenVersionMinorImmutable(); break;
        case 839: *reinterpret_cast<int*>(_v) = _t->defaultLastSeenVersionMinorValue(); break;
        case 840: *reinterpret_cast<int*>(_v) = _t->lastSeenVersionMicro(); break;
        case 841: *reinterpret_cast<bool*>(_v) = _t->isLastSeenVersionMicroImmutable(); break;
        case 842: *reinterpret_cast<int*>(_v) = _t->defaultLastSeenVersionMicroValue(); break;
        case 843: *reinterpret_cast<bool*>(_v) = _t->lock_ratio(); break;
        case 844: *reinterpret_cast<bool*>(_v) = _t->isLock_ratioImmutable(); break;
        case 845: *reinterpret_cast<bool*>(_v) = _t->defaultLock_ratioValue(); break;
        case 846: *reinterpret_cast<QString*>(_v) = _t->selected_template(); break;
        case 847: *reinterpret_cast<bool*>(_v) = _t->isSelected_templateImmutable(); break;
        case 848: *reinterpret_cast<bool*>(_v) = _t->titlerShowGuides(); break;
        case 849: *reinterpret_cast<bool*>(_v) = _t->isTitlerShowGuidesImmutable(); break;
        case 850: *reinterpret_cast<bool*>(_v) = _t->defaultTitlerShowGuidesValue(); break;
        case 851: *reinterpret_cast<int*>(_v) = _t->titlerVersion(); break;
        case 852: *reinterpret_cast<bool*>(_v) = _t->isTitlerVersionImmutable(); break;
        case 853: *reinterpret_cast<int*>(_v) = _t->defaultTitlerVersionValue(); break;
        case 854: *reinterpret_cast<int*>(_v) = _t->titlerHGuides(); break;
        case 855: *reinterpret_cast<bool*>(_v) = _t->isTitlerHGuidesImmutable(); break;
        case 856: *reinterpret_cast<int*>(_v) = _t->defaultTitlerHGuidesValue(); break;
        case 857: *reinterpret_cast<int*>(_v) = _t->titlerVGuides(); break;
        case 858: *reinterpret_cast<bool*>(_v) = _t->isTitlerVGuidesImmutable(); break;
        case 859: *reinterpret_cast<int*>(_v) = _t->defaultTitlerVGuidesValue(); break;
        case 860: *reinterpret_cast<QColor*>(_v) = _t->titleGuideColor(); break;
        case 861: *reinterpret_cast<bool*>(_v) = _t->isTitleGuideColorImmutable(); break;
        case 862: *reinterpret_cast<QColor*>(_v) = _t->defaultTitleGuideColorValue(); break;
        case 863: *reinterpret_cast<int*>(_v) = _t->titlerbg(); break;
        case 864: *reinterpret_cast<bool*>(_v) = _t->isTitlerbgImmutable(); break;
        case 865: *reinterpret_cast<int*>(_v) = _t->defaultTitlerbgValue(); break;
        case 866: *reinterpret_cast<bool*>(_v) = _t->titlerShowbg(); break;
        case 867: *reinterpret_cast<bool*>(_v) = _t->isTitlerShowbgImmutable(); break;
        case 868: *reinterpret_cast<bool*>(_v) = _t->defaultTitlerShowbgValue(); break;
        case 869: *reinterpret_cast<int*>(_v) = _t->titlerAlign(); break;
        case 870: *reinterpret_cast<bool*>(_v) = _t->isTitlerAlignImmutable(); break;
        case 871: *reinterpret_cast<int*>(_v) = _t->defaultTitlerAlignValue(); break;
        case 872: *reinterpret_cast<QString*>(_v) = _t->samModelFile(); break;
        case 873: *reinterpret_cast<bool*>(_v) = _t->isSamModelFileImmutable(); break;
        case 874: *reinterpret_cast<bool*>(_v) = _t->sam_offload_video(); break;
        case 875: *reinterpret_cast<bool*>(_v) = _t->isSam_offload_videoImmutable(); break;
        case 876: *reinterpret_cast<bool*>(_v) = _t->defaultSam_offload_videoValue(); break;
        case 877: *reinterpret_cast<bool*>(_v) = _t->sam_system_python(); break;
        case 878: *reinterpret_cast<bool*>(_v) = _t->isSam_system_pythonImmutable(); break;
        case 879: *reinterpret_cast<bool*>(_v) = _t->defaultSam_system_pythonValue(); break;
        case 880: *reinterpret_cast<QString*>(_v) = _t->sam_system_python_path(); break;
        case 881: *reinterpret_cast<bool*>(_v) = _t->isSam_system_python_pathImmutable(); break;
        case 882: *reinterpret_cast<int*>(_v) = _t->maskBorderWidth(); break;
        case 883: *reinterpret_cast<bool*>(_v) = _t->isMaskBorderWidthImmutable(); break;
        case 884: *reinterpret_cast<int*>(_v) = _t->defaultMaskBorderWidthValue(); break;
        case 885: *reinterpret_cast<QColor*>(_v) = _t->maskBorderColor(); break;
        case 886: *reinterpret_cast<bool*>(_v) = _t->isMaskBorderColorImmutable(); break;
        case 887: *reinterpret_cast<QColor*>(_v) = _t->defaultMaskBorderColorValue(); break;
        case 888: *reinterpret_cast<QColor*>(_v) = _t->maskColor(); break;
        case 889: *reinterpret_cast<bool*>(_v) = _t->isMaskColorImmutable(); break;
        case 890: *reinterpret_cast<QColor*>(_v) = _t->defaultMaskColorValue(); break;
        case 891: *reinterpret_cast<bool*>(_v) = _t->speech_system_python(); break;
        case 892: *reinterpret_cast<bool*>(_v) = _t->isSpeech_system_pythonImmutable(); break;
        case 893: *reinterpret_cast<bool*>(_v) = _t->defaultSpeech_system_pythonValue(); break;
        case 894: *reinterpret_cast<QString*>(_v) = _t->speech_system_python_path(); break;
        case 895: *reinterpret_cast<bool*>(_v) = _t->isSpeech_system_python_pathImmutable(); break;
        case 896: *reinterpret_cast<QString*>(_v) = _t->vosk_folder_path(); break;
        case 897: *reinterpret_cast<bool*>(_v) = _t->isVosk_folder_pathImmutable(); break;
        case 898: *reinterpret_cast<QString*>(_v) = _t->vosk_text_model(); break;
        case 899: *reinterpret_cast<bool*>(_v) = _t->isVosk_text_modelImmutable(); break;
        case 900: *reinterpret_cast<QString*>(_v) = _t->vosk_srt_model(); break;
        case 901: *reinterpret_cast<bool*>(_v) = _t->isVosk_srt_modelImmutable(); break;
        case 902: *reinterpret_cast<bool*>(_v) = _t->speech_zone(); break;
        case 903: *reinterpret_cast<bool*>(_v) = _t->isSpeech_zoneImmutable(); break;
        case 904: *reinterpret_cast<bool*>(_v) = _t->defaultSpeech_zoneValue(); break;
        case 905: *reinterpret_cast<QString*>(_v) = _t->whisperModel(); break;
        case 906: *reinterpret_cast<bool*>(_v) = _t->isWhisperModelImmutable(); break;
        case 907: *reinterpret_cast<QString*>(_v) = _t->defaultWhisperModelValue(); break;
        case 908: *reinterpret_cast<QStringList*>(_v) = _t->whisperInstalledModels(); break;
        case 909: *reinterpret_cast<bool*>(_v) = _t->isWhisperInstalledModelsImmutable(); break;
        case 910: *reinterpret_cast<QStringList*>(_v) = _t->whisperAvailableModels(); break;
        case 911: *reinterpret_cast<bool*>(_v) = _t->isWhisperAvailableModelsImmutable(); break;
        case 912: *reinterpret_cast<QStringList*>(_v) = _t->defaultWhisperAvailableModelsValue(); break;
        case 913: *reinterpret_cast<QStringList*>(_v) = _t->whisperAvailableModelsHash(); break;
        case 914: *reinterpret_cast<bool*>(_v) = _t->isWhisperAvailableModelsHashImmutable(); break;
        case 915: *reinterpret_cast<QString*>(_v) = _t->whisperModelFolder(); break;
        case 916: *reinterpret_cast<bool*>(_v) = _t->isWhisperModelFolderImmutable(); break;
        case 917: *reinterpret_cast<QString*>(_v) = _t->whisperLanguage(); break;
        case 918: *reinterpret_cast<bool*>(_v) = _t->isWhisperLanguageImmutable(); break;
        case 919: *reinterpret_cast<bool*>(_v) = _t->enableSeamless(); break;
        case 920: *reinterpret_cast<bool*>(_v) = _t->isEnableSeamlessImmutable(); break;
        case 921: *reinterpret_cast<bool*>(_v) = _t->defaultEnableSeamlessValue(); break;
        case 922: *reinterpret_cast<bool*>(_v) = _t->srtSeamlessTranslate(); break;
        case 923: *reinterpret_cast<bool*>(_v) = _t->isSrtSeamlessTranslateImmutable(); break;
        case 924: *reinterpret_cast<bool*>(_v) = _t->defaultSrtSeamlessTranslateValue(); break;
        case 925: *reinterpret_cast<QString*>(_v) = _t->seamless_input(); break;
        case 926: *reinterpret_cast<bool*>(_v) = _t->isSeamless_inputImmutable(); break;
        case 927: *reinterpret_cast<QString*>(_v) = _t->seamless_output(); break;
        case 928: *reinterpret_cast<bool*>(_v) = _t->isSeamless_outputImmutable(); break;
        case 929: *reinterpret_cast<int*>(_v) = _t->whisperMaxChars(); break;
        case 930: *reinterpret_cast<bool*>(_v) = _t->isWhisperMaxCharsImmutable(); break;
        case 931: *reinterpret_cast<int*>(_v) = _t->defaultWhisperMaxCharsValue(); break;
        case 932: *reinterpret_cast<int*>(_v) = _t->subtitleMode(); break;
        case 933: *reinterpret_cast<bool*>(_v) = _t->isSubtitleModeImmutable(); break;
        case 934: *reinterpret_cast<int*>(_v) = _t->defaultSubtitleModeValue(); break;
        case 935: *reinterpret_cast<bool*>(_v) = _t->cutWhisperMaxChars(); break;
        case 936: *reinterpret_cast<bool*>(_v) = _t->isCutWhisperMaxCharsImmutable(); break;
        case 937: *reinterpret_cast<bool*>(_v) = _t->defaultCutWhisperMaxCharsValue(); break;
        case 938: *reinterpret_cast<QString*>(_v) = _t->whisperDevice(); break;
        case 939: *reinterpret_cast<bool*>(_v) = _t->isWhisperDeviceImmutable(); break;
        case 940: *reinterpret_cast<QString*>(_v) = _t->defaultWhisperDeviceValue(); break;
        case 941: *reinterpret_cast<QString*>(_v) = _t->samDevice(); break;
        case 942: *reinterpret_cast<bool*>(_v) = _t->isSamDeviceImmutable(); break;
        case 943: *reinterpret_cast<QString*>(_v) = _t->defaultSamDeviceValue(); break;
        case 944: *reinterpret_cast<bool*>(_v) = _t->whisperTranslate(); break;
        case 945: *reinterpret_cast<bool*>(_v) = _t->isWhisperTranslateImmutable(); break;
        case 946: *reinterpret_cast<bool*>(_v) = _t->defaultWhisperTranslateValue(); break;
        case 947: *reinterpret_cast<bool*>(_v) = _t->whisperDisableFP16(); break;
        case 948: *reinterpret_cast<bool*>(_v) = _t->isWhisperDisableFP16Immutable(); break;
        case 949: *reinterpret_cast<bool*>(_v) = _t->defaultWhisperDisableFP16Value(); break;
        case 950: *reinterpret_cast<QString*>(_v) = _t->whisperExtra(); break;
        case 951: *reinterpret_cast<bool*>(_v) = _t->isWhisperExtraImmutable(); break;
        case 952: *reinterpret_cast<QString*>(_v) = _t->speechEngine(); break;
        case 953: *reinterpret_cast<bool*>(_v) = _t->isSpeechEngineImmutable(); break;
        case 954: *reinterpret_cast<QString*>(_v) = _t->defaultSpeechEngineValue(); break;
        case 955: *reinterpret_cast<int*>(_v) = _t->mediaIconSize(); break;
        case 956: *reinterpret_cast<bool*>(_v) = _t->isMediaIconSizeImmutable(); break;
        case 957: *reinterpret_cast<int*>(_v) = _t->defaultMediaIconSizeValue(); break;
        case 958: *reinterpret_cast<QString*>(_v) = _t->mediaManagerPanelLayout(); break;
        case 959: *reinterpret_cast<bool*>(_v) = _t->isMediaManagerPanelLayoutImmutable(); break;
        case 960: *reinterpret_cast<int*>(_v) = _t->mediaManagerPanelWidth(); break;
        case 961: *reinterpret_cast<bool*>(_v) = _t->isMediaManagerPanelWidthImmutable(); break;
        case 962: *reinterpret_cast<int*>(_v) = _t->defaultMediaManagerPanelWidthValue(); break;
        case 963: *reinterpret_cast<bool*>(_v) = _t->mediaBrowserAutoPlay(); break;
        case 964: *reinterpret_cast<bool*>(_v) = _t->isMediaBrowserAutoPlayImmutable(); break;
        case 965: *reinterpret_cast<bool*>(_v) = _t->defaultMediaBrowserAutoPlayValue(); break;
        case 966: *reinterpret_cast<bool*>(_v) = _t->mediaBrowserWithAudio(); break;
        case 967: *reinterpret_cast<bool*>(_v) = _t->isMediaBrowserWithAudioImmutable(); break;
        case 968: *reinterpret_cast<bool*>(_v) = _t->defaultMediaBrowserWithAudioValue(); break;
        case 969: *reinterpret_cast<bool*>(_v) = _t->mediaDoubleClickImport(); break;
        case 970: *reinterpret_cast<bool*>(_v) = _t->isMediaDoubleClickImportImmutable(); break;
        case 971: *reinterpret_cast<bool*>(_v) = _t->defaultMediaDoubleClickImportValue(); break;
        case 972: *reinterpret_cast<bool*>(_v) = _t->mediaBrowserInlinePreview(); break;
        case 973: *reinterpret_cast<bool*>(_v) = _t->isMediaBrowserInlinePreviewImmutable(); break;
        case 974: *reinterpret_cast<bool*>(_v) = _t->defaultMediaBrowserInlinePreviewValue(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTreeviewheaders(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setBinSorting(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setBinMode(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setBin_zoom(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setAddedExtensions(*reinterpret_cast<QString*>(_v)); break;
        case 13: _t->setHoverPreview(*reinterpret_cast<bool*>(_v)); break;
        case 16: _t->setBinsCount(*reinterpret_cast<int*>(_v)); break;
        case 19: _t->setScenesplitthreshold(*reinterpret_cast<int*>(_v)); break;
        case 22: _t->setScenesplitmarkers(*reinterpret_cast<bool*>(_v)); break;
        case 25: _t->setScenesplitrangemarkers(*reinterpret_cast<bool*>(_v)); break;
        case 28: _t->setScenesplitsubclips(*reinterpret_cast<bool*>(_v)); break;
        case 31: _t->setCleanCacheMonths(*reinterpret_cast<int*>(_v)); break;
        case 34: _t->setOpenlastproject(*reinterpret_cast<bool*>(_v)); break;
        case 37: _t->setCrashrecovery(*reinterpret_cast<bool*>(_v)); break;
        case 40: _t->setAutosave_time(*reinterpret_cast<int*>(_v)); break;
        case 43: _t->setAutosave_ops(*reinterpret_cast<int*>(_v)); break;
        case 46: _t->setTabposition(*reinterpret_cast<int*>(_v)); break;
        case 49: _t->setCheckfirstprojectclip(*reinterpret_cast<bool*>(_v)); break;
        case 52: _t->setKeep_original_frame_size(*reinterpret_cast<bool*>(_v)); break;
        case 55: _t->setExportframe_usingsourceres(*reinterpret_cast<bool*>(_v)); break;
        case 58: _t->setColor_duration(*reinterpret_cast<QString*>(_v)); break;
        case 61: _t->setImage_duration(*reinterpret_cast<QString*>(_v)); break;
        case 64: _t->setSequence_duration(*reinterpret_cast<QString*>(_v)); break;
        case 67: _t->setFade_duration(*reinterpret_cast<QString*>(_v)); break;
        case 70: _t->setMix_duration(*reinterpret_cast<QString*>(_v)); break;
        case 73: _t->setSubtitle_duration(*reinterpret_cast<QString*>(_v)); break;
        case 76: _t->setAutoimagesequence(*reinterpret_cast<bool*>(_v)); break;
        case 79: _t->setIgnoresubdirstructure(*reinterpret_cast<bool*>(_v)); break;
        case 82: _t->setDisableimagescaling(*reinterpret_cast<bool*>(_v)); break;
        case 85: _t->setAutomultistreams(*reinterpret_cast<bool*>(_v)); break;
        case 88: _t->setUse_exiftool(*reinterpret_cast<bool*>(_v)); break;
        case 91: _t->setUse_magicLantern(*reinterpret_cast<bool*>(_v)); break;
        case 94: _t->setTitle_duration(*reinterpret_cast<QString*>(_v)); break;
        case 97: _t->setTransition_duration(*reinterpret_cast<QString*>(_v)); break;
        case 100: _t->setEnableAssetsIncludeList(*reinterpret_cast<bool*>(_v)); break;
        case 103: _t->setEffectsInfoHeight(*reinterpret_cast<QString*>(_v)); break;
        case 105: _t->setShowEffectsInfo(*reinterpret_cast<bool*>(_v)); break;
        case 108: _t->setTransitionsInfoHeight(*reinterpret_cast<QString*>(_v)); break;
        case 110: _t->setShowTransitionsInfo(*reinterpret_cast<bool*>(_v)); break;
        case 113: _t->setDisable_effect_parameters(*reinterpret_cast<bool*>(_v)); break;
        case 116: _t->setProfile_fps_filter(*reinterpret_cast<QString*>(_v)); break;
        case 118: _t->setProfile_scanning_filter(*reinterpret_cast<QString*>(_v)); break;
        case 120: _t->setOpengl_backend(*reinterpret_cast<int*>(_v)); break;
        case 123: _t->setVideotracks(*reinterpret_cast<int*>(_v)); break;
        case 126: _t->setAudiotracks(*reinterpret_cast<int*>(_v)); break;
        case 129: _t->setAudio_channels(*reinterpret_cast<int*>(_v)); break;
        case 132: _t->setEnableproxy(*reinterpret_cast<bool*>(_v)); break;
        case 135: _t->setExternalproxy(*reinterpret_cast<bool*>(_v)); break;
        case 138: _t->setGenerateproxy(*reinterpret_cast<bool*>(_v)); break;
        case 141: _t->setExternal_proxy_profile(*reinterpret_cast<int*>(_v)); break;
        case 143: _t->setExternalProxyProfile(*reinterpret_cast<QString*>(_v)); break;
        case 145: _t->setGenerateimageproxy(*reinterpret_cast<bool*>(_v)); break;
        case 148: _t->setProxyminsize(*reinterpret_cast<int*>(_v)); break;
        case 151: _t->setProxyimageminsize(*reinterpret_cast<int*>(_v)); break;
        case 154: _t->setProxyimagesize(*reinterpret_cast<int*>(_v)); break;
        case 157: _t->setProxyscale(*reinterpret_cast<int*>(_v)); break;
        case 160: _t->setEnforceLowerTrackCompositing(*reinterpret_cast<bool*>(_v)); break;
        case 163: _t->setProxyextension(*reinterpret_cast<QString*>(_v)); break;
        case 165: _t->setProxyparams(*reinterpret_cast<QString*>(_v)); break;
        case 167: _t->setProxy_profile(*reinterpret_cast<int*>(_v)); break;
        case 170: _t->setProxyalphaextension(*reinterpret_cast<QString*>(_v)); break;
        case 172: _t->setProxyalphaparams(*reinterpret_cast<QString*>(_v)); break;
        case 174: _t->setAlpha_profile(*reinterpret_cast<int*>(_v)); break;
        case 177: _t->setTranscodeFriendly(*reinterpret_cast<QString*>(_v)); break;
        case 179: _t->setTranscodingReplace(*reinterpret_cast<bool*>(_v)); break;
        case 182: _t->setPreviewextension(*reinterpret_cast<QString*>(_v)); break;
        case 184: _t->setPreview_profile(*reinterpret_cast<int*>(_v)); break;
        case 187: _t->setPreviewparams(*reinterpret_cast<QString*>(_v)); break;
        case 189: _t->setParallelrender(*reinterpret_cast<bool*>(_v)); break;
        case 192: _t->setRenderInterp(*reinterpret_cast<QString*>(_v)); break;
        case 195: _t->setRenderDeinterlacer(*reinterpret_cast<QString*>(_v)); break;
        case 198: _t->setVaapiEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 201: _t->setAmfEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 204: _t->setSupportedHWCodecs(*reinterpret_cast<QStringList*>(_v)); break;
        case 206: _t->setNvScalingEnabled(*reinterpret_cast<bool*>(_v)); break;
        case 209: _t->setHwDecoding(*reinterpret_cast<QString*>(_v)); break;
        case 211: _t->setShowRenderTextParameters(*reinterpret_cast<bool*>(_v)); break;
        case 214: _t->setHeaderwidth(*reinterpret_cast<int*>(_v)); break;
        case 217: _t->setDefaultkeyframeinterp(*reinterpret_cast<int*>(_v)); break;
        case 220: _t->setTimelinechunks(*reinterpret_cast<int*>(_v)); break;
        case 223: _t->setAutopreview(*reinterpret_cast<bool*>(_v)); break;
        case 226: _t->setDraginprogress(*reinterpret_cast<bool*>(_v)); break;
        case 229: _t->setProxypreview(*reinterpret_cast<bool*>(_v)); break;
        case 232: _t->setMultistream(*reinterpret_cast<int*>(_v)); break;
        case 235: _t->setMultistream_checktrack(*reinterpret_cast<bool*>(_v)); break;
        case 238: _t->setVideothumbnails(*reinterpret_cast<bool*>(_v)); break;
        case 241: _t->setAudiothumbnails(*reinterpret_cast<bool*>(_v)); break;
        case 244: _t->setWaveformScaler(*reinterpret_cast<int*>(_v)); break;
        case 247: _t->setShowmarkers(*reinterpret_cast<bool*>(_v)); break;
        case 250: _t->setDisplayallchannels(*reinterpret_cast<bool*>(_v)); break;
        case 253: _t->setNormalizechannels(*reinterpret_cast<bool*>(_v)); break;
        case 256: _t->setAutotrackheight(*reinterpret_cast<bool*>(_v)); break;
        case 259: _t->setAutoscroll(*reinterpret_cast<bool*>(_v)); break;
        case 262: _t->setCenteredplayhead(*reinterpret_cast<bool*>(_v)); break;
        case 265: _t->setJumptostart(*reinterpret_cast<bool*>(_v)); break;
        case 268: _t->setPauseonseek(*reinterpret_cast<bool*>(_v)); break;
        case 271: _t->setSeekonaddeffect(*reinterpret_cast<bool*>(_v)); break;
        case 274: _t->setEnableBuiltInEffects(*reinterpret_cast<bool*>(_v)); break;
        case 277: _t->setTenbitpipeline(*reinterpret_cast<bool*>(_v)); break;
        case 280: _t->setEffectsFilter(*reinterpret_cast<bool*>(_v)); break;
        case 283: _t->setTransitionsFilter(*reinterpret_cast<bool*>(_v)); break;
        case 286: _t->setScrollvertically(*reinterpret_cast<bool*>(_v)); break;
        case 289: _t->setTrackheight(*reinterpret_cast<int*>(_v)); break;
        case 292: _t->setAudiotracksbelow(*reinterpret_cast<int*>(_v)); break;
        case 295: _t->setRaisepropsclips(*reinterpret_cast<bool*>(_v)); break;
        case 298: _t->setRaisepropscompositions(*reinterpret_cast<bool*>(_v)); break;
        case 301: _t->setRaisepropsmixes(*reinterpret_cast<bool*>(_v)); break;
        case 304: _t->setRaisepropstracks(*reinterpret_cast<bool*>(_v)); break;
        case 307: _t->setUiDebugMode(*reinterpret_cast<bool*>(_v)); break;
        case 310: _t->setGpu_accel(*reinterpret_cast<bool*>(_v)); break;
        case 313: _t->setAudio_scrub(*reinterpret_cast<bool*>(_v)); break;
        case 316: _t->setSdlAudioBackend(*reinterpret_cast<QString*>(_v)); break;
        case 319: _t->setAudio_backend(*reinterpret_cast<int*>(_v)); break;
        case 322: _t->setAudiobackend(*reinterpret_cast<QString*>(_v)); break;
        case 325: _t->setAudio_driver(*reinterpret_cast<uint*>(_v)); break;
        case 328: _t->setAudiodevicename(*reinterpret_cast<QString*>(_v)); break;
        case 330: _t->setAudiodrivername(*reinterpret_cast<QString*>(_v)); break;
        case 332: _t->setDisablereccountdown(*reinterpret_cast<bool*>(_v)); break;
        case 335: _t->setVideodrivername(*reinterpret_cast<QString*>(_v)); break;
        case 337: _t->setAudio_device(*reinterpret_cast<int*>(_v)); break;
        case 339: _t->setWindow_background(*reinterpret_cast<QColor*>(_v)); break;
        case 342: _t->setShowMonitorGrid(*reinterpret_cast<bool*>(_v)); break;
        case 345: _t->setMonitorGridH(*reinterpret_cast<int*>(_v)); break;
        case 348: _t->setMonitorGridV(*reinterpret_cast<int*>(_v)); break;
        case 351: _t->setMonitor_background(*reinterpret_cast<QString*>(_v)); break;
        case 354: _t->setMonitor_progressive(*reinterpret_cast<bool*>(_v)); break;
        case 357: _t->setVolume(*reinterpret_cast<int*>(_v)); break;
        case 360: _t->setMonitor_dropframes(*reinterpret_cast<bool*>(_v)); break;
        case 363: _t->setExternal_display(*reinterpret_cast<bool*>(_v)); break;
        case 366: _t->setBlackmagic_output_device(*reinterpret_cast<int*>(_v)); break;
        case 369: _t->setPlay_monitor_on_click(*reinterpret_cast<bool*>(_v)); break;
        case 372: _t->setMirrorMonitorOnFullscreen(*reinterpret_cast<bool*>(_v)); break;
        case 375: _t->setFullscreen_monitor(*reinterpret_cast<QString*>(_v)); break;
        case 377: _t->setProject_monitor_fullscreen(*reinterpret_cast<QString*>(_v)); break;
        case 379: _t->setClip_monitor_fullscreen(*reinterpret_cast<QString*>(_v)); break;
        case 381: _t->setPreferredcomposite(*reinterpret_cast<QString*>(_v)); break;
        case 383: _t->setCompositingList(*reinterpret_cast<QStringList*>(_v)); break;
        case 386: _t->setSubtitle_razor_mode(*reinterpret_cast<int*>(_v)); break;
        case 389: _t->setMltpath(*reinterpret_cast<QString*>(_v)); break;
        case 391: _t->setKdenliverendererpath(*reinterpret_cast<QString*>(_v)); break;
        case 393: _t->setMeltpath(*reinterpret_cast<QString*>(_v)); break;
        case 395: _t->setFfmpegpath(*reinterpret_cast<QString*>(_v)); break;
        case 397: _t->setFfplaypath(*reinterpret_cast<QString*>(_v)); break;
        case 399: _t->setFfprobepath(*reinterpret_cast<QString*>(_v)); break;
        case 401: _t->setProcessingthreads(*reinterpret_cast<int*>(_v)); break;
        case 404: _t->setProxythreads(*reinterpret_cast<int*>(_v)); break;
        case 407: _t->setEncodethreads(*reinterpret_cast<int*>(_v)); break;
        case 410: _t->setCurrenttmpfolder(*reinterpret_cast<QString*>(_v)); break;
        case 413: _t->setMaxcachesize(*reinterpret_cast<int*>(_v)); break;
        case 416: _t->setCheckForUpdate(*reinterpret_cast<bool*>(_v)); break;
        case 419: _t->setUsePowerManagement(*reinterpret_cast<bool*>(_v)); break;
        case 422: _t->setLastCacheCheck(*reinterpret_cast<QDateTime*>(_v)); break;
        case 424: _t->setDefaultprojectfolder(*reinterpret_cast<QString*>(_v)); break;
        case 426: _t->setCustomprojectfolder(*reinterpret_cast<bool*>(_v)); break;
        case 429: _t->setSameprojectfolder(*reinterpret_cast<bool*>(_v)); break;
        case 432: _t->setCapturetoprojectfolder(*reinterpret_cast<int*>(_v)); break;
        case 435: _t->setCapturefolder(*reinterpret_cast<QString*>(_v)); break;
        case 438: _t->setCaptureprojectsubfolder(*reinterpret_cast<QString*>(_v)); break;
        case 440: _t->setLibrarytodefaultfolder(*reinterpret_cast<bool*>(_v)); break;
        case 443: _t->setVideotodefaultfolder(*reinterpret_cast<int*>(_v)); break;
        case 446: _t->setLibraryfolder(*reinterpret_cast<QString*>(_v)); break;
        case 448: _t->setVideofolder(*reinterpret_cast<QString*>(_v)); break;
        case 450: _t->setDefaultimageapp(*reinterpret_cast<QString*>(_v)); break;
        case 452: _t->setDefaultaudioapp(*reinterpret_cast<QString*>(_v)); break;
        case 454: _t->setGlaxnimatePath(*reinterpret_cast<QString*>(_v)); break;
        case 456: _t->setDefaultvideoapp(*reinterpret_cast<QString*>(_v)); break;
        case 458: _t->setNice_tasks(*reinterpret_cast<bool*>(_v)); break;
        case 461: _t->setExportGuidesFormat(*reinterpret_cast<QString*>(_v)); break;
        case 463: _t->setMultipleguidesinterval(*reinterpret_cast<double*>(_v)); break;
        case 466: _t->setGuidesShowThumbs(*reinterpret_cast<bool*>(_v)); break;
        case 469: _t->setGuidesSelectZone(*reinterpret_cast<bool*>(_v)); break;
        case 472: _t->setDefaultaudiocapture(*reinterpret_cast<QString*>(_v)); break;
        case 475: _t->setAudiocapturevolume(*reinterpret_cast<int*>(_v)); break;
        case 478: _t->setAudiocapturechannels(*reinterpret_cast<int*>(_v)); break;
        case 481: _t->setAudiocapturesamplerate(*reinterpret_cast<int*>(_v)); break;
        case 484: _t->setAudiocapturesampleformat(*reinterpret_cast<int*>(_v)); break;
        case 487: _t->setDefaultcapture(*reinterpret_cast<int*>(_v)); break;
        case 490: _t->setAlsachannels(*reinterpret_cast<uint*>(_v)); break;
        case 493: _t->setGrab_profile(*reinterpret_cast<int*>(_v)); break;
        case 496: _t->setGrab_parameters(*reinterpret_cast<QString*>(_v)); break;
        case 498: _t->setGrab_extension(*reinterpret_cast<QString*>(_v)); break;
        case 500: _t->setGrab_capture_type(*reinterpret_cast<int*>(_v)); break;
        case 503: _t->setGrab_follow_mouse(*reinterpret_cast<bool*>(_v)); break;
        case 506: _t->setGrab_offsetx(*reinterpret_cast<int*>(_v)); break;
        case 509: _t->setGrab_offsety(*reinterpret_cast<int*>(_v)); break;
        case 512: _t->setGrab_width(*reinterpret_cast<int*>(_v)); break;
        case 515: _t->setGrab_height(*reinterpret_cast<int*>(_v)); break;
        case 518: _t->setGrab_fps(*reinterpret_cast<double*>(_v)); break;
        case 521: _t->setGrab_hide_frame(*reinterpret_cast<bool*>(_v)); break;
        case 524: _t->setGrab_hide_mouse(*reinterpret_cast<bool*>(_v)); break;
        case 527: _t->setDecklink_device_found(*reinterpret_cast<bool*>(_v)); break;
        case 530: _t->setDecklink_capturedevice(*reinterpret_cast<uint*>(_v)); break;
        case 533: _t->setDecklink_profile(*reinterpret_cast<int*>(_v)); break;
        case 536: _t->setDecklink_filename(*reinterpret_cast<QString*>(_v)); break;
        case 539: _t->setDecklink_parameters(*reinterpret_cast<QString*>(_v)); break;
        case 541: _t->setDecklink_extension(*reinterpret_cast<QString*>(_v)); break;
        case 543: _t->setEnableshuttle(*reinterpret_cast<bool*>(_v)); break;
        case 546: _t->setShuttledevice(*reinterpret_cast<QString*>(_v)); break;
        case 548: _t->setShuttledevicenames(*reinterpret_cast<QStringList*>(_v)); break;
        case 550: _t->setShuttledevicepaths(*reinterpret_cast<QStringList*>(_v)); break;
        case 552: _t->setShuttlebuttons(*reinterpret_cast<QString*>(_v)); break;
        case 554: _t->setBezier_gridlines(*reinterpret_cast<int*>(_v)); break;
        case 557: _t->setBezier_showpixmap(*reinterpret_cast<bool*>(_v)); break;
        case 560: _t->setBezier_showallhandles(*reinterpret_cast<bool*>(_v)); break;
        case 563: _t->setDragvalue_mode(*reinterpret_cast<int*>(_v)); break;
        case 566: _t->setDragvalue_directupdate(*reinterpret_cast<bool*>(_v)); break;
        case 569: _t->setRecentProfiles(*reinterpret_cast<QStringList*>(_v)); break;
        case 571: _t->setRecentProfileNames(*reinterpret_cast<QStringList*>(_v)); break;
        case 573: _t->setProperties_panel_page(*reinterpret_cast<int*>(_v)); break;
        case 576: _t->setProject_fps(*reinterpret_cast<double*>(_v)); break;
        case 579: _t->setDefault_profile(*reinterpret_cast<QString*>(_v)); break;
        case 581: _t->setKdockLayout(*reinterpret_cast<QString*>(_v)); break;
        case 583: _t->setLayoutsOrder(*reinterpret_cast<QStringList*>(_v)); break;
        case 586: _t->setShowdescriptioncolumn(*reinterpret_cast<bool*>(_v)); break;
        case 589: _t->setShowratingcolumn(*reinterpret_cast<bool*>(_v)); break;
        case 592: _t->setShowdatecolumn(*reinterpret_cast<bool*>(_v)); break;
        case 595: _t->setFrametimecode(*reinterpret_cast<bool*>(_v)); break;
        case 598: _t->setRectimecode(*reinterpret_cast<bool*>(_v)); break;
        case 601: _t->setSnaptopoints(*reinterpret_cast<bool*>(_v)); break;
        case 604: _t->setShowClipOverlays(*reinterpret_cast<bool*>(_v)); break;
        case 607: _t->setRippleResize(*reinterpret_cast<bool*>(_v)); break;
        case 610: _t->setLockedGuides(*reinterpret_cast<bool*>(_v)); break;
        case 613: _t->setGuidesCategories(*reinterpret_cast<QStringList*>(_v)); break;
        case 615: _t->setTagsintimeline(*reinterpret_cast<bool*>(_v)); break;
        case 618: _t->setTimelinemousezoomonplayhead(*reinterpret_cast<bool*>(_v)); break;
        case 621: _t->setTransitionfollowcursor(*reinterpret_cast<bool*>(_v)); break;
        case 624: _t->setKeyframeseek(*reinterpret_cast<bool*>(_v)); break;
        case 627: _t->setShoweffectinfo(*reinterpret_cast<bool*>(_v)); break;
        case 630: _t->setApplyEffectParamsToGroup(*reinterpret_cast<bool*>(_v)); break;
        case 633: _t->setApplyEffectParamsToGroupWithSameValue(*reinterpret_cast<bool*>(_v)); break;
        case 636: _t->setRenderProfile(*reinterpret_cast<QString*>(_v)); break;
        case 639: _t->setKeepRenderLogFiles(*reinterpret_cast<bool*>(_v)); break;
        case 642: _t->setValidated_luts(*reinterpret_cast<QStringList*>(_v)); break;
        case 644: _t->setDisplayClipMonitorInfo(*reinterpret_cast<int*>(_v)); break;
        case 647: _t->setShowClipMonitorSafeZone(*reinterpret_cast<bool*>(_v)); break;
        case 650: _t->setShowProjectMonitorSafeZone(*reinterpret_cast<bool*>(_v)); break;
        case 653: _t->setDisplayProjectMonitorInfo(*reinterpret_cast<int*>(_v)); break;
        case 656: _t->setPreviewScaling(*reinterpret_cast<int*>(_v)); break;
        case 659: _t->setAutoKeyframe(*reinterpret_cast<bool*>(_v)); break;
        case 662: _t->setLimitAutoKeyframes(*reinterpret_cast<int*>(_v)); break;
        case 665: _t->setLimitAutoKeyframesInterval(*reinterpret_cast<int*>(_v)); break;
        case 668: _t->setMaskOpacity(*reinterpret_cast<int*>(_v)); break;
        case 671: _t->setMaskInverted(*reinterpret_cast<bool*>(_v)); break;
        case 674: _t->setClipMonitorOverlayGuides(*reinterpret_cast<int*>(_v)); break;
        case 677: _t->setProjectMonitorOverlayGuides(*reinterpret_cast<int*>(_v)); break;
        case 680: _t->setAlwaysShowMonitorAudio(*reinterpret_cast<bool*>(_v)); break;
        case 683: _t->setDisplayAudioOverlay(*reinterpret_cast<bool*>(_v)); break;
        case 686: _t->setMonitoraudio(*reinterpret_cast<int*>(_v)); break;
        case 689: _t->setShowOnMonitorScene(*reinterpret_cast<bool*>(_v)); break;
        case 692: _t->setAutoaudiodrivername(*reinterpret_cast<QString*>(_v)); break;
        case 694: _t->setMixerCollapse(*reinterpret_cast<bool*>(_v)); break;
        case 697: _t->setConsumerslist(*reinterpret_cast<QStringList*>(_v)); break;
        case 699: _t->setProducerslist(*reinterpret_cast<QStringList*>(_v)); break;
        case 701: _t->setWidgetstyle(*reinterpret_cast<QString*>(_v)); break;
        case 703: _t->setShowslideshowthumbs(*reinterpret_cast<bool*>(_v)); break;
        case 706: _t->setShowtitlebars(*reinterpret_cast<bool*>(_v)); break;
        case 709: _t->setColorclipcolor(*reinterpret_cast<QColor*>(_v)); break;
        case 712: _t->setShowSubtitles(*reinterpret_cast<bool*>(_v)); break;
        case 715: _t->setSubtitleEditFontSize(*reinterpret_cast<double*>(_v)); break;
        case 718: _t->setThumbColor1(*reinterpret_cast<QColor*>(_v)); break;
        case 721: _t->setThumbColor2(*reinterpret_cast<QColor*>(_v)); break;
        case 724: _t->setOverlayColor(*reinterpret_cast<QColor*>(_v)); break;
        case 727: _t->setSafeColor(*reinterpret_cast<QColor*>(_v)); break;
        case 730: _t->setDefaultrescalewidth(*reinterpret_cast<int*>(_v)); break;
        case 733: _t->setDefaultrescaleheight(*reinterpret_cast<int*>(_v)); break;
        case 736: _t->setSlideshowbymime(*reinterpret_cast<bool*>(_v)); break;
        case 739: _t->setSlideshowmimeextension(*reinterpret_cast<QString*>(_v)); break;
        case 741: _t->setMonitorscene_directupdate(*reinterpret_cast<bool*>(_v)); break;
        case 744: _t->setAnalyse_stopmotion(*reinterpret_cast<bool*>(_v)); break;
        case 747: _t->setEnableaudiospectrum(*reinterpret_cast<bool*>(_v)); break;
        case 750: _t->setShowstopmotionthumbs(*reinterpret_cast<bool*>(_v)); break;
        case 753: _t->setCaptureinterval(*reinterpret_cast<int*>(_v)); break;
        case 756: _t->setSm_notifytime(*reinterpret_cast<int*>(_v)); break;
        case 759: _t->setSm_prenotify(*reinterpret_cast<bool*>(_v)); break;
        case 762: _t->setSm_loop(*reinterpret_cast<bool*>(_v)); break;
        case 765: _t->setSm_playsound(*reinterpret_cast<bool*>(_v)); break;
        case 768: _t->setSm_framesplayback(*reinterpret_cast<int*>(_v)); break;
        case 771: _t->setStopmotioneffect(*reinterpret_cast<int*>(_v)); break;
        case 774: _t->setOnmonitoreffects_cornersshowlines(*reinterpret_cast<bool*>(_v)); break;
        case 777: _t->setOnmonitoreffects_geometryshowprevious(*reinterpret_cast<bool*>(_v)); break;
        case 780: _t->setOnmonitoreffects_geometryshowpath(*reinterpret_cast<bool*>(_v)); break;
        case 783: _t->setOnmonitoreffects_cornersshowcontrols(*reinterpret_cast<bool*>(_v)); break;
        case 786: _t->setProjectloading_avformatnovalidate(*reinterpret_cast<bool*>(_v)); break;
        case 789: _t->setMonitor_audio(*reinterpret_cast<bool*>(_v)); break;
        case 792: _t->setEnable_recording_preview(*reinterpret_cast<bool*>(_v)); break;
        case 795: _t->setAdd_new_clip(*reinterpret_cast<bool*>(_v)); break;
        case 798: _t->setAdd_new_clip_to_folder(*reinterpret_cast<bool*>(_v)); break;
        case 801: _t->setDefault_marker_type(*reinterpret_cast<int*>(_v)); break;
        case 804: _t->setMltdeinterlacer(*reinterpret_cast<QString*>(_v)); break;
        case 807: _t->setMltinterpolation(*reinterpret_cast<QString*>(_v)); break;
        case 810: _t->setFavorite_effects(*reinterpret_cast<QStringList*>(_v)); break;
        case 813: _t->setFavorite_transitions(*reinterpret_cast<QStringList*>(_v)); break;
        case 816: _t->setSelected_effecttab(*reinterpret_cast<int*>(_v)); break;
        case 819: _t->setEffectViewAsIcon(*reinterpret_cast<bool*>(_v)); break;
        case 822: _t->setTransitionViewAsIcon(*reinterpret_cast<bool*>(_v)); break;
        case 825: _t->setForce_breeze(*reinterpret_cast<bool*>(_v)); break;
        case 828: _t->setUse_dark_breeze(*reinterpret_cast<bool*>(_v)); break;
        case 831: _t->setShowWelcome(*reinterpret_cast<bool*>(_v)); break;
        case 834: _t->setLastSeenVersionMajor(*reinterpret_cast<int*>(_v)); break;
        case 837: _t->setLastSeenVersionMinor(*reinterpret_cast<int*>(_v)); break;
        case 840: _t->setLastSeenVersionMicro(*reinterpret_cast<int*>(_v)); break;
        case 843: _t->setLock_ratio(*reinterpret_cast<bool*>(_v)); break;
        case 846: _t->setSelected_template(*reinterpret_cast<QString*>(_v)); break;
        case 848: _t->setTitlerShowGuides(*reinterpret_cast<bool*>(_v)); break;
        case 851: _t->setTitlerVersion(*reinterpret_cast<int*>(_v)); break;
        case 854: _t->setTitlerHGuides(*reinterpret_cast<int*>(_v)); break;
        case 857: _t->setTitlerVGuides(*reinterpret_cast<int*>(_v)); break;
        case 860: _t->setTitleGuideColor(*reinterpret_cast<QColor*>(_v)); break;
        case 863: _t->setTitlerbg(*reinterpret_cast<int*>(_v)); break;
        case 866: _t->setTitlerShowbg(*reinterpret_cast<bool*>(_v)); break;
        case 869: _t->setTitlerAlign(*reinterpret_cast<int*>(_v)); break;
        case 872: _t->setSamModelFile(*reinterpret_cast<QString*>(_v)); break;
        case 874: _t->setSam_offload_video(*reinterpret_cast<bool*>(_v)); break;
        case 877: _t->setSam_system_python(*reinterpret_cast<bool*>(_v)); break;
        case 880: _t->setSam_system_python_path(*reinterpret_cast<QString*>(_v)); break;
        case 882: _t->setMaskBorderWidth(*reinterpret_cast<int*>(_v)); break;
        case 885: _t->setMaskBorderColor(*reinterpret_cast<QColor*>(_v)); break;
        case 888: _t->setMaskColor(*reinterpret_cast<QColor*>(_v)); break;
        case 891: _t->setSpeech_system_python(*reinterpret_cast<bool*>(_v)); break;
        case 894: _t->setSpeech_system_python_path(*reinterpret_cast<QString*>(_v)); break;
        case 896: _t->setVosk_folder_path(*reinterpret_cast<QString*>(_v)); break;
        case 898: _t->setVosk_text_model(*reinterpret_cast<QString*>(_v)); break;
        case 900: _t->setVosk_srt_model(*reinterpret_cast<QString*>(_v)); break;
        case 902: _t->setSpeech_zone(*reinterpret_cast<bool*>(_v)); break;
        case 905: _t->setWhisperModel(*reinterpret_cast<QString*>(_v)); break;
        case 908: _t->setWhisperInstalledModels(*reinterpret_cast<QStringList*>(_v)); break;
        case 910: _t->setWhisperAvailableModels(*reinterpret_cast<QStringList*>(_v)); break;
        case 913: _t->setWhisperAvailableModelsHash(*reinterpret_cast<QStringList*>(_v)); break;
        case 915: _t->setWhisperModelFolder(*reinterpret_cast<QString*>(_v)); break;
        case 917: _t->setWhisperLanguage(*reinterpret_cast<QString*>(_v)); break;
        case 919: _t->setEnableSeamless(*reinterpret_cast<bool*>(_v)); break;
        case 922: _t->setSrtSeamlessTranslate(*reinterpret_cast<bool*>(_v)); break;
        case 925: _t->setSeamless_input(*reinterpret_cast<QString*>(_v)); break;
        case 927: _t->setSeamless_output(*reinterpret_cast<QString*>(_v)); break;
        case 929: _t->setWhisperMaxChars(*reinterpret_cast<int*>(_v)); break;
        case 932: _t->setSubtitleMode(*reinterpret_cast<int*>(_v)); break;
        case 935: _t->setCutWhisperMaxChars(*reinterpret_cast<bool*>(_v)); break;
        case 938: _t->setWhisperDevice(*reinterpret_cast<QString*>(_v)); break;
        case 941: _t->setSamDevice(*reinterpret_cast<QString*>(_v)); break;
        case 944: _t->setWhisperTranslate(*reinterpret_cast<bool*>(_v)); break;
        case 947: _t->setWhisperDisableFP16(*reinterpret_cast<bool*>(_v)); break;
        case 950: _t->setWhisperExtra(*reinterpret_cast<QString*>(_v)); break;
        case 952: _t->setSpeechEngine(*reinterpret_cast<QString*>(_v)); break;
        case 955: _t->setMediaIconSize(*reinterpret_cast<int*>(_v)); break;
        case 958: _t->setMediaManagerPanelLayout(*reinterpret_cast<QString*>(_v)); break;
        case 960: _t->setMediaManagerPanelWidth(*reinterpret_cast<int*>(_v)); break;
        case 963: _t->setMediaBrowserAutoPlay(*reinterpret_cast<bool*>(_v)); break;
        case 966: _t->setMediaBrowserWithAudio(*reinterpret_cast<bool*>(_v)); break;
        case 969: _t->setMediaDoubleClickImport(*reinterpret_cast<bool*>(_v)); break;
        case 972: _t->setMediaBrowserInlinePreview(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KdenliveSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KdenliveSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16KdenliveSettingsE_t>.strings))
        return static_cast<void*>(this);
    return KConfigSkeleton::qt_metacast(_clname);
}

int KdenliveSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KConfigSkeleton::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 350)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 350;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 350)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 350;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 975;
    }
    return _id;
}

// SIGNAL 0
void KdenliveSettings::treeviewheadersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KdenliveSettings::binSortingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KdenliveSettings::binModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KdenliveSettings::bin_zoomChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KdenliveSettings::addedExtensionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KdenliveSettings::hoverPreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void KdenliveSettings::binsCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void KdenliveSettings::scenesplitthresholdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}

// SIGNAL 8
void KdenliveSettings::scenesplitmarkersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}

// SIGNAL 9
void KdenliveSettings::scenesplitrangemarkersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 9, nullptr);
}

// SIGNAL 10
void KdenliveSettings::scenesplitsubclipsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 10, nullptr);
}

// SIGNAL 11
void KdenliveSettings::cleanCacheMonthsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 11, nullptr);
}

// SIGNAL 12
void KdenliveSettings::openlastprojectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 12, nullptr);
}

// SIGNAL 13
void KdenliveSettings::crashrecoveryChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 13, nullptr);
}

// SIGNAL 14
void KdenliveSettings::autosave_timeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 14, nullptr);
}

// SIGNAL 15
void KdenliveSettings::autosave_opsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 15, nullptr);
}

// SIGNAL 16
void KdenliveSettings::tabpositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 16, nullptr);
}

// SIGNAL 17
void KdenliveSettings::checkfirstprojectclipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 17, nullptr);
}

// SIGNAL 18
void KdenliveSettings::keep_original_frame_sizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 18, nullptr);
}

// SIGNAL 19
void KdenliveSettings::exportframe_usingsourceresChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 19, nullptr);
}

// SIGNAL 20
void KdenliveSettings::color_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 20, nullptr);
}

// SIGNAL 21
void KdenliveSettings::image_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 21, nullptr);
}

// SIGNAL 22
void KdenliveSettings::sequence_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 22, nullptr);
}

// SIGNAL 23
void KdenliveSettings::fade_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 23, nullptr);
}

// SIGNAL 24
void KdenliveSettings::mix_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 24, nullptr);
}

// SIGNAL 25
void KdenliveSettings::subtitle_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 25, nullptr);
}

// SIGNAL 26
void KdenliveSettings::autoimagesequenceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 26, nullptr);
}

// SIGNAL 27
void KdenliveSettings::ignoresubdirstructureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 27, nullptr);
}

// SIGNAL 28
void KdenliveSettings::disableimagescalingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 28, nullptr);
}

// SIGNAL 29
void KdenliveSettings::automultistreamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 29, nullptr);
}

// SIGNAL 30
void KdenliveSettings::use_exiftoolChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 30, nullptr);
}

// SIGNAL 31
void KdenliveSettings::use_magicLanternChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 31, nullptr);
}

// SIGNAL 32
void KdenliveSettings::title_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 32, nullptr);
}

// SIGNAL 33
void KdenliveSettings::transition_durationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 33, nullptr);
}

// SIGNAL 34
void KdenliveSettings::enableAssetsIncludeListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 34, nullptr);
}

// SIGNAL 35
void KdenliveSettings::effectsInfoHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 35, nullptr);
}

// SIGNAL 36
void KdenliveSettings::showEffectsInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 36, nullptr);
}

// SIGNAL 37
void KdenliveSettings::transitionsInfoHeightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 37, nullptr);
}

// SIGNAL 38
void KdenliveSettings::showTransitionsInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 38, nullptr);
}

// SIGNAL 39
void KdenliveSettings::disable_effect_parametersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 39, nullptr);
}

// SIGNAL 40
void KdenliveSettings::profile_fps_filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 40, nullptr);
}

// SIGNAL 41
void KdenliveSettings::profile_scanning_filterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 41, nullptr);
}

// SIGNAL 42
void KdenliveSettings::opengl_backendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 42, nullptr);
}

// SIGNAL 43
void KdenliveSettings::videotracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 43, nullptr);
}

// SIGNAL 44
void KdenliveSettings::audiotracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 44, nullptr);
}

// SIGNAL 45
void KdenliveSettings::audio_channelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 45, nullptr);
}

// SIGNAL 46
void KdenliveSettings::enableproxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 46, nullptr);
}

// SIGNAL 47
void KdenliveSettings::externalproxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 47, nullptr);
}

// SIGNAL 48
void KdenliveSettings::generateproxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 48, nullptr);
}

// SIGNAL 49
void KdenliveSettings::external_proxy_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 49, nullptr);
}

// SIGNAL 50
void KdenliveSettings::externalProxyProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 50, nullptr);
}

// SIGNAL 51
void KdenliveSettings::generateimageproxyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 51, nullptr);
}

// SIGNAL 52
void KdenliveSettings::proxyminsizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 52, nullptr);
}

// SIGNAL 53
void KdenliveSettings::proxyimageminsizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 53, nullptr);
}

// SIGNAL 54
void KdenliveSettings::proxyimagesizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 54, nullptr);
}

// SIGNAL 55
void KdenliveSettings::proxyscaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 55, nullptr);
}

// SIGNAL 56
void KdenliveSettings::enforceLowerTrackCompositingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 56, nullptr);
}

// SIGNAL 57
void KdenliveSettings::proxyextensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 57, nullptr);
}

// SIGNAL 58
void KdenliveSettings::proxyparamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 58, nullptr);
}

// SIGNAL 59
void KdenliveSettings::proxy_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 59, nullptr);
}

// SIGNAL 60
void KdenliveSettings::proxyalphaextensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 60, nullptr);
}

// SIGNAL 61
void KdenliveSettings::proxyalphaparamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 61, nullptr);
}

// SIGNAL 62
void KdenliveSettings::alpha_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 62, nullptr);
}

// SIGNAL 63
void KdenliveSettings::transcodeFriendlyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 63, nullptr);
}

// SIGNAL 64
void KdenliveSettings::transcodingReplaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 64, nullptr);
}

// SIGNAL 65
void KdenliveSettings::previewextensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 65, nullptr);
}

// SIGNAL 66
void KdenliveSettings::preview_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 66, nullptr);
}

// SIGNAL 67
void KdenliveSettings::previewparamsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 67, nullptr);
}

// SIGNAL 68
void KdenliveSettings::parallelrenderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 68, nullptr);
}

// SIGNAL 69
void KdenliveSettings::renderInterpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 69, nullptr);
}

// SIGNAL 70
void KdenliveSettings::renderDeinterlacerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 70, nullptr);
}

// SIGNAL 71
void KdenliveSettings::vaapiEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 71, nullptr);
}

// SIGNAL 72
void KdenliveSettings::amfEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 72, nullptr);
}

// SIGNAL 73
void KdenliveSettings::SupportedHWCodecsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 73, nullptr);
}

// SIGNAL 74
void KdenliveSettings::nvScalingEnabledChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 74, nullptr);
}

// SIGNAL 75
void KdenliveSettings::hwDecodingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 75, nullptr);
}

// SIGNAL 76
void KdenliveSettings::showRenderTextParametersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 76, nullptr);
}

// SIGNAL 77
void KdenliveSettings::headerwidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 77, nullptr);
}

// SIGNAL 78
void KdenliveSettings::defaultkeyframeinterpChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 78, nullptr);
}

// SIGNAL 79
void KdenliveSettings::timelinechunksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 79, nullptr);
}

// SIGNAL 80
void KdenliveSettings::autopreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 80, nullptr);
}

// SIGNAL 81
void KdenliveSettings::draginprogressChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 81, nullptr);
}

// SIGNAL 82
void KdenliveSettings::proxypreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 82, nullptr);
}

// SIGNAL 83
void KdenliveSettings::multistreamChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 83, nullptr);
}

// SIGNAL 84
void KdenliveSettings::multistream_checktrackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 84, nullptr);
}

// SIGNAL 85
void KdenliveSettings::videothumbnailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 85, nullptr);
}

// SIGNAL 86
void KdenliveSettings::audiothumbnailsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 86, nullptr);
}

// SIGNAL 87
void KdenliveSettings::waveformScalerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 87, nullptr);
}

// SIGNAL 88
void KdenliveSettings::showmarkersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 88, nullptr);
}

// SIGNAL 89
void KdenliveSettings::displayallchannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 89, nullptr);
}

// SIGNAL 90
void KdenliveSettings::normalizechannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 90, nullptr);
}

// SIGNAL 91
void KdenliveSettings::autotrackheightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 91, nullptr);
}

// SIGNAL 92
void KdenliveSettings::autoscrollChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 92, nullptr);
}

// SIGNAL 93
void KdenliveSettings::centeredplayheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 93, nullptr);
}

// SIGNAL 94
void KdenliveSettings::jumptostartChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 94, nullptr);
}

// SIGNAL 95
void KdenliveSettings::pauseonseekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 95, nullptr);
}

// SIGNAL 96
void KdenliveSettings::seekonaddeffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 96, nullptr);
}

// SIGNAL 97
void KdenliveSettings::enableBuiltInEffectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 97, nullptr);
}

// SIGNAL 98
void KdenliveSettings::tenbitpipelineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 98, nullptr);
}

// SIGNAL 99
void KdenliveSettings::effectsFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 99, nullptr);
}

// SIGNAL 100
void KdenliveSettings::transitionsFilterChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 100, nullptr);
}

// SIGNAL 101
void KdenliveSettings::scrollverticallyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 101, nullptr);
}

// SIGNAL 102
void KdenliveSettings::trackheightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 102, nullptr);
}

// SIGNAL 103
void KdenliveSettings::audiotracksbelowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 103, nullptr);
}

// SIGNAL 104
void KdenliveSettings::raisepropsclipsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 104, nullptr);
}

// SIGNAL 105
void KdenliveSettings::raisepropscompositionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 105, nullptr);
}

// SIGNAL 106
void KdenliveSettings::raisepropsmixesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 106, nullptr);
}

// SIGNAL 107
void KdenliveSettings::raisepropstracksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 107, nullptr);
}

// SIGNAL 108
void KdenliveSettings::uiDebugModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 108, nullptr);
}

// SIGNAL 109
void KdenliveSettings::gpu_accelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 109, nullptr);
}

// SIGNAL 110
void KdenliveSettings::audio_scrubChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 110, nullptr);
}

// SIGNAL 111
void KdenliveSettings::sdlAudioBackendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 111, nullptr);
}

// SIGNAL 112
void KdenliveSettings::audio_backendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 112, nullptr);
}

// SIGNAL 113
void KdenliveSettings::audiobackendChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 113, nullptr);
}

// SIGNAL 114
void KdenliveSettings::audio_driverChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 114, nullptr);
}

// SIGNAL 115
void KdenliveSettings::audiodevicenameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 115, nullptr);
}

// SIGNAL 116
void KdenliveSettings::audiodrivernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 116, nullptr);
}

// SIGNAL 117
void KdenliveSettings::disablereccountdownChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 117, nullptr);
}

// SIGNAL 118
void KdenliveSettings::videodrivernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 118, nullptr);
}

// SIGNAL 119
void KdenliveSettings::audio_deviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 119, nullptr);
}

// SIGNAL 120
void KdenliveSettings::window_backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 120, nullptr);
}

// SIGNAL 121
void KdenliveSettings::showMonitorGridChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 121, nullptr);
}

// SIGNAL 122
void KdenliveSettings::monitorGridHChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 122, nullptr);
}

// SIGNAL 123
void KdenliveSettings::monitorGridVChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 123, nullptr);
}

// SIGNAL 124
void KdenliveSettings::monitor_backgroundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 124, nullptr);
}

// SIGNAL 125
void KdenliveSettings::monitor_progressiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 125, nullptr);
}

// SIGNAL 126
void KdenliveSettings::volumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 126, nullptr);
}

// SIGNAL 127
void KdenliveSettings::monitor_dropframesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 127, nullptr);
}

// SIGNAL 128
void KdenliveSettings::external_displayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 128, nullptr);
}

// SIGNAL 129
void KdenliveSettings::blackmagic_output_deviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 129, nullptr);
}

// SIGNAL 130
void KdenliveSettings::play_monitor_on_clickChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 130, nullptr);
}

// SIGNAL 131
void KdenliveSettings::mirrorMonitorOnFullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 131, nullptr);
}

// SIGNAL 132
void KdenliveSettings::fullscreen_monitorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 132, nullptr);
}

// SIGNAL 133
void KdenliveSettings::project_monitor_fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 133, nullptr);
}

// SIGNAL 134
void KdenliveSettings::clip_monitor_fullscreenChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 134, nullptr);
}

// SIGNAL 135
void KdenliveSettings::preferredcompositeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 135, nullptr);
}

// SIGNAL 136
void KdenliveSettings::compositingListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 136, nullptr);
}

// SIGNAL 137
void KdenliveSettings::subtitle_razor_modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 137, nullptr);
}

// SIGNAL 138
void KdenliveSettings::mltpathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 138, nullptr);
}

// SIGNAL 139
void KdenliveSettings::kdenliverendererpathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 139, nullptr);
}

// SIGNAL 140
void KdenliveSettings::meltpathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 140, nullptr);
}

// SIGNAL 141
void KdenliveSettings::ffmpegpathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 141, nullptr);
}

// SIGNAL 142
void KdenliveSettings::ffplaypathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 142, nullptr);
}

// SIGNAL 143
void KdenliveSettings::ffprobepathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 143, nullptr);
}

// SIGNAL 144
void KdenliveSettings::processingthreadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 144, nullptr);
}

// SIGNAL 145
void KdenliveSettings::proxythreadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 145, nullptr);
}

// SIGNAL 146
void KdenliveSettings::encodethreadsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 146, nullptr);
}

// SIGNAL 147
void KdenliveSettings::currenttmpfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 147, nullptr);
}

// SIGNAL 148
void KdenliveSettings::maxcachesizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 148, nullptr);
}

// SIGNAL 149
void KdenliveSettings::checkForUpdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 149, nullptr);
}

// SIGNAL 150
void KdenliveSettings::usePowerManagementChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 150, nullptr);
}

// SIGNAL 151
void KdenliveSettings::lastCacheCheckChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 151, nullptr);
}

// SIGNAL 152
void KdenliveSettings::defaultprojectfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 152, nullptr);
}

// SIGNAL 153
void KdenliveSettings::customprojectfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 153, nullptr);
}

// SIGNAL 154
void KdenliveSettings::sameprojectfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 154, nullptr);
}

// SIGNAL 155
void KdenliveSettings::capturetoprojectfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 155, nullptr);
}

// SIGNAL 156
void KdenliveSettings::capturefolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 156, nullptr);
}

// SIGNAL 157
void KdenliveSettings::captureprojectsubfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 157, nullptr);
}

// SIGNAL 158
void KdenliveSettings::librarytodefaultfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 158, nullptr);
}

// SIGNAL 159
void KdenliveSettings::videotodefaultfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 159, nullptr);
}

// SIGNAL 160
void KdenliveSettings::libraryfolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 160, nullptr);
}

// SIGNAL 161
void KdenliveSettings::videofolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 161, nullptr);
}

// SIGNAL 162
void KdenliveSettings::defaultimageappChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 162, nullptr);
}

// SIGNAL 163
void KdenliveSettings::defaultaudioappChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 163, nullptr);
}

// SIGNAL 164
void KdenliveSettings::glaxnimatePathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 164, nullptr);
}

// SIGNAL 165
void KdenliveSettings::defaultvideoappChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 165, nullptr);
}

// SIGNAL 166
void KdenliveSettings::nice_tasksChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 166, nullptr);
}

// SIGNAL 167
void KdenliveSettings::exportGuidesFormatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 167, nullptr);
}

// SIGNAL 168
void KdenliveSettings::multipleguidesintervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 168, nullptr);
}

// SIGNAL 169
void KdenliveSettings::guidesShowThumbsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 169, nullptr);
}

// SIGNAL 170
void KdenliveSettings::guidesSelectZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 170, nullptr);
}

// SIGNAL 171
void KdenliveSettings::defaultaudiocaptureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 171, nullptr);
}

// SIGNAL 172
void KdenliveSettings::audiocapturevolumeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 172, nullptr);
}

// SIGNAL 173
void KdenliveSettings::audiocapturechannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 173, nullptr);
}

// SIGNAL 174
void KdenliveSettings::audiocapturesamplerateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 174, nullptr);
}

// SIGNAL 175
void KdenliveSettings::audiocapturesampleformatChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 175, nullptr);
}

// SIGNAL 176
void KdenliveSettings::defaultcaptureChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 176, nullptr);
}

// SIGNAL 177
void KdenliveSettings::alsachannelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 177, nullptr);
}

// SIGNAL 178
void KdenliveSettings::grab_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 178, nullptr);
}

// SIGNAL 179
void KdenliveSettings::grab_parametersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 179, nullptr);
}

// SIGNAL 180
void KdenliveSettings::grab_extensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 180, nullptr);
}

// SIGNAL 181
void KdenliveSettings::grab_capture_typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 181, nullptr);
}

// SIGNAL 182
void KdenliveSettings::grab_follow_mouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 182, nullptr);
}

// SIGNAL 183
void KdenliveSettings::grab_offsetxChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 183, nullptr);
}

// SIGNAL 184
void KdenliveSettings::grab_offsetyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 184, nullptr);
}

// SIGNAL 185
void KdenliveSettings::grab_widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 185, nullptr);
}

// SIGNAL 186
void KdenliveSettings::grab_heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 186, nullptr);
}

// SIGNAL 187
void KdenliveSettings::grab_fpsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 187, nullptr);
}

// SIGNAL 188
void KdenliveSettings::grab_hide_frameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 188, nullptr);
}

// SIGNAL 189
void KdenliveSettings::grab_hide_mouseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 189, nullptr);
}

// SIGNAL 190
void KdenliveSettings::decklink_device_foundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 190, nullptr);
}

// SIGNAL 191
void KdenliveSettings::decklink_capturedeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 191, nullptr);
}

// SIGNAL 192
void KdenliveSettings::decklink_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 192, nullptr);
}

// SIGNAL 193
void KdenliveSettings::decklink_filenameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 193, nullptr);
}

// SIGNAL 194
void KdenliveSettings::decklink_parametersChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 194, nullptr);
}

// SIGNAL 195
void KdenliveSettings::decklink_extensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 195, nullptr);
}

// SIGNAL 196
void KdenliveSettings::enableshuttleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 196, nullptr);
}

// SIGNAL 197
void KdenliveSettings::shuttledeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 197, nullptr);
}

// SIGNAL 198
void KdenliveSettings::shuttledevicenamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 198, nullptr);
}

// SIGNAL 199
void KdenliveSettings::shuttledevicepathsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 199, nullptr);
}

// SIGNAL 200
void KdenliveSettings::shuttlebuttonsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 200, nullptr);
}

// SIGNAL 201
void KdenliveSettings::bezier_gridlinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 201, nullptr);
}

// SIGNAL 202
void KdenliveSettings::bezier_showpixmapChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 202, nullptr);
}

// SIGNAL 203
void KdenliveSettings::bezier_showallhandlesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 203, nullptr);
}

// SIGNAL 204
void KdenliveSettings::dragvalue_modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 204, nullptr);
}

// SIGNAL 205
void KdenliveSettings::dragvalue_directupdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 205, nullptr);
}

// SIGNAL 206
void KdenliveSettings::recentProfilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 206, nullptr);
}

// SIGNAL 207
void KdenliveSettings::recentProfileNamesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 207, nullptr);
}

// SIGNAL 208
void KdenliveSettings::properties_panel_pageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 208, nullptr);
}

// SIGNAL 209
void KdenliveSettings::project_fpsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 209, nullptr);
}

// SIGNAL 210
void KdenliveSettings::default_profileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 210, nullptr);
}

// SIGNAL 211
void KdenliveSettings::kdockLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 211, nullptr);
}

// SIGNAL 212
void KdenliveSettings::layoutsOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 212, nullptr);
}

// SIGNAL 213
void KdenliveSettings::showdescriptioncolumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 213, nullptr);
}

// SIGNAL 214
void KdenliveSettings::showratingcolumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 214, nullptr);
}

// SIGNAL 215
void KdenliveSettings::showdatecolumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 215, nullptr);
}

// SIGNAL 216
void KdenliveSettings::frametimecodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 216, nullptr);
}

// SIGNAL 217
void KdenliveSettings::rectimecodeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 217, nullptr);
}

// SIGNAL 218
void KdenliveSettings::snaptopointsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 218, nullptr);
}

// SIGNAL 219
void KdenliveSettings::showClipOverlaysChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 219, nullptr);
}

// SIGNAL 220
void KdenliveSettings::rippleResizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 220, nullptr);
}

// SIGNAL 221
void KdenliveSettings::lockedGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 221, nullptr);
}

// SIGNAL 222
void KdenliveSettings::guidesCategoriesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 222, nullptr);
}

// SIGNAL 223
void KdenliveSettings::tagsintimelineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 223, nullptr);
}

// SIGNAL 224
void KdenliveSettings::timelinemousezoomonplayheadChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 224, nullptr);
}

// SIGNAL 225
void KdenliveSettings::transitionfollowcursorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 225, nullptr);
}

// SIGNAL 226
void KdenliveSettings::keyframeseekChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 226, nullptr);
}

// SIGNAL 227
void KdenliveSettings::showeffectinfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 227, nullptr);
}

// SIGNAL 228
void KdenliveSettings::applyEffectParamsToGroupChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 228, nullptr);
}

// SIGNAL 229
void KdenliveSettings::applyEffectParamsToGroupWithSameValueChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 229, nullptr);
}

// SIGNAL 230
void KdenliveSettings::renderProfileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 230, nullptr);
}

// SIGNAL 231
void KdenliveSettings::keepRenderLogFilesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 231, nullptr);
}

// SIGNAL 232
void KdenliveSettings::validated_lutsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 232, nullptr);
}

// SIGNAL 233
void KdenliveSettings::displayClipMonitorInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 233, nullptr);
}

// SIGNAL 234
void KdenliveSettings::showClipMonitorSafeZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 234, nullptr);
}

// SIGNAL 235
void KdenliveSettings::showProjectMonitorSafeZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 235, nullptr);
}

// SIGNAL 236
void KdenliveSettings::displayProjectMonitorInfoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 236, nullptr);
}

// SIGNAL 237
void KdenliveSettings::previewScalingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 237, nullptr);
}

// SIGNAL 238
void KdenliveSettings::autoKeyframeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 238, nullptr);
}

// SIGNAL 239
void KdenliveSettings::limitAutoKeyframesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 239, nullptr);
}

// SIGNAL 240
void KdenliveSettings::limitAutoKeyframesIntervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 240, nullptr);
}

// SIGNAL 241
void KdenliveSettings::maskOpacityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 241, nullptr);
}

// SIGNAL 242
void KdenliveSettings::maskInvertedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 242, nullptr);
}

// SIGNAL 243
void KdenliveSettings::clipMonitorOverlayGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 243, nullptr);
}

// SIGNAL 244
void KdenliveSettings::projectMonitorOverlayGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 244, nullptr);
}

// SIGNAL 245
void KdenliveSettings::alwaysShowMonitorAudioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 245, nullptr);
}

// SIGNAL 246
void KdenliveSettings::displayAudioOverlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 246, nullptr);
}

// SIGNAL 247
void KdenliveSettings::monitoraudioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 247, nullptr);
}

// SIGNAL 248
void KdenliveSettings::showOnMonitorSceneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 248, nullptr);
}

// SIGNAL 249
void KdenliveSettings::autoaudiodrivernameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 249, nullptr);
}

// SIGNAL 250
void KdenliveSettings::mixerCollapseChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 250, nullptr);
}

// SIGNAL 251
void KdenliveSettings::consumerslistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 251, nullptr);
}

// SIGNAL 252
void KdenliveSettings::producerslistChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 252, nullptr);
}

// SIGNAL 253
void KdenliveSettings::widgetstyleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 253, nullptr);
}

// SIGNAL 254
void KdenliveSettings::showslideshowthumbsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 254, nullptr);
}

// SIGNAL 255
void KdenliveSettings::showtitlebarsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 255, nullptr);
}

// SIGNAL 256
void KdenliveSettings::colorclipcolorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 256, nullptr);
}

// SIGNAL 257
void KdenliveSettings::showSubtitlesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 257, nullptr);
}

// SIGNAL 258
void KdenliveSettings::subtitleEditFontSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 258, nullptr);
}

// SIGNAL 259
void KdenliveSettings::thumbColor1Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 259, nullptr);
}

// SIGNAL 260
void KdenliveSettings::thumbColor2Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 260, nullptr);
}

// SIGNAL 261
void KdenliveSettings::overlayColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 261, nullptr);
}

// SIGNAL 262
void KdenliveSettings::safeColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 262, nullptr);
}

// SIGNAL 263
void KdenliveSettings::defaultrescalewidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 263, nullptr);
}

// SIGNAL 264
void KdenliveSettings::defaultrescaleheightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 264, nullptr);
}

// SIGNAL 265
void KdenliveSettings::slideshowbymimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 265, nullptr);
}

// SIGNAL 266
void KdenliveSettings::slideshowmimeextensionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 266, nullptr);
}

// SIGNAL 267
void KdenliveSettings::monitorscene_directupdateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 267, nullptr);
}

// SIGNAL 268
void KdenliveSettings::analyse_stopmotionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 268, nullptr);
}

// SIGNAL 269
void KdenliveSettings::enableaudiospectrumChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 269, nullptr);
}

// SIGNAL 270
void KdenliveSettings::showstopmotionthumbsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 270, nullptr);
}

// SIGNAL 271
void KdenliveSettings::captureintervalChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 271, nullptr);
}

// SIGNAL 272
void KdenliveSettings::sm_notifytimeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 272, nullptr);
}

// SIGNAL 273
void KdenliveSettings::sm_prenotifyChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 273, nullptr);
}

// SIGNAL 274
void KdenliveSettings::sm_loopChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 274, nullptr);
}

// SIGNAL 275
void KdenliveSettings::sm_playsoundChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 275, nullptr);
}

// SIGNAL 276
void KdenliveSettings::sm_framesplaybackChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 276, nullptr);
}

// SIGNAL 277
void KdenliveSettings::stopmotioneffectChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 277, nullptr);
}

// SIGNAL 278
void KdenliveSettings::onmonitoreffects_cornersshowlinesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 278, nullptr);
}

// SIGNAL 279
void KdenliveSettings::onmonitoreffects_geometryshowpreviousChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 279, nullptr);
}

// SIGNAL 280
void KdenliveSettings::onmonitoreffects_geometryshowpathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 280, nullptr);
}

// SIGNAL 281
void KdenliveSettings::onmonitoreffects_cornersshowcontrolsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 281, nullptr);
}

// SIGNAL 282
void KdenliveSettings::projectloading_avformatnovalidateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 282, nullptr);
}

// SIGNAL 283
void KdenliveSettings::monitor_audioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 283, nullptr);
}

// SIGNAL 284
void KdenliveSettings::enable_recording_previewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 284, nullptr);
}

// SIGNAL 285
void KdenliveSettings::add_new_clipChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 285, nullptr);
}

// SIGNAL 286
void KdenliveSettings::add_new_clip_to_folderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 286, nullptr);
}

// SIGNAL 287
void KdenliveSettings::default_marker_typeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 287, nullptr);
}

// SIGNAL 288
void KdenliveSettings::mltdeinterlacerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 288, nullptr);
}

// SIGNAL 289
void KdenliveSettings::mltinterpolationChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 289, nullptr);
}

// SIGNAL 290
void KdenliveSettings::favorite_effectsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 290, nullptr);
}

// SIGNAL 291
void KdenliveSettings::favorite_transitionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 291, nullptr);
}

// SIGNAL 292
void KdenliveSettings::selected_effecttabChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 292, nullptr);
}

// SIGNAL 293
void KdenliveSettings::effectViewAsIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 293, nullptr);
}

// SIGNAL 294
void KdenliveSettings::transitionViewAsIconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 294, nullptr);
}

// SIGNAL 295
void KdenliveSettings::force_breezeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 295, nullptr);
}

// SIGNAL 296
void KdenliveSettings::use_dark_breezeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 296, nullptr);
}

// SIGNAL 297
void KdenliveSettings::showWelcomeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 297, nullptr);
}

// SIGNAL 298
void KdenliveSettings::lastSeenVersionMajorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 298, nullptr);
}

// SIGNAL 299
void KdenliveSettings::lastSeenVersionMinorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 299, nullptr);
}

// SIGNAL 300
void KdenliveSettings::lastSeenVersionMicroChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 300, nullptr);
}

// SIGNAL 301
void KdenliveSettings::lock_ratioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 301, nullptr);
}

// SIGNAL 302
void KdenliveSettings::selected_templateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 302, nullptr);
}

// SIGNAL 303
void KdenliveSettings::titlerShowGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 303, nullptr);
}

// SIGNAL 304
void KdenliveSettings::titlerVersionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 304, nullptr);
}

// SIGNAL 305
void KdenliveSettings::titlerHGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 305, nullptr);
}

// SIGNAL 306
void KdenliveSettings::titlerVGuidesChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 306, nullptr);
}

// SIGNAL 307
void KdenliveSettings::titleGuideColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 307, nullptr);
}

// SIGNAL 308
void KdenliveSettings::titlerbgChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 308, nullptr);
}

// SIGNAL 309
void KdenliveSettings::titlerShowbgChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 309, nullptr);
}

// SIGNAL 310
void KdenliveSettings::titlerAlignChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 310, nullptr);
}

// SIGNAL 311
void KdenliveSettings::samModelFileChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 311, nullptr);
}

// SIGNAL 312
void KdenliveSettings::sam_offload_videoChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 312, nullptr);
}

// SIGNAL 313
void KdenliveSettings::sam_system_pythonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 313, nullptr);
}

// SIGNAL 314
void KdenliveSettings::sam_system_python_pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 314, nullptr);
}

// SIGNAL 315
void KdenliveSettings::maskBorderWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 315, nullptr);
}

// SIGNAL 316
void KdenliveSettings::maskBorderColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 316, nullptr);
}

// SIGNAL 317
void KdenliveSettings::maskColorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 317, nullptr);
}

// SIGNAL 318
void KdenliveSettings::speech_system_pythonChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 318, nullptr);
}

// SIGNAL 319
void KdenliveSettings::speech_system_python_pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 319, nullptr);
}

// SIGNAL 320
void KdenliveSettings::vosk_folder_pathChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 320, nullptr);
}

// SIGNAL 321
void KdenliveSettings::vosk_text_modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 321, nullptr);
}

// SIGNAL 322
void KdenliveSettings::vosk_srt_modelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 322, nullptr);
}

// SIGNAL 323
void KdenliveSettings::speech_zoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 323, nullptr);
}

// SIGNAL 324
void KdenliveSettings::whisperModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 324, nullptr);
}

// SIGNAL 325
void KdenliveSettings::whisperInstalledModelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 325, nullptr);
}

// SIGNAL 326
void KdenliveSettings::whisperAvailableModelsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 326, nullptr);
}

// SIGNAL 327
void KdenliveSettings::whisperAvailableModelsHashChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 327, nullptr);
}

// SIGNAL 328
void KdenliveSettings::whisperModelFolderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 328, nullptr);
}

// SIGNAL 329
void KdenliveSettings::whisperLanguageChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 329, nullptr);
}

// SIGNAL 330
void KdenliveSettings::enableSeamlessChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 330, nullptr);
}

// SIGNAL 331
void KdenliveSettings::srtSeamlessTranslateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 331, nullptr);
}

// SIGNAL 332
void KdenliveSettings::seamless_inputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 332, nullptr);
}

// SIGNAL 333
void KdenliveSettings::seamless_outputChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 333, nullptr);
}

// SIGNAL 334
void KdenliveSettings::whisperMaxCharsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 334, nullptr);
}

// SIGNAL 335
void KdenliveSettings::subtitleModeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 335, nullptr);
}

// SIGNAL 336
void KdenliveSettings::cutWhisperMaxCharsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 336, nullptr);
}

// SIGNAL 337
void KdenliveSettings::whisperDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 337, nullptr);
}

// SIGNAL 338
void KdenliveSettings::samDeviceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 338, nullptr);
}

// SIGNAL 339
void KdenliveSettings::whisperTranslateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 339, nullptr);
}

// SIGNAL 340
void KdenliveSettings::whisperDisableFP16Changed()
{
    QMetaObject::activate(this, &staticMetaObject, 340, nullptr);
}

// SIGNAL 341
void KdenliveSettings::whisperExtraChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 341, nullptr);
}

// SIGNAL 342
void KdenliveSettings::speechEngineChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 342, nullptr);
}

// SIGNAL 343
void KdenliveSettings::mediaIconSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 343, nullptr);
}

// SIGNAL 344
void KdenliveSettings::mediaManagerPanelLayoutChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 344, nullptr);
}

// SIGNAL 345
void KdenliveSettings::mediaManagerPanelWidthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 345, nullptr);
}

// SIGNAL 346
void KdenliveSettings::mediaBrowserAutoPlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 346, nullptr);
}

// SIGNAL 347
void KdenliveSettings::mediaBrowserWithAudioChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 347, nullptr);
}

// SIGNAL 348
void KdenliveSettings::mediaDoubleClickImportChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 348, nullptr);
}

// SIGNAL 349
void KdenliveSettings::mediaBrowserInlinePreviewChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 349, nullptr);
}
QT_WARNING_POP
